#ifdef __cplusplus
extern "C" {
#endif
/*
ANSI C code generated by SmartEiffel The GNU Eiffel Compiler, Eiffel tools and libraries
Release 1.2r7 transitional Release (Sunday April 2nd 2006)
This is an unofficial release. Check http://SmartEiffel.loria.fr for
the official SmartEiffel
Copyright (C), 1994-2003 - INRIA - LORIA - UHP - Nancy 2 - FRANCE
D.COLNET, S.COLLIN, O.ZENDRA, P.RIBET, C.ADRIAN 
Copyright (C) 2005-2006 D.F.MOISSET - smarteiffel@except.com.ar
http://opensvn.csie.org/traccgi/smarteiffel12
C Compiler options used: -pipe -O1 -march=pentium3
*/

/*
-- This file is  free  software, which  comes  along  with  SmartEiffel. This
-- software  is  distributed  in the hope that it will be useful, but WITHOUT
-- ANY  WARRANTY;  without  even  the  implied warranty of MERCHANTABILITY or
-- FITNESS  FOR A PARTICULAR PURPOSE. You can modify it as you want, provided
-- this header is kept unaltered, and a notification of the changes is added.
-- You  are  allowed  to  redistribute  it and sell it, alone or as a part of
-- another product.
--       Copyright (C) 1994-2002 LORIA - INRIA - U.H.P. Nancy 1 - FRANCE
--          Dominique COLNET and Suzanne COLLIN - SmartEiffel@loria.fr
--                       http://SmartEiffel.loria.fr
--
*/
/*
  This file (SmartEiffel/sys/runtime/base.h) contains all basic Eiffel
  type definitions.
  This file is automatically included in the header for all modes of
  compilation: -boost, -no_check, -require_check, -ensure_check, ...
  This file is also included in the header of any cecil file (when the
  -cecil option is used).
  This file is also included in the header file of C++ wrappers (when
  using the external "C++" clause).
*/

#ifndef _BASE_H
#define _BASE_H

#include <stdio.h>
#include <string.h>
#include <math.h>
#include <stdlib.h>
#include <signal.h>
#include <stddef.h>
#include <stdarg.h>
#include <limits.h>
#include <float.h>
#include <setjmp.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#if defined __USE_POSIX || defined __unix__ || defined _POSIX_C_SOURCE
#  include <unistd.h>
#endif
#if !defined(WIN32) && \
       (defined(WINVER) || defined(_WIN32_WINNT) || defined(_WIN32) || \
	defined(__WIN32__) || defined(__TOS_WIN__) || defined(_MSC_VER))
#  define WIN32 1
#endif
#ifdef WIN32
#  include <windows.h>
#else
#  ifndef O_RDONLY
#    include <sys/file.h>
#  endif
#  ifndef O_RDONLY
#    define O_RDONLY 0000
#  endif
#endif

#if defined(_MSC_VER) 
typedef signed char int8_t;
typedef signed short int16_t;
typedef signed int int32_t;
typedef signed __int64 int64_t;
typedef unsigned char uint8_t;
typedef unsigned short uint16_t;
typedef unsigned int uint32_t;
typedef unsigned __int64 uint64_t;
#  define PRId8 "d"
#  define PRId16 "d"
#  define PRId32 "d"
#  define PRId64 "I64d"
#  define INT8_C(c) c
#  define INT16_C(c) c
#  define INT32_C(c) c
#  define INT64_C(c) c ## i64
#elif defined(__WATCOMC__) && (__WATCOMC__ <= 1100) /* WATCOM 11 or lower */
typedef signed char int8_t;
typedef signed short int16_t;
typedef signed long int int32_t;
typedef signed __int64 int64_t;
typedef unsigned char uint8_t;
typedef unsigned short uint16_t;
typedef unsigned long int uint32_t;
typedef unsigned __int64 uint64_t;
#  define PRId8 "d"
#  define PRId16 "d"
#  define PRId32 "d"
#  define PRId64 "Ld"
#  define INT8_C(c) c
#  define INT16_C(c) c
#  define INT32_C(c) c ## L
#  define INT64_C(c) c ## i64
#elif defined(__BORLANDC__) && (__BORLANDC__ < 0x600) /* Borland before 6.0 */
typedef signed char int8_t;
typedef signed short int16_t;
typedef signed long int int32_t;
typedef signed __int64 int64_t;
typedef unsigned char uint8_t;
typedef unsigned short uint16_t;
typedef unsigned long int uint32_t;
typedef unsigned __int64 uint64_t;
#  define PRId8 "d"
#  define PRId16 "d"
#  define PRId32 "ld"
#  define PRId64 "I64Ld"
#  define INT8_C(c) c
#  define INT16_C(c) c
#  define INT32_C(c) c ## L
#  define INT64_C(c) c ## i64
#elif defined(__FreeBSD__) && (__FreeBSD__ < 5) /* FreeBSD before 5.0 */ && !defined (_SYS_INTTYPES_H_)
typedef signed char int8_t;
typedef signed short int16_t;
typedef signed long int int32_t;
typedef signed long long int int64_t;
typedef unsigned char uint8_t;
typedef unsigned short uint16_t;
typedef unsigned long int uint32_t;
typedef unsigned long long int uint64_t;
#elif defined(__CYGWIN__) && defined(__BIT_TYPES_DEFINED__) /* Cygwin defines intxx_t in sys/types.h instead of inttypes.h */
typedef unsigned char uint8_t;
typedef __uint16_t uint16_t;
typedef __uint32_t uint32_t;
typedef __uint64_t uint64_t;
#else
#  include <inttypes.h>
#  if !defined(INT8_MAX) && defined(INT16_MAX)
/* int8_t is not mandatory */
typedef int_least8_t int8_t;
#  endif
#endif

#if !defined(PRId16)
#  define PRId8 "d"
#  define PRId16 "d"
#  define PRId32 "ld"
#  define PRId64 "lld"
#elif !defined(PRId8)
#  define PRId8 "d"
#endif
#if !defined(INT16_C)
#  define INT8_C(c) c
#  define INT16_C(c) c
#  define INT32_C(c) c ## L
#  define INT64_C(c) c ## LL
#elif !defined(INT8_C)
#  define INT8_C(c) c
#endif
#if !defined(INT16_MIN)
#  define INT8_MIN (-INT8_C(127)-1)
#  define INT8_MAX (INT8_C(127))
#  define INT16_MIN (-INT16_C(32767)-1)
#  define INT16_MAX (INT16_C(32767))
#  define INT32_MIN (-INT32_C(2147483647)-1)
#  define INT32_MAX (INT32_C(2147483647))
#  define INT64_MIN (-INT64_C(9223372036854775807)-1)
#  define INT64_MAX (INT64_C(9223372036854775807))
#elif !defined(INT8_MIN)
#  define INT8_MIN (-INT8_C(127)-1)
#endif


/*
  Endian stuff
*/
#if defined(BSD) && (BSD >= 199103)
#  include <machine/endian.h>
#elif defined(__alpha__) || defined(__alpha) || defined(_M_ALPHA)
/* bi-endian processor, current mode should be find in machine/endian.h file */
#  include <machine/endian.h>
#elif defined(linux)
#  include <endian.h>
#endif



#if !defined(BYTE_ORDER) && defined(__BYTE_ORDER)
#  define BYTE_ORDER      __BYTE_ORDER
#endif

#if !defined(LITTLE_ENDIAN) && defined(__LITTLE_ENDIAN)
#  define LITTLE_ENDIAN      __LITTLE_ENDIAN
#endif

#if !defined(BIG_ENDIAN) && defined(__BIG_ENDIAN)
#  define BIG_ENDIAN      __BIG_ENDIAN
#endif

#if !defined(LITTLE_ENDIAN)
#  define LITTLE_ENDIAN   1234    /* LSB first (vax, pc) */
#endif
#if !defined(BIG_ENDIAN)
#  define BIG_ENDIAN      4321    /* MSB first (IBM, net) */
#endif
#if !defined(PDP_ENDIAN)
#  define PDP_ENDIAN      3412    /* LSB first in word, MSW first in long */
#endif

#if !defined(BYTE_ORDER) && defined(BIT_ZERO_ON_RIGHT)
#  define BYTE_ORDER      LITTLE_ENDIAN
#elif !defined(BYTE_ORDER) && defined(BIT_ZERO_ON_LEFT)
#  define BYTE_ORDER      BIG_ENDIAN
#elif !defined(BYTE_ORDER)

/* HP RISC */
#  if defined(__hppa__) || defined(__hppa) || defined(__hp9000) || \
      defined(__hp9000s300) || defined(hp9000s300) || \
      defined(__hp9000s700) || defined(hp9000s700) || \
      defined(__hp9000s800) || defined(hp9000s800) || defined(hp9000s820)
#    define BYTE_ORDER      BIG_ENDIAN
#  endif

/* IBM */
#  if defined(ibm032) || defined(ibm370) || defined(_IBMR2)
#    define BYTE_ORDER      BIG_ENDIAN
#  endif

/* Intel x86 */
#  if defined(i386) || defined(__i386__) || defined(__i386) || \
      defined(_M_IX86) || defined(_X86_) || defined(__THW_INTEL) || \
      defined(sun386)
#    define BYTE_ORDER      LITTLE_ENDIAN
#  endif

/* Intel Itanium */
#  if defined(__ia64__) || defined(_IA64) || defined(__IA64__) || \
      defined(_M_IA64)
#    define BYTE_ORDER      LITTLE_ENDIAN
#  endif

/* Nationnal Semiconductor 32000 serie */
#  if  defined(ns32000)
#    define BYTE_ORDER      LITTLE_ENDIAN
#  endif

/* Motorola 68000 */
#  if defined(mc68000) || defined(is68k) || defined(macII) || defined(m68k)
#    define BYTE_ORDER      BIG_ENDIAN
#  endif

/* MIPS */
#  if defined(MIPSEL) || defined(_MIPSEL)
#    define BYTE_ORDER      LITTLE_ENDIAN
#  elif defined(MIPSEB) || defined(_MIPSEB)
#    define BYTE_ORDER      BIG_ENDIAN
#  elif defined(__mips__) || defined(__mips) || defined(__MIPS__)
#    error "MIPS are bi-endian processors. Endianness is unknown for this system, please drop an e-mail to SmartEiffel@loria.fr"
#  endif

/* Power PC */
/* this processor is bi-endian, how to know if little-endian is set? */
#  if defined(__powerpc) || defined(__powerpc__) || defined(__POWERPC__) || \
      defined(__ppc__) || defined(__ppc) || defined(_M_PPC) || \
      defined(__PPC) || defined(__PPC__)
#    define BYTE_ORDER      BIG_ENDIAN
#  endif

/* Pyramid 9810 */
#  if defined(pyr)
#    define BYTE_ORDER      BIG_ENDIAN
#  endif

/* RS/6000 */
#  if defined(__THW_RS6000) || defined(_IBMR2) || defined(_POWER) || \
      defined(_ARCH_PWR) || defined(_ARCH_PWR2)
#    define BYTE_ORDER      _ENDIAN
#  endif

/* SPARC */
#  if defined(__sparc__) || defined(sparc) || defined(__sparc)
#    define BYTE_ORDER      BIG_ENDIAN
#  endif

/* CCI Tahoe */
#  if defined(tahoe)
#    define BYTE_ORDER      BIG_ENDIAN
#  endif

/* VAX */
#  if defined(vax) || defined(VAX) || defined(__vax__) || defined(_vax_) || \
      defined(__vax) || defined(__VAX)
#    define BYTE_ORDER      LITTLE_ENDIAN
#  endif

/* ELATE is a virtual OS with a little endian Virtual Processor */
#  if defined(__ELATE__)
#    define BYTE_ORDER      LITTLE_ENDIAN
#  endif

/* Miscellaneous little endian */
#  if defined(wrltitan)
#    define BYTE_ORDER      LITTLE_ENDIAN
#  endif

/* Miscellaneous big endian */
#  if defined(apollo) || defined(__convex__) || defined(_CRAY) || defined(sel)
#    define BYTE_ORDER      BIG_ENDIAN
#  endif
#endif


#if !defined(BYTE_ORDER)
#  error "Unknown byte order. Add your system in above macros once you know your system type. Please drop an e-mail to SmartEiffel@loria.fr"
#endif
#if (BYTE_ORDER != BIG_ENDIAN && BYTE_ORDER != LITTLE_ENDIAN)
#  error "Only little-endian and big-endian are valid at this time. Please drop an e-mail to SmartEiffel@loria.fr"
#endif


/*
  Byte swapping stuff
*/
extern void copy_swap_16(const uint16_t *src, uint16_t *dest, int count);


/* Because ANSI C EXIT_* are not always defined: */
#ifndef EXIT_FAILURE
#  define EXIT_FAILURE 1
#endif
#ifndef EXIT_SUCCESS
#  define EXIT_SUCCESS 0
#endif

/*
   On Linux glibc systems, we need to use sig.* versions of jmp_buf,
   setjmp and longjmp to preserve the signal handling context.
   Currently, the way I figured to detect this is if _SIGSET_H_types has
   been defined in /usr/include/setjmp.h.

   NOTE: with gcc, -ansi is used for SmartEiffel generated files EXCEPT in
   -no_split mode. ANSI only recognizes the non-sig versions.
*/
#if (defined(_SIGSET_H_types) && !defined(__STRICT_ANSI__))
#  define JMP_BUF    sigjmp_buf
#  define SETJMP(x)  sigsetjmp( (x), 1)
#  define LONGJMP    siglongjmp
#else
#  define JMP_BUF    jmp_buf
#  define SETJMP(x)  setjmp( (x) )
#  define LONGJMP    longjmp
#endif

/*
   Type to store reference objects Id:
 */
typedef int Tid;
typedef struct S0 T0;
struct S0{Tid id;};

/*
   The default channel used to print runtime error messages:
*/
#define SE_ERR stderr

/*
   Eiffel type INTEGER_8 is #1:
*/
typedef int8_t T1;
#define EIF_INTEGER_8 T1
#define M1 (INT8_C(0))
#define EIF_INTEGER_8_BITS (CHAR_BIT)
#define EIF_MINIMUM_INTEGER_8 (INT8_MIN)
#define EIF_MAXIMUM_INTEGER_8 (INT8_MAX)

/*
  Eiffel type INTEGER_16 is #10:
*/
typedef int16_t T10;
#define EIF_INTEGER_16 T10
#define M10 (INT16_C(0))
#define EIF_INTEGER_16_BITS (CHAR_BIT*sizeof(T10t))
#define EIF_MINIMUM_INTEGER_16 (INT16_MIN) /*-32768*/
#define EIF_MAXIMUM_INTEGER_16 (INT16_MAX) /*+32767*/

/*
  Eiffel type INTEGER or INTEGER_32 is #2:
*/
typedef int32_t T2;
#define EIF_INTEGER T2
#define EIF_INTEGER_32 T2
#define M2 (INT32_C(0))
#define EIF_INTEGER_BITS ((T2)(CHAR_BIT*sizeof(T2)))
#define EIF_INTEGER_32_BITS EIF_INTEGER_BITS
#define EIF_MINIMUM_INTEGER (INT32_MIN)
#define EIF_MAXIMUM_INTEGER (INT32_MAX)

/*
  Eiffel type INTEGER_64 is #11:
*/
typedef int64_t T11;
#define EIF_INTEGER_64 T11
#define M11 (INT64_C(0))
#define EIF_INTEGER_64_BITS (CHAR_BIT*sizeof(T11))
#define EIF_MINIMUM_INTEGER_64 (INT64_MIN)
#define EIF_MAXIMUM_INTEGER_64 (INT64_MAX)

/*
  Eiffel type CHARACTER is #3:
*/
typedef unsigned char T3;
#define EIF_CHARACTER T3
#define M3 (0)
#define EIF_CHARACTER_BITS (CHAR_BIT)
#define EIF_MINIMUM_CHARACTER_CODE (0)
#define EIF_MAXIMUM_CHARACTER_CODE (255)
#define T3code(x) ((T10)(x))
#define T3to_integer(x) ((signed char)(x))
#define T3to_bit(x) (x)

/*
  Eiffel type REAL is #4:
*/
typedef float T4;
#define EIF_REAL T4
#define M4 (0.0)
#define EIF_REAL_BITS (CHAR_BIT*sizeof(float))
#define EIF_MINIMUM_REAL (-(FLT_MAX))
#define EIF_MAXIMUM_REAL (FLT_MAX)

/*
  Eiffel type DOUBLE is #5:
*/
typedef double T5;
#define EIF_DOUBLE T5
#define M5 (0.0)
#define EIF_DOUBLE_BITS (CHAR_BIT*sizeof(double))
#define EIF_MINIMUM_DOUBLE (-(DBL_MAX))
#define EIF_MAXIMUM_DOUBLE (DBL_MAX)

/*
  Eiffel type BOOLEAN is #6:
*/
typedef char T6;
#define EIF_BOOLEAN T6
#define M6 (0)
#define EIF_BOOLEAN_BITS (CHAR_BIT)

/*
   Eiffel type POINTER is #8:
*/
typedef void* T8;
#define EIF_POINTER T8
/* Sometimes, NULL is defined as 0 */
#define M8 ((void*)NULL)
#define EIF_POINTER_BITS (CHAR_BIT*sizeof(void*))

/*
  To use type STRING on the C side:
*/
#define EIF_STRING T7*

/*
  Some Other EIF_* defined in ETL:
*/
#define eif_access(x) ((char*)(x))
#define EIF_REFERENCE T0*
#define EIF_OBJ T0*
#define EIF_OBJECT EIF_OBJ

/*
   Wrappers for `malloc' and `calloc':
*/
void* se_malloc(size_t size);
void* se_calloc(size_t nmemb, size_t size);

/*
   Infinities
*/

#ifdef INFINITY /* ISO C99 constant */
#   define POSITIVE_INFINITY INFINITY
#else /* Fallback for infinity in non-ISO C99 compilers  */
#   define POSITIVE_INFINITY (1.0/0.0)
#endif

#define NEGATIVE_INFINITY (-POSITIVE_INFINITY)

#endif /* #ifndef _BASE_H */
#define SE_BOOST 1
#define SE_EXCEPTIONS 1

/*C Header Pass 1 :*/
typedef struct S237 T237;
typedef struct S116 T116;
typedef struct S803 T803;
typedef struct S128 T128;
typedef struct S359 T359;
typedef struct S812 T812;
typedef struct S622 T622;
typedef struct S813 T813;
typedef struct S814 T814;
typedef struct S816 T816;
typedef struct S148 T148;
typedef struct S548 T548;
typedef struct S104 T104;
typedef struct S576 T576;
typedef struct S799 T799;
typedef void*T715;
typedef struct S173 T173;
typedef struct S202 T202;
typedef struct S639 T639;
typedef struct S350 T350;
typedef struct S472 T472;
typedef struct S445 T445;
typedef void*T356;
typedef struct S743 T743;
typedef struct S510 T510;
typedef struct S702 T702;
typedef struct S554 T554;
typedef struct S334 T334;
typedef struct S92 T92;
typedef struct S322 T322;
typedef struct S863 T863;
typedef struct S714 T714;
typedef struct S27 T27;
typedef struct S184 T184;
typedef struct S612 T612;
typedef struct S646 T646;
typedef struct S69 T69;
typedef struct S477 T477;
typedef struct S340 T340;
typedef struct S611 T611;
typedef struct S586 T586;
typedef struct S154 T154;
typedef struct S794 T794;
typedef struct S278 T278;
typedef struct S818 T818;
typedef struct S680 T680;
typedef struct S122 T122;
typedef struct S724 T724;
typedef struct S777 T777;
typedef void*T634;
typedef struct S610 T610;
typedef struct S263 T263;
typedef struct S209 T209;
typedef void*T642;
typedef struct S110 T110;
typedef void*T360;
typedef struct S585 T585;
typedef struct S722 T722;
typedef struct S609 T609;
typedef struct S810 T810;
typedef struct S625 T625;
typedef void*T618;
typedef struct S764 T764;
typedef struct S439 T439;
typedef struct S501 T501;
typedef struct S834 T834;
typedef void*T827;
typedef struct S637 T637;
typedef struct S86 T86;
typedef struct S725 T725;
typedef struct S297 T297;
typedef struct S425 T425;
typedef struct S179 T179;
typedef struct S500 T500;
typedef struct S255 T255;
typedef struct S645 T645;
typedef struct S630 T630;
typedef struct S802 T802;
typedef struct S178 T178;
typedef struct S851 T851;
typedef void*T608;
typedef struct S768 T768;
typedef struct S503 T503;
typedef void*T606;
typedef struct S537 T537;
typedef void*T676;
typedef struct S732 T732;
typedef struct S99 T99;
typedef struct S570 T570;
typedef void*T507;
typedef struct S335 T335;
typedef struct S693 T693;
typedef struct S66 T66;
typedef void*T844;
typedef struct S203 T203;
typedef struct S591 T591;
typedef struct S723 T723;
typedef void*T770;
typedef struct S617 T617;
typedef struct S831 T831;
typedef struct S329 T329;
typedef void*T607;
typedef struct S858 T858;
typedef struct S505 T505;
typedef void*T696;
typedef struct S852 T852;
typedef struct S459 T459;
typedef void*T580;
typedef struct S773 T773;
typedef struct S687 T687;
typedef struct S317 T317;
typedef void*T392;
typedef struct S571 T571;
typedef void*T829;
typedef struct S603 T603;
typedef struct S805 T805;
typedef struct S315 T315;
typedef struct S726 T726;
typedef struct S249 T249;
typedef void*T720;
typedef struct S745 T745;
typedef struct S303 T303;
typedef struct S136 T136;
typedef void*T707;
typedef struct S347 T347;
typedef struct S137 T137;
typedef struct S620 T620;
typedef struct S838 T838;
typedef struct S256 T256;
typedef struct S806 T806;
typedef struct S621 T621;
typedef void*T539;
typedef struct S660 T660;
typedef struct S497 T497;
typedef struct S635 T635;
typedef struct S599 T599;
typedef struct S862 T862;
typedef struct S631 T631;
typedef struct S728 T728;
typedef struct S841 T841;
typedef struct S105 T105;
typedef struct S771 T771;
typedef struct S161 T161;
typedef struct S504 T504;
typedef struct S593 T593;
typedef struct S509 T509;
typedef struct S644 T644;
typedef struct S746 T746;
typedef void*T760;
typedef struct S602 T602;
typedef void*T565;
typedef struct S522 T522;
typedef struct S159 T159;
typedef struct S123 T123;
typedef void*T633;
typedef struct S578 T578;
typedef struct S98 T98;
typedef struct S709 T709;
typedef struct S218 T218;
typedef struct S730 T730;
typedef struct S225 T225;
typedef void*T711;
typedef void*T697;
typedef struct S516 T516;
typedef void*T727;
typedef struct S196 T196;
typedef struct S596 T596;
typedef struct S567 T567;
typedef struct S80 T80;
typedef struct S142 T142;
typedef void*T695;
typedef struct S7 T7;
typedef struct S498 T498;
typedef struct S800 T800;
typedef void*T767;
typedef struct S243 T243;
typedef void*T573;
typedef struct S167 T167;
typedef struct S117 T117;
typedef struct S643 T643;
typedef void*T550;
typedef struct S298 T298;
typedef struct S285 T285;
typedef struct S238 T238;
typedef struct S825 T825;
typedef struct S93 T93;
typedef struct S292 T292;
typedef struct S191 T191;
typedef struct S833 T833;
typedef struct S111 T111;
typedef void*T717;
typedef struct S166 T166;
typedef struct S197 T197;
typedef struct S186 T186;
typedef struct S584 T584;
typedef void*T758;
typedef void*T605;
typedef struct S131 T131;
typedef void*T716;
typedef void*T588;
typedef struct S615 T615;
typedef void*T759;
typedef struct S628 T628;
typedef void*T574;
typedef struct S783 T783;
typedef struct S688 T688;
typedef struct S708 T708;
typedef struct S524 T524;
typedef struct S476 T476;
typedef struct S81 T81;
typedef struct S87 T87;
typedef struct S601 T601;
typedef struct S614 T614;
typedef struct S761 T761;
typedef struct S308 T308;
typedef struct S436 T436;
typedef struct S244 T244;
typedef void*T719;
typedef struct S616 T616;
typedef struct S819 T819;
typedef struct S821 T821;
typedef struct S552 T552;
typedef void*T721;
typedef struct S741 T741;
typedef struct S669 T669;
typedef void*T547;
typedef struct S817 T817;
typedef struct S592 T592;
typedef struct S231 T231;
typedef struct S310 T310;
typedef struct S480 T480;
typedef struct S569 T569;
typedef struct S77 T77;
typedef struct S811 T811;
typedef struct S636 T636;
typedef void*T589;
typedef struct S658 T658;
typedef struct S53 T53;
typedef struct S250 T250;
typedef void*T623;
typedef void*T641;
typedef void*T718;
typedef struct S563 T563;
typedef void*T380;
typedef struct S791 T791;
typedef struct S220 T220;
typedef struct S540 T540;
typedef struct S470 T470;
typedef struct S345 T345;
typedef struct S613 T613;
typedef struct S756 T756;
typedef struct S284 T284;
typedef struct S483 T483;
typedef struct S499 T499;
typedef struct S598 T598;
typedef struct S467 T467;
typedef struct S385 T385;
typedef struct S549 T549;
typedef struct S143 T143;
typedef struct S587 T587;
typedef void*T712;
typedef struct S561 T561;
typedef struct S434 T434;
typedef struct S502 T502;
typedef struct S419 T419;
typedef struct S431 T431;
typedef void*T629;
typedef struct S226 T226;
typedef struct S632 T632;
typedef struct S361 T361;
typedef void*T710;
typedef struct S595 T595;
typedef struct S268 T268;
typedef struct S466 T466;
typedef struct S604 T604;
typedef struct S600 T600;
typedef struct S273 T273;
typedef struct S213 T213;
typedef void*T566;
typedef struct S232 T232;
typedef struct S772 T772;
typedef struct S795 T795;
typedef struct S782 T782;
typedef struct S12 T12;
typedef struct S532 T532;
typedef void*T624;
typedef struct S414 T414;
typedef struct S478 T478;
typedef struct S208 T208;
typedef struct S279 T279;
typedef struct S582 T582;
typedef void*T830;
typedef void*T640;
typedef struct S479 T479;
typedef struct S581 T581;
typedef struct S619 T619;
typedef struct S671 T671;
typedef void*T358;
typedef struct S379 T379;
typedef struct S656 T656;
typedef void*T508;
typedef struct S597 T597;
typedef struct S323 T323;
typedef struct S395 T395;
typedef struct S626 T626;
typedef struct S590 T590;
typedef struct S577 T577;
typedef struct S808 T808;
typedef struct S807 T807;
typedef void*T357;
typedef struct S473 T473;
typedef struct S698 T698;
typedef struct S673 T673;
typedef void*T558;
typedef struct S627 T627;
typedef struct S420 T420;
typedef struct S559 T559;
typedef struct S149 T149;
typedef struct S647 T647;
typedef void*T555;
typedef struct S792 T792;
typedef struct S485 T485;
typedef struct S575 T575;
typedef void*T713;
typedef struct S494 T494;

/*C Header Pass 2 :*/
typedef T0**T121;
#define M121 NULL
typedef T0**T153;
#define M153 NULL
typedef T0**T109;
#define M109 NULL
typedef T0**T177;
#define M177 NULL
typedef T0**T272;
#define M272 NULL
typedef T0**T267;
#define M267 NULL
typedef T0**T127;
#define M127 NULL
typedef T0**T158;
#define M158 NULL
typedef T0**T115;
#define M115 NULL
typedef T0**T79;
#define M79 NULL
typedef T0**T277;
#define M277 NULL
typedef T0**T840;
#define M840 NULL
typedef T0**T302;
#define M302 NULL
typedef T0**T183;
#define M183 NULL
typedef T0**T307;
#define M307 NULL
typedef T0**T333;
#define M333 NULL
typedef T0**T321;
#define M321 NULL
typedef T0**T141;
#define M141 NULL
typedef T0**T283;
#define M283 NULL
typedef T0**T165;
#define M165 NULL
typedef T0**T103;
#define M103 NULL
typedef T0**T201;
#define M201 NULL
typedef T0**T224;
#define M224 NULL
typedef T0**T544;
#define M544 NULL
typedef T0**T190;
#define M190 NULL
typedef T0**T349;
#define M349 NULL
typedef T0**T339;
#define M339 NULL
typedef T0**T296;
#define M296 NULL
typedef T0**T195;
#define M195 NULL
typedef T0**T207;
#define M207 NULL
typedef T0**T314;
#define M314 NULL
typedef T0**T248;
#define M248 NULL
typedef T0**T97;
#define M97 NULL
typedef T3*T9;
#define M9 NULL
typedef T0**T236;
#define M236 NULL
typedef T0**T254;
#define M254 NULL
typedef T0**T327;
#define M327 NULL
typedef T0**T135;
#define M135 NULL
typedef T0**T171;
#define M171 NULL
typedef T0**T230;
#define M230 NULL
typedef T0**T85;
#define M85 NULL
typedef T0**T242;
#define M242 NULL
typedef T0**T843;
#define M843 NULL
typedef T0**T260;
#define M260 NULL
typedef T0**T217;
#define M217 NULL
typedef T2*T344;
#define M344 NULL
typedef T0**T91;
#define M91 NULL
typedef T0**T706;
#define M706 NULL
typedef T0**T147;
#define M147 NULL
typedef T0**T354;
#define M354 NULL
typedef T0**T289;
#define M289 NULL

/*C Header Pass 3 :*/

/*C Header Pass 4 :*/
struct S237{T0* _item;T0* _next;};
extern T237 M237;
struct S803{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;};
extern T803 M803;
struct S128{T0* _grouping_attributes;T0* _selection;};
extern T128 M128;
struct S359{T0* _directory;T0* _filename;T0* _input_buffer;T6 _use_mode;};
extern T359 M359;
struct S812{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;T6 _is_stored_procedure;T6 _in_user_declaration;};
extern T812 M812;
struct S622{Tid id;T0* _domain_restriction;T2 _length;};
extern T622 M622;
struct S813{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;T6 _is_stored_procedure;T6 _in_user_declaration;};
extern T813 M813;
struct S814{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;T6 _is_stored_procedure;T6 _in_user_declaration;};
extern T814 M814;
struct S816{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;T6 _is_stored_procedure;T6 _in_user_declaration;};
extern T816 M816;
struct S548{Tid id;T6 _required;};
extern T548 M548;
struct S576{Tid id;T0* _name;T0* _representation;T0* _expression;};
extern T576 M576;
struct S799{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;};
extern T799 M799;
struct S173{T177 _storage;T2 _capacity;T2 _upper;};
extern T173 M173;
struct S202{T0* _name;T0* _domain;};
extern T202 M202;
struct S639{Tid id;};
extern T639 M639;
struct S350{T354 _storage;T2 _capacity;T2 _upper;};
extern T350 M350;
struct S472{Tid id;T2 _precision;T2 _width;T3 _padding_character;T6 _plus_sign_enabled;T6 _is_lowercase;T2 _alignment;};
extern T472 M472;
struct S445{Tid id;T0* _equality_tester;T2 _count;T2 _capacity;T2 _last_position;T2 _modulus;T2 _free_slot;T2 _position;T2 _slots_position;T2 _clashes_previous_position;T2 _found_position;T0* _internal_cursor;T0* _item_storage;T0* _clashes;T0* _slots;T0* _special_item_routines;T0* _hash_function;};
extern T445 M445;
struct S743{Tid id;T6 _after;T6 _before;T0* _container;T0* _current_cell;T0* _next_cursor;};
extern T743 M743;
struct S510{T0* _objects;};
extern T510 M510;
struct S702{T706 _storage;T2 _capacity;T2 _upper;};
extern T702 M702;
struct S554{Tid id;T0* _container;T6 _after;T6 _before;T0* _current_cell;T0* _next_cursor;};
extern T554 M554;
struct S334{Tid id;T0* _name;T0* _representation;};
extern T334 M334;
struct S92{Tid id;T0* _type;};
extern T92 M92;
struct S322{Tid id;T0* _item;T0* _next;};
extern T322 M322;
struct S863{T0* _item;T0* _right;};
extern T863 M863;
struct S714{Tid id;T6 _is_required;T6 _is_specialization;T6 _is_unique;T6 _is_init_default;T0* _abstracttype;T0* _init;T0* _role;T6 _overrule_required;};
extern T714 M714;
struct S27{Tid id;T0* _name;T0* _string_name;T3 _last_character;T6 _end_of_file;T0* _character_buffer;T0* _path;T3 _old_last_character;T6 _old_end_of_file;T6 _push_back_flag;T8 _input_stream;T9 _buffer;T6 _end_reached;T2 _buffer_position;T2 _buffer_size;T2 _capacity;};
extern T27 M27;
struct S184{Tid id;T0* _predicate;T0* _subject;T0* _expression_list;T0* _identification_text;T0* _sort_order;};
extern T184 M184;
struct S612{Tid id;T0* _domain_restriction;};
extern T612 M612;
struct S646{T0* _found_immediate_child;T6 _is_forced_left_outer_join;T6 _is_upward_join;T0* _item;T0* _other_items;T0* _next;};
extern T646 M646;
struct S69{Tid id;T0* _value;};
extern T69 M69;
struct S477{Tid id;T2 _precision;T2 _width;T3 _padding_character;T6 _plus_sign_enabled;T6 _is_lowercase;T2 _alignment;T0* _integer_buffer;};
extern T477 M477;
struct S340{T344 _storage;T2 _capacity;T2 _upper;};
extern T340 M340;
struct S611{Tid id;T0* _domain_restriction;T2 _length;};
extern T611 M611;
struct S586{Tid id;T0* _right;T0* _left;T0* _operator;};
extern T586 M586;
struct S154{T158 _storage;T2 _capacity;T2 _upper;};
extern T154 M154;
struct S794{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;};
extern T794 M794;
struct S278{T0* _role;T0* _name;T0* _attribute;T0* _object;};
extern T278 M278;
struct S818{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;T6 _is_stored_procedure;};
extern T818 M818;
struct S680{T0* _equality_tester;T0* _internal_cursor;T0* _table;};
extern T680 M680;
struct S724{Tid id;};
extern T724 M724;
struct S777{Tid id;T0* _equality_tester;T0* _internal_cursor;T0* _table;};
extern T777 M777;
struct S610{Tid id;T0* _domain_restriction;};
extern T610 M610;
struct S263{T267 _storage;T2 _capacity;T2 _upper;};
extern T263 M263;
struct S209{Tid id;T0* _name;T0* _abstract_representation;T0* _representation;T0* _attributes;T2 _constraint_number;};
extern T209 M209;
extern T360 M360;
struct S585{Tid id;T0* _right;T0* _left;T0* _operator;};
extern T585 M585;
struct S722{Tid id;};
extern T722 M722;
struct S609{Tid id;T0* _domain_restriction;T2 _length;};
extern T609 M609;
struct S810{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;};
extern T810 M810;
struct S625{Tid id;T0* _value;};
extern T625 M625;
struct S764{T344 _storage;T2 _capacity;T2 _upper;T2 _lower;};
extern T764 M764;
struct S439{Tid id;};
extern T439 M439;
struct S834{Tid id;T0* _domain_restriction;};
extern T834 M834;
extern T827 M827;
struct S637{Tid id;};
extern T637 M637;
struct S86{Tid id;T0* _subject;T0* _assignment_list;T0* _predicate;};
extern T86 M86;
struct S725{Tid id;};
extern T725 M725;
struct S425{Tid id;T0* _container;T6 _after;T6 _before;T0* _current_cell;T0* _next_cursor;T6 _is_first;};
extern T425 M425;
struct S179{T183 _storage;T2 _capacity;T2 _upper;};
extern T179 M179;
struct S500{Tid id;T354 _storage;T2 _capacity;T2 _upper;T2 _lower;};
extern T500 M500;
struct S255{T0* _item;T0* _next;};
extern T255 M255;
struct S645{T0* _actual_attribute;T0* _attribute;T0* _attribute_alias_name;T0* _aggregate;T0* _aggregate_alias_name;T0* _aggregate_fk;T6 _is_forced_left_outer_join;T6 _is_upward_join;};
extern T645 M645;
struct S630{T0* _type;T0* _name;T6 _is_unique;T6 _is_clustered;T0* _first_attribute;};
extern T630 M630;
struct S802{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;T6 _is_stored_procedure;T0* _init_error;};
extern T802 M802;
struct S851{Tid id;T0* _assertion;T0* _anode;};
extern T851 M851;
struct S768{Tid id;T6 _push_back_flag;T3 _old_last_character;T6 _old_end_of_file;T9 _buffer;T6 _end_reached;T2 _buffer_position;T2 _buffer_size;T2 _capacity;T0* _name;T3 _last_character;T6 _end_of_file;T0* _character_buffer;};
extern T768 M768;
struct S503{T2 _count;T9 _area;T0* _area_string;};
extern T503 M503;
struct S537{Tid id;T2 _position;T0* _container;T0* _next_cursor;};
extern T537 M537;
struct S732{Tid id;T0* _item;T0* _right;T0* _left;};
extern T732 M732;
struct S99{T103 _storage;T2 _capacity;T2 _upper;};
extern T99 M99;
struct S570{Tid id;T0* _right;T0* _left;T0* _operator;};
extern T570 M570;
struct S335{T339 _storage;T2 _capacity;T2 _upper;};
extern T335 M335;
struct S693{Tid id;T2 _position;T0* _container;T0* _next_cursor;};
extern T693 M693;
struct S66{T0* _statements;};
extern T66 M66;
extern T844 M844;
struct S203{T207 _storage;T2 _capacity;T2 _upper;};
extern T203 M203;
struct S591{Tid id;};
extern T591 M591;
struct S723{Tid id;};
extern T723 M723;
struct S617{Tid id;T0* _domain_restriction;};
extern T617 M617;
struct S831{T5 _item;};
extern T831 M831;
struct S329{T333 _storage;T2 _capacity;T2 _upper;};
extern T329 M329;
struct S858{T0* _tags;T0* _attributes;T0* _values;T2 _current_attribute;T2 _attribute_count;T0* _my_xml;T6 _header_written;T6 _may_close_tag;T6 _tag_closed;T6 _tag_written;};
extern T858 M858;
struct S505{Tid id;T0* _item;T0* _right;};
extern T505 M505;
struct S852{T0* _name;T0* _string_name;T0* _path;T9 _buffer;T2 _buffer_position;T2 _capacity;T8 _output_stream;};
extern T852 M852;
struct S116{Tid id;T0* _extension;};
extern T116 M116;
struct S459{Tid id;T2 _position;T0* _container;T0* _next_cursor;};
extern T459 M459;
extern T580 M580;
struct S773{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;};
extern T773 M773;
struct S687{T0* _container;T0* _table_cursor;};
extern T687 M687;
struct S317{T321 _storage;T2 _capacity;T2 _upper;};
extern T317 M317;
extern T392 M392;
struct S571{Tid id;T0* _right;T0* _left;T0* _operator;};
extern T571 M571;
extern T829 M829;
struct S603{Tid id;T0* _parameters;T0* _name;};
extern T603 M603;
struct S805{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;};
extern T805 M805;
struct S726{Tid id;};
extern T726 M726;
struct S249{Tid id;T6 _is_required;T6 _is_specialization;T6 _is_unique;T6 _is_init_default;T0* _abstracttype;T0* _init;T0* _role;T6 _overrule_required;};
extern T249 M249;
struct S745{T2 _count;T0* _first_cell;T0* _last_cell;T0* _internal_cursor;};
extern T745 M745;
struct S303{T307 _storage;T2 _capacity;T2 _upper;};
extern T303 M303;
struct S347{T349 _storage;T2 _capacity;T2 _upper;};
extern T347 M347;
struct S137{T141 _storage;T2 _capacity;T2 _upper;};
extern T137 M137;
struct S620{Tid id;T0* _domain_restriction;T2 _length;};
extern T620 M620;
struct S148{Tid id;T0* _constant;};
extern T148 M148;
struct S838{Tid id;T840 _storage;T2 _capacity;T2 _upper;T2 _lower;};
extern T838 M838;
struct S256{T260 _storage;T2 _capacity;T2 _upper;};
extern T256 M256;
struct S806{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;};
extern T806 M806;
struct S621{Tid id;T6 _required;T0* _owner;};
extern T621 M621;
struct S660{T2 _count;T0* _first_cell;T0* _last_cell;T0* _internal_cursor;};
extern T660 M660;
struct S497{Tid id;T0* _string;};
extern T497 M497;
struct S635{Tid id;T0* _extension;T0* _anode;T0* _expression;};
extern T635 M635;
struct S599{Tid id;T0* _type;};
extern T599 M599;
struct S862{T2 _count;T0* _first_cell;};
extern T862 M862;
struct S631{Tid id;T0* _type;T0* _id;T0* _assignment_list;};
extern T631 M631;
struct S728{Tid id;T0* _name;T0* _representation;T0* _parameters;T6 _is_postgresql_trigger;T6 _recompile;T0* _statements;};
extern T728 M728;
struct S841{Tid id;T843 _storage;T2 _capacity;T2 _upper;T2 _lower;};
extern T841 M841;
struct S297{Tid id;T6 _value;};
extern T297 M297;
struct S105{T109 _storage;T2 _capacity;T2 _upper;};
extern T105 M105;
struct S771{Tid id;T0* _name;};
extern T771 M771;
struct S161{T165 _storage;T2 _capacity;T2 _upper;};
extern T161 M161;
struct S504{Tid id;T2 _count;T0* _first_cell;T0* _last_cell;T0* _internal_cursor;};
extern T504 M504;
struct S593{Tid id;T0* _operands;};
extern T593 M593;
struct S509{Tid id;T0* _name;T0* _representation;T0* _value;};
extern T509 M509;
struct S644{T0* _item;T0* _next;};
extern T644 M644;
struct S746{T0* _item;T0* _right;};
extern T746 M746;
struct S602{Tid id;T0* _name;};
extern T602 M602;
struct S522{Tid id;T0* _equality_tester;T0* _internal_cursor;T0* _table;};
extern T522 M522;
struct S123{T127 _storage;T2 _capacity;T2 _upper;};
extern T123 M123;
struct S578{Tid id;T0* _operand;T0* _operator;};
extern T578 M578;
struct S709{Tid id;T0* _type;};
extern T709 M709;
struct S218{Tid id;T0* _predicate;T0* _subject;T0* _property;T0* _function;};
extern T218 M218;
struct S730{Tid id;T2 _count;T0* _last_cell;T0* _internal_cursor;T0* _first_cell;};
extern T730 M730;
struct S225{T0* _identification;T0* _type;};
extern T225 M225;
struct S516{T0* _equality_tester;T2 _count;T2 _capacity;T2 _last_position;T2 _modulus;T2 _free_slot;T2 _position;T2 _slots_position;T2 _clashes_previous_position;T2 _found_position;T0* _internal_cursor;T0* _key_equality_tester;T0* _internal_keys;T0* _item_storage;T0* _key_storage;T0* _clashes;T0* _slots;T0* _special_item_routines;T0* _special_key_routines;T0* _hash_function;};
extern T516 M516;
struct S596{Tid id;T0* _operand;};
extern T596 M596;
struct S567{T2 _item;};
extern T567 M567;
struct S80{Tid id;T0* _value;};
extern T80 M80;
struct S142{Tid id;T0* _constant;T0* _expression;};
extern T142 M142;
struct S498{Tid id;T2 _precision;T2 _width;T3 _padding_character;T6 _plus_sign_enabled;T6 _is_lowercase;T2 _alignment;};
extern T498 M498;
struct S800{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;T6 _is_stored_procedure;T0* _init_error;};
extern T800 M800;
struct S243{Tid id;T0* _name;T0* _abstract_representation;T0* _attributes;T0* _expression;T0* _representation;T0* _type;T2 _constraint_number;T0* _range;};
extern T243 M243;
struct S167{T171 _storage;T2 _capacity;T2 _upper;};
extern T167 M167;
struct S117{T121 _storage;T2 _capacity;T2 _upper;};
extern T117 M117;
struct S643{T0* _base_aggregate;T6 _is_finalized;T0* _root;T0* _my_first;T6 _force_left_outer_join;T6 _is_upward_join;};
extern T643 M643;
struct S104{Tid id;T0* _procedure;};
extern T104 M104;
struct S298{T302 _storage;T2 _capacity;T2 _upper;};
extern T298 M298;
struct S285{T289 _storage;T2 _capacity;T2 _upper;};
extern T285 M285;
struct S238{T242 _storage;T2 _capacity;T2 _upper;};
extern T238 M238;
struct S825{Tid id;T5 _item;};
extern T825 M825;
struct S93{T97 _storage;T2 _capacity;T2 _upper;};
extern T93 M93;
struct S292{T296 _storage;T2 _capacity;T2 _upper;};
extern T292 M292;
struct S191{T195 _storage;T2 _capacity;T2 _upper;};
extern T191 M191;
struct S159{T0* _item;T0* _next;};
extern T159 M159;
struct S833{Tid id;T0* _container;T6 _after;T6 _before;T0* _current_cell;T0* _next_cursor;T6 _is_first;};
extern T833 M833;
struct S111{T115 _storage;T2 _capacity;T2 _upper;};
extern T111 M111;
struct S166{T0* _item;T0* _next;T0* _new_name;};
extern T166 M166;
struct S197{T201 _storage;T2 _capacity;T2 _upper;};
extern T197 M197;
struct S186{T190 _storage;T2 _capacity;T2 _upper;};
extern T186 M186;
struct S584{Tid id;T0* _expression;};
extern T584 M584;
struct S131{T135 _storage;T2 _capacity;T2 _upper;};
extern T131 M131;
struct S615{Tid id;T0* _domain_restriction;};
extern T615 M615;
struct S628{Tid id;T6 _is_required;T6 _is_specialization;T6 _is_unique;T6 _is_init_default;T0* _abstracttype;T0* _init;T0* _role;T6 _overrule_required;};
extern T628 M628;
struct S783{Tid id;T2 _position;T0* _container;};
extern T783 M783;
struct S688{Tid id;T2 _position;T0* _container;};
extern T688 M688;
struct S708{Tid id;T0* _select_value;};
extern T708 M708;
struct S7{Tid id;T9 _storage;T2 _count;T2 _capacity;};
extern T7 M7;
struct S524{Tid id;T0* _container;T0* _table_cursor;};
extern T524 M524;
struct S501{Tid id;T2 _item;};
extern T501 M501;
struct S476{Tid id;T2 _precision;T2 _width;T3 _padding_character;T6 _plus_sign_enabled;T6 _is_lowercase;T2 _alignment;T0* _integer_buffer;};
extern T476 M476;
struct S81{T85 _storage;T2 _capacity;T2 _upper;};
extern T81 M81;
struct S87{T91 _storage;T2 _capacity;T2 _upper;};
extern T87 M87;
struct S601{Tid id;T0* _value;};
extern T601 M601;
struct S614{Tid id;T0* _domain_restriction;};
extern T614 M614;
struct S761{Tid id;T0* _sqlgenerator;T0* _xml;};
extern T761 M761;
struct S436{Tid id;};
extern T436 M436;
struct S196{Tid id;T0* _extension;T0* _anode;};
extern T196 M196;
struct S244{T248 _storage;T2 _capacity;T2 _upper;};
extern T244 M244;
struct S616{Tid id;T0* _domain_restriction;T2 _before;T2 _after;};
extern T616 M616;
struct S819{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;T6 _is_stored_procedure;};
extern T819 M819;
struct S821{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;T6 _is_stored_procedure;};
extern T821 M821;
struct S552{T0* _item;T0* _right;};
extern T552 M552;
struct S741{Tid id;T0* _container;T6 _after;T6 _before;T0* _current_cell;T0* _next_cursor;};
extern T741 M741;
struct S669{T0* _container;T6 _after;T6 _before;T0* _current_cell;T0* _next_cursor;};
extern T669 M669;
struct S817{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;};
extern T817 M817;
struct S592{Tid id;T0* _condition;T0* _then_specification;T0* _else_specification;};
extern T592 M592;
struct S231{T0* _attribute_name;T0* _expression;};
extern T231 M231;
struct S310{T314 _storage;T2 _capacity;T2 _upper;};
extern T310 M310;
struct S480{Tid id;T2 _precision;T2 _width;T3 _padding_character;T6 _plus_sign_enabled;T6 _is_lowercase;T2 _alignment;T2 _fsign;T2 _integer_part;T0* _fractional_part;T0* _fractional_list;T0* _double_buffer;T0* _string_output_stream;T0* _unsigned_decimal_formatter;T0* _decimal_formatter;};
extern T480 M480;
struct S569{Tid id;T6 _required;T0* _min;T0* _max;};
extern T569 M569;
struct S77{T79 _storage;T2 _capacity;T2 _upper;};
extern T77 M77;
struct S110{Tid id;T0* _selection;};
extern T110 M110;
struct S811{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;T6 _is_stored_procedure;};
extern T811 M811;
struct S636{Tid id;T0* _first;};
extern T636 M636;
struct S658{T0* _item;T0* _right;};
extern T658 M658;
struct S53{T2 _error_count;T0* _yydefgoto;T0* _yycheck;T2 _yy_suspended_yystacksize;T2 _yy_suspended_yystate;T2 _yy_suspended_yy_goto;T2 _yyerrstatus;T2 _yy_parsing_status;T3 _last_character;T2 _line;T2 _column;T0* _yy_content;T2 _yy_start;T2 _yy_position;T0* _yy_ec;T0* _yy_accept;T0* _yy_state_stack;T2 _yy_state_count;T2 _yy_lp;T6 _expect_domain;T0* _yypgoto;T2 _yy_suspended_yychar1;T2 _yy_suspended_yyss_top;T2 _yyssp;T2 _position;T0* _yy_content_area;T2 _yy_end;T0* _yy_chk;T0* _yy_def;T0* _pending_init;T0* _yyr1;T0* _yyss;T2 _last_token;T2 _yy_column;T2 _yy_last_accepting_state;T2 _yy_last_accepting_cpos;T0* _yy_base;T6 _yy_rejected;T2 _yy_full_match;T2 _last_integer_value;T0* _yy_meta;T0* _yy_acclist;T0* _my_sql;T0* _yydefact;T0* _yypact;T0* _yytable;T0* _yytypes1;T0* _yytypes2;T2 _yy_suspended_index;T6 _yy_lookahead_needed;T0* _input_buffer;T2 _yy_start_state;T2 _yy_line;T6 _yy_more_flag;T2 _yy_more_len;T2 _yy_looking_for_trail_begin;T2 _yy_full_lp;T0* _last_string_value;T0* _sqlgenerator;T0* _saved_state;T6 _procedure_mode;T0* _yytranslate;T2 _yy_suspended_yyn;T2 _yy_full_state;T0* _last_any_value;T0* _yy_nxt;T0* _yyvs1;T2 _yyvsc1;T2 _yyvsp1;T0* _yyspecial_routines1;T0* _yyvs2;T2 _yyvsc2;T2 _yyvsp2;T0* _yyspecial_routines2;T0* _yyvs3;T2 _yyvsc3;T2 _yyvsp3;T0* _yyspecial_routines3;T0* _yyvs4;T2 _yyvsc4;T2 _yyvsp4;T0* _yyspecial_routines4;T0* _yyvs5;T2 _yyvsc5;T2 _yyvsp5;T0* _yyspecial_routines5;T0* _yyvs6;T2 _yyvsc6;T2 _yyvsp6;T0* _yyspecial_routines6;T0* _yyvs7;T2 _yyvsc7;T2 _yyvsp7;T0* _yyspecial_routines7;T0* _yyvs8;T2 _yyvsc8;T2 _yyvsp8;T0* _yyspecial_routines8;T0* _yyvs9;T2 _yyvsc9;T2 _yyvsp9;T0* _yyspecial_routines9;T0* _yyvs10;T2 _yyvsc10;T2 _yyvsp10;T0* _yyspecial_routines10;T0* _yyvs11;T2 _yyvsc11;T2 _yyvsp11;T0* _yyspecial_routines11;T0* _yyvs12;T2 _yyvsc12;T2 _yyvsp12;T0* _yyspecial_routines12;T0* _yyvs13;T2 _yyvsc13;T2 _yyvsp13;T0* _yyspecial_routines13;T0* _yyvs14;T2 _yyvsc14;T2 _yyvsp14;T0* _yyspecial_routines14;T0* _yyvs15;T2 _yyvsc15;T2 _yyvsp15;T0* _yyspecial_routines15;T0* _yyvs16;T2 _yyvsc16;T2 _yyvsp16;T0* _yyspecial_routines16;T0* _yyvs17;T2 _yyvsc17;T2 _yyvsp17;T0* _yyspecial_routines17;T0* _yyvs18;T2 _yyvsc18;T2 _yyvsp18;T0* _yyspecial_routines18;T0* _yyvs19;T2 _yyvsc19;T2 _yyvsp19;T0* _yyspecial_routines19;T0* _yyvs20;T2 _yyvsc20;T2 _yyvsp20;T0* _yyspecial_routines20;T0* _yyvs21;T2 _yyvsc21;T2 _yyvsp21;T0* _yyspecial_routines21;T0* _yyvs22;T2 _yyvsc22;T2 _yyvsp22;T0* _yyspecial_routines22;T0* _yyvs23;T2 _yyvsc23;T2 _yyvsp23;T0* _yyspecial_routines23;T0* _yyvs24;T2 _yyvsc24;T2 _yyvsp24;T0* _yyspecial_routines24;T0* _yyvs25;T2 _yyvsc25;T2 _yyvsp25;T0* _yyspecial_routines25;T0* _yyvs26;T2 _yyvsc26;T2 _yyvsp26;T0* _yyspecial_routines26;T0* _yyvs27;T2 _yyvsc27;T2 _yyvsp27;T0* _yyspecial_routines27;T0* _yyvs28;T2 _yyvsc28;T2 _yyvsp28;T0* _yyspecial_routines28;T0* _yyvs29;T2 _yyvsc29;T2 _yyvsp29;T0* _yyspecial_routines29;T0* _yyvs30;T2 _yyvsc30;T2 _yyvsp30;T0* _yyspecial_routines30;T0* _yyvs31;T2 _yyvsc31;T2 _yyvsp31;T0* _yyspecial_routines31;T0* _yyvs32;T2 _yyvsc32;T2 _yyvsp32;T0* _yyspecial_routines32;T0* _yyvs33;T2 _yyvsc33;T2 _yyvsp33;T0* _yyspecial_routines33;T0* _yyvs34;T2 _yyvsc34;T2 _yyvsp34;T0* _yyspecial_routines34;T0* _yyvs35;T2 _yyvsc35;T2 _yyvsp35;T0* _yyspecial_routines35;T0* _yyvs36;T2 _yyvsc36;T2 _yyvsp36;T0* _yyspecial_routines36;T0* _yyvs37;T2 _yyvsc37;T2 _yyvsp37;T0* _yyspecial_routines37;T0* _yyvs38;T2 _yyvsc38;T2 _yyvsp38;T0* _yyspecial_routines38;T0* _yyvs39;T2 _yyvsc39;T2 _yyvsp39;T0* _yyspecial_routines39;T0* _yyvs40;T2 _yyvsc40;T2 _yyvsp40;T0* _yyspecial_routines40;T0* _yyvs41;T2 _yyvsc41;T2 _yyvsp41;T0* _yyspecial_routines41;T0* _yyvs42;T2 _yyvsc42;T2 _yyvsp42;T0* _yyspecial_routines42;T0* _yyvs43;T2 _yyvsc43;T2 _yyvsp43;T0* _yyspecial_routines43;T0* _yyvs44;T2 _yyvsc44;T2 _yyvsp44;T0* _yyspecial_routines44;T0* _yyvs45;T2 _yyvsc45;T2 _yyvsp45;T0* _yyspecial_routines45;T0* _yyvs46;T2 _yyvsc46;T2 _yyvsp46;T0* _yyspecial_routines46;T0* _dummya;T0* _dummyi;T0* _dummye;T0* _dummyl;T0* _dummyrestriction;T2 _last_width;T0* _myobject;T0* _myabstracttype;T0* _mytype;T0* _myvariable;T0* _myvalue;T0* _myattribute;T0* _myindex;T0* _myprocedure;T0* _current_type_name;T0* _my_str;T6 _is_init_default;T0* _subject_type;T0* _extend_type;T0* _my_parameters;T0* _statements;T0* _mwgenerator;T0* _pending_type;T0* _last_object_in_tree;};
extern T53 M53;
struct S250{T254 _storage;T2 _capacity;T2 _upper;};
extern T250 M250;
struct S563{Tid id;T6 _required;T0* _first;};
extern T563 M563;
extern T380 M380;
struct S791{Tid id;T2 _position;T0* _container;T0* _next_cursor;};
extern T791 M791;
struct S220{T224 _storage;T2 _capacity;T2 _upper;};
extern T220 M220;
struct S540{T544 _storage;T2 _capacity;T2 _upper;};
extern T540 M540;
struct S470{Tid id;T2 _precision;T2 _width;T3 _padding_character;T6 _plus_sign_enabled;T6 _is_lowercase;T2 _alignment;};
extern T470 M470;
struct S345{T349 _storage;T2 _capacity;T2 _upper;};
extern T345 M345;
struct S613{Tid id;T0* _domain_restriction;T2 _length;};
extern T613 M613;
struct S756{T0* _container;T6 _after;T6 _before;T0* _current_cell;T0* _next_cursor;};
extern T756 M756;
struct S284{T0* _item;T0* _next;T0* _prefix_table;};
extern T284 M284;
struct S483{Tid id;T2 _precision;T2 _width;T3 _padding_character;T6 _plus_sign_enabled;T6 _is_lowercase;T2 _alignment;T2 _fsign;T2 _integer_part;T0* _fractional_part;T0* _fractional_list;T0* _double_buffer;T0* _string_output_stream;T0* _unsigned_decimal_formatter;T0* _decimal_formatter;};
extern T483 M483;
struct S499{Tid id;T2 _precision;T2 _width;T3 _padding_character;T6 _plus_sign_enabled;T6 _is_lowercase;T2 _alignment;};
extern T499 M499;
struct S598{Tid id;T0* _operand;};
extern T598 M598;
struct S467{T3 _escape_character;T0* _string_output_stream;T0* _single_parameter;T0* _error;T0* _boolean_formatter;T0* _character_formatter;T0* _floating_point_formatter;T0* _fixed_point_formatter;T0* _fixed_or_floating_point_formatter;T0* _decimal_formatter;T0* _octal_formatter;T0* _hexadecimal_formatter;T0* _unsigned_decimal_formatter;T0* _pointer_formatter;T0* _string_formatter;};
extern T467 M467;
struct S385{Tid id;T9 _storage;T2 _count;T2 _capacity;T2 _byte_count;T2 _last_byte_index_input;T2 _last_byte_index_result;};
extern T385 M385;
struct S549{Tid id;T6 _required;};
extern T549 M549;
struct S143{T147 _storage;T2 _capacity;T2 _upper;};
extern T143 M143;
struct S587{Tid id;T0* _expression;};
extern T587 M587;
struct S136{T0* _cascade_attribute;T0* _definition;T0* _subtype;T0* _counter_statement;T0* _increment_value_statement;T0* _round_visited_statement;T0* _first_round_statement;T0* _current_round_statement;T0* _update_round_visited_statement;T0* _finished_statement;};
extern T136 M136;
struct S561{Tid id;T6 _required;T0* _first;};
extern T561 M561;
struct S434{Tid id;T0* _container;T6 _after;T6 _before;T0* _current_cell;T0* _next_cursor;T6 _is_first;T6 _generate_assert;};
extern T434 M434;
struct S502{T0* _content;T2 _count;T2 _capacity;T2 _position;T2 _column;T2 _line;T2 _index;T6 _beginning_of_line;T6 _filled;T6 _interactive;T0* _file;T6 _end_of_file;};
extern T502 M502;
struct S98{Tid id;T0* _sql;};
extern T98 M98;
struct S419{T2 _buffer_position;T9 _buffer;T2 _capacity;T0* _name;};
extern T419 M419;
struct S431{T0* _equality_tester;T2 _count;T0* _first_cell;T0* _last_cell;T0* _internal_cursor;};
extern T431 M431;
struct S226{T230 _storage;T2 _capacity;T2 _upper;};
extern T226 M226;
struct S632{Tid id;T0* _selection;T0* _insert_type;T6 _auto_primary_key;T0* _assignment_list;};
extern T632 M632;
struct S361{T0* _name;};
extern T361 M361;
struct S595{Tid id;T0* _operand;};
extern T595 M595;
struct S268{T272 _storage;T2 _capacity;T2 _upper;};
extern T268 M268;
struct S178{T0* _item;T0* _next;T6 _ascending;};
extern T178 M178;
struct S466{Tid id;T349 _storage;T2 _capacity;T2 _upper;T2 _lower;};
extern T466 M466;
struct S604{Tid id;T0* _value;};
extern T604 M604;
struct S600{Tid id;T0* _value;};
extern T600 M600;
struct S273{T277 _storage;T2 _capacity;T2 _upper;};
extern T273 M273;
struct S213{T217 _storage;T2 _capacity;T2 _upper;};
extern T213 M213;
struct S232{T236 _storage;T2 _capacity;T2 _upper;};
extern T232 M232;
struct S772{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;};
extern T772 M772;
struct S795{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;T6 _is_stored_procedure;};
extern T795 M795;
struct S782{Tid id;T0* _container;T0* _table_cursor;};
extern T782 M782;
struct S12{T0* _parser;};
extern T12 M12;
struct S532{Tid id;T2 _position;T0* _container;};
extern T532 M532;
struct S414{T0* _container;T6 _after;T6 _before;T0* _current_cell;T0* _next_cursor;};
extern T414 M414;
struct S478{Tid id;T2 _precision;T2 _width;T3 _padding_character;T6 _plus_sign_enabled;T6 _is_lowercase;T2 _alignment;T0* _integer_buffer;};
extern T478 M478;
struct S279{T283 _storage;T2 _capacity;T2 _upper;};
extern T279 M279;
struct S308{Tid id;T0* _expression;};
extern T308 M308;
struct S582{Tid id;T0* _expression;};
extern T582 M582;
extern T830 M830;
struct S479{Tid id;T2 _precision;T2 _width;T3 _padding_character;T6 _plus_sign_enabled;T6 _is_lowercase;T2 _alignment;T2 _fsign;T2 _integer_part;T0* _fractional_part;T0* _fractional_list;T0* _double_buffer;T0* _string_output_stream;T0* _unsigned_decimal_formatter;T0* _decimal_formatter;};
extern T479 M479;
struct S581{Tid id;T0* _name;};
extern T581 M581;
struct S619{Tid id;T6 _required;T0* _owner;};
extern T619 M619;
struct S671{T0* _item;T0* _right;};
extern T671 M671;
struct S379{T2 _count;T0* _first_cell;T0* _last_cell;T0* _internal_cursor;};
extern T379 M379;
struct S656{T0* _container;T6 _after;T6 _before;T0* _current_cell;T0* _next_cursor;};
extern T656 M656;
struct S597{Tid id;T0* _operand;};
extern T597 M597;
struct S323{T327 _storage;T2 _capacity;T2 _upper;};
extern T323 M323;
struct S395{T0* _item;T0* _right;};
extern T395 M395;
struct S626{Tid id;T0* _variable;};
extern T626 M626;
struct S590{Tid id;};
extern T590 M590;
struct S577{Tid id;T0* _operand;T0* _operator;};
extern T577 M577;
struct S315{Tid id;T0* _item;T0* _next;};
extern T315 M315;
struct S808{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;};
extern T808 M808;
struct S807{Tid id;T6 _identifierwithspacesenabled;T6 _setdatabaseenabled;T6 _domainsenabled;T6 _attributerequiredenabled;T6 _autoprimarykeyenabled;T6 _sequence_name_format_one_parameter;T6 _oldconstraintnames;T6 _timestampenabled;T6 _storedprocedureenabled;T6 _viewsenabled;T6 _extendindex;T6 _timezoneenabled;T6 _assertenabled;T6 _inupdatestatement;T6 _valuetablecreated;T6 _constanttablecreated;T0* _declared_values;T0* _update_type;T6 _wherewritten;T0* _updated_extension;T6 _is_stored_procedure;};
extern T807 M807;
struct S473{Tid id;T2 _precision;T2 _width;T3 _padding_character;T6 _plus_sign_enabled;T6 _is_lowercase;T2 _alignment;T0* _integer_buffer;};
extern T473 M473;
struct S698{T0* _equality_tester;T2 _count;T2 _capacity;T2 _last_position;T2 _modulus;T2 _free_slot;T2 _position;T2 _slots_position;T2 _clashes_previous_position;T2 _found_position;T0* _internal_cursor;T0* _key_equality_tester;T0* _internal_keys;T0* _item_storage;T0* _key_storage;T0* _clashes;T0* _slots;T0* _special_item_routines;T0* _special_key_routines;T0* _hash_function;};
extern T698 M698;
struct S122{Tid id;T0* _subject;T0* _predicate;};
extern T122 M122;
struct S673{Tid id;T0* _equality_tester;T2 _count;T2 _capacity;T2 _last_position;T2 _modulus;T2 _free_slot;T2 _position;T2 _slots_position;T2 _clashes_previous_position;T2 _found_position;T0* _internal_cursor;T0* _key_equality_tester;T0* _internal_keys;T0* _item_storage;T0* _key_storage;T0* _clashes;T0* _slots;T0* _special_item_routines;T0* _special_key_routines;T0* _hash_function;};
extern T673 M673;
struct S627{Tid id;T0* _extension;T0* _anode;T0* _per_property;T0* _selection;T0* _sqlfromaliasname;};
extern T627 M627;
struct S420{T2 _buffer_position;T9 _buffer;T2 _capacity;};
extern T420 M420;
struct S559{Tid id;T6 _required;T0* _pattern;};
extern T559 M559;
struct S149{T153 _storage;T2 _capacity;T2 _upper;};
extern T149 M149;
struct S647{T2 _count;T0* _first_cell;T0* _last_cell;T0* _internal_cursor;};
extern T647 M647;
struct S792{T0* _program_name;};
extern T792 M792;
struct S485{Tid id;T2 _count;T2 _capacity;T0* _storage;T0* _special_routines;T0* _internal_cursor;};
extern T485 M485;
struct S575{Tid id;T0* _expression;};
extern T575 M575;
struct S208{Tid id;T0* _name;T0* _abstract_representation;T0* _attributes;T0* _expression;T0* _representation;T0* _type;T2 _constraint_number;};
extern T208 M208;
struct S494{Tid id;T0* _container;T2 _position;T0* _next_cursor;};
extern T494 M494;
extern char*s380_0;
extern char*s54_10;
extern char*s820_6174;
extern char*s798_118123832;
extern char*s25_32;
extern char*s821_34;
extern char*s498_35;
extern char*s468_39;
extern char*s25_40;
extern char*s25_41;
extern char*s586_10727386;
extern char*s53_42;
extern char*s53_43;
extern char*s820_44;
extern char*s53_45;
extern char*s53_46;
extern char*s53_47;
extern char*s136_48;
extern char*s136_49;
extern char*s801_80015;
extern char*s53_1158547056;
extern char*s25_59;
extern char*s25_60;
extern char*s53_60;
extern char*s585_61;
extern char*s53_62;
extern char*s795_64;
extern char*s799_77;
extern char*s25_84;
extern char*s53_95;
extern char*s25_5320712;
extern char*s25_99;
extern char*s820_1720244181;
extern char*s53_319858334;
extern char*s25_192;
extern char*s25_200;
extern char*s25_201;
extern char*s53_205;
extern char*s820_12516;
extern char*s25_215;
extern char*s25_230;
extern char*s578_232;
extern char*s25_234;
extern char*s775_240;
extern char*s815_241;
extern char*s797_246;
extern char*s25_252;
extern char*s25_1188717919;
extern char*s25_270;
extern char*s816_2050971299;
extern char*s54_322;
extern char*s25_55623832;
extern char*s586_362;
extern char*s799_375;
extern char*s609_449403;
extern char*s25_2030216;
extern char*s616_1956443;
extern char*s820_6581;
extern char*s818_388041;
extern char*s25_10727948;
extern char*s800_371096635;
extern char*s801_80626;
extern char*s53_669;
extern char*s811_167394040;
extern char*s816_10937208;
extern char*s801_13127;
extern char*s816_1591719713;
extern char*s25_7010;
extern char*s25_7032;
extern char*s25_7099;
extern char*s798_982426390;
extern char*s592_7175;
extern char*s801_1752285648;
extern char*s569_274551003;
extern char*s820_2227791;
extern char*s53_117645162;
extern char*s25_1137;
extern char*s820_50839162;
extern char*s25_7335;
extern char*s798_1200;
extern char*s795_9836651;
extern char*s25_7357;
extern char*s798_1226;
extern char*s810_990066253;
extern char*s25_2113798604;
extern char*s53_1325714044;
extern char*s25_1835385931;
extern char*s811_1364;
extern char*s53_1371;
extern char*s25_1844268019;
extern char*s25_81352;
extern char*s811_1434;
extern char*s617_1461;
extern char*s820_1062451472;
extern char*s25_9855471;
extern char*s817_7752;
extern char*s761_87716;
extern char*s592_180037;
extern char*s821_1338889876;
extern char*s64_1338477769;
extern char*s773_832785612;
extern char*s499_14036;
extern char*s815_475215716;
extern char*s25_901480040;
extern char*s795_1454787255;
extern char*s815_1964120;
extern char*s820_1438302609;
extern char*s809_9782255;
extern char*s166_395830;
extern char*s761_1447702;
extern char*s798_452094615;
extern char*s820_60140614;
extern char*s820_82291;
extern char*s795_1730918391;
extern char*s814_4437276;
extern char*s761_439136;
extern char*s569_539844983;
extern char*s811_374850603;
extern char*s25_1771908816;
extern char*s807_245267627;
extern char*s569_1739394753;
extern char*s811_2167885;
extern char*s25_11160700;
extern char*s54_21666682;
extern char*s25_925310124;
extern char*s761_1619253645;
extern char*s820_9782990;
extern char*s811_181352;
extern char*s795_9758526;
extern char*s815_15368;
extern char*s53_3075;
extern char*s811_1252266737;
extern char*s53_383161196;
extern char*s795_11074916;
extern char*s811_1979370313;
extern char*s25_89261;
extern char*s53_3175;
extern char*s816_956846587;
extern char*s806_3291;
extern char*s817_15603;
extern char*s722_3330;
extern char*s723_3360;
extern char*s609_93836922;
extern char*s25_3496;
extern char*s820_3565;
extern char*s809_10595603;
extern char*s569_1134629434;
extern char*s811_16018;
extern char*s468_1375853251;
extern char*s820_9771521;
extern char*s800_16127;
extern char*s25_452865;
extern char*s795_1237123737;
extern char*s499_59251;
extern char*s795_1236459462;
extern char*s54_83912;
extern char*s761_274599;
extern char*s53_38601482;
extern char*s25_20320712;
extern char*s820_800968770;
extern char*s25_16320;
extern char*s25_4537323;
extern char*s815_1523692874;
extern char*s795_385435;
extern char*s592_188607;
extern char*s806_77910;
extern char*s54_871412;
extern char*s761_422446;
extern char*s592_242002982;
extern char*s761_16516;
extern char*s25_49507462;
extern char*s53_354906;
extern char*s811_1948036;
extern char*s25_1898282920;
extern char*s25_35157;
extern char*s585_16761;
extern char*s808_153109067;
extern char*s761_324411;
extern char*s807_1702146191;
extern char*s761_2077861575;
extern char*s815_16916;
extern char*s25_35385;
extern char*s815_398302;
extern char*s569_969918927;
extern char*s800_1979182;
extern char*s815_1910794451;
extern char*s800_67807310;
extern char*s761_17176;
extern char*s25_2256187;
extern char*s801_9938791;
extern char*s820_10843035;
extern char*s25_17323;
extern char*s795_593189031;
extern char*s817_17368;
extern char*s53_12774544;
extern char*s807_17412;
extern char*s622_1010122334;
extern char*s25_17512;
extern char*s815_2041214587;
extern char*s801_36127;
extern char*s25_327607645;
extern char*s820_85376;
extern char*s25_17716;
extern char*s815_17741;
extern char*s468_69210392;
extern char*s725_79341;
extern char*s25_1129944261;
extern char*s25_952887;
extern char*s807_664209073;
extern char*s809_10597741;
extern char*s25_5725;
extern char*s499_18036;
extern char*s820_18037;
extern char*s801_79629;
extern char*s814_998731400;
extern char*s25_20378016;
extern char*s816_1763620637;
extern char*s761_288487821;
extern char*s809_399591;
extern char*s815_971470266;
extern char*s25_2195712;
extern char*s817_2072694;
extern char*s800_820936892;
extern char*s809_52449416;
extern char*s820_51317690;
extern char*s53_107138063;
extern char*s25_387475;
/*
-- This file is  free  software, which  comes  along  with  SmartEiffel. This
-- software  is  distributed  in the hope that it will be useful, but WITHOUT
-- ANY  WARRANTY;  without  even  the  implied warranty of MERCHANTABILITY or
-- FITNESS  FOR A PARTICULAR PURPOSE. You can modify it as you want, provided
-- this header is kept unaltered, and a notification of the changes is added.
-- You  are  allowed  to  redistribute  it and sell it, alone or as a part of
-- another product.
--       Copyright (C) 1994-2002 LORIA - INRIA - U.H.P. Nancy 1 - FRANCE
--          Dominique COLNET and Suzanne COLLIN - SmartEiffel@loria.fr
--                       http://SmartEiffel.loria.fr
--
*/

/*
  This file (SmartEiffel/sys/runtime/boost.h) is automatically included when
  `run_control.boost' is true (ie. only for mode -boost).
*/
#define SE_BOOST 1
void se_print_run_time_stack (void);
void se_signal_handler(int sig);
/*
-- This file is  free  software, which  comes  along  with  SmartEiffel. This
-- software  is  distributed  in the hope that it will be useful, but WITHOUT
-- ANY  WARRANTY;  without  even  the  implied warranty of MERCHANTABILITY or
-- FITNESS  FOR A PARTICULAR PURPOSE. You can modify it as you want, provided
-- this header is kept unaltered, and a notification of the changes is added.
-- You  are  allowed  to  redistribute  it and sell it, alone or as a part of
-- another product.
--       Copyright (C) 1994-2002 LORIA - INRIA - U.H.P. Nancy 1 - FRANCE
--          Dominique COLNET and Suzanne COLLIN - SmartEiffel@loria.fr
--                       http://SmartEiffel.loria.fr
--
*/
/*
  This file (SmartEiffel/sys/runtime/exception.h) is automatically included
  when exception handling is used somewhere in the live code.
*/

#define SE_EXCEPTIONS 1

/*
  Constants from Eiffel class EXCEPTIONS :
*/
#define Check_instruction 	  1
#define Class_invariant 	  2
#define Developer_exception 	  3
#define Incorrect_inspect_value   4
#define Loop_invariant 		  5
#define Loop_variant 		  6
#define No_more_memory  	  7
#define Postcondition 		  8
#define Precondition  		  9
#define Routine_failure  	  10
#define	Os_signal		  11
#define Void_attached_to_expanded 12
#define Void_call_target 	  13
#define System_level_type_error	  14

/*
   This will be the structure of rescue contexts.  A rescue context
   will be declared for every routine that has a rescue clause.

   The `next' pointer is the address of the next rescue context if there
   is one higher up the call chain, or NULL if there is no other
   context.
*/
struct rescue_context {
  JMP_BUF jb;
#ifndef SE_BOOST
    /* To keep track of dump stack to unwind it safely
       before the LONGJMP :
    */
    struct _se_dump_stack * top_of_ds ;
#endif
  struct rescue_context *next;
};

extern struct rescue_context *rescue_context_top;
extern int internal_exception_number;
extern int original_internal_exception_number;
extern int signal_exception_number;
extern char *additional_error_message;

void setup_signal_handler(void);
void signal_exception_handler(int);
void internal_exception_handler(int);
void print_exception(void);

#ifndef SE_BOOST
void free_exception_frames(void);
#endif
/*
-- This file is  free  software, which  comes  along  with  SmartEiffel. This
-- software  is  distributed  in the hope that it will be useful, but WITHOUT
-- ANY  WARRANTY;  without  even  the  implied warranty of MERCHANTABILITY or
-- FITNESS  FOR A PARTICULAR PURPOSE. You can modify it as you want, provided
-- this header is kept unaltered, and a notification of the changes is added.
-- You  are  allowed  to  redistribute  it and sell it, alone or as a part of
-- another product.
--       Copyright (C) 1994-2002 LORIA - INRIA - U.H.P. Nancy 1 - FRANCE
--          Dominique COLNET and Suzanne COLLIN - SmartEiffel@loria.fr
--                       http://SmartEiffel.loria.fr
--
*/
/*
  This file (SmartEiffel/sys/runtime/basic_io.h) is automatically
  included when some external "SmartEiffel" basic_io_* feature is used.
*/

#define basic_io_stdin (stdin)
#define basic_io_stdout (stdout)
#define basic_io_stderr (stderr)
#define basic_io_eof (EOF)
#define basic_io_text_file_read_open(p) (fopen(((char*)(p)),"r"))
#define basic_io_text_file_write_open(p) (fopen(((char*)(p)),"w"))
#define basic_io_text_file_write_append(p) (fopen(((char*)(p)),"a"))
#define basic_io_text_file_read_write_open(p) (fopen(((char*)(p)),"r+"))
#define basic_io_text_file_read_write_append(p) (fopen(((char*)(p)),"a+"))
#define basic_io_binary_file_read_open(p) (fopen(((char*)(p)),"rb"))
#define basic_io_binary_file_write_open(p) (fopen(((char*)(p)),"wb"))
#define basic_io_binary_file_write_append(p) (fopen(((char*)(p)),"ab"))
#define basic_io_fclose(p) (fclose((FILE*)(p)))
#define basic_io_flush(p) (fflush((FILE*)(p)))
#define basic_io_getc(f) (getc(((FILE*)(f))))
#define basic_io_putc(b, f) (putc((b),((FILE*)(f))))
#define basic_io_fread(b, n, f) (fread((void *)(b),(size_t)(1), (size_t)(n),(FILE*)(f)))
#define basic_io_fwrite(b, n, f) (fwrite((void *)(b),(size_t)(1), (size_t)(n),(FILE*)(f)))
#define basic_io_feof(f) (feof(((FILE*)(f))))
#define basic_io_rename(o, n) (rename(((char*)(o)),((char*)(n))))
#define basic_io_remove(f) (remove(((char*)(f))))

#if defined __USE_POSIX || defined __unix__ || defined _POSIX_C_SOURCE
#  define basic_io_read_stdin(b, s) (read(STDIN_FILENO, b, s))
#else
  extern int basic_io_read_stdin(char *buffer, int size);
#endif

/*
-- This file is  free  software, which  comes  along  with  SmartEiffel. This
-- software  is  distributed  in the hope that it will be useful, but WITHOUT
-- ANY  WARRANTY;  without  even  the  implied warranty of MERCHANTABILITY or
-- FITNESS  FOR A PARTICULAR PURPOSE. You can modify it as you want, provided
-- this header is kept unaltered, and a notification of the changes is added.
-- You  are  allowed  to  redistribute  it and sell it, alone or as a part of
-- another product.
--       Copyright (C) 1994-2002 LORIA - INRIA - U.H.P. Nancy 1 - FRANCE
--          Dominique COLNET and Suzanne COLLIN - SmartEiffel@loria.fr
--                       http://SmartEiffel.loria.fr
--
*/
/*
  This file (SmartEiffel/sys/runtime/basic_sprintf.h) is automatically
  included when the external "SmartEiffel" basic_sprintf feature is used.
*/

#define basic_sprintf_pointer(buffer, pointer) sprintf((char*)(buffer),"%p",pointer)

void basic_sprintf_double(EIF_CHARACTER* b, int f, double d);
/*POINTER*/
T0* r8out(T8 C);
extern T0*oBC8string_buffer;
/*POINTER*/
void r8append_in(T8 C,T0* a1);
extern T0*oBC19tagged_out_memory;
/*BOOLEAN*/
T6 r6_ix_and(T6 C,T6 a1);
/*BOOLEAN*/
T6 r6_px_not(T6 C);
/*BOOLEAN*/
T6 r6_ix_or(T6 C,T6 a1);
/*CHARACTER*/
T0* r3out(T3 C);
/*CHARACTER*/
T6 r3is_digit(T3 C);
/*CHARACTER*/
T6 r3is_separator(T3 C);
/*CHARACTER*/
void r3out_in_tagged_out_memory(T3 C);
/*CHARACTER*/
T6 r3_ix_6061(T3 C,T3 a1);
/*CHARACTER*/
T1 r3value(T3 C);
/*CHARACTER*/
T1 r3decimal_value(T3 C);
/*CHARACTER*/
T6 r3_ix_6261(T3 C,T3 a1);
/*INTEGER*/
T0* r2out(T2 C);
/*INTEGER*/
T2 r2max(T2 C,T2 a1);
/*INTEGER*/
T2 r2min(T2 C,T2 a1);
/*INTEGER*/
T3 r2digit(T2 C);
/*INTEGER*/
void r2append_in(T2 C,T0* a1);
/*INTEGER*/
T2 r2abs(T2 C);
/*DOUBLE*/
T2 r5floor(T5 C);
/*DOUBLE*/
T1 r5sign(T5 C);
/*DOUBLE*/
T5 r5abs(T5 C);
/*INTEGER_16*/
T0* r10out(T10 C);
/*INTEGER_16*/
T3 r10digit(T10 C);
/*INTEGER_16*/
void r10append_in(T10 C,T0* a1);
/*REAL*/
T5 r4_ix_94(T4 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_EXTEND_STATEMENT]*/
void r121clear_all(T121 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_EXTEND_STATEMENT]*/
T121 r121realloc(T121 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTEND_STATEMENT]*/
void r121set_all_with(T121 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTEND_STATEMENT]*/
void r121clear(T121 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTEND_STATEMENT]*/
void r121copy_from(T121 C,T121 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CONSTANT_STATEMENT]*/
void r153clear_all(T153 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_CONSTANT_STATEMENT]*/
T153 r153realloc(T153 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CONSTANT_STATEMENT]*/
void r153set_all_with(T153 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CONSTANT_STATEMENT]*/
void r153clear(T153 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CONSTANT_STATEMENT]*/
void r153copy_from(T153 C,T153 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_PROCEDURE_STATEMENT]*/
void r109clear_all(T109 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_PROCEDURE_STATEMENT]*/
T109 r109realloc(T109 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_PROCEDURE_STATEMENT]*/
void r109set_all_with(T109 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_PROCEDURE_STATEMENT]*/
void r109clear(T109 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_PROCEDURE_STATEMENT]*/
void r109copy_from(T109 C,T109 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_FUNCTION]*/
void r177clear_all(T177 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_FUNCTION]*/
T177 r177realloc(T177 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_FUNCTION]*/
void r177set_all_with(T177 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_FUNCTION]*/
void r177clear(T177 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_FUNCTION]*/
void r177copy_from(T177 C,T177 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_REPRESENTATION]*/
void r272clear_all(T272 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_REPRESENTATION]*/
T272 r272realloc(T272 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_REPRESENTATION]*/
void r272set_all_with(T272 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_REPRESENTATION]*/
void r272clear(T272 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_REPRESENTATION]*/
void r272copy_from(T272 C,T272 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_PK_REPRESENTATION]*/
void r267clear_all(T267 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_PK_REPRESENTATION]*/
T267 r267realloc(T267 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_PK_REPRESENTATION]*/
void r267set_all_with(T267 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_PK_REPRESENTATION]*/
void r267clear(T267 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_PK_REPRESENTATION]*/
void r267copy_from(T267 C,T267 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_DELETE_STATEMENT]*/
void r127clear_all(T127 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_DELETE_STATEMENT]*/
T127 r127realloc(T127 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_DELETE_STATEMENT]*/
void r127set_all_with(T127 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_DELETE_STATEMENT]*/
void r127clear(T127 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_DELETE_STATEMENT]*/
void r127copy_from(T127 C,T127 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_STATEMENT]*/
void r158clear_all(T158 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_STATEMENT]*/
T158 r158realloc(T158 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_STATEMENT]*/
void r158set_all_with(T158 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_STATEMENT]*/
void r158clear(T158 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_STATEMENT]*/
void r158copy_from(T158 C,T158 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_GET_STATEMENT]*/
void r115clear_all(T115 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_GET_STATEMENT]*/
T115 r115realloc(T115 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_GET_STATEMENT]*/
void r115set_all_with(T115 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_GET_STATEMENT]*/
void r115clear(T115 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_GET_STATEMENT]*/
void r115copy_from(T115 C,T115 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_VALUE_SELECTION_STATEMENT]*/
void r79clear_all(T79 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_VALUE_SELECTION_STATEMENT]*/
T79 r79realloc(T79 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_VALUE_SELECTION_STATEMENT]*/
void r79set_all_with(T79 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_VALUE_SELECTION_STATEMENT]*/
void r79clear(T79 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_VALUE_SELECTION_STATEMENT]*/
void r79copy_from(T79 C,T79 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_TYPE]*/
void r277clear_all(T277 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_TYPE]*/
T277 r277realloc(T277 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_TYPE]*/
void r277set_all_with(T277 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_TYPE]*/
void r277clear(T277 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_TYPE]*/
void r277copy_from(T277 C,T277 a1,T2 a2);
/*NATIVE_ARRAY[DS_CELL[INTEGER]]*/
void r840set_all_with(T840 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_LOGICAL_VALUE_EXPRESSION]*/
void r302clear_all(T302 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_LOGICAL_VALUE_EXPRESSION]*/
T302 r302realloc(T302 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_LOGICAL_VALUE_EXPRESSION]*/
void r302set_all_with(T302 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_LOGICAL_VALUE_EXPRESSION]*/
void r302clear(T302 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_LOGICAL_VALUE_EXPRESSION]*/
void r302copy_from(T302 C,T302 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SORT_NODE]*/
void r183clear_all(T183 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_SORT_NODE]*/
T183 r183realloc(T183 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SORT_NODE]*/
void r183set_all_with(T183 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SORT_NODE]*/
void r183clear(T183 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SORT_NODE]*/
void r183copy_from(T183 C,T183 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXPRESSION]*/
void r307clear_all(T307 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_EXPRESSION]*/
T307 r307realloc(T307 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXPRESSION]*/
void r307set_all_with(T307 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXPRESSION]*/
void r307clear(T307 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXPRESSION]*/
void r307copy_from(T307 C,T307 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_DOMAIN_RESTRICTION]*/
void r333clear_all(T333 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_DOMAIN_RESTRICTION]*/
T333 r333realloc(T333 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_DOMAIN_RESTRICTION]*/
void r333set_all_with(T333 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_DOMAIN_RESTRICTION]*/
void r333clear(T333 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_DOMAIN_RESTRICTION]*/
void r333copy_from(T333 C,T333 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_I_NODE]*/
void r321clear_all(T321 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_I_NODE]*/
T321 r321realloc(T321 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_I_NODE]*/
void r321set_all_with(T321 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_I_NODE]*/
void r321clear(T321 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_I_NODE]*/
void r321copy_from(T321 C,T321 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CASCADE_STATEMENT]*/
void r141clear_all(T141 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_CASCADE_STATEMENT]*/
T141 r141realloc(T141 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CASCADE_STATEMENT]*/
void r141set_all_with(T141 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CASCADE_STATEMENT]*/
void r141clear(T141 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CASCADE_STATEMENT]*/
void r141copy_from(T141 C,T141 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NAME]*/
void r283clear_all(T283 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NAME]*/
T283 r283realloc(T283 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NAME]*/
void r283set_all_with(T283 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NAME]*/
void r283clear(T283 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NAME]*/
void r283copy_from(T283 C,T283 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_STATEMENT_NODE]*/
void r165clear_all(T165 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_STATEMENT_NODE]*/
T165 r165realloc(T165 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_STATEMENT_NODE]*/
void r165set_all_with(T165 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_STATEMENT_NODE]*/
void r165clear(T165 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_STATEMENT_NODE]*/
void r165copy_from(T165 C,T165 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SQL_STATEMENT]*/
void r103clear_all(T103 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_SQL_STATEMENT]*/
T103 r103realloc(T103 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SQL_STATEMENT]*/
void r103set_all_with(T103 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SQL_STATEMENT]*/
void r103clear(T103 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SQL_STATEMENT]*/
void r103copy_from(T103 C,T103 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTENSION_EXPRESSION]*/
void r201clear_all(T201 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_EXTENSION_EXPRESSION]*/
T201 r201realloc(T201 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTENSION_EXPRESSION]*/
void r201set_all_with(T201 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTENSION_EXPRESSION]*/
void r201clear(T201 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTENSION_EXPRESSION]*/
void r201copy_from(T201 C,T201 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SELECTION_FUNCTION]*/
void r224clear_all(T224 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_SELECTION_FUNCTION]*/
T224 r224realloc(T224 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SELECTION_FUNCTION]*/
void r224set_all_with(T224 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SELECTION_FUNCTION]*/
void r224clear(T224 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SELECTION_FUNCTION]*/
void r224copy_from(T224 C,T224 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ABSTRACT_OBJECT]*/
void r544clear_all(T544 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_ABSTRACT_OBJECT]*/
T544 r544realloc(T544 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ABSTRACT_OBJECT]*/
void r544clear(T544 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ABSTRACT_OBJECT]*/
void r544copy_from(T544 C,T544 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SELECTION_LIST]*/
void r190clear_all(T190 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_SELECTION_LIST]*/
T190 r190realloc(T190 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SELECTION_LIST]*/
void r190set_all_with(T190 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SELECTION_LIST]*/
void r190clear(T190 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SELECTION_LIST]*/
void r190copy_from(T190 C,T190 a1,T2 a2);
/*NATIVE_ARRAY[STRING]*/
void r349clear_all(T349 C,T2 a1);
/*NATIVE_ARRAY[STRING]*/
T349 r349realloc(T349 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[STRING]*/
void r349move(T349 C,T2 a1,T2 a2,T2 a3);
/*NATIVE_ARRAY[STRING]*/
void r349set_all_with(T349 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[STRING]*/
void r349clear(T349 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[STRING]*/
void r349copy_from(T349 C,T349 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_BASE]*/
void r339clear_all(T339 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_BASE]*/
T339 r339realloc(T339 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_BASE]*/
void r339set_all_with(T339 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_BASE]*/
void r339clear(T339 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_BASE]*/
void r339copy_from(T339 C,T339 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SYSTEM_EXPRESSION]*/
void r296clear_all(T296 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_SYSTEM_EXPRESSION]*/
T296 r296realloc(T296 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SYSTEM_EXPRESSION]*/
void r296set_all_with(T296 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SYSTEM_EXPRESSION]*/
void r296clear(T296 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SYSTEM_EXPRESSION]*/
void r296copy_from(T296 C,T296 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SELECTION]*/
void r195clear_all(T195 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_SELECTION]*/
T195 r195realloc(T195 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SELECTION]*/
void r195set_all_with(T195 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SELECTION]*/
void r195clear(T195 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SELECTION]*/
void r195copy_from(T195 C,T195 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTEND_ATTRIBUTE]*/
void r207clear_all(T207 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_EXTEND_ATTRIBUTE]*/
T207 r207realloc(T207 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTEND_ATTRIBUTE]*/
void r207set_all_with(T207 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTEND_ATTRIBUTE]*/
void r207clear(T207 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTEND_ATTRIBUTE]*/
void r207copy_from(T207 C,T207 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_LOGICAL_EXPRESSION]*/
void r314clear_all(T314 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_LOGICAL_EXPRESSION]*/
T314 r314realloc(T314 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_LOGICAL_EXPRESSION]*/
void r314set_all_with(T314 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_LOGICAL_EXPRESSION]*/
void r314clear(T314 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_LOGICAL_EXPRESSION]*/
void r314copy_from(T314 C,T314 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ASSERTION]*/
void r248clear_all(T248 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_ASSERTION]*/
T248 r248realloc(T248 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ASSERTION]*/
void r248set_all_with(T248 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ASSERTION]*/
void r248clear(T248 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ASSERTION]*/
void r248copy_from(T248 C,T248 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_TYPE_STATEMENT]*/
void r97clear_all(T97 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_TYPE_STATEMENT]*/
T97 r97realloc(T97 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_TYPE_STATEMENT]*/
void r97set_all_with(T97 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_TYPE_STATEMENT]*/
void r97clear(T97 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_TYPE_STATEMENT]*/
void r97copy_from(T97 C,T97 a1,T2 a2);
/*NATIVE_ARRAY[CHARACTER]*/
void r9copy_slice(T9 C,T2 a1,T9 a2,T2 a3,T2 a4);
/*NATIVE_ARRAY[CHARACTER]*/
T9 r9realloc(T9 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[CHARACTER]*/
void r9move(T9 C,T2 a1,T2 a2,T2 a3);
/*NATIVE_ARRAY[CHARACTER]*/
T6 r9fast_memcmp(T9 C,T9 a1,T2 a2);
/*NATIVE_ARRAY[CHARACTER]*/
void r9set_all_with(T9 C,T3 a1,T2 a2);
/*NATIVE_ARRAY[CHARACTER]*/
T6 r9fast_has(T9 C,T3 a1,T2 a2);
/*NATIVE_ARRAY[CHARACTER]*/
void r9copy_at(T9 C,T2 a1,T9 a2,T2 a3);
/*NATIVE_ARRAY[CHARACTER]*/
void r9clear(T9 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[CHARACTER]*/
void r9copy_from(T9 C,T9 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ASSIGNMENT]*/
void r236clear_all(T236 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_ASSIGNMENT]*/
T236 r236realloc(T236 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ASSIGNMENT]*/
void r236set_all_with(T236 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ASSIGNMENT]*/
void r236clear(T236 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ASSIGNMENT]*/
void r236copy_from(T236 C,T236 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE]*/
void r254clear_all(T254 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE]*/
T254 r254realloc(T254 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE]*/
void r254set_all_with(T254 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE]*/
void r254clear(T254 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE]*/
void r254copy_from(T254 C,T254 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_A_NODE]*/
void r327clear_all(T327 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_A_NODE]*/
T327 r327realloc(T327 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_A_NODE]*/
void r327set_all_with(T327 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_A_NODE]*/
void r327clear(T327 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_A_NODE]*/
void r327copy_from(T327 C,T327 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CASCADE_FUNCTION_EXPRESSION]*/
void r135clear_all(T135 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_CASCADE_FUNCTION_EXPRESSION]*/
T135 r135realloc(T135 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CASCADE_FUNCTION_EXPRESSION]*/
void r135set_all_with(T135 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CASCADE_FUNCTION_EXPRESSION]*/
void r135clear(T135 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CASCADE_FUNCTION_EXPRESSION]*/
void r135copy_from(T135 C,T135 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXPRESSION_NODE]*/
void r171clear_all(T171 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_EXPRESSION_NODE]*/
T171 r171realloc(T171 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXPRESSION_NODE]*/
void r171set_all_with(T171 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXPRESSION_NODE]*/
void r171clear(T171 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXPRESSION_NODE]*/
void r171copy_from(T171 C,T171 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SUBJECT]*/
void r230clear_all(T230 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_SUBJECT]*/
T230 r230realloc(T230 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SUBJECT]*/
void r230set_all_with(T230 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SUBJECT]*/
void r230clear(T230 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_SUBJECT]*/
void r230copy_from(T230 C,T230 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_VALUE_STATEMENT]*/
void r85clear_all(T85 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_VALUE_STATEMENT]*/
T85 r85realloc(T85 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_VALUE_STATEMENT]*/
void r85set_all_with(T85 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_VALUE_STATEMENT]*/
void r85clear(T85 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_VALUE_STATEMENT]*/
void r85copy_from(T85 C,T85 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ASSIGNMENT_NODE]*/
void r242clear_all(T242 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_ASSIGNMENT_NODE]*/
T242 r242realloc(T242 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ASSIGNMENT_NODE]*/
void r242set_all_with(T242 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ASSIGNMENT_NODE]*/
void r242clear(T242 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ASSIGNMENT_NODE]*/
void r242copy_from(T242 C,T242 a1,T2 a2);
/*NATIVE_ARRAY[DS_CELL[DOUBLE]]*/
void r843set_all_with(T843 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NODE]*/
void r260clear_all(T260 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NODE]*/
T260 r260realloc(T260 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NODE]*/
void r260set_all_with(T260 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NODE]*/
void r260clear(T260 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NODE]*/
void r260copy_from(T260 C,T260 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTENSION]*/
void r217clear_all(T217 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_EXTENSION]*/
T217 r217realloc(T217 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTENSION]*/
void r217set_all_with(T217 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTENSION]*/
void r217clear(T217 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_EXTENSION]*/
void r217copy_from(T217 C,T217 a1,T2 a2);
/*NATIVE_ARRAY[INTEGER]*/
void r344clear_all(T344 C,T2 a1);
/*NATIVE_ARRAY[INTEGER]*/
T344 r344realloc(T344 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[INTEGER]*/
void r344set_all_with(T344 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[INTEGER]*/
void r344clear(T344 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[INTEGER]*/
void r344copy_from(T344 C,T344 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_UPDATE_STATEMENT]*/
void r91clear_all(T91 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_UPDATE_STATEMENT]*/
T91 r91realloc(T91 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_UPDATE_STATEMENT]*/
void r91set_all_with(T91 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_UPDATE_STATEMENT]*/
void r91clear(T91 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_UPDATE_STATEMENT]*/
void r91copy_from(T91 C,T91 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_VALUE]*/
void r706clear_all(T706 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_VALUE]*/
T706 r706realloc(T706 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_VALUE]*/
void r706clear(T706 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_VALUE]*/
void r706copy_from(T706 C,T706 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT]*/
void r147clear_all(T147 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT]*/
T147 r147realloc(T147 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT]*/
void r147set_all_with(T147 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT]*/
void r147clear(T147 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT]*/
void r147copy_from(T147 C,T147 a1,T2 a2);
/*NATIVE_ARRAY[ANY]*/
void r354clear_all(T354 C,T2 a1);
/*NATIVE_ARRAY[ANY]*/
T354 r354realloc(T354 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[ANY]*/
void r354set_all_with(T354 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[ANY]*/
void r354clear(T354 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[ANY]*/
void r354copy_from(T354 C,T354 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r289clear_all(T289 C,T2 a1);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NAME_NODE]*/
T289 r289realloc(T289 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r289set_all_with(T289 C,T0* a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r289clear(T289 C,T2 a1,T2 a2);
/*NATIVE_ARRAY[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r289copy_from(T289 C,T289 a1,T2 a2);
/*STRING*/
T0* r7out(T7* C);
/*STRING*/
void r7copy(T7* C,T0* a1);
/*STRING*/
T0* r7substring(T7* C,T2 a1,T2 a2);
/*STRING*/
void r7keep_tail(T7* C,T2 a1);
/*STRING*/
void r7remove_first(T7* C,T2 a1);
/*STRING*/
T2 r7item_code(T7* C,T2 a1);
/*STRING*/
void r7remove_between(T7* C,T2 a1,T2 a2);
/*STRING*/
T6 r7is_equal(T7* C,T0* a1);
/*STRING*/
void r7insert_character(T7* C,T3 a1,T2 a2);
/*STRING*/
T3 r7item(T7* C,T2 a1);
/*STRING*/
void r7append(T7* C,T0* a1);
/*STRING*/
void r7print_on(T7* C,T0* a1);
/*STRING*/
void r7make_from_string(T7* C,T0* a1);
/*STRING*/
T2 r7index_of(T7* C,T3 a1,T2 a2);
/*STRING*/
void r7out_in_tagged_out_memory(T7* C);
/*STRING*/
T6 r7is_integer(T7* C);
/*STRING*/
void r7remove_tail(T7* C,T2 a1);
/*STRING*/
void r7make(T7* C,T2 a1);
/*STRING*/
void r7fill_tagged_out_memory(T7* C);
/*STRING*/
void r7append_string(T7* C,T0* a1);
/*STRING*/
void r7make_filled(T7* C,T3 a1,T2 a2);
/*STRING*/
void r7remove(T7* C,T2 a1);
/*STRING*/
T0* r7string(T7* C);
/*STRING*/
void r7extend(T7* C,T3 a1);
/*STRING*/
void r7insert_string(T7* C,T0* a1,T2 a2);
/*STRING*/
T2 r7hash_code(T7* C);
/*STRING*/
void r7remove_last(T7* C,T2 a1);
/*STRING*/
T6 r7has(T7* C,T3 a1);
/*STRING*/
void r7keep_head(T7* C,T2 a1);
/*STRING*/
T2 r7to_integer(T7* C);
/*STRING*/
void r7precede(T7* C,T3 a1);
/*STRING*/
void r7append_character(T7* C,T3 a1);
/*STRING*/
void r7resize(T7* C,T2 a1);
/*STRING*/
void r7right_adjust(T7* C);
/*STRING*/
T8 r7to_external(T7* C);
/*STRING*/
T6 r7same_string(T7* C,T0* a1);
/*STRING*/
T0* r7twin(T7* C);
/*STRING*/
T0* r7_ix_43(T7* C,T0* a1);
/*STRING*/
void r7swap(T7* C,T2 a1,T2 a2);
/*ARRAY[INTEGER]*/
T2 r764count(T764* C);
/*ARRAY[INTEGER]*/
T2 r764item(T764* C,T2 a1);
/*ARRAY[INTEGER]*/
void r764make(T764* C,T2 a1,T2 a2);
/*ARRAY[ANY]*/
void r500clear_all(T500* C);
/*ARRAY[ANY]*/
T0* r500item(T500* C,T2 a1);
/*ARRAY[ANY]*/
void r500make(T500* C,T2 a1,T2 a2);
/*ARRAY[DS_CELL[INTEGER]]*/
T0* r838item(T838* C,T2 a1);
/*ARRAY[DS_CELL[INTEGER]]*/
void r838make(T838* C,T2 a1,T2 a2);
/*ARRAY[DS_CELL[DOUBLE]]*/
T0* r841item(T841* C,T2 a1);
/*ARRAY[DS_CELL[DOUBLE]]*/
void r841make(T841* C,T2 a1,T2 a2);
/*ARRAY[STRING]*/
T2 r466count(T466* C);
/*ARRAY[STRING]*/
T0* r466item(T466* C,T2 a1);
/*ARRAY[STRING]*/
void r466make(T466* C,T2 a1,T2 a2);
/*ARRAY[STRING]*/
void r466resize(T466* C,T2 a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_EXTENSION]*/
T0* r715make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_EXTENSION]*/
T0* r715resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_FUNCTION]*/
void r173make(T173* C,T2 a1);
/*SPECIAL[XPLAIN_FUNCTION]*/
T0* r173resize(T173* C,T2 a1);
/*SPECIAL[XPLAIN_FUNCTION]*/
void r173array_resize(T173* C,T2 a1);
/*SPECIAL[ANY]*/
void r350make(T350* C,T2 a1);
/*SPECIAL[ANY]*/
T0* r350resize(T350* C,T2 a1);
/*SPECIAL[ANY]*/
void r350array_resize(T350* C,T2 a1);
/*DS_HASH_SET[STRING]*/
T2 r445new_capacity(T2 a1);
/*DS_HASH_SET[STRING]*/
void r445force(T445* C,T0* a1);
/*DS_HASH_SET[STRING]*/
void r445make_clashes(T445* C,T2 a1);
/*DS_HASH_SET[STRING]*/
T0* r445cursor_item(T445* C,T0* a1);
/*DS_HASH_SET[STRING]*/
void r445search_position(T445* C,T0* a1);
/*DS_HASH_SET[STRING]*/
void r445remove_traversing_cursor(T445* C,T0* a1);
/*DS_HASH_SET[STRING]*/
void r445cursor_go_after(T445* C,T0* a1);
/*DS_HASH_SET[STRING]*/
void r445add_traversing_cursor(T445* C,T0* a1);
/*DS_HASH_SET[STRING]*/
void r445make_item_storage(T445* C,T2 a1);
/*DS_HASH_SET[STRING]*/
void r445make(T445* C,T2 a1);
/*DS_HASH_SET[STRING]*/
void r445item_storage_resize(T445* C,T2 a1);
extern T0*oBC62special_integer_;
/*DS_HASH_SET[STRING]*/
T6 r445cursor_after(T0* a1);
/*DS_HASH_SET[STRING]*/
T6 r445has(T445* C,T0* a1);
/*DS_HASH_SET[STRING]*/
void r445cursor_search_forth(T445* C,T0* a1,T0* a2);
/*DS_HASH_SET[STRING]*/
T2 r445hash_position(T445* C,T0* a1);
/*DS_HASH_SET[STRING]*/
void r445cursor_forth(T445* C,T0* a1);
/*DS_HASH_SET[STRING]*/
void r445resize(T445* C,T2 a1);
/*DS_HASH_SET[STRING]*/
void r445cursor_start(T445* C,T0* a1);
/*DS_HASH_SET[STRING]*/
void r445clashes_resize(T445* C,T2 a1);
/*DS_HASH_SET[STRING]*/
void r445slots_resize(T445* C,T2 a1);
/*DS_HASH_SET[STRING]*/
T0* r445new_cursor(T445* C);
/*DS_HASH_SET[STRING]*/
T0* r445key_storage_item(T445* C,T2 a1);
/*DS_HASH_SET[STRING]*/
void r445make_slots(T445* C,T2 a1);
/*DS_HASH_SET[STRING]*/
T2 r445new_modulus(T2 a1);
/*DS_HASH_SET[STRING]*/
T6 r445cursor_off(T0* a1);
/*KL_SPECIAL_ROUTINES[ANY]*/
T0* r356make(T2 a1);
/*KL_SPECIAL_ROUTINES[ANY]*/
T0* r356resize(T0* a1,T2 a2);
/*DS_BILINKED_LIST_CURSOR[XPLAIN_STATEMENT]*/
void r743set(T743* C,T0* a1,T6 a2,T6 a3);
/*DS_BILINKED_LIST_CURSOR[XPLAIN_STATEMENT]*/
T6 r743is_first(T743* C);
/*DS_BILINKED_LIST_CURSOR[XPLAIN_STATEMENT]*/
void r743make(T743* C,T0* a1);
/*SPECIAL[XPLAIN_VALUE]*/
void r702make(T702* C,T2 a1);
/*SPECIAL[XPLAIN_VALUE]*/
T0* r702resize(T702* C,T2 a1);
/*SPECIAL[XPLAIN_VALUE]*/
void r702array_resize(T702* C,T2 a1);
/*DS_LINKED_LIST_CURSOR[XPLAIN_ATTRIBUTE]*/
void r554set(T554* C,T0* a1,T6 a2,T6 a3);
/*DS_LINKED_LIST_CURSOR[XPLAIN_ATTRIBUTE]*/
T0* r554item(T554* C);
/*DS_LINKED_LIST_CURSOR[XPLAIN_ATTRIBUTE]*/
T6 r554is_first(T554* C);
/*DS_LINKED_LIST_CURSOR[XPLAIN_ATTRIBUTE]*/
T6 r554is_last(T554* C);
/*DS_LINKED_LIST_CURSOR[XPLAIN_ATTRIBUTE]*/
void r554make(T554* C,T0* a1);
/*DS_LINKED_LIST_CURSOR[XPLAIN_ATTRIBUTE]*/
void r554set_after(T554* C);
/*SPECIAL[INTEGER]*/
void r340make(T340* C,T2 a1);
/*SPECIAL[INTEGER]*/
T0* r340resize(T340* C,T2 a1);
/*SPECIAL[INTEGER]*/
void r340array_resize(T340* C,T2 a1);
/*SPECIAL[INTEGER]*/
void r340with_capacity(T340* C,T2 a1);
/*SPECIAL[INTEGER]*/
void r340from_collection(T340* C,T0* a1);
/*SPECIAL[XPLAIN_STATEMENT]*/
void r154make(T154* C,T2 a1);
/*SPECIAL[XPLAIN_STATEMENT]*/
T0* r154resize(T154* C,T2 a1);
/*SPECIAL[XPLAIN_STATEMENT]*/
void r154array_resize(T154* C,T2 a1);
/*DS_SPARSE_TABLE_KEYS[INTEGER,XPLAIN_TYPE]*/
void r680make(T680* C,T0* a1);
/*DS_SPARSE_TABLE_KEYS[INTEGER,XPLAIN_TYPE]*/
T0* r680new_cursor(T680* C);
/*DS_SPARSE_TABLE_KEYS[XPLAIN_VALUE,STRING]*/
void r777make(T777* C,T0* a1);
/*DS_SPARSE_TABLE_KEYS[XPLAIN_VALUE,STRING]*/
T0* r777new_cursor(T777* C);
/*KL_SPECIAL_ROUTINES[XPLAIN_ASSIGNMENT]*/
T0* r634make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_ASSIGNMENT]*/
T0* r634resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_PK_REPRESENTATION]*/
void r263make(T263* C,T2 a1);
/*SPECIAL[XPLAIN_PK_REPRESENTATION]*/
T0* r263resize(T263* C,T2 a1);
/*SPECIAL[XPLAIN_PK_REPRESENTATION]*/
void r263array_resize(T263* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_DELETE_STATEMENT]*/
T0* r642make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_DELETE_STATEMENT]*/
T0* r642resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_PK_REPRESENTATION]*/
T0* r618make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_PK_REPRESENTATION]*/
T0* r618resize(T0* a1,T2 a2);
extern T0*oBC15any_;
/*KL_EQUALITY_TESTER[STRING]*/
T6 r439test(T0* a1,T0* a2);
/*SPECIAL[XPLAIN_SORT_NODE]*/
void r179make(T179* C,T2 a1);
/*SPECIAL[XPLAIN_SORT_NODE]*/
T0* r179resize(T179* C,T2 a1);
/*SPECIAL[XPLAIN_SORT_NODE]*/
void r179array_resize(T179* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_REPRESENTATION]*/
T0* r608make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_REPRESENTATION]*/
T0* r608resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_ATTRIBUTE_NAME]*/
T0* r606make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_ATTRIBUTE_NAME]*/
T0* r606resize(T0* a1,T2 a2);
/*DS_HASH_TABLE_CURSOR[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r537make(T537* C,T0* a1);
/*KL_EQUALITY_TESTER[XPLAIN_TYPE]*/
T6 r676test(T0* a1,T0* a2);
/*DS_BILINKABLE[XPLAIN_STATEMENT]*/
void r732put_right(T732* C,T0* a1);
/*SPECIAL[XPLAIN_SQL_STATEMENT]*/
void r99make(T99* C,T2 a1);
/*SPECIAL[XPLAIN_SQL_STATEMENT]*/
T0* r99resize(T99* C,T2 a1);
/*SPECIAL[XPLAIN_SQL_STATEMENT]*/
void r99array_resize(T99* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_STATEMENT]*/
T0* r507make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_STATEMENT]*/
T0* r507resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_BASE]*/
void r335make(T335* C,T2 a1);
/*SPECIAL[XPLAIN_BASE]*/
T0* r335resize(T335* C,T2 a1);
/*SPECIAL[XPLAIN_BASE]*/
void r335array_resize(T335* C,T2 a1);
/*DS_HASH_TABLE_CURSOR[INTEGER,XPLAIN_TYPE]*/
void r693make(T693* C,T0* a1);
/*SPECIAL[XPLAIN_EXTEND_ATTRIBUTE]*/
void r203make(T203* C,T2 a1);
/*SPECIAL[XPLAIN_EXTEND_ATTRIBUTE]*/
T0* r203resize(T203* C,T2 a1);
/*SPECIAL[XPLAIN_EXTEND_ATTRIBUTE]*/
void r203array_resize(T203* C,T2 a1);
/*KL_ARRAY_ROUTINES[ANY]*/
T6 r770has(T0* a1,T0* a2);
/*SPECIAL[XPLAIN_DOMAIN_RESTRICTION]*/
void r329make(T329* C,T2 a1);
/*SPECIAL[XPLAIN_DOMAIN_RESTRICTION]*/
T0* r329resize(T329* C,T2 a1);
/*SPECIAL[XPLAIN_DOMAIN_RESTRICTION]*/
void r329array_resize(T329* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_TYPE]*/
T0* r607make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_TYPE]*/
T0* r607resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_UPDATE_STATEMENT]*/
T0* r696make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_UPDATE_STATEMENT]*/
T0* r696resize(T0* a1,T2 a2);
/*DS_HASH_SET_CURSOR[STRING]*/
T6 r459after(T459* C);
/*DS_HASH_SET_CURSOR[STRING]*/
void r459make(T459* C,T0* a1);
/*DS_SPARSE_TABLE_KEYS_CURSOR[INTEGER,XPLAIN_TYPE]*/
void r687make(T687* C,T0* a1);
/*SPECIAL[XPLAIN_I_NODE]*/
void r317make(T317* C,T2 a1);
/*SPECIAL[XPLAIN_I_NODE]*/
T0* r317resize(T317* C,T2 a1);
/*SPECIAL[XPLAIN_I_NODE]*/
void r317array_resize(T317* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_SORT_NODE]*/
T0* r720make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_SORT_NODE]*/
T0* r720resize(T0* a1,T2 a2);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME]*/
T0* r745cursor_item(T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME]*/
void r745remove_traversing_cursor(T745* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME]*/
void r745add_traversing_cursor(T745* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME]*/
T6 r745after(T745* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME]*/
void r745make(T745* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME]*/
T0* r745item_for_iteration(T745* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME]*/
T6 r745cursor_after(T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME]*/
void r745cursor_forth(T745* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME]*/
void r745cursor_start(T745* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME]*/
T0* r745new_cursor(T745* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME]*/
void r745put_last(T745* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME]*/
T6 r745cursor_off(T0* a1);
/*SPECIAL[XPLAIN_EXPRESSION]*/
void r303make(T303* C,T2 a1);
/*SPECIAL[XPLAIN_EXPRESSION]*/
T0* r303resize(T303* C,T2 a1);
/*SPECIAL[XPLAIN_EXPRESSION]*/
void r303array_resize(T303* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_VALUE]*/
T0* r707make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_VALUE]*/
T0* r707resize(T0* a1,T2 a2);
/*FAST_ARRAY[STRING]*/
void r347make(T347* C,T2 a1);
/*SPECIAL[XPLAIN_CASCADE_STATEMENT]*/
void r137make(T137* C,T2 a1);
/*SPECIAL[XPLAIN_CASCADE_STATEMENT]*/
T0* r137resize(T137* C,T2 a1);
/*SPECIAL[XPLAIN_CASCADE_STATEMENT]*/
void r137array_resize(T137* C,T2 a1);
/*SPECIAL[XPLAIN_ATTRIBUTE_NODE]*/
void r256make(T256* C,T2 a1);
/*SPECIAL[XPLAIN_ATTRIBUTE_NODE]*/
T0* r256resize(T256* C,T2 a1);
/*SPECIAL[XPLAIN_ATTRIBUTE_NODE]*/
void r256array_resize(T256* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_ABSTRACT_OBJECT]*/
T0* r539make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_ABSTRACT_OBJECT]*/
T0* r539resize(T0* a1,T2 a2);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME_NODE]*/
T0* r660cursor_item(T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r660remove_traversing_cursor(T660* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r660add_traversing_cursor(T660* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME_NODE]*/
T6 r660after(T660* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r660make(T660* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME_NODE]*/
T0* r660item_for_iteration(T660* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME_NODE]*/
T6 r660cursor_after(T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r660cursor_forth(T660* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r660cursor_start(T660* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME_NODE]*/
T0* r660new_cursor(T660* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r660put_last(T660* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE_NAME_NODE]*/
T6 r660cursor_off(T0* a1);
/*DS_LINKED_STACK[STRING]*/
void r862wipe_out(T862* C);
/*DS_LINKED_STACK[STRING]*/
void r862put(T862* C,T0* a1);
/*DS_LINKED_STACK[STRING]*/
void r862remove(T862* C);
/*SPECIAL[XPLAIN_PROCEDURE_STATEMENT]*/
void r105make(T105* C,T2 a1);
/*SPECIAL[XPLAIN_PROCEDURE_STATEMENT]*/
T0* r105resize(T105* C,T2 a1);
/*SPECIAL[XPLAIN_PROCEDURE_STATEMENT]*/
void r105array_resize(T105* C,T2 a1);
/*SPECIAL[XPLAIN_STATEMENT_NODE]*/
void r161make(T161* C,T2 a1);
/*SPECIAL[XPLAIN_STATEMENT_NODE]*/
T0* r161resize(T161* C,T2 a1);
/*SPECIAL[XPLAIN_STATEMENT_NODE]*/
void r161array_resize(T161* C,T2 a1);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
void r504cursor_back(T504* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
T0* r504cursor_item(T0* a1);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
void r504remove_traversing_cursor(T504* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
void r504add_traversing_cursor(T504* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
T6 r504after(T504* C);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
T6 r504cursor_before(T0* a1);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
void r504make(T504* C);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
T0* r504item_for_iteration(T504* C);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
void r504forth(T504* C);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
T6 r504cursor_after(T0* a1);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
void r504cursor_finish(T504* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
void r504start(T504* C);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
void r504cursor_forth(T504* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
void r504put_first(T504* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
void r504cursor_start(T504* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
T0* r504new_cursor(T504* C);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
T6 r504cursor_is_first(T504* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_STATEMENT]*/
T6 r504cursor_off(T0* a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_SQL_STATEMENT]*/
T0* r760make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_SQL_STATEMENT]*/
T0* r760resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_A_NODE]*/
T0* r565make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_A_NODE]*/
T0* r565resize(T0* a1,T2 a2);
/*DS_SPARSE_TABLE_KEYS[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r522make(T522* C,T0* a1);
/*DS_SPARSE_TABLE_KEYS[XPLAIN_ABSTRACT_OBJECT,STRING]*/
T0* r522new_cursor(T522* C);
/*SPECIAL[XPLAIN_DELETE_STATEMENT]*/
void r123make(T123* C,T2 a1);
/*SPECIAL[XPLAIN_DELETE_STATEMENT]*/
T0* r123resize(T123* C,T2 a1);
/*SPECIAL[XPLAIN_DELETE_STATEMENT]*/
void r123array_resize(T123* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_ASSIGNMENT_NODE]*/
T0* r633make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_ASSIGNMENT_NODE]*/
T0* r633resize(T0* a1,T2 a2);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
void r730cursor_back(T730* C,T0* a1);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
T0* r730cursor_item(T0* a1);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
void r730remove_traversing_cursor(T730* C,T0* a1);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
void r730add_traversing_cursor(T730* C,T0* a1);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
T6 r730after(T730* C);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
T6 r730cursor_before(T0* a1);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
void r730make(T730* C);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
T0* r730item_for_iteration(T730* C);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
T6 r730cursor_after(T0* a1);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
void r730cursor_finish(T730* C,T0* a1);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
void r730cursor_forth(T730* C,T0* a1);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
void r730put_first(T730* C,T0* a1);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
void r730cursor_start(T730* C,T0* a1);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
T0* r730new_cursor(T730* C);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
T6 r730cursor_is_first(T730* C,T0* a1);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
void r730put_last(T730* C,T0* a1);
/*DS_BILINKED_LIST[XPLAIN_STATEMENT]*/
T6 r730cursor_off(T0* a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_SELECTION_FUNCTION]*/
T0* r711make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_SELECTION_FUNCTION]*/
T0* r711resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_VALUE_STATEMENT]*/
T0* r697make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_VALUE_STATEMENT]*/
T0* r697resize(T0* a1,T2 a2);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516make_key_storage(T516* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
T2 r516new_capacity(T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516force(T516* C,T0* a1,T0* a2);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516make_clashes(T516* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516search_position(T516* C,T0* a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516remove_found_item(T516* C);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516make_item_storage(T516* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516remove_position(T516* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516make(T516* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516internal_set_key_equality_tester(T516* C,T0* a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516item_storage_resize(T516* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
T6 r516has(T516* C,T0* a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
T2 r516hash_position(T516* C,T0* a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516move_cursors_after(T516* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516resize(T516* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
T0* r516found_item(T516* C);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516make_with_equality_testers(T516* C,T2 a1,T0* a2,T0* a3);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516make_sparse_container(T516* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516move_cursors_forth(T516* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516search(T516* C,T0* a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516clashes_resize(T516* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516slots_resize(T516* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
T0* r516new_cursor(T516* C);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516make_slots(T516* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516move_all_cursors(T516* C,T2 a1,T2 a2);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
T2 r516new_modulus(T2 a1);
/*DS_HASH_TABLE[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r516key_storage_resize(T516* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_EXPRESSION_NODE]*/
T0* r727make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_EXPRESSION_NODE]*/
T0* r727resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_SUBJECT]*/
T0* r695make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_SUBJECT]*/
T0* r695resize(T0* a1,T2 a2);
/*KL_ARRAY_ROUTINES[INTEGER]*/
void r767subcopy(T0* a1,T0* a2,T2 a3,T2 a4,T2 a5);
/*KL_SPECIAL_ROUTINES[XPLAIN_LOGICAL_EXPRESSION]*/
T0* r573make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_LOGICAL_EXPRESSION]*/
T0* r573resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_EXPRESSION_NODE]*/
void r167make(T167* C,T2 a1);
/*SPECIAL[XPLAIN_EXPRESSION_NODE]*/
T0* r167resize(T167* C,T2 a1);
/*SPECIAL[XPLAIN_EXPRESSION_NODE]*/
void r167array_resize(T167* C,T2 a1);
/*SPECIAL[XPLAIN_EXTEND_STATEMENT]*/
void r117make(T117* C,T2 a1);
/*SPECIAL[XPLAIN_EXTEND_STATEMENT]*/
T0* r117resize(T117* C,T2 a1);
/*SPECIAL[XPLAIN_EXTEND_STATEMENT]*/
void r117array_resize(T117* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_TYPE_STATEMENT]*/
T0* r550make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_TYPE_STATEMENT]*/
T0* r550resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_LOGICAL_VALUE_EXPRESSION]*/
void r298make(T298* C,T2 a1);
/*SPECIAL[XPLAIN_LOGICAL_VALUE_EXPRESSION]*/
T0* r298resize(T298* C,T2 a1);
/*SPECIAL[XPLAIN_LOGICAL_VALUE_EXPRESSION]*/
void r298array_resize(T298* C,T2 a1);
/*SPECIAL[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r285make(T285* C,T2 a1);
/*SPECIAL[XPLAIN_ATTRIBUTE_NAME_NODE]*/
T0* r285resize(T285* C,T2 a1);
/*SPECIAL[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r285array_resize(T285* C,T2 a1);
/*SPECIAL[XPLAIN_ASSIGNMENT_NODE]*/
void r238make(T238* C,T2 a1);
/*SPECIAL[XPLAIN_ASSIGNMENT_NODE]*/
T0* r238resize(T238* C,T2 a1);
/*SPECIAL[XPLAIN_ASSIGNMENT_NODE]*/
void r238array_resize(T238* C,T2 a1);
/*DS_CELL[DOUBLE]*/
T0* r825out(T825* C);
/*DS_CELL[DOUBLE]*/
T6 r825is_equal(T825* C,T0* a1);
/*DS_CELL[DOUBLE]*/
void r825out_in_tagged_out_memory(T825* C);
/*SPECIAL[XPLAIN_TYPE_STATEMENT]*/
void r93make(T93* C,T2 a1);
/*SPECIAL[XPLAIN_TYPE_STATEMENT]*/
T0* r93resize(T93* C,T2 a1);
/*SPECIAL[XPLAIN_TYPE_STATEMENT]*/
void r93array_resize(T93* C,T2 a1);
/*SPECIAL[XPLAIN_SYSTEM_EXPRESSION]*/
void r292make(T292* C,T2 a1);
/*SPECIAL[XPLAIN_SYSTEM_EXPRESSION]*/
T0* r292resize(T292* C,T2 a1);
/*SPECIAL[XPLAIN_SYSTEM_EXPRESSION]*/
void r292array_resize(T292* C,T2 a1);
/*SPECIAL[XPLAIN_SELECTION]*/
void r191make(T191* C,T2 a1);
/*SPECIAL[XPLAIN_SELECTION]*/
T0* r191resize(T191* C,T2 a1);
/*SPECIAL[XPLAIN_SELECTION]*/
void r191array_resize(T191* C,T2 a1);
/*XPLAIN_INIT_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r833ds_make(T833* C,T0* a1);
/*XPLAIN_INIT_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
T6 r833is_initialized_attribute(T833* C);
/*XPLAIN_INIT_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r833set(T833* C,T0* a1,T6 a2,T6 a3);
/*XPLAIN_INIT_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
T6 r833is_last(T833* C);
/*XPLAIN_INIT_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r833forth(T833* C);
/*XPLAIN_INIT_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r833_404Pforth(T833* C);
/*XPLAIN_INIT_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r833start(T833* C);
/*XPLAIN_INIT_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r833set_after(T833* C);
/*XPLAIN_INIT_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r833_404Pstart(T833* C);
/*SPECIAL[XPLAIN_GET_STATEMENT]*/
void r111make(T111* C,T2 a1);
/*SPECIAL[XPLAIN_GET_STATEMENT]*/
T0* r111resize(T111* C,T2 a1);
/*SPECIAL[XPLAIN_GET_STATEMENT]*/
void r111array_resize(T111* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_EXTENSION_EXPRESSION]*/
T0* r717make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_EXTENSION_EXPRESSION]*/
T0* r717resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_EXTENSION_EXPRESSION]*/
void r197make(T197* C,T2 a1);
/*SPECIAL[XPLAIN_EXTENSION_EXPRESSION]*/
T0* r197resize(T197* C,T2 a1);
/*SPECIAL[XPLAIN_EXTENSION_EXPRESSION]*/
void r197array_resize(T197* C,T2 a1);
/*SPECIAL[XPLAIN_SELECTION_LIST]*/
void r186make(T186* C,T2 a1);
/*SPECIAL[XPLAIN_SELECTION_LIST]*/
T0* r186resize(T186* C,T2 a1);
/*SPECIAL[XPLAIN_SELECTION_LIST]*/
void r186array_resize(T186* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_PROCEDURE_STATEMENT]*/
T0* r758make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_PROCEDURE_STATEMENT]*/
T0* r758resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_ATTRIBUTE_NAME_NODE]*/
T0* r605make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_ATTRIBUTE_NAME_NODE]*/
T0* r605resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_CASCADE_FUNCTION_EXPRESSION]*/
void r131make(T131* C,T2 a1);
/*SPECIAL[XPLAIN_CASCADE_FUNCTION_EXPRESSION]*/
T0* r131resize(T131* C,T2 a1);
/*SPECIAL[XPLAIN_CASCADE_FUNCTION_EXPRESSION]*/
void r131array_resize(T131* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_EXTEND_ATTRIBUTE]*/
T0* r716make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_EXTEND_ATTRIBUTE]*/
T0* r716resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_LOGICAL_VALUE_EXPRESSION]*/
T0* r588make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_LOGICAL_VALUE_EXPRESSION]*/
T0* r588resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_STATEMENT_NODE]*/
T0* r759make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_STATEMENT_NODE]*/
T0* r759resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_EXPRESSION]*/
T0* r574make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_EXPRESSION]*/
T0* r574resize(T0* a1,T2 a2);
/*DS_SPARSE_TABLE_CURSOR[XPLAIN_VALUE,STRING]*/
void r783make(T783* C,T0* a1);
/*DS_SPARSE_TABLE_CURSOR[INTEGER,XPLAIN_TYPE]*/
void r688make(T688* C,T0* a1);
/*DS_SPARSE_TABLE_KEYS_CURSOR[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r524make(T524* C,T0* a1);
/*DS_CELL[INTEGER]*/
T0* r501out(T501* C);
/*DS_CELL[INTEGER]*/
T6 r501is_equal(T501* C,T0* a1);
/*DS_CELL[INTEGER]*/
void r501out_in_tagged_out_memory(T501* C);
/*SPECIAL[XPLAIN_VALUE_STATEMENT]*/
void r81make(T81* C,T2 a1);
/*SPECIAL[XPLAIN_VALUE_STATEMENT]*/
T0* r81resize(T81* C,T2 a1);
/*SPECIAL[XPLAIN_VALUE_STATEMENT]*/
void r81array_resize(T81* C,T2 a1);
/*SPECIAL[XPLAIN_UPDATE_STATEMENT]*/
void r87make(T87* C,T2 a1);
/*SPECIAL[XPLAIN_UPDATE_STATEMENT]*/
T0* r87resize(T87* C,T2 a1);
/*SPECIAL[XPLAIN_UPDATE_STATEMENT]*/
void r87array_resize(T87* C,T2 a1);
/*SPECIAL[XPLAIN_ASSERTION]*/
void r244make(T244* C,T2 a1);
/*SPECIAL[XPLAIN_ASSERTION]*/
T0* r244resize(T244* C,T2 a1);
/*SPECIAL[XPLAIN_ASSERTION]*/
void r244array_resize(T244* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_SELECTION_LIST]*/
T0* r719make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_SELECTION_LIST]*/
T0* r719resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_FUNCTION]*/
T0* r721make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_FUNCTION]*/
T0* r721resize(T0* a1,T2 a2);
/*DS_LINKED_LIST_CURSOR[XPLAIN_STATEMENT]*/
void r741set(T741* C,T0* a1,T6 a2,T6 a3);
/*DS_LINKED_LIST_CURSOR[XPLAIN_STATEMENT]*/
void r741back(T741* C);
/*DS_LINKED_LIST_CURSOR[XPLAIN_STATEMENT]*/
T0* r741item(T741* C);
/*DS_LINKED_LIST_CURSOR[XPLAIN_STATEMENT]*/
T6 r741is_first(T741* C);
/*DS_LINKED_LIST_CURSOR[XPLAIN_STATEMENT]*/
void r741make(T741* C,T0* a1);
/*DS_LINKED_LIST_CURSOR[XPLAIN_STATEMENT]*/
void r741forth(T741* C);
/*DS_LINKED_LIST_CURSOR[XPLAIN_STATEMENT]*/
void r741start(T741* C);
/*DS_LINKED_LIST_CURSOR[XPLAIN_STATEMENT]*/
void r741finish(T741* C);
/*DS_LINKED_LIST_CURSOR[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r669set(T669* C,T0* a1,T6 a2,T6 a3);
/*DS_LINKED_LIST_CURSOR[XPLAIN_ATTRIBUTE_NAME_NODE]*/
void r669make(T669* C,T0* a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_BASE]*/
T0* r547make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_BASE]*/
T0* r547resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_LOGICAL_EXPRESSION]*/
void r310make(T310* C,T2 a1);
/*SPECIAL[XPLAIN_LOGICAL_EXPRESSION]*/
T0* r310resize(T310* C,T2 a1);
/*SPECIAL[XPLAIN_LOGICAL_EXPRESSION]*/
void r310array_resize(T310* C,T2 a1);
/*SPECIAL[XPLAIN_VALUE_SELECTION_STATEMENT]*/
void r77make(T77* C,T2 a1);
/*SPECIAL[XPLAIN_VALUE_SELECTION_STATEMENT]*/
T0* r77resize(T77* C,T2 a1);
/*SPECIAL[XPLAIN_VALUE_SELECTION_STATEMENT]*/
void r77array_resize(T77* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_SYSTEM_EXPRESSION]*/
T0* r589make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_SYSTEM_EXPRESSION]*/
T0* r589resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_ATTRIBUTE]*/
void r250make(T250* C,T2 a1);
/*SPECIAL[XPLAIN_ATTRIBUTE]*/
T0* r250resize(T250* C,T2 a1);
/*SPECIAL[XPLAIN_ATTRIBUTE]*/
void r250array_resize(T250* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_ATTRIBUTE_NODE]*/
T0* r623make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_ATTRIBUTE_NODE]*/
T0* r623resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_CASCADE_FUNCTION_EXPRESSION]*/
T0* r641make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_CASCADE_FUNCTION_EXPRESSION]*/
T0* r641resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_SELECTION]*/
T0* r718make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_SELECTION]*/
T0* r718resize(T0* a1,T2 a2);
/*DS_HASH_TABLE_CURSOR[XPLAIN_VALUE,STRING]*/
void r791make(T791* C,T0* a1);
/*SPECIAL[XPLAIN_SELECTION_FUNCTION]*/
void r220make(T220* C,T2 a1);
/*SPECIAL[XPLAIN_SELECTION_FUNCTION]*/
T0* r220resize(T220* C,T2 a1);
/*SPECIAL[XPLAIN_SELECTION_FUNCTION]*/
void r220array_resize(T220* C,T2 a1);
/*SPECIAL[XPLAIN_ABSTRACT_OBJECT]*/
void r540make(T540* C,T2 a1);
/*SPECIAL[XPLAIN_ABSTRACT_OBJECT]*/
T0* r540resize(T540* C,T2 a1);
/*SPECIAL[XPLAIN_ABSTRACT_OBJECT]*/
void r540array_resize(T540* C,T2 a1);
/*SPECIAL[STRING]*/
void r345make(T345* C,T2 a1);
/*SPECIAL[STRING]*/
T0* r345resize(T345* C,T2 a1);
/*SPECIAL[STRING]*/
void r345array_resize(T345* C,T2 a1);
/*DS_LINKED_LIST_CURSOR[XPLAIN_ATTRIBUTE_NAME]*/
void r756set(T756* C,T0* a1,T6 a2,T6 a3);
/*DS_LINKED_LIST_CURSOR[XPLAIN_ATTRIBUTE_NAME]*/
void r756make(T756* C,T0* a1);
/*SPECIAL[XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT]*/
void r143make(T143* C,T2 a1);
/*SPECIAL[XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT]*/
T0* r143resize(T143* C,T2 a1);
/*SPECIAL[XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT]*/
void r143array_resize(T143* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_GET_STATEMENT]*/
T0* r712make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_GET_STATEMENT]*/
T0* r712resize(T0* a1,T2 a2);
/*XPLAIN_ALL_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r434ds_make(T434* C,T0* a1);
/*XPLAIN_ALL_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r434set(T434* C,T0* a1,T6 a2,T6 a3);
/*XPLAIN_ALL_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
T6 r434is_last(T434* C);
/*XPLAIN_ALL_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r434make(T434* C,T0* a1,T0* a2);
/*XPLAIN_ALL_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r434forth(T434* C);
/*XPLAIN_ALL_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
T6 r434is_generated_attribute(T434* C);
/*XPLAIN_ALL_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r434_404Pforth(T434* C);
/*XPLAIN_ALL_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r434start(T434* C);
/*XPLAIN_ALL_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r434set_after(T434* C);
/*XPLAIN_ALL_ATTRIBUTES_CURSOR[XPLAIN_ATTRIBUTE]*/
void r434_404Pstart(T434* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431set_last_cell(T431* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431wipe_out(T431* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431remove_first(T431* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
T0* r431cursor_item(T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
T6 r431cursor_is_last(T431* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431remove_traversing_cursor(T431* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431move_all_cursors_after(T431* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431add_traversing_cursor(T431* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
T6 r431after(T431* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431make(T431* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
T0* r431item_for_iteration(T431* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431remove_last(T431* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
T6 r431cursor_after(T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431cursor_forth(T431* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431move_last_cursors_after(T431* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431delete(T431* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431cursor_start(T431* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
T0* r431new_cursor(T431* C);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
T6 r431cursor_is_first(T431* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431remove_at_cursor(T431* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431put_last(T431* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
void r431move_all_cursors(T431* C,T0* a1,T0* a2);
/*DS_LINKED_LIST[XPLAIN_ATTRIBUTE]*/
T6 r431cursor_off(T0* a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_ASSERTION]*/
T0* r629make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_ASSERTION]*/
T0* r629resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_SUBJECT]*/
void r226make(T226* C,T2 a1);
/*SPECIAL[XPLAIN_SUBJECT]*/
T0* r226resize(T226* C,T2 a1);
/*SPECIAL[XPLAIN_SUBJECT]*/
void r226array_resize(T226* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_VALUE_SELECTION_STATEMENT]*/
T0* r710make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_VALUE_SELECTION_STATEMENT]*/
T0* r710resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_REPRESENTATION]*/
void r268make(T268* C,T2 a1);
/*SPECIAL[XPLAIN_REPRESENTATION]*/
T0* r268resize(T268* C,T2 a1);
/*SPECIAL[XPLAIN_REPRESENTATION]*/
void r268array_resize(T268* C,T2 a1);
/*SPECIAL[XPLAIN_TYPE]*/
void r273make(T273* C,T2 a1);
/*SPECIAL[XPLAIN_TYPE]*/
T0* r273resize(T273* C,T2 a1);
/*SPECIAL[XPLAIN_TYPE]*/
void r273array_resize(T273* C,T2 a1);
/*SPECIAL[XPLAIN_EXTENSION]*/
void r213make(T213* C,T2 a1);
/*SPECIAL[XPLAIN_EXTENSION]*/
T0* r213resize(T213* C,T2 a1);
/*SPECIAL[XPLAIN_EXTENSION]*/
void r213array_resize(T213* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_I_NODE]*/
T0* r566make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_I_NODE]*/
T0* r566resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_ASSIGNMENT]*/
void r232make(T232* C,T2 a1);
/*SPECIAL[XPLAIN_ASSIGNMENT]*/
T0* r232resize(T232* C,T2 a1);
/*SPECIAL[XPLAIN_ASSIGNMENT]*/
void r232array_resize(T232* C,T2 a1);
/*DS_SPARSE_TABLE_KEYS_CURSOR[XPLAIN_VALUE,STRING]*/
void r782make(T782* C,T0* a1);
/*DS_SPARSE_TABLE_CURSOR[XPLAIN_ABSTRACT_OBJECT,STRING]*/
void r532make(T532* C,T0* a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_ATTRIBUTE]*/
T0* r624make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_ATTRIBUTE]*/
T0* r624resize(T0* a1,T2 a2);
/*DS_LINKED_LIST_CURSOR[XPLAIN_SCANNER_STATE]*/
void r414set(T414* C,T0* a1,T6 a2,T6 a3);
/*DS_LINKED_LIST_CURSOR[XPLAIN_SCANNER_STATE]*/
T6 r414is_first(T414* C);
/*DS_LINKED_LIST_CURSOR[XPLAIN_SCANNER_STATE]*/
void r414make(T414* C,T0* a1);
/*DS_LINKED_LIST_CURSOR[XPLAIN_SCANNER_STATE]*/
void r414set_after(T414* C);
/*SPECIAL[XPLAIN_ATTRIBUTE_NAME]*/
void r279make(T279* C,T2 a1);
/*SPECIAL[XPLAIN_ATTRIBUTE_NAME]*/
T0* r279resize(T279* C,T2 a1);
/*SPECIAL[XPLAIN_ATTRIBUTE_NAME]*/
void r279array_resize(T279* C,T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_CASCADE_STATEMENT]*/
T0* r640make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_CASCADE_STATEMENT]*/
T0* r640resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[INTEGER]*/
T0* r358make(T2 a1);
/*KL_SPECIAL_ROUTINES[INTEGER]*/
T0* r358make_from_array(T0* a1);
/*KL_SPECIAL_ROUTINES[INTEGER]*/
T0* r358resize(T0* a1,T2 a2);
/*KL_SPECIAL_ROUTINES[INTEGER]*/
T0* r358to_special(T0* a1);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
void r379set_last_cell(T379* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
void r379wipe_out(T379* C);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
void r379cursor_back(T379* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
T0* r379cursor_item(T0* a1);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
void r379remove_traversing_cursor(T379* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
void r379move_all_cursors_after(T379* C);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
void r379add_traversing_cursor(T379* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
T6 r379cursor_before(T0* a1);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
void r379make(T379* C);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
void r379remove_last(T379* C);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
void r379cursor_finish(T379* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
void r379move_last_cursors_after(T379* C);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
T0* r379new_cursor(T379* C);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
T6 r379cursor_is_first(T379* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
void r379put_last(T379* C,T0* a1);
/*DS_LINKED_LIST[XPLAIN_SCANNER_STATE]*/
T6 r379cursor_off(T0* a1);
/*DS_LINKED_LIST_CURSOR[JOIN_TREE_NODE]*/
void r656set(T656* C,T0* a1,T6 a2,T6 a3);
/*DS_LINKED_LIST_CURSOR[JOIN_TREE_NODE]*/
void r656make(T656* C,T0* a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT]*/
T0* r508make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT]*/
T0* r508resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_A_NODE]*/
void r323make(T323* C,T2 a1);
/*SPECIAL[XPLAIN_A_NODE]*/
T0* r323resize(T323* C,T2 a1);
/*SPECIAL[XPLAIN_A_NODE]*/
void r323array_resize(T323* C,T2 a1);
/*KL_SPECIAL_ROUTINES[STRING]*/
T0* r357make(T2 a1);
/*KL_SPECIAL_ROUTINES[STRING]*/
T0* r357resize(T0* a1,T2 a2);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698make_key_storage(T698* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
T2 r698new_capacity(T2 a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698force(T698* C,T0* a1,T0* a2);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698wipe_out(T698* C);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698make_clashes(T698* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698search_position(T698* C,T0* a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
T0* r698item(T698* C,T0* a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698move_all_cursors_after(T698* C);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698make_item_storage(T698* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698set_key_equality_tester(T698* C,T0* a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698key_storage_wipe_out(T698* C);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698slots_wipe_out(T698* C);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698make(T698* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698clashes_wipe_out(T698* C);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698item_storage_resize(T698* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698item_storage_wipe_out(T698* C);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
T6 r698has(T698* C,T0* a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
T2 r698hash_position(T698* C,T0* a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698make_with_equality_testers(T698* C,T2 a1,T0* a2,T0* a3);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698resize(T698* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698make_sparse_container(T698* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698clashes_resize(T698* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698slots_resize(T698* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
T0* r698new_cursor(T698* C);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698make_slots(T698* C,T2 a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
T2 r698new_modulus(T2 a1);
/*DS_HASH_TABLE[XPLAIN_VALUE,STRING]*/
void r698key_storage_resize(T698* C,T2 a1);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673make_key_storage(T673* C,T2 a1);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673wipe_out(T673* C);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673make_clashes(T673* C,T2 a1);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673put(T673* C,T2 a1,T0* a2);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673search_position(T673* C,T0* a1);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673move_all_cursors_after(T673* C);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673make_item_storage(T673* C,T2 a1);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673key_storage_wipe_out(T673* C);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673slots_wipe_out(T673* C);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673make(T673* C,T2 a1);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673clashes_wipe_out(T673* C);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673item_storage_wipe_out(T673* C);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
T2 r673hash_position(T673* C,T0* a1);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
T2 r673found_item(T673* C);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673make_with_equality_testers(T673* C,T2 a1,T0* a2,T0* a3);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673make_sparse_container(T673* C,T2 a1);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673search(T673* C,T0* a1);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
T0* r673new_cursor(T673* C);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673make_slots(T673* C,T2 a1);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
T2 r673new_modulus(T2 a1);
/*DS_HASH_TABLE[INTEGER,XPLAIN_TYPE]*/
void r673replace(T673* C,T2 a1,T0* a2);
/*KL_SPECIAL_ROUTINES[XPLAIN_DOMAIN_RESTRICTION]*/
T0* r558make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_DOMAIN_RESTRICTION]*/
T0* r558resize(T0* a1,T2 a2);
/*SPECIAL[XPLAIN_CONSTANT_STATEMENT]*/
void r149make(T149* C,T2 a1);
/*SPECIAL[XPLAIN_CONSTANT_STATEMENT]*/
T0* r149resize(T149* C,T2 a1);
/*SPECIAL[XPLAIN_CONSTANT_STATEMENT]*/
void r149array_resize(T149* C,T2 a1);
/*DS_LINKED_LIST[JOIN_TREE_NODE]*/
T0* r647cursor_item(T0* a1);
/*DS_LINKED_LIST[JOIN_TREE_NODE]*/
void r647remove_traversing_cursor(T647* C,T0* a1);
/*DS_LINKED_LIST[JOIN_TREE_NODE]*/
void r647add_traversing_cursor(T647* C,T0* a1);
/*DS_LINKED_LIST[JOIN_TREE_NODE]*/
T6 r647after(T647* C);
/*DS_LINKED_LIST[JOIN_TREE_NODE]*/
void r647make(T647* C);
/*DS_LINKED_LIST[JOIN_TREE_NODE]*/
T0* r647item_for_iteration(T647* C);
/*DS_LINKED_LIST[JOIN_TREE_NODE]*/
T6 r647cursor_after(T0* a1);
/*DS_LINKED_LIST[JOIN_TREE_NODE]*/
void r647cursor_forth(T647* C,T0* a1);
/*DS_LINKED_LIST[JOIN_TREE_NODE]*/
void r647cursor_start(T647* C,T0* a1);
/*DS_LINKED_LIST[JOIN_TREE_NODE]*/
T0* r647new_cursor(T647* C);
/*DS_LINKED_LIST[JOIN_TREE_NODE]*/
void r647put_last(T647* C,T0* a1);
/*DS_LINKED_LIST[JOIN_TREE_NODE]*/
T6 r647cursor_off(T0* a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_CONSTANT_STATEMENT]*/
T0* r555make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_CONSTANT_STATEMENT]*/
T0* r555resize(T0* a1,T2 a2);
/*DS_ARRAYED_LIST[INTEGER]*/
T2 r485new_capacity(T2 a1);
/*DS_ARRAYED_LIST[INTEGER]*/
void r485clear_items(T485* C,T2 a1,T2 a2);
/*DS_ARRAYED_LIST[INTEGER]*/
T6 r485extendible(T485* C,T2 a1);
/*DS_ARRAYED_LIST[INTEGER]*/
void r485wipe_out(T485* C);
/*DS_ARRAYED_LIST[INTEGER]*/
void r485move_all_cursors_after(T485* C);
/*DS_ARRAYED_LIST[INTEGER]*/
void r485make(T485* C,T2 a1);
/*DS_ARRAYED_LIST[INTEGER]*/
void r485resize(T485* C,T2 a1);
/*DS_ARRAYED_LIST[INTEGER]*/
void r485force_last(T485* C,T2 a1);
/*DS_ARRAYED_LIST[INTEGER]*/
T0* r485new_cursor(T485* C);
/*KL_SPECIAL_ROUTINES[XPLAIN_EXTEND_STATEMENT]*/
T0* r713make(T2 a1);
/*KL_SPECIAL_ROUTINES[XPLAIN_EXTEND_STATEMENT]*/
T0* r713resize(T0* a1,T2 a2);
/*XPLAIN_ASSIGNMENT_NODE*/
void r237make(T237* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS97*/
void r803drop_value(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_extend(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803datatype_text(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803drop_table(T803* C,T0* a1);
extern T0*oBC25sqlsysfunction_system_user;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803no_space_identifier(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803write_drop(T803* C,T0* a1);
extern T0*oBC16scientific_formatter;
extern int fBC16scientific_formatter;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803scientific_formatter(void);
extern T6 oBC25domainchecksupported;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlcolumnrequired_base(T803* C,T0* a1);
extern T6 oBC804temporarytablessupported;
/*SQL_GENERATOR_MSACCESS97*/
void r803write_procedure(T0* a1);
extern T0*oBC25value_representation_system_user;
extern int fBC25value_representation_system_user;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803value_representation_system_user(T803* C);
extern T6 oBC25constraintnamesupported;
extern T0*oBC25multilinecommentpostfix;
extern T0*oBC25sql_select_function_limit_after;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803datatype_ref_int(T803* C,T0* a1);
extern T0*oBC25sqlfunction_some;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803do_sql_cast_to_real(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_extension_function(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_value_alter_table(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T6 r803init_necessary(T0* a1);
extern T0*oBC22std;
/*SQL_GENERATOR_MSACCESS97*/
void r803do_do_create_select_list(T803* C,T0* a1,T6 a2);
extern T6 oBC25columnnullallowed;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803value_representation_float(T803* C);
/*SQL_GENERATOR_MSACCESS97*/
T6 r803table_has_auto_pk(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803make_valid_identifier(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803columndatatype_type(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_get_insert(T803* C,T0* a1,T0* a2,T6 a3,T0* a4);
extern T6 oBC25viewssupported;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlcolumnidentifier_type(T803* C,T0* a1,T0* a2);
extern T0*oBC25tabtab;
extern int fBC25tabtab;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803tabtab(void);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_last_auto_generated_primary_key(T0* a1);
extern T0*oBC25sqlfunction_max;
/*SQL_GENERATOR_MSACCESS97*/
void r803write_select(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_value_declare_outside_sp(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803drop_procedure(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803write_assertion(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803datatype_datetime(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803datatype_varchar(T0* a1);
extern T0*oBC25value_representation_text;
extern int fBC25value_representation_text;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803value_representation_text(T803* C);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803datatype_boolean(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803make_valid_constraint_identifier(T0* a1);
extern T6 oBC803uniqueconstraintsupported;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_infix_expression(T803* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlcolumnconstraint_type(T803* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803quoted_value_identifier(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803datatype_pk_int(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_predicate(T803* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS97*/
void r803drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_cast_to_date(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803table_name(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803drop_domain(T803* C,T0* a1);
extern T6 oBC25dropcolumnsupported;
extern T6 oBC25columnnulldefault;
extern T0*oBC25sqlfunction_min;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803temporarytableprefix(void);
extern T6 oBC25existentialfromneeded;
extern T6 oBC25indexsupported;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803assertion_name(T0* a1);
extern T0*oBC25sqlfalse;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlcolumndefault_type(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_select_value(T803* C,T0* a1);
extern T6 oBC25createautoprimarykey;
extern int fBC25createautoprimarykey;
/*SQL_GENERATOR_MSACCESS97*/
T6 r803createautoprimarykey(T803* C);
extern T6 oBC25domainnullallowed;
/*SQL_GENERATOR_MSACCESS97*/
void r803create_select_function(T803* C,T0* a1);
extern T0*oBC25domainnameprefix;
extern T6 oBC25expressionsindefaultclausesupported;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_infix_expression_as_wildcard(T803* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_select_function_as_subselect(T803* C,T0* a1);
extern T6 oBC804autoprimarykeysupported;
/*SQL_GENERATOR_MSACCESS97*/
void r803create_extend_create_table(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_cast_to_string(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_select_function_as_left_outer_join(T803* C,T0* a1);
extern T0*oBC803target_name;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803do_sql_cast_to_integer(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803do_sql_select_for_extension_function(T803* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803_24Pdatatype_ref_int(T0* a1);
extern T0*oBC25sqlfunction_nil;
extern int fBC25sqlfunction_nil;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlfunction_nil(void);
/*SQL_GENERATOR_MSACCESS97*/
void r803write_init(T0* a1);
extern T6 oBC25createassert;
extern int fBC25createassert;
/*SQL_GENERATOR_MSACCESS97*/
T6 r803createassert(T803* C);
/*SQL_GENERATOR_MSACCESS97*/
void r803write_base(T803* C,T0* a1);
extern T0*oBC25value_representation_money;
extern int fBC25value_representation_money;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803value_representation_money(T803* C);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_select_joins(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_update(T803* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_index(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlgetvalue_outside_sp(T803* C,T0* a1);
extern T0*oBC25sql_string_combine_end;
extern T0*oBC25constraint_names;
extern int fBC25constraint_names;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803constraint_names(void);
extern T0*oBC25createviewsql;
extern T6 oBC25createdomaincheck;
extern int fBC25createdomaincheck;
/*SQL_GENERATOR_MSACCESS97*/
T6 r803createdomaincheck(T803* C);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_select_for_extension_function(T803* C,T0* a1,T0* a2);
extern T6 oBC25timestampsupported;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803datatype_pk_char(T0* a1);
extern T0*oBC25tablenameprefix;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_combine_expression(T803* C,T0* a1);
extern T0*oBC25value_representation_current_timestamp;
extern int fBC25value_representation_current_timestamp;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803value_representation_current_timestamp(T803* C);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803as_string(T0* a1);
extern T0*oBC25sql_string_combine_start;
/*SQL_GENERATOR_MSACCESS97*/
void r803echo(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803datatype_char(T0* a1);
extern T6 oBC25domainnulldefault;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlgetconstant(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803columndatatype_base(T803* C,T0* a1);
extern T6 oBC24calculatedcolumnssupported;
/*SQL_GENERATOR_MSACCESS97*/
void r803write_extend(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T6 r803createviews(T803* C);
extern T0*oBC25sql_select_function_limit_before;
extern T6 oBC804checkconstraintsupported;
/*SQL_GENERATOR_MSACCESS97*/
void r803write_index(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803constant_identifier(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_value_assign_outside_sp(T803* C,T0* a1);
extern T0*oBC25sql_string_combine_separator;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803datatype_money(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803optional_create_value_declare(T803* C,T0* a1);
extern T0*oBC25commandseparator;
extern T6 oBC25columnnotnullallowed;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlcolumnconstraint_base(T803* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS97*/
T6 r803check_if_required(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_subselect_for_attribute(T803* C,T0* a1);
extern T6 oBC803inlineuniqueconstraintsupported;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803datatype_int(T0* a1);
extern T6 oBC25domainnotnullallowed;
/*SQL_GENERATOR_MSACCESS97*/
T6 r803is_value_data_type_changed(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803datatype_numeric(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803datatype_picture(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_cast_to_integer(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_value_create_table(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlcolumndefault_base(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803column_constraint_name(T803* C,T0* a1,T0* a2);
extern T0*oBC25sqlfunction_any;
extern int fBC25sqlfunction_any;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlfunction_any(void);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlgetvalue(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803set_sequence_name_format(T803* C,T0* a1);
extern T0*oBC25valuetablename;
extern int fBC25valuetablename;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803valuetablename(void);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_constant_assignment(T803* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803safe_string(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803do_sql_cast_to_date(T803* C,T0* a1);
extern T6 oBC774domainssupported;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS97*/
T6 r803equal(T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_MSACCESS97*/
void r803write_type(T803* C,T0* a1);
extern T0*oBC20string_;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_combine_expression_as_wildcard(T803* C,T0* a1);
extern T0*oBC25sqlsysfunction_current_timestamp;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803extension_name(T0* a1);
extern T6 oBC25clusteredindexsupported;
extern T0*oBC25createtemporarytablestatement;
extern int fBC25createtemporarytablestatement;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803createtemporarytablestatement(void);
extern T6 oBC25noonelinecommentssupported;
extern int fBC25noonelinecommentssupported;
/*SQL_GENERATOR_MSACCESS97*/
T6 r803noonelinecommentssupported(void);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803value_identifier(T0* a1);
extern T6 oBC25ansi92joinssupported;
extern T0*oBC16formatter;
extern int fBC16formatter;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803formatter(void);
/*SQL_GENERATOR_MSACCESS97*/
void r803write_sql(T0* a1);
extern T6 oBC25createdomains;
extern int fBC25createdomains;
/*SQL_GENERATOR_MSACCESS97*/
T6 r803createdomains(T803* C);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803_25Pdatatype_pk_int(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803write_one_line_comment(T0* a1);
extern T0*oBC25primarykeyconstraint;
extern T0*oBC25value_representation_date;
extern int fBC25value_representation_date;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803value_representation_date(T803* C);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_assertion(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803quote_identifier(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_constant(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803datatype_float(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803set_primary_key_format(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803extension_index_name(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803set_options(T803* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_view(T803* C,T0* a1);
extern T0*oBC25sqlcoalesce;
/*SQL_GENERATOR_MSACCESS97*/
void r803write_use_database(T803* C,T0* a1);
extern T6 oBC25identifierwithspacessupported;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803domain_identifier(T0* a1);
extern T0*oBC25multilinecommentprefix;
/*SQL_GENERATOR_MSACCESS97*/
void r803create_value(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T6 r803assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803do_create_select_list(T803* C,T0* a1,T6 a2);
extern T0*oBC25timestampdatatype;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_cast_to_real(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_table(T803* C,T0* a1);
extern T0*oBC25onelinecommentprefix;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803value_representation_char(T803* C,T2 a1);
extern T0*oBC25value_representation_boolean;
extern int fBC25value_representation_boolean;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803value_representation_boolean(T803* C);
/*SQL_GENERATOR_MSACCESS97*/
T6 r803createtimestamp(T803* C);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sp_function_type_for_selection(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803finishtemporarytablestatement(void);
extern T0*oBC25sqlfunction_count;
extern T6 oBC25coalescesupported;
extern int fBC25coalescesupported;
/*SQL_GENERATOR_MSACCESS97*/
T6 r803coalescesupported(void);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_subselect_for_extension(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803table_pk_name(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803drop_constant(T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_insert(T803* C,T0* a1,T0* a2,T0* a3);
extern T0*oBC803autoprimarykeyconstraint;
/*SQL_GENERATOR_MSACCESS97*/
T6 r803is_value_declared(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803columndatatype_assertion(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlcolumnidentifier_base(T0* a1,T0* a2);
extern T0*oBC25sqltrue;
/*SQL_GENERATOR_MSACCESS97*/
T6 r803valid_format_and_parameters(T0* a1,T0* a2);
extern T0*oBC25sqlfunction_total;
/*SQL_GENERATOR_MSACCESS97*/
void r803make(T803* C);
extern T2 oBC804maxidentifierlength;
/*SQL_GENERATOR_MSACCESS97*/
T0* r803value_representation_integer(T803* C,T2 a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803table_ts_name(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_extend_create_index(T803* C,T0* a1);
extern T6 oBC25createindex;
extern int fBC25createindex;
/*SQL_GENERATOR_MSACCESS97*/
T6 r803createindex(void);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803create_table_name(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803format(T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_expression_as_boolean_value(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803index_name(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_select_joins_oldstyle(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_delete(T803* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_select_joins_ansi92(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803do_sql_cast_to_string(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_domain(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_notnot_expression(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_not_expression(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sql_select_for_extension_expression(T803* C,T0* a1);
/*SQL_GENERATOR_MSACCESS97*/
T0* r803sqlcheck_in(T803* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS97*/
void r803create_value_declare(T803* C,T0* a1);
/*XPLAIN_CASCADE_FUNCTION_EXPRESSION*/
void r128make(T128* C,T0* a1,T0* a2);
/*XPLAIN_SCANNER_STATE*/
void r359make_use(T359* C,T0* a1,T0* a2);
/*XPLAIN_SCANNER_STATE*/
void r359set_directory(T359* C);
/*XPLAIN_SCANNER_STATE*/
void r359make_include(T359* C,T0* a1,T0* a2);
/*XPLAIN_SCANNER_STATE*/
void r359make_file(T359* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
void r812_25Pdrop_table(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812drop_value(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812output_update_from_clause(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
void r812sp_start(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_extend(T812* C,T0* a1);
extern T0*oBC815datatype_text;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sp_define_out_param(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812drop_table(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812_25Pdrop_value(T812* C,T0* a1);
extern T0*oBC815sqlsysfunction_system_user;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812no_space_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812write_drop(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812make_valid_sp_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812scientific_formatter(void);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlcolumnrequired_base(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812write_procedure(T812* C,T0* a1);
extern T6 oBC815temporarytablessupported;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812value_representation_system_user(T812* C);
extern T6 oBC797checksnullaftertrigger;
extern T0*oBC815sql_select_function_limit_after;
extern int fBC815sql_select_function_limit_after;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_select_function_limit_after(void);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812datatype_ref_int(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_value_declare_inside_sp(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812do_sql_cast_to_real(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_extension_function(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_value_alter_table(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812init_necessary(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812do_do_create_select_list(T812* C,T0* a1,T6 a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812value_representation_float(T812* C);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812table_has_auto_pk(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812make_valid_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812columndatatype_type(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_get_insert(T812* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlcolumnidentifier_type(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812tabtab(void);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_last_auto_generated_primary_key(T812* C,T0* a1);
extern T2 oBC25max_numeric_precision;
/*SQL_GENERATOR_PGSQL_82*/
void r812create_value_assign_inside_sp(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sp_function_type_for_selection_value(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812_25Psqlcolumnrequired_base(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812write_select(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_value_declare_outside_sp(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812datatype_varchar(T0* a1);
extern T0*oBC815datatype_datetime;
extern int fBC815datatype_datetime;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812datatype_datetime(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812write_assertion(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812value_representation_text(T812* C);
extern T0*oBC815datatype_boolean;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812make_valid_constraint_identifier(T0* a1);
extern T6 oBC25uniqueconstraintsupported;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_infix_expression(T812* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlcolumnconstraint_type(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812quoted_value_identifier(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812datatype_pk_int(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sp_update_name(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_predicate(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_sp_insert(T812* C,T0* a1);
extern T0*oBC797new_row_prefix;
/*SQL_GENERATOR_PGSQL_82*/
void r812drop_column(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_cast_to_date(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812_815Psp_user_declaration(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812table_name(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812drop_domain(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_init_cast_to_real(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812do_drop_procedure(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812drop_table_if_exist(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812temporarytableprefix(void);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sp_define_param_name(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812assertion_name(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812sp_delete_declaration(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlcolumndefault_type(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_sp_type(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_select_value(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812createautoprimarykey(T812* C);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sp_function_type_for_selection_list(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_select_function(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812init_forced_null(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_infix_expression_as_wildcard(T812* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_select_function_as_subselect(T812* C,T0* a1);
extern T6 oBC815autoprimarykeysupported;
/*SQL_GENERATOR_PGSQL_82*/
void r812create_extend_create_table(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_cast_to_string(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_select_function_as_left_outer_join(T812* C,T0* a1);
extern T0*oBC812target_name;
/*SQL_GENERATOR_PGSQL_82*/
void r812_25Pcreate_select_list(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812do_sql_select_for_extension_function(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812do_sql_cast_to_integer(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlfunction_nil(void);
/*SQL_GENERATOR_PGSQL_82*/
void r812write_init(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812createassert(T812* C);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_select_value_inside_sp(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812write_base(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_sp_delete(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812value_representation_money(T812* C);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_init_infix_expression(T812* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_select_joins(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812sp_insert_declaration(T812* C,T0* a1,T0* a2,T6 a3);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_update_joins(T812* C,T6 a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_update(T812* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_index(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlgetvalue_outside_sp(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812constraint_names(void);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_sync_auto_generated_primary_key_with_supplied_value(T812* C,T0* a1,T2 a2);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812createdomaincheck(T812* C);
/*SQL_GENERATOR_PGSQL_82*/
void r812_25Pwrite_type(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_init_cast_to_string(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_select_for_extension_function(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812datatype_pk_char(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_select_list(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sp_insert_name(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_combine_expression(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812value_representation_current_timestamp(T812* C);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812as_string(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_init_expression(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812echo(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812datatype_char(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlgetconstant(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812columndatatype_base(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812createviews(T812* C);
extern T0*oBC815sql_select_function_limit_before;
extern T6 oBC25checkconstraintsupported;
/*SQL_GENERATOR_PGSQL_82*/
void r812write_index(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812constant_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_value_assign_outside_sp(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812sp_end(T812* C);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sp_use_param(T0* a1);
extern T0*oBC815datatype_money;
/*SQL_GENERATOR_PGSQL_82*/
T6 r812init_forced_default(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812sp_body_statements(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812optional_create_value_declare(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlcolumnconstraint_base(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
void r812sp_update_declaration(T812* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812check_if_required(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_subselect_for_attribute(T812* C,T0* a1);
extern T0*oBC798sp_return_parameter_format_string;
extern T6 oBC25inlineuniqueconstraintsupported;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812datatype_int(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_procedure(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812is_value_data_type_changed(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812datatype_numeric(T0* a1);
extern T0*oBC815datatype_picture;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_cast_to_integer(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_value_create_table(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812storedprocedureparamlistend(void);
/*SQL_GENERATOR_PGSQL_82*/
void r812_25Pcreate_select_function(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812quote_valid_identifier(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlcolumndefault_base(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlgetvalue_inside_sp(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812column_constraint_name(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlfunction_any(void);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlgetvalue(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812set_sequence_name_format(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812valuetablename(void);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_constant_assignment(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812safe_string(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812safe_sql(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812do_sql_cast_to_date(T812* C,T0* a1);
extern T6 oBC815domainssupported;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
void r812write_type(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812equal(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_combine_expression_as_wildcard(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812extension_name(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812createtemporarytablestatement(void);
/*SQL_GENERATOR_PGSQL_82*/
void r812output_update_extend_from_clause(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812noonelinecommentssupported(void);
extern T6 oBC798storedproceduresupported;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812value_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812formatter(void);
/*SQL_GENERATOR_PGSQL_82*/
void r812write_sql(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812createdomains(T812* C);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812_25Pdatatype_pk_int(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812write_one_line_comment(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812value_representation_date(T812* C);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_assertion(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sp_type_name(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812quote_identifier(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_constant(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812drop_sp(T812* C,T0* a1);
extern T0*oBC815datatype_float;
/*SQL_GENERATOR_PGSQL_82*/
void r812_25Pcreate_extend_create_table(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812set_primary_key_format(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812extension_index_name(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812set_options(T812* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_init_cast_to_date(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_view(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812write_use_database(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812drop_sp_type(T812* C,T0* a1);
extern T6 oBC815identifierwithspacessupported;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812domain_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_value(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_sp_update(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_value_assign(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812do_create_select_list(T812* C,T0* a1,T6 a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812storedprocedurereturnparamliststart(void);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_cast_to_real(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlcolumnrequired_type(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sp_get_auto_generated_primary_key(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_table(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812value_representation_char(T812* C,T2 a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812value_representation_boolean(T812* C);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812createtimestamp(T812* C);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sp_function_type_for_selection(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812finishtemporarytablestatement(void);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_init_combine_expression(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlinitvalue_if(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sp_name(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812coalescesupported(void);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_subselect_for_extension(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlinitvalue_attribute(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812table_pk_name(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812drop_constant(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_insert(T812* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sp_delete_name(T812* C,T0* a1);
extern T0*oBC815autoprimarykeyconstraint;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sp_define_in_param(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812is_value_declared(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812columndatatype_assertion(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_init_cast_to_integer(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
void r812make(T812* C);
extern T2 oBC813maxidentifierlength;
/*SQL_GENERATOR_PGSQL_82*/
T0* r812value_representation_integer(T812* C,T2 a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812sp_user_declaration(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_echo(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812_25Psqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812table_ts_name(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_extend_create_index(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T6 r812createindex(void);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812create_table_name(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_init(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812format(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_expression_as_boolean_value(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812index_name(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812sp_result_parameter(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_select_joins_oldstyle(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_delete(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_select_joins_ansi92(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812do_sql_cast_to_string(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_domain(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_notnot_expression(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812storedprocedureparamliststart(void);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_not_expression(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sql_select_for_extension_expression(T812* C,T0* a1);
/*SQL_GENERATOR_PGSQL_82*/
T0* r812sqlcheck_in(T812* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_82*/
void r812create_value_declare(T812* C,T0* a1);
/*XPLAIN_PK_I_REPRESENTATION*/
T0* r622domain(T622* C);
/*XPLAIN_PK_I_REPRESENTATION*/
T0* r622min_value(T622* C,T0* a1);
extern T0*oBC613default_value;
/*XPLAIN_PK_I_REPRESENTATION*/
T0* r622value_representation(T622* C,T0* a1);
/*XPLAIN_PK_I_REPRESENTATION*/
void r622set_domain_restriction(T622* C,T0* a1,T0* a2);
/*XPLAIN_PK_I_REPRESENTATION*/
T0* r622pkdatatype(T622* C,T0* a1);
/*XPLAIN_PK_I_REPRESENTATION*/
T0* r622xml_schema_data_type(void);
/*XPLAIN_PK_I_REPRESENTATION*/
T0* r622max_value(T622* C,T0* a1);
/*XPLAIN_PK_I_REPRESENTATION*/
T0* r622datatype(T622* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813_25Pdrop_table(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813drop_value(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813output_update_from_clause(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
void r813sp_start(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_extend(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sp_define_out_param(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813drop_table(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813_25Pdrop_value(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813no_space_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813write_drop(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813make_valid_sp_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813scientific_formatter(void);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlcolumnrequired_base(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813write_procedure(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813value_representation_system_user(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_select_function_limit_after(void);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813datatype_ref_int(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_value_declare_inside_sp(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813do_sql_cast_to_real(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_extension_function(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_value_alter_table(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813init_necessary(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813do_do_create_select_list(T813* C,T0* a1,T6 a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813value_representation_float(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813table_has_auto_pk(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813make_valid_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813columndatatype_type(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_get_insert(T813* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlcolumnidentifier_type(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813tabtab(void);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_last_auto_generated_primary_key(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_value_assign_inside_sp(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sp_function_type_for_selection_value(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813_25Psqlcolumnrequired_base(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813write_select(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_value_declare_outside_sp(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813datatype_varchar(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813datatype_datetime(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813write_assertion(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813value_representation_text(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_infix_expression(T813* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlcolumnconstraint_type(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813quoted_value_identifier(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813datatype_pk_int(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sp_update_name(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_predicate(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_sp_insert(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813drop_column(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_cast_to_date(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813_815Psp_user_declaration(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813table_name(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813drop_domain(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_init_cast_to_real(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813do_drop_procedure(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813drop_table_if_exist(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813temporarytableprefix(void);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sp_define_param_name(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813assertion_name(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813sp_delete_declaration(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlcolumndefault_type(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_sp_type(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_select_value(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813createautoprimarykey(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sp_function_type_for_selection_list(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_select_function(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813init_forced_null(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_infix_expression_as_wildcard(T813* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_select_function_as_subselect(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_extend_create_table(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_cast_to_string(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_select_function_as_left_outer_join(T813* C,T0* a1);
extern T0*oBC813target_name;
/*SQL_GENERATOR_PGSQL_81*/
void r813_25Pcreate_select_list(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813do_sql_select_for_extension_function(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813do_sql_cast_to_integer(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlfunction_nil(void);
/*SQL_GENERATOR_PGSQL_81*/
void r813write_init(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813createassert(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_select_value_inside_sp(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813write_base(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_sp_delete(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813value_representation_money(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_init_infix_expression(T813* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_select_joins(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813sp_insert_declaration(T813* C,T0* a1,T0* a2,T6 a3);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_update_joins(T813* C,T6 a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_update(T813* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_index(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlgetvalue_outside_sp(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813constraint_names(void);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_sync_auto_generated_primary_key_with_supplied_value(T813* C,T0* a1,T2 a2);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813createdomaincheck(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
void r813_25Pwrite_type(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_init_cast_to_string(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_select_for_extension_function(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813datatype_pk_char(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_select_list(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sp_insert_name(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_combine_expression(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813value_representation_current_timestamp(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813as_string(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_init_expression(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813echo(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813datatype_char(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlgetconstant(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813columndatatype_base(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813createviews(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
void r813write_index(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813constant_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_value_assign_outside_sp(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813sp_end(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sp_use_param(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813init_forced_default(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813sp_body_statements(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813optional_create_value_declare(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlcolumnconstraint_base(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
void r813sp_update_declaration(T813* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813check_if_required(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_subselect_for_attribute(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813datatype_int(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_procedure(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813is_value_data_type_changed(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813datatype_numeric(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_cast_to_integer(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_value_create_table(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813storedprocedureparamlistend(void);
/*SQL_GENERATOR_PGSQL_81*/
void r813_25Pcreate_select_function(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813quote_valid_identifier(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlcolumndefault_base(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlgetvalue_inside_sp(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813column_constraint_name(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlfunction_any(void);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlgetvalue(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813set_sequence_name_format(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813valuetablename(void);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_constant_assignment(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813safe_string(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813safe_sql(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813do_sql_cast_to_date(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
void r813write_type(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813equal(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_combine_expression_as_wildcard(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813extension_name(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813createtemporarytablestatement(void);
/*SQL_GENERATOR_PGSQL_81*/
void r813output_update_extend_from_clause(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813noonelinecommentssupported(void);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813value_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813formatter(void);
/*SQL_GENERATOR_PGSQL_81*/
void r813write_sql(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813createdomains(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813_25Pdatatype_pk_int(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813write_one_line_comment(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813value_representation_date(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_assertion(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sp_type_name(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813quote_identifier(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_constant(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813drop_sp(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813_25Pcreate_extend_create_table(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813set_primary_key_format(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813extension_index_name(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813set_options(T813* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_init_cast_to_date(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_view(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813write_use_database(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813drop_sp_type(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813domain_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_value(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_sp_update(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_value_assign(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813do_create_select_list(T813* C,T0* a1,T6 a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813storedprocedurereturnparamliststart(void);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_cast_to_real(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlcolumnrequired_type(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sp_get_auto_generated_primary_key(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_table(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813value_representation_char(T813* C,T2 a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813value_representation_boolean(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813createtimestamp(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sp_function_type_for_selection(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813finishtemporarytablestatement(void);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_init_combine_expression(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlinitvalue_if(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sp_name(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813coalescesupported(void);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_subselect_for_extension(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlinitvalue_attribute(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813table_pk_name(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813drop_constant(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_insert(T813* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sp_delete_name(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sp_define_in_param(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813is_value_declared(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813columndatatype_assertion(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_init_cast_to_integer(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
void r813make(T813* C);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813value_representation_integer(T813* C,T2 a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813sp_user_declaration(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_echo(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813_25Psqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813table_ts_name(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_extend_create_index(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T6 r813createindex(void);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813create_table_name(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_init(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813format(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_expression_as_boolean_value(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813index_name(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813sp_result_parameter(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_select_joins_oldstyle(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_delete(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_select_joins_ansi92(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813do_sql_cast_to_string(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_domain(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_notnot_expression(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813storedprocedureparamliststart(void);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_not_expression(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sql_select_for_extension_expression(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_81*/
T0* r813sqlcheck_in(T813* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_81*/
void r813create_value_declare(T813* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814_25Pdrop_table(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814drop_value(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814sp_start(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_extend(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sp_define_out_param(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814drop_table(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814_25Pdrop_value(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814no_space_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814write_drop(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814make_valid_sp_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814scientific_formatter(void);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlcolumnrequired_base(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814write_procedure(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814value_representation_system_user(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_select_function_limit_after(void);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814datatype_ref_int(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_value_declare_inside_sp(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814do_sql_cast_to_real(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_extension_function(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_value_alter_table(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814init_necessary(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814do_do_create_select_list(T814* C,T0* a1,T6 a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814value_representation_float(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814table_has_auto_pk(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814make_valid_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814columndatatype_type(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_get_insert(T814* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlcolumnidentifier_type(T814* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814tabtab(void);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_last_auto_generated_primary_key(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_value_assign_inside_sp(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sp_function_type_for_selection_value(T814* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814_25Psqlcolumnrequired_base(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814write_select(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_value_declare_outside_sp(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814datatype_varchar(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814datatype_datetime(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814write_assertion(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814value_representation_text(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_infix_expression(T814* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlcolumnconstraint_type(T814* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814quoted_value_identifier(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814datatype_pk_int(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sp_update_name(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_predicate(T814* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_sp_insert(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814drop_column(T814* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_cast_to_date(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814_815Psp_user_declaration(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814table_name(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814drop_domain(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_init_cast_to_real(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814do_drop_procedure(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814drop_table_if_exist(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814temporarytableprefix(void);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sp_define_param_name(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814assertion_name(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814sp_delete_declaration(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlcolumndefault_type(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_sp_type(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_select_value(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814createautoprimarykey(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sp_function_type_for_selection_list(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_select_function(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814init_forced_null(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_infix_expression_as_wildcard(T814* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_select_function_as_subselect(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_extend_create_table(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_cast_to_string(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_select_function_as_left_outer_join(T814* C,T0* a1);
extern T0*oBC814target_name;
/*SQL_GENERATOR_PGSQL_73*/
void r814_25Pcreate_select_list(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814do_sql_select_for_extension_function(T814* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814do_sql_cast_to_integer(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlfunction_nil(void);
/*SQL_GENERATOR_PGSQL_73*/
void r814write_init(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814createassert(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_select_value_inside_sp(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814write_base(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_sp_delete(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814value_representation_money(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_init_infix_expression(T814* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_select_joins(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814sp_insert_declaration(T814* C,T0* a1,T0* a2,T6 a3);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_update(T814* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_index(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlgetvalue_outside_sp(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814constraint_names(void);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_sync_auto_generated_primary_key_with_supplied_value(T814* C,T0* a1,T2 a2);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814createdomaincheck(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
void r814_25Pwrite_type(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_init_cast_to_string(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_select_for_extension_function(T814* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814datatype_pk_char(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_select_list(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sp_insert_name(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_combine_expression(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814value_representation_current_timestamp(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814as_string(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_init_expression(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814echo(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814datatype_char(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlgetconstant(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814columndatatype_base(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814createviews(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
void r814write_index(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814constant_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_value_assign_outside_sp(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814sp_end(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sp_use_param(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814init_forced_default(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814sp_body_statements(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814optional_create_value_declare(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlcolumnconstraint_base(T814* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
void r814sp_update_declaration(T814* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814check_if_required(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_subselect_for_attribute(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814datatype_int(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_procedure(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814is_value_data_type_changed(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814datatype_numeric(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_cast_to_integer(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_value_create_table(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814storedprocedureparamlistend(void);
/*SQL_GENERATOR_PGSQL_73*/
void r814_25Pcreate_select_function(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814quote_valid_identifier(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlcolumndefault_base(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlgetvalue_inside_sp(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814column_constraint_name(T814* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlfunction_any(void);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlgetvalue(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814set_sequence_name_format(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814valuetablename(void);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_constant_assignment(T814* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814safe_string(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814safe_sql(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814do_sql_cast_to_date(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
void r814write_type(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814equal(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_combine_expression_as_wildcard(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814_25Pas_string(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814extension_name(T0* a1);
extern T0*oBC815plpgsql_block_demarcation;
/*SQL_GENERATOR_PGSQL_73*/
T0* r814createtemporarytablestatement(void);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814noonelinecommentssupported(void);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814value_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814formatter(void);
/*SQL_GENERATOR_PGSQL_73*/
void r814write_sql(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814createdomains(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814_25Pdatatype_pk_int(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814write_one_line_comment(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814value_representation_date(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_assertion(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sp_type_name(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814quote_identifier(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_constant(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814drop_sp(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814_25Pcreate_extend_create_table(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814set_primary_key_format(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814extension_index_name(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814set_options(T814* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_init_cast_to_date(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_view(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814write_use_database(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814drop_sp_type(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814domain_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_value(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_sp_update(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_value_assign(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814do_create_select_list(T814* C,T0* a1,T6 a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814storedprocedurereturnparamliststart(void);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_cast_to_real(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlcolumnrequired_type(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sp_get_auto_generated_primary_key(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_table(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814value_representation_char(T814* C,T2 a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814value_representation_boolean(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814createtimestamp(T814* C);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sp_function_type_for_selection(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814finishtemporarytablestatement(void);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_init_combine_expression(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlinitvalue_if(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sp_name(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814coalescesupported(void);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_subselect_for_extension(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlinitvalue_attribute(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814table_pk_name(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814drop_constant(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_insert(T814* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sp_delete_name(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sp_define_in_param(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814is_value_declared(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814columndatatype_assertion(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_init_cast_to_integer(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
void r814make(T814* C);
extern T2 oBC815maxidentifierlength;
/*SQL_GENERATOR_PGSQL_73*/
T0* r814value_representation_integer(T814* C,T2 a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814sp_user_declaration(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_echo(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814_25Psqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814table_ts_name(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_extend_create_index(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T6 r814createindex(void);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814create_table_name(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_init(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814format(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_expression_as_boolean_value(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814index_name(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814sp_result_parameter(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_select_joins_oldstyle(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_delete(T814* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_select_joins_ansi92(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814do_sql_cast_to_string(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_domain(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_notnot_expression(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814storedprocedureparamliststart(void);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_not_expression(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sql_select_for_extension_expression(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_73*/
T0* r814sqlcheck_in(T814* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_73*/
void r814create_value_declare(T814* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816_25Pdrop_table(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816drop_value(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816sp_start(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_extend(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sp_define_out_param(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816drop_table(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816_25Pdrop_value(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816no_space_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816write_drop(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816make_valid_sp_identifier(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816scientific_formatter(void);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlcolumnrequired_base(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816write_procedure(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816value_representation_system_user(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_select_function_limit_after(void);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816datatype_ref_int(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_value_declare_inside_sp(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816do_sql_cast_to_real(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_extension_function(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_value_alter_table(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816init_necessary(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816do_do_create_select_list(T816* C,T0* a1,T6 a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816value_representation_float(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816table_has_auto_pk(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816make_valid_identifier(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816columndatatype_type(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_get_insert(T816* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlcolumnidentifier_type(T816* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816tabtab(void);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_last_auto_generated_primary_key(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_value_assign_inside_sp(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sp_function_type_for_selection_value(T816* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816_25Psqlcolumnrequired_base(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816write_select(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_value_declare_outside_sp(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816datatype_varchar(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816datatype_datetime(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816write_assertion(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816value_representation_text(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816make_valid_constraint_identifier(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_infix_expression(T816* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlcolumnconstraint_type(T816* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816quoted_value_identifier(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816datatype_pk_int(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sp_update_name(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_predicate(T816* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_sp_insert(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816drop_column(T816* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_cast_to_date(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816_815Psp_user_declaration(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816table_name(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816drop_domain(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_init_cast_to_real(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816do_drop_procedure(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816drop_table_if_exist(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816temporarytableprefix(void);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sp_define_param_name(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816assertion_name(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816sp_delete_declaration(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlcolumndefault_type(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_select_value(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816createautoprimarykey(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sp_function_type_for_selection_list(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_select_function(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816init_forced_null(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_infix_expression_as_wildcard(T816* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_select_function_as_subselect(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_extend_create_table(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_cast_to_string(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_select_function_as_left_outer_join(T816* C,T0* a1);
extern T0*oBC816target_name;
/*SQL_GENERATOR_PGSQL_72*/
void r816_25Pcreate_select_list(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816do_sql_select_for_extension_function(T816* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816do_sql_cast_to_integer(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlfunction_nil(void);
/*SQL_GENERATOR_PGSQL_72*/
void r816write_init(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816createassert(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_select_value_inside_sp(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816write_base(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_sp_delete(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816value_representation_money(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_init_infix_expression(T816* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_select_joins(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816sp_insert_declaration(T816* C,T0* a1,T0* a2,T6 a3);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_update(T816* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_index(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlgetvalue_outside_sp(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816constraint_names(void);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_sync_auto_generated_primary_key_with_supplied_value(T816* C,T0* a1,T2 a2);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816createdomaincheck(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
void r816_25Pwrite_type(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_init_cast_to_string(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_select_for_extension_function(T816* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816datatype_pk_char(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_select_list(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sp_insert_name(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_combine_expression(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816value_representation_current_timestamp(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816as_string(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_init_expression(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816echo(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816datatype_char(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlgetconstant(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816columndatatype_base(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816createviews(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
void r816write_index(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816constant_identifier(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_value_assign_outside_sp(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816sp_end(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sp_use_param(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816init_forced_default(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816sp_body_statements(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816optional_create_value_declare(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlcolumnconstraint_base(T816* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
void r816sp_update_declaration(T816* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816check_if_required(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_subselect_for_attribute(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816datatype_int(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_procedure(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816is_value_data_type_changed(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816datatype_numeric(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_cast_to_integer(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_value_create_table(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816storedprocedureparamlistend(void);
/*SQL_GENERATOR_PGSQL_72*/
void r816_25Pcreate_select_function(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816quote_valid_identifier(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlcolumndefault_base(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlgetvalue_inside_sp(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816column_constraint_name(T816* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlfunction_any(void);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlgetvalue(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816set_sequence_name_format(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816valuetablename(void);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_constant_assignment(T816* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816safe_string(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816safe_sql(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816do_sql_cast_to_date(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
void r816write_type(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816equal(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_combine_expression_as_wildcard(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816_25Pas_string(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816extension_name(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816createtemporarytablestatement(void);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816noonelinecommentssupported(void);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816value_identifier(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816formatter(void);
/*SQL_GENERATOR_PGSQL_72*/
void r816write_sql(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816createdomains(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816_25Pdatatype_pk_int(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816write_one_line_comment(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816value_representation_date(T816* C);
extern T0*oBC816sp_type_name;
/*SQL_GENERATOR_PGSQL_72*/
void r816create_assertion(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816quote_identifier(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_constant(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816drop_sp(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816_25Pcreate_extend_create_table(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816set_primary_key_format(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816extension_index_name(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816set_options(T816* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_init_cast_to_date(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_view(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816write_use_database(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816domain_identifier(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_value(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_sp_update(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_value_assign(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816do_create_select_list(T816* C,T0* a1,T6 a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816storedprocedurereturnparamliststart(void);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_cast_to_real(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlcolumnrequired_type(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sp_get_auto_generated_primary_key(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_table(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816value_representation_char(T816* C,T2 a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816value_representation_boolean(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816createtimestamp(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sp_function_type_for_selection(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816finishtemporarytablestatement(void);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_init_combine_expression(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlinitvalue_if(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sp_name(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816coalescesupported(void);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_subselect_for_extension(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlinitvalue_attribute(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816table_pk_name(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816drop_constant(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_insert(T816* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sp_delete_name(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sp_define_in_param(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816is_value_declared(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816columndatatype_assertion(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlcolumnidentifier_base(T816* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_init_cast_to_integer(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816_25Pmake_valid_identifier(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816make(T816* C);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816value_representation_integer(T816* C,T2 a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816sp_user_declaration(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_echo(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816_25Psqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816table_ts_name(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_extend_create_index(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T6 r816createindex(void);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816create_table_name(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_init(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816format(T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_expression_as_boolean_value(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816index_name(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816sp_result_parameter(T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_select_joins_oldstyle(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_delete(T816* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_select_joins_ansi92(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816do_sql_cast_to_string(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_domain(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_notnot_expression(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816storedprocedureparamliststart(void);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_not_expression(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sql_select_for_extension_expression(T816* C,T0* a1);
/*SQL_GENERATOR_PGSQL_72*/
T0* r816sqlcheck_in(T816* C,T0* a1,T0* a2);
/*SQL_GENERATOR_PGSQL_72*/
void r816create_value_declare(T816* C,T0* a1);
/*XPLAIN_B_RESTRICTION*/
T0* r548sqldomainconstraint(T548* C,T0* a1,T0* a2);
/*XPLAIN_B_RESTRICTION*/
T0* r548sqlcolumnconstraint(T548* C,T0* a1,T0* a2);
/*XPLAIN_VALUE*/
T0* r576quoted_name(T576* C,T0* a1);
/*XPLAIN_VALUE*/
void r576inherited_make(T576* C,T0* a1,T0* a2);
/*XPLAIN_VALUE*/
T0* r576create_expression(T0* a1);
/*XPLAIN_VALUE*/
void r576make(T576* C,T0* a1,T0* a2,T0* a3);
/*XPLAIN_VALUE*/
void r576write_drop(T576* C,T0* a1);
/*XPLAIN_VALUE*/
T0* r576sqlname(T576* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799drop_value(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_extend(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799datatype_text(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799drop_table(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799no_space_identifier(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799write_drop(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799scientific_formatter(void);
/*SQL_GENERATOR_FOXPRO*/
T0* r799domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlcolumnrequired_base(T799* C,T0* a1);
extern T6 oBC25temporarytablessupported;
/*SQL_GENERATOR_FOXPRO*/
void r799write_procedure(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799value_representation_system_user(T799* C);
/*SQL_GENERATOR_FOXPRO*/
T0* r799datatype_ref_int(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799do_sql_cast_to_real(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_extension_function(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_value_alter_table(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T6 r799init_necessary(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799do_do_create_select_list(T799* C,T0* a1,T6 a2);
/*SQL_GENERATOR_FOXPRO*/
T0* r799value_representation_float(T799* C);
/*SQL_GENERATOR_FOXPRO*/
T6 r799table_has_auto_pk(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799make_valid_identifier(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799columndatatype_type(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_get_insert(T799* C,T0* a1,T0* a2,T6 a3,T0* a4);
extern T6 oBC799viewssupported;
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlcolumnidentifier_type(T799* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T0* r799tabtab(void);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_last_auto_generated_primary_key(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799write_select(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_value_declare_outside_sp(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799drop_procedure(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799write_assertion(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799datatype_datetime(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799datatype_varchar(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799value_representation_text(T799* C);
/*SQL_GENERATOR_FOXPRO*/
T0* r799datatype_boolean(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_infix_expression(T799* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlcolumnconstraint_type(T799* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T0* r799quoted_value_identifier(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799datatype_pk_int(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_predicate(T799* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
void r799drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_cast_to_date(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799table_name(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799drop_domain(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799temporarytableprefix(void);
/*SQL_GENERATOR_FOXPRO*/
T0* r799assertion_name(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlcolumndefault_type(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_select_value(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T6 r799createautoprimarykey(T799* C);
/*SQL_GENERATOR_FOXPRO*/
void r799create_select_function(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_infix_expression_as_wildcard(T799* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_select_function_as_subselect(T799* C,T0* a1);
extern T6 oBC25autoprimarykeysupported;
/*SQL_GENERATOR_FOXPRO*/
void r799create_extend_create_table(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_cast_to_string(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_select_function_as_left_outer_join(T799* C,T0* a1);
extern T0*oBC799target_name;
/*SQL_GENERATOR_FOXPRO*/
T0* r799do_sql_cast_to_integer(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799do_sql_select_for_extension_function(T799* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlfunction_nil(void);
/*SQL_GENERATOR_FOXPRO*/
void r799write_init(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T6 r799createassert(T799* C);
/*SQL_GENERATOR_FOXPRO*/
void r799write_base(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799value_representation_money(T799* C);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_select_joins(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_update(T799* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_FOXPRO*/
void r799create_index(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlgetvalue_outside_sp(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799constraint_names(void);
/*SQL_GENERATOR_FOXPRO*/
T6 r799createdomaincheck(T799* C);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_select_for_extension_function(T799* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T0* r799datatype_pk_char(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_combine_expression(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799value_representation_current_timestamp(T799* C);
/*SQL_GENERATOR_FOXPRO*/
T0* r799as_string(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799echo(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799datatype_char(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlgetconstant(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799columndatatype_base(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799write_extend(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T6 r799createviews(T799* C);
/*SQL_GENERATOR_FOXPRO*/
void r799write_index(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799constant_identifier(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_value_assign_outside_sp(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799datatype_money(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799optional_create_value_declare(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlcolumnconstraint_base(T799* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T6 r799check_if_required(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_subselect_for_attribute(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799datatype_int(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T6 r799is_value_data_type_changed(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799datatype_numeric(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799datatype_picture(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_cast_to_integer(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_value_create_table(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlcolumndefault_base(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799column_constraint_name(T799* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlfunction_any(void);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlgetvalue(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799set_sequence_name_format(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799valuetablename(void);
/*SQL_GENERATOR_FOXPRO*/
void r799create_constant_assignment(T799* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T0* r799safe_string(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799do_sql_cast_to_date(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T6 r799equal(T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T0* r799finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_FOXPRO*/
void r799write_type(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_combine_expression_as_wildcard(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799extension_name(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799createtemporarytablestatement(void);
/*SQL_GENERATOR_FOXPRO*/
T6 r799noonelinecommentssupported(void);
/*SQL_GENERATOR_FOXPRO*/
T0* r799value_identifier(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799formatter(void);
/*SQL_GENERATOR_FOXPRO*/
void r799write_sql(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T6 r799createdomains(T799* C);
/*SQL_GENERATOR_FOXPRO*/
void r799write_one_line_comment(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799value_representation_date(T799* C);
/*SQL_GENERATOR_FOXPRO*/
void r799create_assertion(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799quote_identifier(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_constant(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799datatype_float(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799set_primary_key_format(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799extension_index_name(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799set_options(T799* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_FOXPRO*/
void r799create_view(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799write_use_database(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799domain_identifier(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_value(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T6 r799assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799do_create_select_list(T799* C,T0* a1,T6 a2);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_cast_to_real(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_table(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799value_representation_char(T799* C,T2 a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799value_representation_boolean(T799* C);
/*SQL_GENERATOR_FOXPRO*/
T6 r799createtimestamp(T799* C);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sp_function_type_for_selection(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799finishtemporarytablestatement(void);
/*SQL_GENERATOR_FOXPRO*/
T6 r799coalescesupported(void);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_subselect_for_extension(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799table_pk_name(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799drop_constant(T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_insert(T799* C,T0* a1,T0* a2,T0* a3);
extern T0*oBC25autoprimarykeyconstraint;
extern int fBC25autoprimarykeyconstraint;
/*SQL_GENERATOR_FOXPRO*/
T0* r799autoprimarykeyconstraint(void);
/*SQL_GENERATOR_FOXPRO*/
T6 r799is_value_declared(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799columndatatype_assertion(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T6 r799valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
void r799make(T799* C);
extern T2 oBC799maxidentifierlength;
/*SQL_GENERATOR_FOXPRO*/
T0* r799value_representation_integer(T799* C,T2 a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799table_ts_name(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_extend_create_index(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T6 r799createindex(void);
/*SQL_GENERATOR_FOXPRO*/
T0* r799column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799create_table_name(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799format(T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_expression_as_boolean_value(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799index_name(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_select_joins_oldstyle(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_delete(T799* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_select_joins_ansi92(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799do_sql_cast_to_string(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
void r799create_domain(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_notnot_expression(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_not_expression(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sql_select_for_extension_expression(T799* C,T0* a1);
/*SQL_GENERATOR_FOXPRO*/
T0* r799sqlcheck_in(T799* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FOXPRO*/
void r799create_value_declare(T799* C,T0* a1);
/*XPLAIN_EXTEND_ATTRIBUTE*/
void r202make(T202* C,T0* a1,T0* a2);
/*ST_POINTER_FORMATTER*/
void r472center_format_to(T472* C,T0* a1,T0* a2);
/*ST_POINTER_FORMATTER*/
T6 r472valid_parameter(T0* a1);
/*ST_POINTER_FORMATTER*/
void r472format_to(T472* C,T0* a1,T0* a2);
/*ST_POINTER_FORMATTER*/
void r472right_format_to(T472* C,T0* a1,T0* a2);
/*ST_POINTER_FORMATTER*/
void r472reset_options(T472* C);
/*ST_POINTER_FORMATTER*/
void r472justify_format_to(T472* C,T0* a1,T0* a2);
/*ST_POINTER_FORMATTER*/
void r472left_format_to(T472* C,T0* a1,T0* a2);
/*XPLAIN_UNIVERSE*/
T0* r510find_type(T510* C,T0* a1);
/*XPLAIN_UNIVERSE*/
T0* r510find_base(T510* C,T0* a1);
/*XPLAIN_UNIVERSE*/
T0* r510find_object(T510* C,T0* a1);
/*XPLAIN_UNIVERSE*/
T0* r510find_value(T510* C,T0* a1);
/*XPLAIN_UNIVERSE*/
void r510make(T510* C);
/*XPLAIN_UNIVERSE*/
void r510add(T510* C,T0* a1);
/*XPLAIN_UNIVERSE*/
T0* r510find_variable(T510* C,T0* a1);
/*XPLAIN_UNIVERSE*/
void r510delete(T510* C,T0* a1);
/*XPLAIN_UNIVERSE*/
T0* r510find_base_or_type(T510* C,T0* a1);
/*XPLAIN_BASE*/
T0* r334sqlcolumnrequired(T0* a1,T0* a2);
/*XPLAIN_BASE*/
T0* r334columndatatype(T334* C,T0* a1);
/*XPLAIN_BASE*/
T0* r334sqlcolumnidentifier(T334* C,T0* a1,T0* a2);
/*XPLAIN_BASE*/
T0* r334q_sql_select_name(T334* C,T0* a1,T0* a2);
/*XPLAIN_BASE*/
T0* r334sqlcolumndefault(T0* a1,T0* a2);
/*XPLAIN_BASE*/
T0* r334create_expression(T0* a1);
/*XPLAIN_BASE*/
void r334make(T334* C,T0* a1,T0* a2);
/*XPLAIN_BASE*/
void r334write_drop(T334* C,T0* a1);
/*XPLAIN_BASE*/
T0* r334sql_select_name(T334* C,T0* a1,T0* a2);
/*XPLAIN_TYPE_STATEMENT*/
void r92write(T92* C,T0* a1);
/*XPLAIN_A_NODE*/
void r322make(T322* C,T0* a1,T0* a2);
/*XPLAIN_A_NODE*/
T0* r322to_sqlcode(T322* C,T0* a1);
/*XPLAIN_EXTENSION_ATTRIBUTE*/
T0* r714out(T714* C);
/*XPLAIN_EXTENSION_ATTRIBUTE*/
T0* r714full_name(T714* C);
/*XPLAIN_EXTENSION_ATTRIBUTE*/
T0* r714name(T714* C);
/*XPLAIN_EXTENSION_ATTRIBUTE*/
T6 r714is_equal(T714* C,T0* a1);
/*XPLAIN_EXTENSION_ATTRIBUTE*/
T0* r714q_sql_select_name(T714* C,T0* a1);
/*XPLAIN_EXTENSION_ATTRIBUTE*/
void r714inherited_make(T714* C,T0* a1,T0* a2,T6 a3,T6 a4,T6 a5,T6 a6);
/*XPLAIN_EXTENSION_ATTRIBUTE*/
void r714out_in_tagged_out_memory(T714* C);
/*XPLAIN_EXTENSION_ATTRIBUTE*/
void r714set_init(T714* C,T0* a1);
/*XPLAIN_EXTENSION_ATTRIBUTE*/
void r714write_drop(T714* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_ATTRIBUTE*/
T0* r714sql_select_name(T714* C,T0* a1);
/*XPLAIN_EXTENSION_ATTRIBUTE*/
T0* r714extension(T714* C);
/*XPLAIN_EXTENSION_ATTRIBUTE*/
void r714set_init_default(T714* C,T0* a1);
/*KL_TEXT_INPUT_FILE*/
T6 r27is_closed(T27* C);
/*KL_TEXT_INPUT_FILE*/
void r27old_close(T27* C);
/*KL_TEXT_INPUT_FILE*/
T2 r27read_to_string(T27* C,T0* a1,T2 a2,T2 a3);
/*KL_TEXT_INPUT_FILE*/
void r27open_read(T27* C);
/*KL_TEXT_INPUT_FILE*/
void r27old_read_character(T27* C);
/*KL_TEXT_INPUT_FILE*/
void r27read_character(T27* C);
/*KL_TEXT_INPUT_FILE*/
void r27fill_buffer(T27* C);
/*KL_TEXT_INPUT_FILE*/
void r27close(T27* C);
/*KL_TEXT_INPUT_FILE*/
void r27make(T27* C,T0* a1);
/*KL_TEXT_INPUT_FILE*/
T2 r27read_to_buffer(T27* C,T0* a1,T2 a2,T2 a3);
/*KL_TEXT_INPUT_FILE*/
void r27connect_to(T27* C,T0* a1);
/*KL_TEXT_INPUT_FILE*/
T2 r27_45Pread_to_buffer(T27* C,T0* a1,T2 a2,T2 a3);
/*KL_TEXT_INPUT_FILE*/
void r27old_open_read(T27* C);
/*XPLAIN_SELECTION_LIST*/
void r184add_to_join(T184* C,T0* a1,T0* a2);
/*XPLAIN_SELECTION_LIST*/
T6 r184_185Puses_parameter(T184* C,T0* a1);
/*XPLAIN_SELECTION_LIST*/
T6 r184show_only_identifier_column(T184* C);
/*XPLAIN_SELECTION_LIST*/
T6 r184uses_parameter(T184* C,T0* a1);
/*XPLAIN_SELECTION_LIST*/
void r184_185Padd_to_join(T184* C,T0* a1,T0* a2);
/*XPLAIN_SELECTION_LIST*/
void r184make(T184* C,T0* a1,T0* a2,T0* a3,T0* a4);
/*XPLAIN_SELECTION_LIST*/
void r184write_select(T184* C,T0* a1);
/*XPLAIN_SELECTION_LIST*/
T0* r184sp_function_type(T184* C,T0* a1);
extern T0*oBC646table_counter;
extern int fBC646table_counter;
/*JOIN_TREE_NODE*/
T0* r646table_counter(void);
/*JOIN_TREE_NODE*/
T6 r646has_immediate_child(T646* C,T0* a1,T6 a2);
/*JOIN_TREE_NODE*/
void r646add_additional_item(T646* C,T0* a1);
/*JOIN_TREE_NODE*/
void r646append_child(T646* C,T0* a1,T6 a2,T6 a3);
/*JOIN_TREE_NODE*/
T0* r646generate_join_nodes(T646* C,T0* a1,T0* a2,T0* a3);
/*JOIN_TREE_NODE*/
void r646set_prefix_table(T646* C,T0* a1);
/*JOIN_TREE_NODE*/
T6 r646has_children(T646* C);
/*JOIN_TREE_NODE*/
void r646make(T646* C,T0* a1,T6 a2,T6 a3);
/*JOIN_TREE_NODE*/
T0* r646alias_name(T0* a1,T0* a2);
/*JOIN_TREE_NODE*/
void r646increment_usage(T0* a1);
/*JOIN_TREE_NODE*/
T0* r646get_immediate_child(T646* C,T0* a1,T6 a2);
/*XPLAIN_VALUE_SELECTION_STATEMENT*/
T6 r69uses_parameter(T0* a1);
/*XPLAIN_VALUE_SELECTION_STATEMENT*/
void r69write(T69* C,T0* a1);
/*ST_UNSIGNED_OCTAL_FORMATTER*/
void r477center_format_to(T477* C,T0* a1,T0* a2);
/*ST_UNSIGNED_OCTAL_FORMATTER*/
void r477append_abs_to_string(T477* C,T2 a1,T0* a2);
extern T0*oBC35integer_;
/*ST_UNSIGNED_OCTAL_FORMATTER*/
T6 r477valid_parameter(T0* a1);
/*ST_UNSIGNED_OCTAL_FORMATTER*/
void r477_471Pmake(T477* C);
/*ST_UNSIGNED_OCTAL_FORMATTER*/
void r477make(T477* C);
/*ST_UNSIGNED_OCTAL_FORMATTER*/
void r477_475Pinteger_format_to(T477* C,T2 a1,T0* a2);
extern T0*oBC42platform;
/*ST_UNSIGNED_OCTAL_FORMATTER*/
void r477format_to(T477* C,T0* a1,T0* a2);
/*ST_UNSIGNED_OCTAL_FORMATTER*/
void r477right_format_to(T477* C,T0* a1,T0* a2);
/*ST_UNSIGNED_OCTAL_FORMATTER*/
void r477_471Preset_options(T477* C);
/*ST_UNSIGNED_OCTAL_FORMATTER*/
void r477integer_format_to(T477* C,T2 a1,T0* a2);
/*ST_UNSIGNED_OCTAL_FORMATTER*/
void r477reset_options(T477* C);
/*ST_UNSIGNED_OCTAL_FORMATTER*/
void r477append_to_string(T477* C,T2 a1,T0* a2);
/*ST_UNSIGNED_OCTAL_FORMATTER*/
void r477justify_format_to(T477* C,T0* a1,T0* a2);
/*ST_UNSIGNED_OCTAL_FORMATTER*/
void r477left_format_to(T477* C,T0* a1,T0* a2);
/*XPLAIN_C_REPRESENTATION*/
T0* r611domain(T611* C);
/*XPLAIN_C_REPRESENTATION*/
T0* r611min_value(T0* a1);
extern T0*oBC611default_value;
/*XPLAIN_C_REPRESENTATION*/
T0* r611value_representation(T611* C,T0* a1);
/*XPLAIN_C_REPRESENTATION*/
void r611set_domain_restriction(T611* C,T0* a1,T0* a2);
/*XPLAIN_C_REPRESENTATION*/
T0* r611xml_schema_data_type(void);
/*XPLAIN_C_REPRESENTATION*/
T0* r611max_value(T0* a1);
/*XPLAIN_C_REPRESENTATION*/
T0* r611datatype(T611* C,T0* a1);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
void r586add_to_join(T586* C,T0* a1,T0* a2);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
T6 r586uses_parameter(T586* C,T0* a1);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
T0* r586sqlmaxvalue(T586* C,T0* a1);
extern T6 oBC130is_specialization;
extern T0*oBC586xplain_operator;
/*XPLAIN_NOT_LIKE_EXPRESSION*/
void r586make_infix(T586* C,T0* a1,T0* a2,T0* a3);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
T6 r586is_string_expression(void);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
T0* r586representation(T586* C,T0* a1);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
T0* r586outer_sqlvalue(T586* C,T0* a1);
extern T0*oBC586sqloperator;
/*XPLAIN_NOT_LIKE_EXPRESSION*/
T0* r586sqlvalue_as_wildcard(T586* C,T0* a1);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
T6 r586is_using_other_attributes(T586* C,T0* a1);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
T0* r586exact_representation(T586* C,T0* a1);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
T6 r586is_literal(T586* C);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
T0* r586sqlvalue(T586* C,T0* a1);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
void r586make_two_operands(T586* C,T0* a1,T0* a2);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
T0* r586sqlinitvalue(T586* C,T0* a1);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
T0* r586sqlminvalue(T586* C,T0* a1);
/*XPLAIN_NOT_LIKE_EXPRESSION*/
T6 r586has_wild_card_characters(T586* C);
/*SQL_GENERATOR_DB2_6*/
void r794drop_value(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_extend(T794* C,T0* a1);
extern T0*oBC794datatype_text;
/*SQL_GENERATOR_DB2_6*/
void r794drop_table(T794* C,T0* a1);
extern T0*oBC794sqlsysfunction_system_user;
/*SQL_GENERATOR_DB2_6*/
T0* r794no_space_identifier(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794write_drop(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794scientific_formatter(void);
/*SQL_GENERATOR_DB2_6*/
T0* r794domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlcolumnrequired_base(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794write_procedure(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794value_representation_system_user(T794* C);
/*SQL_GENERATOR_DB2_6*/
T0* r794datatype_ref_int(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794do_sql_cast_to_real(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_extension_function(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_value_alter_table(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T6 r794init_necessary(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794do_do_create_select_list(T794* C,T0* a1,T6 a2);
extern T6 oBC794columnnullallowed;
/*SQL_GENERATOR_DB2_6*/
T0* r794value_representation_float(T794* C);
/*SQL_GENERATOR_DB2_6*/
T6 r794table_has_auto_pk(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794make_valid_identifier(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794columndatatype_type(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_get_insert(T794* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlcolumnidentifier_type(T794* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
T0* r794tabtab(void);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_last_auto_generated_primary_key(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794write_select(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_value_declare_outside_sp(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794drop_procedure(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794datatype_varchar(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794write_assertion(T794* C,T0* a1);
extern T0*oBC794datatype_datetime;
/*SQL_GENERATOR_DB2_6*/
T0* r794value_representation_text(T794* C);
extern T0*oBC794datatype_boolean;
/*SQL_GENERATOR_DB2_6*/
T0* r794make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_infix_expression(T794* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlcolumnconstraint_type(T794* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
T0* r794quoted_value_identifier(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794datatype_pk_int(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_predicate(T794* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
void r794drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_cast_to_date(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794table_name(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794drop_domain(T794* C,T0* a1);
extern T6 oBC794dropcolumnsupported;
/*SQL_GENERATOR_DB2_6*/
T0* r794temporarytableprefix(void);
/*SQL_GENERATOR_DB2_6*/
T0* r794assertion_name(T0* a1);
extern T0*oBC794sqlfalse;
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlcolumndefault_type(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_select_value(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T6 r794createautoprimarykey(T794* C);
/*SQL_GENERATOR_DB2_6*/
void r794create_select_function(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_infix_expression_as_wildcard(T794* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_select_function_as_subselect(T794* C,T0* a1);
extern T6 oBC794autoprimarykeysupported;
/*SQL_GENERATOR_DB2_6*/
void r794create_extend_create_table(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_cast_to_string(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_select_function_as_left_outer_join(T794* C,T0* a1);
extern T0*oBC794target_name;
/*SQL_GENERATOR_DB2_6*/
T0* r794do_sql_cast_to_integer(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794do_sql_select_for_extension_function(T794* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlfunction_nil(void);
/*SQL_GENERATOR_DB2_6*/
void r794write_init(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T6 r794createassert(T794* C);
/*SQL_GENERATOR_DB2_6*/
void r794write_base(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794value_representation_money(T794* C);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_select_joins(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_update(T794* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_DB2_6*/
void r794create_index(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlgetvalue_outside_sp(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794constraint_names(void);
/*SQL_GENERATOR_DB2_6*/
T6 r794createdomaincheck(T794* C);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_select_for_extension_function(T794* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
T0* r794datatype_pk_char(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_combine_expression(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794value_representation_current_timestamp(T794* C);
/*SQL_GENERATOR_DB2_6*/
T0* r794as_string(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794echo(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794datatype_char(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlgetconstant(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794columndatatype_base(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_end(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794write_extend(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T6 r794createviews(T794* C);
/*SQL_GENERATOR_DB2_6*/
void r794write_index(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794constant_identifier(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_value_assign_outside_sp(T794* C,T0* a1);
extern T0*oBC794datatype_money;
/*SQL_GENERATOR_DB2_6*/
void r794optional_create_value_declare(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlcolumnconstraint_base(T794* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
T6 r794check_if_required(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_subselect_for_attribute(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794datatype_int(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T6 r794is_value_data_type_changed(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794datatype_numeric(T0* a1);
extern T0*oBC794datatype_picture;
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_cast_to_integer(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_value_create_table(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlcolumndefault_base(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794column_constraint_name(T794* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlfunction_any(void);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlgetvalue(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794set_sequence_name_format(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794valuetablename(void);
/*SQL_GENERATOR_DB2_6*/
void r794create_constant_assignment(T794* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
T0* r794safe_string(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794do_sql_cast_to_date(T794* C,T0* a1);
extern T6 oBC794domainssupported;
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
T6 r794equal(T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
T0* r794finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_DB2_6*/
void r794write_type(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_combine_expression_as_wildcard(T794* C,T0* a1);
extern T0*oBC794sqlsysfunction_current_timestamp;
/*SQL_GENERATOR_DB2_6*/
T0* r794extension_name(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794createtemporarytablestatement(void);
/*SQL_GENERATOR_DB2_6*/
T6 r794noonelinecommentssupported(void);
/*SQL_GENERATOR_DB2_6*/
void r794create_use_database(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794value_identifier(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794formatter(void);
/*SQL_GENERATOR_DB2_6*/
void r794write_sql(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T6 r794createdomains(T794* C);
/*SQL_GENERATOR_DB2_6*/
void r794write_one_line_comment(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794value_representation_date(T794* C);
/*SQL_GENERATOR_DB2_6*/
void r794create_assertion(T794* C,T0* a1);
extern T2 oBC794maxconstraintidentifierlength;
/*SQL_GENERATOR_DB2_6*/
T0* r794quote_identifier(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_constant(T794* C,T0* a1);
extern T0*oBC794datatype_float;
/*SQL_GENERATOR_DB2_6*/
void r794set_primary_key_format(T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794extension_index_name(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794set_options(T794* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_DB2_6*/
void r794create_view(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794write_use_database(T794* C,T0* a1);
extern T6 oBC794identifierwithspacessupported;
/*SQL_GENERATOR_DB2_6*/
T0* r794domain_identifier(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_value(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T6 r794assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794do_create_select_list(T794* C,T0* a1,T6 a2);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_cast_to_real(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_table(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794value_representation_char(T794* C,T2 a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794value_representation_boolean(T794* C);
/*SQL_GENERATOR_DB2_6*/
T6 r794createtimestamp(T794* C);
/*SQL_GENERATOR_DB2_6*/
T0* r794sp_function_type_for_selection(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794finishtemporarytablestatement(void);
/*SQL_GENERATOR_DB2_6*/
T6 r794coalescesupported(void);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_subselect_for_extension(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794table_pk_name(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794drop_constant(T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_insert(T794* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_DB2_6*/
T0* r794autoprimarykeyconstraint(void);
/*SQL_GENERATOR_DB2_6*/
T6 r794is_value_declared(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794columndatatype_assertion(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlcolumnidentifier_base(T0* a1,T0* a2);
extern T0*oBC794sqltrue;
/*SQL_GENERATOR_DB2_6*/
T6 r794valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
void r794make(T794* C);
extern T2 oBC794maxidentifierlength;
/*SQL_GENERATOR_DB2_6*/
T0* r794value_representation_integer(T794* C,T2 a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794table_ts_name(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_extend_create_index(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T6 r794createindex(void);
/*SQL_GENERATOR_DB2_6*/
T0* r794column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794create_table_name(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794format(T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_expression_as_boolean_value(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794index_name(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_select_joins_oldstyle(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_delete(T794* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_select_joins_ansi92(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794do_sql_cast_to_string(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
void r794create_domain(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_notnot_expression(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_not_expression(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sql_select_for_extension_expression(T794* C,T0* a1);
/*SQL_GENERATOR_DB2_6*/
T0* r794sqlcheck_in(T794* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_6*/
void r794create_value_declare(T794* C,T0* a1);
/*JOIN_LIST*/
void r643copy_role_to_next(T0* a1);
/*JOIN_LIST*/
void r643make(T643* C,T0* a1);
/*JOIN_LIST*/
void r643extend(T643* C,T0* a1,T0* a2);
/*JOIN_LIST*/
void r643add_join_to_aggregate(T643* C,T0* a1,T0* a2,T0* a3);
/*JOIN_LIST*/
T0* r643revert_alist(T0* a1);
/*JOIN_LIST*/
void r643finalize(T643* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818_25Pdrop_table(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818do_create_value_assign(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818output_update_from_clause(T818* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
void r818sp_start(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_extend(T818* C,T0* a1);
extern T0*oBC820datatype_text;
/*SQL_GENERATOR_TSQL2000*/
T0* r818_25Psql_infix_expression(T818* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sp_define_out_param(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818drop_table(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818no_space_identifier(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818write_drop(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818make_valid_sp_identifier(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818scientific_formatter(void);
/*SQL_GENERATOR_TSQL2000*/
T0* r818domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlcolumnrequired_base(T818* C,T0* a1);
extern T0*oBC819asserted_format_string;
/*SQL_GENERATOR_TSQL2000*/
void r818write_procedure(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818value_representation_system_user(T818* C);
extern T6 oBC820checksnullaftertrigger;
/*SQL_GENERATOR_TSQL2000*/
T0* r818datatype_ref_int(T0* a1);
extern T0*oBC819sqlfunction_some;
/*SQL_GENERATOR_TSQL2000*/
T6 r818table_has_identity_column(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818do_sql_cast_to_real(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_extension_function(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_value_alter_table(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T6 r818init_necessary(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818do_do_create_select_list(T818* C,T0* a1,T6 a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818value_representation_float(T818* C);
/*SQL_GENERATOR_TSQL2000*/
T6 r818table_has_auto_pk(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818make_valid_identifier(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818columndatatype_type(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_get_insert(T818* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlcolumnidentifier_type(T818* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818tabtab(void);
extern T0*oBC820sql_last_auto_generated_primary_key;
extern T2 oBC818max_numeric_precision;
/*SQL_GENERATOR_TSQL2000*/
void r818do_create_value_declare(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818_25Psqlcolumnrequired_base(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818write_select(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818datatype_varchar(T0* a1);
extern T0*oBC820datatype_datetime;
/*SQL_GENERATOR_TSQL2000*/
void r818write_assertion(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818value_representation_text(T818* C);
extern T0*oBC820datatype_boolean;
/*SQL_GENERATOR_TSQL2000*/
T0* r818make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_infix_expression(T818* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlcolumnconstraint_type(T818* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818quoted_value_identifier(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818datatype_pk_int(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sp_update_name(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_predicate(T818* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
void r818create_sp_insert(T818* C,T0* a1);
extern T6 oBC798outputparameterssupported;
/*SQL_GENERATOR_TSQL2000*/
void r818drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_cast_to_date(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818_25Pcreate_constant(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818table_name(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818drop_domain(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818do_drop_procedure(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818drop_table_if_exist(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818temporarytableprefix(void);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sp_define_param_name(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818assertion_name(T0* a1);
extern T0*oBC819sqlfalse;
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlcolumndefault_type(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_select_value(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T6 r818createautoprimarykey(T818* C);
/*SQL_GENERATOR_TSQL2000*/
void r818_25Pcreate_table(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_select_function(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T6 r818init_forced_null(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_infix_expression_as_wildcard(T818* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_select_function_as_subselect(T818* C,T0* a1);
extern T6 oBC820autoprimarykeysupported;
/*SQL_GENERATOR_TSQL2000*/
void r818create_extend_create_table(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_cast_to_string(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_select_function_as_left_outer_join(T818* C,T0* a1);
extern T0*oBC818target_name;
/*SQL_GENERATOR_TSQL2000*/
T0* r818do_sql_cast_to_integer(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818do_sql_select_for_extension_function(T818* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlfunction_nil(void);
/*SQL_GENERATOR_TSQL2000*/
void r818write_init(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T6 r818createassert(T818* C);
/*SQL_GENERATOR_TSQL2000*/
void r818write_base(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_sp_delete(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818value_representation_money(T818* C);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_select_joins(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_update(T818* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL2000*/
void r818create_index(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlgetvalue_outside_sp(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818constraint_names(void);
extern T6 oBC820createdomaincheck;
/*SQL_GENERATOR_TSQL2000*/
void r818_25Pwrite_type(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_select_for_extension_function(T818* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818datatype_pk_char(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sp_insert_name(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_combine_expression(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818value_representation_current_timestamp(T818* C);
/*SQL_GENERATOR_TSQL2000*/
T0* r818as_string(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818echo(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818datatype_char(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlgetconstant(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818columndatatype_base(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818_25Pdrop_constant(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818_25Pcreate_insert(T818* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL2000*/
void r818write_extend(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T6 r818createviews(T818* C);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_select_function_limit_before(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818write_index(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818sp_end(T818* C);
/*SQL_GENERATOR_TSQL2000*/
T0* r818constant_identifier(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sp_use_param(T0* a1);
extern T0*oBC820datatype_money;
/*SQL_GENERATOR_TSQL2000*/
T6 r818init_forced_default(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818sp_body_statements(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818optional_create_value_declare(T818* C,T0* a1);
extern T0*oBC820commandseparator;
/*SQL_GENERATOR_TSQL2000*/
void r818conditional_drop_procedure(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlcolumnconstraint_base(T818* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T6 r818check_if_required(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_subselect_for_attribute(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818do_create_select_value(T818* C,T0* a1);
extern T0*oBC820sp_return_parameter_format_string;
/*SQL_GENERATOR_TSQL2000*/
T0* r818datatype_int(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_procedure(T818* C,T0* a1);
extern T2 oBC819maxtemporarytablenamelength;
/*SQL_GENERATOR_TSQL2000*/
T6 r818is_value_data_type_changed(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818datatype_numeric(T0* a1);
extern T0*oBC820datatype_picture;
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_cast_to_integer(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_value_create_table(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818storedprocedureparamlistend(void);
/*SQL_GENERATOR_TSQL2000*/
T0* r818quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlcolumndefault_base(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlgetvalue_inside_sp(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818column_constraint_name(T818* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlfunction_any(void);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlgetvalue(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818set_sequence_name_format(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818valuetablename(void);
/*SQL_GENERATOR_TSQL2000*/
void r818create_constant_assignment(T818* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818safe_string(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818do_sql_cast_to_date(T818* C,T0* a1);
extern T6 oBC25domainssupported;
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818rule_identifier(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818write_type(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T6 r818equal(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_combine_expression_as_wildcard(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818extension_name(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818_25Pcreate_assertion(T818* C,T0* a1);
extern T6 oBC820clusteredindexsupported;
/*SQL_GENERATOR_TSQL2000*/
T0* r818createtemporarytablestatement(void);
/*SQL_GENERATOR_TSQL2000*/
void r818output_update_extend_from_clause(T818* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T6 r818noonelinecommentssupported(void);
/*SQL_GENERATOR_TSQL2000*/
void r818create_use_database(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818value_identifier(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818init_trigger_name(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818formatter(void);
/*SQL_GENERATOR_TSQL2000*/
void r818write_sql(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T6 r818createdomains(T818* C);
/*SQL_GENERATOR_TSQL2000*/
void r818write_one_line_comment(T0* a1);
extern T0*oBC820primarykeyconstraint;
/*SQL_GENERATOR_TSQL2000*/
T0* r818value_representation_date(T818* C);
/*SQL_GENERATOR_TSQL2000*/
void r818create_assertion(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818_798Psp_start(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818quote_identifier(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_constant(T818* C,T0* a1);
extern T0*oBC820datatype_float;
/*SQL_GENERATOR_TSQL2000*/
void r818drop_sp(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818set_primary_key_format(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818extension_index_name(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818set_options(T818* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_TSQL2000*/
void r818create_view(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818write_use_database(T818* C,T0* a1);
extern T6 oBC820identifierwithspacessupported;
extern T6 oBC798namedparameterssupported;
/*SQL_GENERATOR_TSQL2000*/
T0* r818domain_identifier(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_value(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818sp_user_result(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_sp_update(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T6 r818assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_value_assign(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818do_create_select_list(T818* C,T0* a1,T6 a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818storedprocedurereturnparamliststart(void);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_cast_to_real(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlcolumnrequired_type(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sp_get_auto_generated_primary_key(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_table(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818value_representation_char(T818* C,T2 a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818value_representation_boolean(T818* C);
/*SQL_GENERATOR_TSQL2000*/
T6 r818createtimestamp(T818* C);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sp_function_type_for_selection(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818finishtemporarytablestatement(void);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sp_name(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T6 r818coalescesupported(void);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_subselect_for_extension(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818table_pk_name(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818drop_constant(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_insert(T818* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sp_delete_name(T818* C,T0* a1);
extern T0*oBC820autoprimarykeyconstraint;
extern int fBC820autoprimarykeyconstraint;
/*SQL_GENERATOR_TSQL2000*/
T0* r818autoprimarykeyconstraint(void);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sp_define_in_param(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T6 r818is_value_declared(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818columndatatype_assertion(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlcolumnidentifier_base(T0* a1,T0* a2);
extern T0*oBC819sqltrue;
/*SQL_GENERATOR_TSQL2000*/
T6 r818valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
void r818make(T818* C);
extern T2 oBC819maxidentifierlength;
/*SQL_GENERATOR_TSQL2000*/
T0* r818value_representation_integer(T818* C,T2 a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_echo(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818_25Pcreate_index(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818_25Psqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818table_ts_name(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_extend_create_index(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T6 r818createindex(void);
/*SQL_GENERATOR_TSQL2000*/
T0* r818column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818create_table_name(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_init(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818format(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_expression_as_boolean_value(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818index_name(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_select_joins_oldstyle(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_delete(T818* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_select_joins_ansi92(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818do_sql_cast_to_string(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
void r818create_domain(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_notnot_expression(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818storedprocedureparamliststart(void);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_not_expression(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sql_select_for_extension_expression(T818* C,T0* a1);
/*SQL_GENERATOR_TSQL2000*/
T0* r818sqlcheck_in(T818* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL2000*/
void r818create_value_declare(T818* C,T0* a1);
/*XPLAIN_TYPE*/
T0* r209sqlcolumnrequired(T0* a1,T0* a2);
/*XPLAIN_TYPE*/
T0* r209out(T209* C);
/*XPLAIN_TYPE*/
T0* r209quoted_name(T209* C,T0* a1);
/*XPLAIN_TYPE*/
T0* r209sqlpkname(T209* C,T0* a1);
/*XPLAIN_TYPE*/
T0* r209new_data_attributes_cursor(T209* C,T0* a1);
/*XPLAIN_TYPE*/
void r209remove_extension(T209* C,T0* a1);
/*XPLAIN_TYPE*/
T0* r209columndatatype(T209* C,T0* a1);
/*XPLAIN_TYPE*/
T6 r209is_equal(T209* C,T0* a1);
/*XPLAIN_TYPE*/
T0* r209sqlcolumnidentifier(T209* C,T0* a1,T0* a2);
/*XPLAIN_TYPE*/
T0* r209q_sql_select_name(T209* C,T0* a1,T0* a2);
/*XPLAIN_TYPE*/
T0* r209sqlcolumndefault(T0* a1,T0* a2);
/*XPLAIN_TYPE*/
void r209add_extension(T209* C,T0* a1);
/*XPLAIN_TYPE*/
T0* r209create_expression(T0* a1);
/*XPLAIN_TYPE*/
void r209write_drop_attribute(T209* C,T0* a1,T0* a2);
/*XPLAIN_TYPE*/
void r209out_in_tagged_out_memory(T209* C);
/*XPLAIN_TYPE*/
T0* r209q_sqlpkname(T209* C,T0* a1);
/*XPLAIN_TYPE*/
void r209add_assertion(T209* C,T0* a1);
/*XPLAIN_TYPE*/
void r209make_abstract_type(T209* C,T0* a1,T0* a2);
/*XPLAIN_TYPE*/
void r209make(T209* C,T0* a1,T0* a2,T0* a3);
/*XPLAIN_TYPE*/
T6 r209has_non_constant_init(T209* C);
/*XPLAIN_TYPE*/
T6 r209equal(T0* a1,T0* a2);
/*XPLAIN_TYPE*/
T2 r209hash_code(T209* C);
/*XPLAIN_TYPE*/
T6 r209has_non_literal_init(T209* C);
/*XPLAIN_TYPE*/
T6 r209has_updatable_attributes(T209* C);
/*XPLAIN_TYPE*/
T0* r209new_all_attributes_cursor(T209* C,T0* a1);
/*XPLAIN_TYPE*/
void r209write_drop(T209* C,T0* a1);
/*XPLAIN_TYPE*/
T0* r209sql_select_name(T209* C,T0* a1,T0* a2);
/*XPLAIN_TYPE*/
T0* r209sqlname(T209* C,T0* a1);
/*XPLAIN_TYPE*/
T0* r209find_attribute(T209* C,T0* a1);
/*XPLAIN_TYPE*/
T0* r209new_init_attributes_cursor(T209* C,T0* a1);
/*XPLAIN_TYPE*/
void r209next_constraint_number(T209* C);
/*XPLAIN_TYPE*/
T6 r209has_auto_pk(T209* C,T0* a1);
/*XPLAIN_TYPE*/
T6 r209has_attribute(T209* C,T0* a1,T0* a2);
/*XPLAIN_TYPE*/
T0* r209sqltablename(T209* C,T0* a1);
/*XPLAIN_LIKE_EXPRESSION*/
void r585add_to_join(T585* C,T0* a1,T0* a2);
/*XPLAIN_LIKE_EXPRESSION*/
T6 r585uses_parameter(T585* C,T0* a1);
/*XPLAIN_LIKE_EXPRESSION*/
T0* r585sqlmaxvalue(T585* C,T0* a1);
extern T0*oBC585xplain_operator;
/*XPLAIN_LIKE_EXPRESSION*/
void r585make_infix(T585* C,T0* a1,T0* a2,T0* a3);
/*XPLAIN_LIKE_EXPRESSION*/
T6 r585is_string_expression(void);
/*XPLAIN_LIKE_EXPRESSION*/
T0* r585representation(T585* C,T0* a1);
/*XPLAIN_LIKE_EXPRESSION*/
T0* r585outer_sqlvalue(T585* C,T0* a1);
extern T0*oBC585sqloperator;
/*XPLAIN_LIKE_EXPRESSION*/
T0* r585sqlvalue_as_wildcard(T585* C,T0* a1);
/*XPLAIN_LIKE_EXPRESSION*/
T6 r585is_using_other_attributes(T585* C,T0* a1);
/*XPLAIN_LIKE_EXPRESSION*/
T0* r585exact_representation(T585* C,T0* a1);
/*XPLAIN_LIKE_EXPRESSION*/
T6 r585is_literal(T585* C);
/*XPLAIN_LIKE_EXPRESSION*/
T0* r585sqlvalue(T585* C,T0* a1);
/*XPLAIN_LIKE_EXPRESSION*/
void r585make_two_operands(T585* C,T0* a1,T0* a2);
/*XPLAIN_LIKE_EXPRESSION*/
T0* r585sqlinitvalue(T585* C,T0* a1);
/*XPLAIN_LIKE_EXPRESSION*/
T0* r585sqlminvalue(T585* C,T0* a1);
/*XPLAIN_LIKE_EXPRESSION*/
T6 r585has_wild_card_characters(T585* C);
/*XPLAIN_A_REPRESENTATION*/
T0* r609domain(T609* C);
/*XPLAIN_A_REPRESENTATION*/
T0* r609min_value(T0* a1);
extern T0*oBC609default_value;
/*XPLAIN_A_REPRESENTATION*/
T0* r609value_representation(T609* C,T0* a1);
/*XPLAIN_A_REPRESENTATION*/
void r609set_domain_restriction(T609* C,T0* a1,T0* a2);
/*XPLAIN_A_REPRESENTATION*/
T0* r609xml_schema_data_type(void);
/*XPLAIN_A_REPRESENTATION*/
T0* r609max_value(T0* a1);
/*XPLAIN_A_REPRESENTATION*/
T0* r609datatype(T609* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810drop_value(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_extend(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810datatype_text(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810drop_table(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810no_space_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810write_drop(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810scientific_formatter(void);
/*SQL_GENERATOR_MYSQL322*/
T0* r810domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlcolumnrequired_base(T810* C,T0* a1);
extern T6 oBC809temporarytablessupported;
/*SQL_GENERATOR_MYSQL322*/
void r810write_procedure(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810value_representation_system_user(T810* C);
extern T6 oBC809constraintnamesupported;
/*SQL_GENERATOR_MYSQL322*/
T0* r810datatype_ref_int(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810do_sql_cast_to_real(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_extension_function(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_value_alter_table(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T6 r810init_necessary(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810do_do_create_select_list(T810* C,T0* a1,T6 a2);
/*SQL_GENERATOR_MYSQL322*/
T0* r810value_representation_float(T810* C);
/*SQL_GENERATOR_MYSQL322*/
T6 r810table_has_auto_pk(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810make_valid_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810columndatatype_type(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_get_insert(T810* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlcolumnidentifier_type(T810* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
T0* r810tabtab(void);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_last_auto_generated_primary_key(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810write_select(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_value_declare_outside_sp(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810drop_procedure(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810write_assertion(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810datatype_datetime(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810datatype_varchar(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810value_representation_text(T810* C);
/*SQL_GENERATOR_MYSQL322*/
T0* r810datatype_boolean(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_infix_expression(T810* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlcolumnconstraint_type(T810* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
T0* r810quoted_value_identifier(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810datatype_pk_int(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_predicate(T810* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
void r810drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_cast_to_date(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810table_name(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810drop_domain(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810temporarytableprefix(void);
/*SQL_GENERATOR_MYSQL322*/
T0* r810assertion_name(T0* a1);
extern T0*oBC809sqlfalse;
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlcolumndefault_type(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_select_value(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T6 r810createautoprimarykey(T810* C);
/*SQL_GENERATOR_MYSQL322*/
void r810create_select_function(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_infix_expression_as_wildcard(T810* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_select_function_as_subselect(T810* C,T0* a1);
extern T6 oBC809autoprimarykeysupported;
/*SQL_GENERATOR_MYSQL322*/
void r810create_extend_create_table(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_cast_to_string(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_select_function_as_left_outer_join(T810* C,T0* a1);
extern T0*oBC810target_name;
/*SQL_GENERATOR_MYSQL322*/
T0* r810do_sql_cast_to_integer(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810do_sql_select_for_extension_function(T810* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlfunction_nil(void);
/*SQL_GENERATOR_MYSQL322*/
void r810write_init(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T6 r810createassert(T810* C);
/*SQL_GENERATOR_MYSQL322*/
void r810write_base(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810value_representation_money(T810* C);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_select_joins(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_update(T810* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MYSQL322*/
void r810create_index(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlgetvalue_outside_sp(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810constraint_names(void);
/*SQL_GENERATOR_MYSQL322*/
T6 r810createdomaincheck(T810* C);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_select_for_extension_function(T810* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
T0* r810datatype_pk_char(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_combine_expression(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810value_representation_current_timestamp(T810* C);
/*SQL_GENERATOR_MYSQL322*/
T0* r810as_string(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810echo(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810datatype_char(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlgetconstant(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810columndatatype_base(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810write_extend(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T6 r810createviews(T810* C);
extern T6 oBC809checkconstraintsupported;
/*SQL_GENERATOR_MYSQL322*/
void r810write_index(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810constant_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_value_assign_outside_sp(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810datatype_money(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810optional_create_value_declare(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlcolumnconstraint_base(T810* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
T6 r810check_if_required(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_subselect_for_attribute(T810* C,T0* a1);
extern T6 oBC809inlineuniqueconstraintsupported;
/*SQL_GENERATOR_MYSQL322*/
T0* r810datatype_int(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T6 r810is_value_data_type_changed(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810datatype_numeric(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810datatype_picture(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_cast_to_integer(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_value_create_table(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlcolumndefault_base(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810column_constraint_name(T810* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlfunction_any(void);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlgetvalue(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810set_sequence_name_format(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810valuetablename(void);
/*SQL_GENERATOR_MYSQL322*/
void r810create_constant_assignment(T810* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
T0* r810safe_string(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810do_sql_cast_to_date(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
T6 r810equal(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
T0* r810finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_MYSQL322*/
void r810write_type(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_combine_expression_as_wildcard(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810extension_name(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810createtemporarytablestatement(void);
/*SQL_GENERATOR_MYSQL322*/
T6 r810noonelinecommentssupported(void);
/*SQL_GENERATOR_MYSQL322*/
T0* r810value_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810formatter(void);
/*SQL_GENERATOR_MYSQL322*/
void r810write_sql(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T6 r810createdomains(T810* C);
/*SQL_GENERATOR_MYSQL322*/
void r810write_one_line_comment(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810value_representation_date(T810* C);
/*SQL_GENERATOR_MYSQL322*/
void r810create_assertion(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810quote_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_constant(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810datatype_float(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810set_primary_key_format(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810extension_index_name(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810set_options(T810* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_MYSQL322*/
void r810create_view(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810write_use_database(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810domain_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_value(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T6 r810assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810do_create_select_list(T810* C,T0* a1,T6 a2);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_cast_to_real(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_table(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810value_representation_char(T810* C,T2 a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810value_representation_boolean(T810* C);
/*SQL_GENERATOR_MYSQL322*/
T6 r810createtimestamp(T810* C);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sp_function_type_for_selection(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810finishtemporarytablestatement(void);
/*SQL_GENERATOR_MYSQL322*/
T6 r810coalescesupported(void);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_subselect_for_extension(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810table_pk_name(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810drop_constant(T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_insert(T810* C,T0* a1,T0* a2,T0* a3);
extern T0*oBC810autoprimarykeyconstraint;
extern int fBC810autoprimarykeyconstraint;
/*SQL_GENERATOR_MYSQL322*/
T0* r810autoprimarykeyconstraint(void);
/*SQL_GENERATOR_MYSQL322*/
T6 r810is_value_declared(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810columndatatype_assertion(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlcolumnidentifier_base(T0* a1,T0* a2);
extern T0*oBC809sqltrue;
/*SQL_GENERATOR_MYSQL322*/
T6 r810valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
void r810make(T810* C);
extern T2 oBC809maxidentifierlength;
/*SQL_GENERATOR_MYSQL322*/
T0* r810value_representation_integer(T810* C,T2 a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810table_ts_name(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_extend_create_index(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T6 r810createindex(void);
/*SQL_GENERATOR_MYSQL322*/
T0* r810column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810create_table_name(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810format(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_expression_as_boolean_value(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810index_name(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_select_joins_oldstyle(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_delete(T810* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_select_joins_ansi92(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810do_sql_cast_to_string(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
void r810create_domain(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_notnot_expression(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_not_expression(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sql_select_for_extension_expression(T810* C,T0* a1);
/*SQL_GENERATOR_MYSQL322*/
T0* r810sqlcheck_in(T810* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL322*/
void r810create_value_declare(T810* C,T0* a1);
/*XPLAIN_VALUE_EXPRESSION*/
T6 r625uses_parameter(T625* C,T0* a1);
/*XPLAIN_VALUE_EXPRESSION*/
T0* r625sqlmaxvalue(T625* C,T0* a1);
/*XPLAIN_VALUE_EXPRESSION*/
T6 r625is_string_expression(void);
/*XPLAIN_VALUE_EXPRESSION*/
T0* r625representation(T625* C,T0* a1);
/*XPLAIN_VALUE_EXPRESSION*/
T0* r625outer_sqlvalue(T625* C,T0* a1);
/*XPLAIN_VALUE_EXPRESSION*/
T0* r625sqlvalue_as_wildcard(T625* C,T0* a1);
/*XPLAIN_VALUE_EXPRESSION*/
T0* r625exact_representation(T625* C,T0* a1);
/*XPLAIN_VALUE_EXPRESSION*/
T6 r625is_literal(T625* C);
/*XPLAIN_VALUE_EXPRESSION*/
T0* r625sqlvalue(T625* C,T0* a1);
/*XPLAIN_VALUE_EXPRESSION*/
T0* r625sqlinitvalue(T625* C,T0* a1);
/*XPLAIN_VALUE_EXPRESSION*/
T0* r625sqlminvalue(T625* C,T0* a1);
/*XPLAIN_UPDATE_STATEMENT*/
T6 r86uses_parameter(T86* C,T0* a1);
/*XPLAIN_UPDATE_STATEMENT*/
void r86write(T86* C,T0* a1);
/*XPLAIN_UPDATE_STATEMENT*/
void r86make(T86* C,T0* a1,T0* a2,T0* a3);
/*XPLAIN_DATA_ATTRIBUTES_CURSOR*/
void r425ds_make(T425* C,T0* a1);
/*XPLAIN_DATA_ATTRIBUTES_CURSOR*/
void r425set(T425* C,T0* a1,T6 a2,T6 a3);
/*XPLAIN_DATA_ATTRIBUTES_CURSOR*/
T6 r425is_last(T425* C);
/*XPLAIN_DATA_ATTRIBUTES_CURSOR*/
void r425forth(T425* C);
/*XPLAIN_DATA_ATTRIBUTES_CURSOR*/
T6 r425is_not_virtual_attribute(T425* C);
/*XPLAIN_DATA_ATTRIBUTES_CURSOR*/
void r425_404Pforth(T425* C);
/*XPLAIN_DATA_ATTRIBUTES_CURSOR*/
void r425start(T425* C);
/*XPLAIN_DATA_ATTRIBUTES_CURSOR*/
void r425set_after(T425* C);
/*XPLAIN_DATA_ATTRIBUTES_CURSOR*/
void r425_404Pstart(T425* C);
/*XPLAIN_ATTRIBUTE_NODE*/
void r255make(T255* C,T0* a1,T0* a2);
/*JOIN*/
T6 r645is_inner_join(T645* C);
/*JOIN*/
void r645make(T645* C,T0* a1,T0* a2,T0* a3,T0* a4,T0* a5,T0* a6,T6 a7,T6 a8);
/*XPLAIN_INDEX*/
void r630make(T630* C,T0* a1,T0* a2,T6 a3,T6 a4,T0* a5);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802_25Pdrop_table(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802drop_value(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802sp_start(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_extend(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802datatype_text(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sp_define_out_param(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802drop_table(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802_25Pdrop_value(T802* C,T0* a1);
extern T0*oBC801sqlsysfunction_system_user;
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802no_space_identifier(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802write_drop(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802make_valid_sp_identifier(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802scientific_formatter(void);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlcolumnrequired_base(T802* C,T0* a1);
extern T0*oBC801asserted_format_string;
/*SQL_GENERATOR_FIREBIRD_21*/
void r802write_procedure(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802value_representation_system_user(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802datatype_ref_int(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_value_declare_inside_sp(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802do_sql_cast_to_real(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_extension_function(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802_25Pcreate_extend_create_index(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_value_alter_table(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802init_necessary(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802do_do_create_select_list(T802* C,T0* a1,T6 a2);
extern T6 oBC801columnnullallowed;
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802value_representation_float(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802table_has_auto_pk(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802make_valid_identifier(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802columndatatype_type(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_get_insert(T802* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlcolumnidentifier_type(T802* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802tabtab(void);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_last_auto_generated_primary_key(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802drop_primary_key_generator(T802* C,T0* a1);
extern T2 oBC800max_numeric_precision;
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_value_assign_inside_sp(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802_25Psqlcolumnrequired_base(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802write_select(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_value_declare_outside_sp(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802datatype_varchar(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802datatype_datetime(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802write_assertion(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802value_representation_text(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802datatype_boolean(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_infix_expression(T802* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlcolumnconstraint_type(T802* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802quoted_value_identifier(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802datatype_pk_int(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sp_update_name(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_predicate(T802* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_sp_insert(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_cast_to_date(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802table_name(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802drop_domain(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_init_cast_to_real(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802do_drop_procedure(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802temporarytableprefix(void);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sp_define_param_name(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802assertion_name(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlcolumndefault_type(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_select_value(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802createautoprimarykey(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802_25Pcreate_table(T802* C,T0* a1);
extern T6 oBC801domainnullallowed;
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_select_function(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802init_forced_null(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_infix_expression_as_wildcard(T802* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_select_function_as_subselect(T802* C,T0* a1);
extern T6 oBC801autoprimarykeysupported;
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_extend_create_table(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_cast_to_string(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_select_function_as_left_outer_join(T802* C,T0* a1);
extern T0*oBC802target_name;
/*SQL_GENERATOR_FIREBIRD_21*/
void r802_25Pcreate_select_list(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802do_sql_select_for_extension_function(T802* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802do_sql_cast_to_integer(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlfunction_nil(void);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802write_init(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802createassert(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_select_value_inside_sp(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802write_base(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_sp_delete(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802value_representation_money(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_init_infix_expression(T802* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_select_joins(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_update(T802* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_index(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlgetvalue_outside_sp(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802constraint_names(void);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802createdomaincheck(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802_25Pwrite_type(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_init_cast_to_string(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_select_for_extension_function(T802* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802datatype_pk_char(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_select_list(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sp_insert_name(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_combine_expression(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802value_representation_current_timestamp(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802as_string(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_init_expression(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802echo(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802datatype_char(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlgetconstant(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802columndatatype_base(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802generator_name(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802write_extend(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802createviews(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802write_index(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802constant_identifier(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_value_assign_outside_sp(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802sp_end(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sp_use_param(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802datatype_money(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802sp_body_statements(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802optional_create_value_declare(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlcolumnconstraint_base(T802* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802check_if_required(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_subselect_for_attribute(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802datatype_int(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_procedure(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802is_value_data_type_changed(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802datatype_numeric(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802datatype_picture(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_cast_to_integer(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_value_create_table(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802storedprocedureparamlistend(void);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802_25Pcreate_select_function(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlcolumndefault_base(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlgetvalue_inside_sp(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802column_constraint_name(T802* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlfunction_any(void);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlgetvalue(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802set_sequence_name_format(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802valuetablename(void);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_constant_assignment(T802* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802safe_string(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802do_sql_cast_to_date(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802write_type(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802equal(T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_combine_expression_as_wildcard(T802* C,T0* a1);
extern T0*oBC801sqlsysfunction_current_timestamp;
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802extension_name(T0* a1);
extern T0*oBC802createtemporarytablestatement;
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802noonelinecommentssupported(void);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_use_database(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802value_identifier(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_primary_key_generator(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802formatter(void);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802write_sql(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802createdomains(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802write_one_line_comment(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802value_representation_date(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_assertion(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802_798Psp_start(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802quote_identifier(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_constant(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802drop_sp(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802datatype_float(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802set_primary_key_format(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802extension_index_name(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802set_options(T802* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_init_cast_to_date(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_view(T802* C,T0* a1);
extern T0*oBC802sqlcoalesce;
/*SQL_GENERATOR_FIREBIRD_21*/
void r802write_use_database(T802* C,T0* a1);
extern T6 oBC800identifierwithspacessupported;
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802domain_identifier(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_value(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802sp_user_result(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_sp_update(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_value_assign(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802do_create_select_list(T802* C,T0* a1,T6 a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_cast_to_real(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlcolumnrequired_type(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sp_get_auto_generated_primary_key(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_table(T802* C,T0* a1);
extern T0*oBC801onelinecommentprefix;
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802value_representation_char(T802* C,T2 a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802value_representation_boolean(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802createtimestamp(T802* C);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sp_function_type_for_selection(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlcheck_boolean(T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_init_combine_expression(T802* C,T0* a1);
extern T6 oBC801supportsdefaultvalues;
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlinitvalue_if(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802_801Pcreate_use_database(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sp_name(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802coalescesupported(void);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_subselect_for_extension(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlinitvalue_attribute(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802table_pk_name(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802drop_constant(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_insert(T802* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sp_delete_name(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802autoprimarykeyconstraint(void);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sp_define_in_param(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802is_value_declared(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802columndatatype_assertion(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_init_cast_to_integer(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802make(T802* C);
extern T2 oBC801maxidentifierlength;
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802value_representation_integer(T802* C,T2 a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802sp_user_declaration(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802_25Psqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802table_ts_name(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_extend_create_index(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T6 r802createindex(void);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802create_table_name(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_init(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802format(T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_expression_as_boolean_value(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802index_name(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_select_joins_oldstyle(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_delete(T802* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_select_joins_ansi92(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802do_sql_cast_to_string(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_domain(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_notnot_expression(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802storedprocedureparamliststart(void);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_not_expression(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sql_select_for_extension_expression(T802* C,T0* a1);
/*SQL_GENERATOR_FIREBIRD_21*/
T0* r802sqlcheck_in(T802* C,T0* a1,T0* a2);
/*SQL_GENERATOR_FIREBIRD_21*/
void r802create_value_declare(T802* C,T0* a1);
/*XPLAIN_ASSERTION_EXPRESSION*/
void r851add_to_join(T851* C,T0* a1,T0* a2);
/*XPLAIN_ASSERTION_EXPRESSION*/
T6 r851uses_parameter(T0* a1);
/*XPLAIN_ASSERTION_EXPRESSION*/
T0* r851sqlmaxvalue(T851* C,T0* a1);
/*XPLAIN_ASSERTION_EXPRESSION*/
T6 r851is_string_expression(void);
/*XPLAIN_ASSERTION_EXPRESSION*/
T0* r851representation(T851* C,T0* a1);
/*XPLAIN_ASSERTION_EXPRESSION*/
void r851make(T851* C,T0* a1,T0* a2);
/*XPLAIN_ASSERTION_EXPRESSION*/
T0* r851outer_sqlvalue(T851* C,T0* a1);
/*XPLAIN_ASSERTION_EXPRESSION*/
T0* r851sqlvalue_as_wildcard(T851* C,T0* a1);
/*XPLAIN_ASSERTION_EXPRESSION*/
T6 r851is_using_other_attributes(T851* C,T0* a1);
/*XPLAIN_ASSERTION_EXPRESSION*/
T0* r851exact_representation(T851* C,T0* a1);
/*XPLAIN_ASSERTION_EXPRESSION*/
T0* r851sqlvalue(T851* C,T0* a1);
/*XPLAIN_ASSERTION_EXPRESSION*/
T0* r851sqlinitvalue(T851* C,T0* a1);
/*XPLAIN_ASSERTION_EXPRESSION*/
T0* r851sqlminvalue(T851* C,T0* a1);
/*KL_STDIN_FILE*/
T2 r768read_to_string(T768* C,T0* a1,T2 a2,T2 a3);
/*KL_STDIN_FILE*/
void r768old_read_character(T768* C);
/*KL_STDIN_FILE*/
void r768read_character(T768* C);
/*KL_STDIN_FILE*/
void r768fill_buffer(T768* C);
/*KL_STDIN_FILE*/
void r768make(T768* C);
/*KL_STDIN_FILE*/
T2 r768read_to_buffer(T768* C,T0* a1,T2 a2,T2 a3);
extern T0*oBC19std_output;
/*KL_STDIN_FILE*/
void r768old_make(T768* C);
/*KL_STDIN_FILE*/
T2 r768_45Pread_to_buffer(T768* C,T0* a1,T2 a2,T2 a3);
/*KL_CHARACTER_BUFFER*/
T0* r503substring(T503* C,T2 a1,T2 a2);
/*KL_CHARACTER_BUFFER*/
T2 r503fill_from_stream(T503* C,T0* a1,T2 a2,T2 a3);
/*KL_CHARACTER_BUFFER*/
void r503move_left(T503* C,T2 a1,T2 a2,T2 a3);
/*KL_CHARACTER_BUFFER*/
void r503make(T503* C,T2 a1);
/*KL_CHARACTER_BUFFER*/
void r503resize(T503* C,T2 a1);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
void r570add_to_join(T570* C,T0* a1,T0* a2);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
T6 r570uses_parameter(T570* C,T0* a1);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
T0* r570sqlmaxvalue(T570* C,T0* a1);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
T6 r570is_string_expression(void);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
T0* r570representation(T570* C,T0* a1);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
void r570make(T570* C,T0* a1,T0* a2,T0* a3);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
T0* r570outer_sqlvalue(T570* C,T0* a1);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
T0* r570sqlvalue_as_wildcard(T570* C,T0* a1);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
T6 r570is_using_other_attributes(T570* C,T0* a1);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
T0* r570exact_representation(T570* C,T0* a1);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
T6 r570is_literal(T570* C);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
T0* r570sqlvalue(T570* C,T0* a1);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
void r570make_two_operands(T570* C,T0* a1,T0* a2);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
T0* r570sqlinitvalue(T570* C,T0* a1);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
T0* r570sqlminvalue(T570* C,T0* a1);
/*XPLAIN_LOGICAL_INFIX_EXPRESSION*/
T6 r570has_wild_card_characters(T570* C);
/*XPLAIN_STATEMENTS*/
void r66make(T66* C);
/*XPLAIN_STATEMENTS*/
void r66add(T66* C,T0* a1);
/*XML_WRITER*/
void r858set_attribute(T858* C,T0* a1,T0* a2);
/*XML_WRITER*/
void r858add_header(T858* C,T0* a1);
/*XML_WRITER*/
T0* r858make_valid_attribute_value(T0* a1);
/*XML_WRITER*/
void r858clear_attributes(T858* C);
/*XML_WRITER*/
void r858add_attribute(T858* C,T0* a1);
/*XML_WRITER*/
T6 r858on_new_line(T858* C);
/*XML_WRITER*/
void r858assure_last_tag_written(T858* C);
/*XML_WRITER*/
T0* r858empty_tag_closing_chars(void);
/*XML_WRITER*/
T6 r858exist_attribute(T858* C,T0* a1);
/*XML_WRITER*/
void r858extend(T858* C,T0* a1);
/*XML_WRITER*/
void r858make_with_capacity(T858* C,T2 a1);
/*XML_WRITER*/
void r858indent(T858* C);
/*XML_WRITER*/
void r858clear(T858* C);
/*XML_WRITER*/
void r858start_tag(T858* C,T0* a1);
/*XML_WRITER*/
void r858stop_tag(T858* C);
/*XML_WRITER*/
void r858do_set_attribute(T858* C,T0* a1,T0* a2);
/*KL_TEXT_OUTPUT_FILE*/
T6 r852is_closed(T852* C);
/*KL_TEXT_OUTPUT_FILE*/
void r852old_close(T852* C);
/*KL_TEXT_OUTPUT_FILE*/
void r852old_open_write(T852* C);
/*KL_TEXT_OUTPUT_FILE*/
void r852close(T852* C);
/*KL_TEXT_OUTPUT_FILE*/
void r852make(T852* C,T0* a1);
/*KL_TEXT_OUTPUT_FILE*/
void r852old_put_string(T852* C,T0* a1);
/*KL_TEXT_OUTPUT_FILE*/
void r852old_put_character(T852* C,T3 a1);
/*KL_TEXT_OUTPUT_FILE*/
void r852connect_to(T852* C,T0* a1);
/*KL_TEXT_OUTPUT_FILE*/
void r852old_make(T852* C);
/*KL_TEXT_OUTPUT_FILE*/
void r852open_write(T852* C);
/*KL_TEXT_OUTPUT_FILE*/
void r852write_buffer(T852* C);
/*XPLAIN_EXTEND_STATEMENT*/
T6 r116uses_parameter(T116* C,T0* a1);
/*XPLAIN_EXTEND_STATEMENT*/
void r116write(T116* C,T0* a1);
/*XPLAIN_EXTEND_STATEMENT*/
void r116cleanup(T116* C);
/*SQL_GENERATOR_BASIC*/
void r773drop_value(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_extend(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773datatype_text(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773drop_table(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773no_space_identifier(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773write_drop(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773scientific_formatter(void);
/*SQL_GENERATOR_BASIC*/
T0* r773domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlcolumnrequired_base(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773write_procedure(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773value_representation_system_user(T773* C);
/*SQL_GENERATOR_BASIC*/
T0* r773datatype_ref_int(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773do_sql_cast_to_real(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_extension_function(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_value_alter_table(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T6 r773init_necessary(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773do_do_create_select_list(T773* C,T0* a1,T6 a2);
/*SQL_GENERATOR_BASIC*/
T0* r773value_representation_float(T773* C);
/*SQL_GENERATOR_BASIC*/
T6 r773table_has_auto_pk(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773make_valid_identifier(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773columndatatype_type(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_get_insert(T773* C,T0* a1,T0* a2,T6 a3,T0* a4);
extern T6 oBC773viewssupported;
/*SQL_GENERATOR_BASIC*/
T0* r773sqlcolumnidentifier_type(T773* C,T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T0* r773tabtab(void);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_last_auto_generated_primary_key(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773write_select(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_value_declare_outside_sp(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773drop_procedure(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773write_assertion(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773datatype_datetime(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773datatype_varchar(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773value_representation_text(T773* C);
/*SQL_GENERATOR_BASIC*/
T0* r773datatype_boolean(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_infix_expression(T773* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlcolumnconstraint_type(T773* C,T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T0* r773quoted_value_identifier(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773datatype_pk_int(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_predicate(T773* C,T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
void r773drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_cast_to_date(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773table_name(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773drop_domain(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773temporarytableprefix(void);
/*SQL_GENERATOR_BASIC*/
T0* r773assertion_name(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlcolumndefault_type(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_select_value(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T6 r773createautoprimarykey(T773* C);
/*SQL_GENERATOR_BASIC*/
void r773create_select_function(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_infix_expression_as_wildcard(T773* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_select_function_as_subselect(T773* C,T0* a1);
extern T6 oBC773autoprimarykeysupported;
/*SQL_GENERATOR_BASIC*/
void r773create_extend_create_table(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_cast_to_string(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_select_function_as_left_outer_join(T773* C,T0* a1);
extern T0*oBC773target_name;
/*SQL_GENERATOR_BASIC*/
T0* r773do_sql_cast_to_integer(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773do_sql_select_for_extension_function(T773* C,T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlfunction_nil(void);
/*SQL_GENERATOR_BASIC*/
void r773write_init(T0* a1);
/*SQL_GENERATOR_BASIC*/
T6 r773createassert(T773* C);
/*SQL_GENERATOR_BASIC*/
void r773write_base(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773value_representation_money(T773* C);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_select_joins(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_update(T773* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_BASIC*/
void r773create_index(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlgetvalue_outside_sp(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773constraint_names(void);
/*SQL_GENERATOR_BASIC*/
T6 r773createdomaincheck(T773* C);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_select_for_extension_function(T773* C,T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T0* r773datatype_pk_char(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_combine_expression(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773value_representation_current_timestamp(T773* C);
/*SQL_GENERATOR_BASIC*/
T0* r773as_string(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773echo(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773datatype_char(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlgetconstant(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773columndatatype_base(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773write_extend(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T6 r773createviews(T773* C);
/*SQL_GENERATOR_BASIC*/
void r773write_index(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773constant_identifier(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_value_assign_outside_sp(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773datatype_money(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773optional_create_value_declare(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlcolumnconstraint_base(T773* C,T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T6 r773check_if_required(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_subselect_for_attribute(T773* C,T0* a1);
extern T0*oBC25datatype_int;
/*SQL_GENERATOR_BASIC*/
T6 r773is_value_data_type_changed(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773datatype_numeric(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773datatype_picture(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_cast_to_integer(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_value_create_table(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlcolumndefault_base(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773column_constraint_name(T773* C,T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlfunction_any(void);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlgetvalue(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773set_sequence_name_format(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773valuetablename(void);
/*SQL_GENERATOR_BASIC*/
void r773create_constant_assignment(T773* C,T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T0* r773safe_string(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773do_sql_cast_to_date(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T6 r773equal(T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T0* r773finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_BASIC*/
void r773write_type(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_combine_expression_as_wildcard(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773extension_name(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773createtemporarytablestatement(void);
/*SQL_GENERATOR_BASIC*/
T6 r773noonelinecommentssupported(void);
/*SQL_GENERATOR_BASIC*/
T0* r773value_identifier(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773formatter(void);
/*SQL_GENERATOR_BASIC*/
void r773write_sql(T0* a1);
/*SQL_GENERATOR_BASIC*/
T6 r773createdomains(T773* C);
/*SQL_GENERATOR_BASIC*/
void r773write_one_line_comment(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773value_representation_date(T773* C);
/*SQL_GENERATOR_BASIC*/
void r773create_assertion(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773quote_identifier(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_constant(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773datatype_float(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773set_primary_key_format(T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773extension_index_name(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773set_options(T773* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_BASIC*/
void r773create_view(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773write_use_database(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773domain_identifier(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_value(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T6 r773assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773do_create_select_list(T773* C,T0* a1,T6 a2);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_cast_to_real(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_table(T773* C,T0* a1);
extern T0*oBC773onelinecommentprefix;
/*SQL_GENERATOR_BASIC*/
T0* r773value_representation_char(T773* C,T2 a1);
/*SQL_GENERATOR_BASIC*/
T0* r773value_representation_boolean(T773* C);
/*SQL_GENERATOR_BASIC*/
T6 r773createtimestamp(T773* C);
/*SQL_GENERATOR_BASIC*/
T0* r773sp_function_type_for_selection(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773finishtemporarytablestatement(void);
/*SQL_GENERATOR_BASIC*/
T6 r773coalescesupported(void);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_subselect_for_extension(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773table_pk_name(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773drop_constant(T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_insert(T773* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_BASIC*/
T0* r773autoprimarykeyconstraint(void);
/*SQL_GENERATOR_BASIC*/
T6 r773is_value_declared(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773columndatatype_assertion(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T6 r773valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
void r773make(T773* C);
extern T2 oBC773maxidentifierlength;
/*SQL_GENERATOR_BASIC*/
T0* r773value_representation_integer(T773* C,T2 a1);
/*SQL_GENERATOR_BASIC*/
T0* r773table_ts_name(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_extend_create_index(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T6 r773createindex(void);
/*SQL_GENERATOR_BASIC*/
T0* r773column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_BASIC*/
T0* r773create_table_name(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773format(T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_expression_as_boolean_value(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773index_name(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_select_joins_oldstyle(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_delete(T773* C,T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_select_joins_ansi92(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773do_sql_cast_to_string(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
void r773create_domain(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_notnot_expression(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_not_expression(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sql_select_for_extension_expression(T773* C,T0* a1);
/*SQL_GENERATOR_BASIC*/
T0* r773sqlcheck_in(T773* C,T0* a1,T0* a2);
/*SQL_GENERATOR_BASIC*/
void r773create_value_declare(T773* C,T0* a1);
/*XPLAIN_INFIX_EXPRESSION*/
void r571add_to_join(T571* C,T0* a1,T0* a2);
/*XPLAIN_INFIX_EXPRESSION*/
T6 r571uses_parameter(T571* C,T0* a1);
/*XPLAIN_INFIX_EXPRESSION*/
T0* r571sqlmaxvalue(T571* C,T0* a1);
/*XPLAIN_INFIX_EXPRESSION*/
T6 r571is_string_expression(void);
/*XPLAIN_INFIX_EXPRESSION*/
T0* r571representation(T571* C,T0* a1);
/*XPLAIN_INFIX_EXPRESSION*/
void r571make(T571* C,T0* a1,T0* a2,T0* a3);
/*XPLAIN_INFIX_EXPRESSION*/
T0* r571outer_sqlvalue(T571* C,T0* a1);
/*XPLAIN_INFIX_EXPRESSION*/
T0* r571sqlvalue_as_wildcard(T571* C,T0* a1);
/*XPLAIN_INFIX_EXPRESSION*/
T6 r571is_using_other_attributes(T571* C,T0* a1);
/*XPLAIN_INFIX_EXPRESSION*/
T0* r571exact_representation(T571* C,T0* a1);
/*XPLAIN_INFIX_EXPRESSION*/
T6 r571is_literal(T571* C);
/*XPLAIN_INFIX_EXPRESSION*/
T0* r571sqlvalue(T571* C,T0* a1);
/*XPLAIN_INFIX_EXPRESSION*/
void r571make_two_operands(T571* C,T0* a1,T0* a2);
/*XPLAIN_INFIX_EXPRESSION*/
T0* r571sqlinitvalue(T571* C,T0* a1);
/*XPLAIN_INFIX_EXPRESSION*/
T0* r571sqlminvalue(T571* C,T0* a1);
/*XPLAIN_INFIX_EXPRESSION*/
T6 r571has_wild_card_characters(T571* C);
/*XPLAIN_USER_FUNCTION*/
void r603add_to_join(T603* C,T0* a1,T0* a2);
/*XPLAIN_USER_FUNCTION*/
T6 r603uses_parameter(T603* C,T0* a1);
/*XPLAIN_USER_FUNCTION*/
T0* r603sqlmaxvalue(T0* a1);
/*XPLAIN_USER_FUNCTION*/
T6 r603is_string_expression(void);
/*XPLAIN_USER_FUNCTION*/
T0* r603representation(T0* a1);
/*XPLAIN_USER_FUNCTION*/
void r603make(T603* C,T0* a1,T0* a2);
/*XPLAIN_USER_FUNCTION*/
T0* r603outer_sqlvalue(T603* C,T0* a1);
/*XPLAIN_USER_FUNCTION*/
T0* r603sqlvalue_as_wildcard(T603* C,T0* a1);
/*XPLAIN_USER_FUNCTION*/
T6 r603is_using_other_attributes(T603* C,T0* a1);
/*XPLAIN_USER_FUNCTION*/
T0* r603exact_representation(T0* a1);
/*XPLAIN_USER_FUNCTION*/
T0* r603sqlvalue(T603* C,T0* a1);
/*XPLAIN_USER_FUNCTION*/
T0* r603sqlinitvalue(T603* C,T0* a1);
/*XPLAIN_USER_FUNCTION*/
T0* r603sqlminvalue(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805drop_value(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_extend(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805datatype_text(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805drop_table(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805no_space_identifier(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805write_drop(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805scientific_formatter(void);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlcolumnrequired_base(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805write_procedure(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805value_representation_system_user(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805datatype_ref_int(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805do_sql_cast_to_real(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_extension_function(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_value_alter_table(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805init_necessary(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805do_do_create_select_list(T805* C,T0* a1,T6 a2);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805value_representation_float(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805table_has_auto_pk(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805make_valid_identifier(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805columndatatype_type(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_get_insert(T805* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlcolumnidentifier_type(T805* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805tabtab(void);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_last_auto_generated_primary_key(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805write_select(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_value_declare_outside_sp(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805drop_procedure(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805write_assertion(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805datatype_datetime(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805datatype_varchar(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805value_representation_text(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805datatype_boolean(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_infix_expression(T805* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlcolumnconstraint_type(T805* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805quoted_value_identifier(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805datatype_pk_int(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_predicate(T805* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
void r805drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_cast_to_date(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805table_name(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805drop_domain(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805temporarytableprefix(void);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805assertion_name(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlcolumndefault_type(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_select_value(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805createautoprimarykey(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_select_function(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_infix_expression_as_wildcard(T805* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_select_function_as_subselect(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_extend_create_table(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_cast_to_string(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_select_function_as_left_outer_join(T805* C,T0* a1);
extern T0*oBC805target_name;
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805do_sql_cast_to_integer(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805do_sql_select_for_extension_function(T805* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805_24Pdatatype_ref_int(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlfunction_nil(void);
/*SQL_GENERATOR_MSACCESS2000*/
void r805write_init(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805createassert(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
void r805write_base(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805value_representation_money(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_select_joins(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_update(T805* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_index(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlgetvalue_outside_sp(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805constraint_names(void);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805createdomaincheck(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_select_for_extension_function(T805* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805datatype_pk_char(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_combine_expression(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805value_representation_current_timestamp(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805as_string(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805echo(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805datatype_char(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlgetconstant(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805columndatatype_base(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805write_extend(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805createviews(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
void r805write_index(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805constant_identifier(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_value_assign_outside_sp(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805datatype_money(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805optional_create_value_declare(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlcolumnconstraint_base(T805* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805check_if_required(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_subselect_for_attribute(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805datatype_int(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805is_value_data_type_changed(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805datatype_numeric(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805datatype_picture(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_cast_to_integer(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_value_create_table(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlcolumndefault_base(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805column_constraint_name(T805* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlfunction_any(void);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlgetvalue(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805set_sequence_name_format(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805valuetablename(void);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_constant_assignment(T805* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805safe_string(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805do_sql_cast_to_date(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805equal(T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_MSACCESS2000*/
void r805write_type(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_combine_expression_as_wildcard(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805extension_name(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805createtemporarytablestatement(void);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805noonelinecommentssupported(void);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805value_identifier(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805formatter(void);
/*SQL_GENERATOR_MSACCESS2000*/
void r805write_sql(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805createdomains(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805_25Pdatatype_pk_int(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805write_one_line_comment(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805value_representation_date(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_assertion(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805quote_identifier(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_constant(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805datatype_float(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805set_primary_key_format(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805extension_index_name(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805set_options(T805* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_view(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805write_use_database(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805domain_identifier(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_value(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805do_create_select_list(T805* C,T0* a1,T6 a2);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_cast_to_real(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_table(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805value_representation_char(T805* C,T2 a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805value_representation_boolean(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805createtimestamp(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sp_function_type_for_selection(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805finishtemporarytablestatement(void);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805coalescesupported(void);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_subselect_for_extension(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805table_pk_name(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805drop_constant(T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_insert(T805* C,T0* a1,T0* a2,T0* a3);
extern T0*oBC805autoprimarykeyconstraint;
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805is_value_declared(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805columndatatype_assertion(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
void r805make(T805* C);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805value_representation_integer(T805* C,T2 a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805table_ts_name(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_extend_create_index(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T6 r805createindex(void);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805create_table_name(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805format(T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_expression_as_boolean_value(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805index_name(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_select_joins_oldstyle(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_delete(T805* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_select_joins_ansi92(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805do_sql_cast_to_string(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_domain(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_notnot_expression(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_not_expression(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sql_select_for_extension_expression(T805* C,T0* a1);
/*SQL_GENERATOR_MSACCESS2000*/
T0* r805sqlcheck_in(T805* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSACCESS2000*/
void r805create_value_declare(T805* C,T0* a1);
/*XPLAIN_ATTRIBUTE*/
T0* r249out(T249* C);
/*XPLAIN_ATTRIBUTE*/
T0* r249full_name(T249* C);
/*XPLAIN_ATTRIBUTE*/
T0* r249name(T249* C);
/*XPLAIN_ATTRIBUTE*/
T6 r249is_equal(T249* C,T0* a1);
/*XPLAIN_ATTRIBUTE*/
T0* r249q_sql_select_name(T249* C,T0* a1);
/*XPLAIN_ATTRIBUTE*/
void r249out_in_tagged_out_memory(T249* C);
/*XPLAIN_ATTRIBUTE*/
void r249set_init(T249* C,T0* a1);
/*XPLAIN_ATTRIBUTE*/
void r249make(T249* C,T0* a1,T0* a2,T6 a3,T6 a4,T6 a5,T6 a6);
/*XPLAIN_ATTRIBUTE*/
void r249write_drop(T249* C,T0* a1,T0* a2);
/*XPLAIN_ATTRIBUTE*/
T0* r249sql_select_name(T249* C,T0* a1);
/*XPLAIN_ATTRIBUTE*/
void r249set_init_default(T249* C,T0* a1);
/*XPLAIN_PK_A_REPRESENTATION*/
T0* r620domain(T620* C);
/*XPLAIN_PK_A_REPRESENTATION*/
T0* r620min_value(T0* a1);
/*XPLAIN_PK_A_REPRESENTATION*/
T0* r620value_representation(T620* C,T0* a1);
/*XPLAIN_PK_A_REPRESENTATION*/
void r620set_domain_restriction(T620* C,T0* a1,T0* a2);
/*XPLAIN_PK_A_REPRESENTATION*/
T0* r620pkdatatype(T620* C,T0* a1);
/*XPLAIN_PK_A_REPRESENTATION*/
T0* r620xml_schema_data_type(void);
/*XPLAIN_PK_A_REPRESENTATION*/
T0* r620max_value(T0* a1);
/*XPLAIN_PK_A_REPRESENTATION*/
T0* r620datatype(T620* C,T0* a1);
/*XPLAIN_CONSTANT_STATEMENT*/
T6 r148uses_parameter(T0* a1);
/*XPLAIN_CONSTANT_STATEMENT*/
void r148write(T148* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806drop_value(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_extend(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806datatype_text(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806drop_table(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806no_space_identifier(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806write_drop(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806scientific_formatter(void);
/*SQL_GENERATOR_MSQL*/
T0* r806domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlcolumnrequired_base(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806write_procedure(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806value_representation_system_user(T806* C);
extern T6 oBC806constraintnamesupported;
/*SQL_GENERATOR_MSQL*/
T0* r806datatype_ref_int(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806do_sql_cast_to_real(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_extension_function(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_value_alter_table(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T6 r806init_necessary(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806do_do_create_select_list(T806* C,T0* a1,T6 a2);
extern T6 oBC806columnnullallowed;
/*SQL_GENERATOR_MSQL*/
T0* r806value_representation_float(T806* C);
/*SQL_GENERATOR_MSQL*/
T6 r806table_has_auto_pk(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806make_valid_identifier(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806columndatatype_type(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_get_insert(T806* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlcolumnidentifier_type(T806* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T0* r806tabtab(void);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_last_auto_generated_primary_key(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806write_select(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_value_declare_outside_sp(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806drop_procedure(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806write_assertion(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806datatype_datetime(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806datatype_varchar(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806value_representation_text(T806* C);
/*SQL_GENERATOR_MSQL*/
T0* r806datatype_boolean(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_infix_expression(T806* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlcolumnconstraint_type(T806* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T0* r806quoted_value_identifier(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806datatype_pk_int(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_predicate(T806* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
void r806drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_cast_to_date(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806table_name(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806drop_domain(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806temporarytableprefix(void);
/*SQL_GENERATOR_MSQL*/
T0* r806assertion_name(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlcolumndefault_type(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_select_value(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T6 r806createautoprimarykey(T806* C);
/*SQL_GENERATOR_MSQL*/
void r806create_select_function(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_infix_expression_as_wildcard(T806* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_select_function_as_subselect(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_extend_create_table(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_cast_to_string(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_select_function_as_left_outer_join(T806* C,T0* a1);
extern T0*oBC806target_name;
/*SQL_GENERATOR_MSQL*/
T0* r806do_sql_cast_to_integer(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806do_sql_select_for_extension_function(T806* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlfunction_nil(void);
/*SQL_GENERATOR_MSQL*/
void r806write_init(T0* a1);
/*SQL_GENERATOR_MSQL*/
T6 r806createassert(T806* C);
/*SQL_GENERATOR_MSQL*/
void r806write_base(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806value_representation_money(T806* C);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_select_joins(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_update(T806* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MSQL*/
void r806create_index(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlgetvalue_outside_sp(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806constraint_names(void);
/*SQL_GENERATOR_MSQL*/
T6 r806createdomaincheck(T806* C);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_select_for_extension_function(T806* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T0* r806datatype_pk_char(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_combine_expression(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806value_representation_current_timestamp(T806* C);
/*SQL_GENERATOR_MSQL*/
T0* r806as_string(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806echo(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806datatype_char(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlgetconstant(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806columndatatype_base(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806write_extend(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T6 r806createviews(T806* C);
extern T6 oBC806checkconstraintsupported;
/*SQL_GENERATOR_MSQL*/
void r806write_index(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806constant_identifier(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_value_assign_outside_sp(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806datatype_money(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806optional_create_value_declare(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlcolumnconstraint_base(T806* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T6 r806check_if_required(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_subselect_for_attribute(T806* C,T0* a1);
extern T6 oBC806inlineuniqueconstraintsupported;
/*SQL_GENERATOR_MSQL*/
T0* r806datatype_int(T0* a1);
/*SQL_GENERATOR_MSQL*/
T6 r806is_value_data_type_changed(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806datatype_numeric(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_cast_to_integer(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_value_create_table(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlcolumndefault_base(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806column_constraint_name(T806* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlfunction_any(void);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlgetvalue(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806set_sequence_name_format(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806valuetablename(void);
/*SQL_GENERATOR_MSQL*/
void r806create_constant_assignment(T806* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T0* r806safe_string(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806do_sql_cast_to_date(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T6 r806equal(T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T0* r806finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_MSQL*/
void r806write_type(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_combine_expression_as_wildcard(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806extension_name(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806createtemporarytablestatement(void);
/*SQL_GENERATOR_MSQL*/
T6 r806noonelinecommentssupported(void);
/*SQL_GENERATOR_MSQL*/
T0* r806value_identifier(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806formatter(void);
/*SQL_GENERATOR_MSQL*/
void r806write_sql(T0* a1);
/*SQL_GENERATOR_MSQL*/
T6 r806createdomains(T806* C);
/*SQL_GENERATOR_MSQL*/
void r806write_one_line_comment(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806value_representation_date(T806* C);
/*SQL_GENERATOR_MSQL*/
void r806create_assertion(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806quote_identifier(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_constant(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806datatype_float(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806set_primary_key_format(T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806extension_index_name(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806set_options(T806* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_MSQL*/
void r806create_view(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806write_use_database(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806domain_identifier(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_value(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T6 r806assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806do_create_select_list(T806* C,T0* a1,T6 a2);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_cast_to_real(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_table(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806value_representation_char(T806* C,T2 a1);
/*SQL_GENERATOR_MSQL*/
T0* r806value_representation_boolean(T806* C);
/*SQL_GENERATOR_MSQL*/
T6 r806createtimestamp(T806* C);
/*SQL_GENERATOR_MSQL*/
T0* r806sp_function_type_for_selection(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806finishtemporarytablestatement(void);
/*SQL_GENERATOR_MSQL*/
T6 r806coalescesupported(void);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_subselect_for_extension(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806table_pk_name(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806drop_constant(T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_insert(T806* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MSQL*/
T0* r806autoprimarykeyconstraint(void);
/*SQL_GENERATOR_MSQL*/
T6 r806is_value_declared(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806columndatatype_assertion(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T6 r806valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
void r806make(T806* C);
extern T2 oBC806maxidentifierlength;
/*SQL_GENERATOR_MSQL*/
T0* r806value_representation_integer(T806* C,T2 a1);
/*SQL_GENERATOR_MSQL*/
T0* r806table_ts_name(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_extend_create_index(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T6 r806createindex(void);
/*SQL_GENERATOR_MSQL*/
T0* r806column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_MSQL*/
T0* r806create_table_name(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806format(T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_expression_as_boolean_value(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806index_name(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_select_joins_oldstyle(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_delete(T806* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_select_joins_ansi92(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806do_sql_cast_to_string(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
void r806create_domain(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_notnot_expression(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_not_expression(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sql_select_for_extension_expression(T806* C,T0* a1);
/*SQL_GENERATOR_MSQL*/
T0* r806sqlcheck_in(T806* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MSQL*/
void r806create_value_declare(T806* C,T0* a1);
/*XPLAIN_I_REFERENCES*/
T0* r621sqlcolumnconstraint(T621* C,T0* a1,T0* a2);
/*ST_SCIENTIFIC_FORMATTER*/
T0* r467format(T467* C,T0* a1,T0* a2);
extern T0*oBC61any_array_;
extern T0*oBC469null_output_stream;
extern int fBC469null_output_stream;
/*ST_SCIENTIFIC_FORMATTER*/
T0* r467null_output_stream(void);
/*ST_SCIENTIFIC_FORMATTER*/
T6 r467valid_format_and_parameters(T467* C,T0* a1,T0* a2);
/*ST_SCIENTIFIC_FORMATTER*/
void r467set_error(T467* C,T0* a1);
/*ST_SCIENTIFIC_FORMATTER*/
void r467_468Pmake_with_escape(T467* C,T3 a1);
/*ST_SCIENTIFIC_FORMATTER*/
void r467do_format_to(T467* C,T0* a1,T0* a2,T0* a3);
/*ST_SCIENTIFIC_FORMATTER*/
T0* r467internal_parameter_formatter(T467* C,T3 a1);
/*ST_SCIENTIFIC_FORMATTER*/
void r467make_with_escape(T467* C,T3 a1);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
void r635add_to_join(T635* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T6 r635uses_parameter(T635* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
void r635set_extension(T635* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T0* r635sqlmaxvalue(T635* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
void r635inherited_make(T635* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T0* r635sqlselect(T635* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T0* r635column_name(T635* C);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T0* r635sqlfromaliasname(void);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T6 r635is_string_expression(void);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T0* r635representation(T635* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T0* r635outer_sqlvalue(T635* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T0* r635sqlvalue_as_wildcard(T635* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T6 r635is_using_other_attributes(T635* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T0* r635exact_representation(T635* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T6 r635is_literal(T635* C);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T0* r635sqlvalue(T635* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T0* r635sqlinitvalue(T635* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T6 r635is_logical_expression(T635* C);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T0* r635sqlname(T635* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION_EXPRESSION*/
T0* r635sqlminvalue(T635* C,T0* a1);
/*XPLAIN_ID_FUNCTION*/
T0* r599sqlmaxvalue(T599* C,T0* a1);
/*XPLAIN_ID_FUNCTION*/
T6 r599is_string_expression(void);
/*XPLAIN_ID_FUNCTION*/
T0* r599representation(T599* C,T0* a1);
/*XPLAIN_ID_FUNCTION*/
T0* r599outer_sqlvalue(T599* C,T0* a1);
/*XPLAIN_ID_FUNCTION*/
T0* r599sqlvalue_as_wildcard(T599* C,T0* a1);
/*XPLAIN_ID_FUNCTION*/
T0* r599exact_representation(T599* C,T0* a1);
/*XPLAIN_ID_FUNCTION*/
T0* r599sqlvalue(T599* C,T0* a1);
/*XPLAIN_ID_FUNCTION*/
T0* r599sqlinitvalue(T599* C,T0* a1);
/*XPLAIN_ID_FUNCTION*/
T0* r599sqlminvalue(T599* C,T0* a1);
/*XPLAIN_INSERT_STATEMENT*/
T6 r631uses_parameter(T631* C,T0* a1);
/*XPLAIN_INSERT_STATEMENT*/
void r631write(T631* C,T0* a1);
/*XPLAIN_INSERT_STATEMENT*/
void r631make(T631* C,T0* a1,T0* a2,T0* a3);
/*XPLAIN_PROCEDURE*/
T0* r728quoted_name(T728* C,T0* a1);
/*XPLAIN_PROCEDURE*/
T0* r728last_get_statement(T728* C);
/*XPLAIN_PROCEDURE*/
T0* r728last_value_selection_statement(T728* C);
/*XPLAIN_PROCEDURE*/
void r728abstract_make(T728* C,T0* a1,T0* a2);
/*XPLAIN_PROCEDURE*/
T6 r728returns_rows(T728* C);
/*XPLAIN_PROCEDURE*/
void r728make(T728* C,T0* a1,T0* a2,T2 a3,T0* a4);
/*XPLAIN_PROCEDURE*/
void r728write_drop(T728* C,T0* a1);
/*XPLAIN_PROCEDURE*/
void r728warn_about_unused_parameters(T728* C);
/*XPLAIN_PROCEDURE*/
T0* r728sqlname(T728* C,T0* a1);
/*XPLAIN_PROCEDURE*/
T0* r728sp_function_type(T728* C,T0* a1);
/*XPLAIN_PROCEDURE*/
void r728cleanup_after_write(T728* C);
/*XPLAIN_LOGICAL_VALUE_EXPRESSION*/
T0* r297sqlmaxvalue(T0* a1);
/*XPLAIN_LOGICAL_VALUE_EXPRESSION*/
T6 r297is_string_expression(void);
/*XPLAIN_LOGICAL_VALUE_EXPRESSION*/
T0* r297representation(T0* a1);
/*XPLAIN_LOGICAL_VALUE_EXPRESSION*/
T0* r297outer_sqlvalue(T297* C,T0* a1);
/*XPLAIN_LOGICAL_VALUE_EXPRESSION*/
T0* r297sqlvalue_as_wildcard(T297* C,T0* a1);
/*XPLAIN_LOGICAL_VALUE_EXPRESSION*/
T0* r297exact_representation(T0* a1);
/*XPLAIN_LOGICAL_VALUE_EXPRESSION*/
T0* r297sqlvalue(T297* C,T0* a1);
/*XPLAIN_LOGICAL_VALUE_EXPRESSION*/
T0* r297sqlinitvalue(T297* C,T0* a1);
/*XPLAIN_LOGICAL_VALUE_EXPRESSION*/
T0* r297sqlminvalue(T0* a1);
/*KL_NULL_TEXT_OUTPUT_STREAM*/
void r771put_substring(T0* a1,T2 a2,T2 a3);
/*XPLAIN_COMBINE_FUNCTION*/
void r593add_to_join(T593* C,T0* a1,T0* a2);
/*XPLAIN_COMBINE_FUNCTION*/
T6 r593uses_parameter(T593* C,T0* a1);
/*XPLAIN_COMBINE_FUNCTION*/
T0* r593sqlmaxvalue(T593* C,T0* a1);
/*XPLAIN_COMBINE_FUNCTION*/
T0* r593representation(T593* C,T0* a1);
/*XPLAIN_COMBINE_FUNCTION*/
T0* r593outer_sqlvalue(T593* C,T0* a1);
/*XPLAIN_COMBINE_FUNCTION*/
T0* r593sqlvalue_as_wildcard(T593* C,T0* a1);
/*XPLAIN_COMBINE_FUNCTION*/
T6 r593is_using_other_attributes(T593* C,T0* a1);
/*XPLAIN_COMBINE_FUNCTION*/
T0* r593exact_representation(T593* C,T0* a1);
/*XPLAIN_COMBINE_FUNCTION*/
T6 r593is_literal(T593* C);
/*XPLAIN_COMBINE_FUNCTION*/
T0* r593sqlvalue(T593* C,T0* a1);
/*XPLAIN_COMBINE_FUNCTION*/
T0* r593sqlinitvalue(T593* C,T0* a1);
/*XPLAIN_COMBINE_FUNCTION*/
T0* r593sqlminvalue(T593* C,T0* a1);
/*XPLAIN_COMBINE_FUNCTION*/
T6 r593has_wild_card_characters(T593* C);
/*XPLAIN_VARIABLE*/
T0* r509quoted_name(T509* C,T0* a1);
/*XPLAIN_VARIABLE*/
T0* r509create_expression(T0* a1);
/*XPLAIN_VARIABLE*/
void r509make(T509* C,T0* a1,T0* a2);
/*XPLAIN_VARIABLE*/
void r509write_drop(T509* C,T0* a1);
/*XPLAIN_VARIABLE*/
T0* r509sqlname(T509* C,T0* a1);
/*JOIN_NODE*/
T0* r644last(T644* C);
/*JOIN_NODE*/
void r644make(T644* C,T0* a1,T0* a2);
/*XPLAIN_UNMANAGED_PARAMETER_EXPRESSION*/
T0* r602sqlmaxvalue(T0* a1);
/*XPLAIN_UNMANAGED_PARAMETER_EXPRESSION*/
T6 r602is_string_expression(void);
/*XPLAIN_UNMANAGED_PARAMETER_EXPRESSION*/
T0* r602representation(T0* a1);
/*XPLAIN_UNMANAGED_PARAMETER_EXPRESSION*/
T0* r602outer_sqlvalue(T602* C,T0* a1);
/*XPLAIN_UNMANAGED_PARAMETER_EXPRESSION*/
T0* r602sqlvalue_as_wildcard(T602* C,T0* a1);
/*XPLAIN_UNMANAGED_PARAMETER_EXPRESSION*/
T0* r602exact_representation(T0* a1);
/*XPLAIN_UNMANAGED_PARAMETER_EXPRESSION*/
T0* r602sqlvalue(T602* C,T0* a1);
/*XPLAIN_UNMANAGED_PARAMETER_EXPRESSION*/
T0* r602sqlinitvalue(T602* C,T0* a1);
/*XPLAIN_UNMANAGED_PARAMETER_EXPRESSION*/
T0* r602sqlminvalue(T0* a1);
/*XPLAIN_PREFIX_EXPRESSION*/
void r578add_to_join(T578* C,T0* a1,T0* a2);
/*XPLAIN_PREFIX_EXPRESSION*/
T6 r578uses_parameter(T578* C,T0* a1);
/*XPLAIN_PREFIX_EXPRESSION*/
T0* r578sqlmaxvalue(T578* C,T0* a1);
/*XPLAIN_PREFIX_EXPRESSION*/
T6 r578is_string_expression(void);
/*XPLAIN_PREFIX_EXPRESSION*/
T0* r578representation(T578* C,T0* a1);
/*XPLAIN_PREFIX_EXPRESSION*/
void r578make(T578* C,T0* a1,T0* a2);
/*XPLAIN_PREFIX_EXPRESSION*/
T0* r578outer_sqlvalue(T578* C,T0* a1);
/*XPLAIN_PREFIX_EXPRESSION*/
T0* r578sqlvalue_as_wildcard(T578* C,T0* a1);
/*XPLAIN_PREFIX_EXPRESSION*/
T6 r578is_using_other_attributes(T578* C,T0* a1);
/*XPLAIN_PREFIX_EXPRESSION*/
T0* r578exact_representation(T578* C,T0* a1);
/*XPLAIN_PREFIX_EXPRESSION*/
T0* r578sqlvalue(T578* C,T0* a1);
/*XPLAIN_PREFIX_EXPRESSION*/
T0* r578sqlinitvalue(T578* C,T0* a1);
/*XPLAIN_PREFIX_EXPRESSION*/
T0* r578sqlminvalue(T578* C,T0* a1);
/*XPLAIN_LAST_AUTO_PK_EXPRESSION*/
T0* r709sqlmaxvalue(T0* a1);
/*XPLAIN_LAST_AUTO_PK_EXPRESSION*/
T6 r709is_string_expression(void);
/*XPLAIN_LAST_AUTO_PK_EXPRESSION*/
T0* r709representation(T0* a1);
/*XPLAIN_LAST_AUTO_PK_EXPRESSION*/
T0* r709outer_sqlvalue(T709* C,T0* a1);
/*XPLAIN_LAST_AUTO_PK_EXPRESSION*/
T0* r709sqlvalue_as_wildcard(T709* C,T0* a1);
/*XPLAIN_LAST_AUTO_PK_EXPRESSION*/
T0* r709exact_representation(T0* a1);
/*XPLAIN_LAST_AUTO_PK_EXPRESSION*/
T0* r709sqlvalue(T709* C,T0* a1);
/*XPLAIN_LAST_AUTO_PK_EXPRESSION*/
T0* r709sqlinitvalue(T709* C,T0* a1);
/*XPLAIN_LAST_AUTO_PK_EXPRESSION*/
T0* r709sqlminvalue(T0* a1);
/*XPLAIN_SELECTION_FUNCTION*/
void r218add_to_join(T218* C,T0* a1,T0* a2);
/*XPLAIN_SELECTION_FUNCTION*/
T6 r218_185Puses_parameter(T218* C,T0* a1);
/*XPLAIN_SELECTION_FUNCTION*/
T6 r218uses_parameter(T218* C,T0* a1);
/*XPLAIN_SELECTION_FUNCTION*/
void r218_185Padd_to_join(T218* C,T0* a1,T0* a2);
/*XPLAIN_SELECTION_FUNCTION*/
T0* r218representation(T218* C,T0* a1);
/*XPLAIN_SELECTION_FUNCTION*/
void r218make(T218* C,T0* a1,T0* a2,T0* a3,T0* a4);
/*XPLAIN_SELECTION_FUNCTION*/
T6 r218supports_left_outer_join(T218* C);
/*XPLAIN_SELECTION_FUNCTION*/
T0* r218sqlvalue(T218* C,T0* a1);
/*XPLAIN_SELECTION_FUNCTION*/
void r218write_select(T218* C,T0* a1);
/*XPLAIN_SELECTION_FUNCTION*/
T0* r218sp_function_type(T218* C,T0* a1);
/*XPLAIN_SUBJECT*/
void r225make(T225* C,T0* a1,T0* a2);
/*XPLAIN_INTEGER_FUNCTION*/
void r596add_to_join(T596* C,T0* a1,T0* a2);
/*XPLAIN_INTEGER_FUNCTION*/
T6 r596uses_parameter(T596* C,T0* a1);
/*XPLAIN_INTEGER_FUNCTION*/
T0* r596sqlmaxvalue(T0* a1);
/*XPLAIN_INTEGER_FUNCTION*/
T6 r596is_string_expression(void);
/*XPLAIN_INTEGER_FUNCTION*/
T0* r596representation(T0* a1);
/*XPLAIN_INTEGER_FUNCTION*/
T0* r596outer_sqlvalue(T596* C,T0* a1);
/*XPLAIN_INTEGER_FUNCTION*/
T0* r596sqlvalue_as_wildcard(T596* C,T0* a1);
/*XPLAIN_INTEGER_FUNCTION*/
T6 r596is_using_other_attributes(T596* C,T0* a1);
/*XPLAIN_INTEGER_FUNCTION*/
T0* r596exact_representation(T0* a1);
/*XPLAIN_INTEGER_FUNCTION*/
T0* r596sqlvalue(T596* C,T0* a1);
/*XPLAIN_INTEGER_FUNCTION*/
T0* r596sqlinitvalue(T596* C,T0* a1);
/*XPLAIN_INTEGER_FUNCTION*/
T0* r596sqlminvalue(T0* a1);
/*XPLAIN_VALUE_STATEMENT*/
T6 r80uses_parameter(T80* C,T0* a1);
extern T0*oBC26universe;
extern int fBC26universe;
/*XPLAIN_VALUE_STATEMENT*/
T0* r80universe(void);
/*XPLAIN_VALUE_STATEMENT*/
void r80write(T80* C,T0* a1);
/*XPLAIN_VALUE_STATEMENT*/
void r80cleanup(T80* C);
/*XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT*/
T6 r142uses_parameter(T0* a1);
/*XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT*/
void r142write(T142* C,T0* a1);
/*XPLAIN_CONSTANT_ASSIGNMENT_STATEMENT*/
void r142make(T142* C,T0* a1,T0* a2);
/*ST_CHARACTER_FORMATTER*/
void r498center_format_to(T498* C,T0* a1,T0* a2);
/*ST_CHARACTER_FORMATTER*/
T6 r498valid_parameter(T0* a1);
/*ST_CHARACTER_FORMATTER*/
void r498format_to(T498* C,T0* a1,T0* a2);
/*ST_CHARACTER_FORMATTER*/
void r498right_format_to(T498* C,T0* a1,T0* a2);
/*ST_CHARACTER_FORMATTER*/
void r498reset_options(T498* C);
/*ST_CHARACTER_FORMATTER*/
void r498justify_format_to(T498* C,T0* a1,T0* a2);
/*ST_CHARACTER_FORMATTER*/
void r498character_format_to(T498* C,T3 a1,T0* a2);
/*ST_CHARACTER_FORMATTER*/
void r498left_format_to(T498* C,T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
void r800_25Pdrop_table(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800drop_value(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800sp_start(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_extend(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800datatype_text(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sp_define_out_param(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800drop_table(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800_25Pdrop_value(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800no_space_identifier(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800write_drop(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800make_valid_sp_identifier(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800scientific_formatter(void);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlcolumnrequired_base(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800write_procedure(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800value_representation_system_user(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800datatype_ref_int(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_value_declare_inside_sp(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800do_sql_cast_to_real(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_extension_function(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_value_alter_table(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800init_necessary(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800do_do_create_select_list(T800* C,T0* a1,T6 a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800value_representation_float(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800table_has_auto_pk(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800make_valid_identifier(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800columndatatype_type(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_get_insert(T800* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlcolumnidentifier_type(T800* C,T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800tabtab(void);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_last_auto_generated_primary_key(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800drop_primary_key_generator(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_value_assign_inside_sp(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800_25Psqlcolumnrequired_base(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800write_select(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_value_declare_outside_sp(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800datatype_varchar(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800datatype_datetime(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800write_assertion(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800value_representation_text(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800datatype_boolean(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_infix_expression(T800* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlcolumnconstraint_type(T800* C,T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800quoted_value_identifier(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800datatype_pk_int(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sp_update_name(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_predicate(T800* C,T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_sp_insert(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_cast_to_date(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800table_name(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800drop_domain(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_init_cast_to_real(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800do_drop_procedure(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800temporarytableprefix(void);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sp_define_param_name(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800assertion_name(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlcolumndefault_type(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_select_value(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800createautoprimarykey(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_select_function(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800init_forced_null(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_infix_expression_as_wildcard(T800* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_select_function_as_subselect(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_extend_create_table(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_cast_to_string(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_select_function_as_left_outer_join(T800* C,T0* a1);
extern T0*oBC800target_name;
/*SQL_GENERATOR_INTERBASE6*/
void r800_25Pcreate_select_list(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800do_sql_select_for_extension_function(T800* C,T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800do_sql_cast_to_integer(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlfunction_nil(void);
/*SQL_GENERATOR_INTERBASE6*/
void r800write_init(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800createassert(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_select_value_inside_sp(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800write_base(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_sp_delete(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800value_representation_money(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_init_infix_expression(T800* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_select_joins(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_update(T800* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_index(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlgetvalue_outside_sp(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800constraint_names(void);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800createdomaincheck(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
void r800_25Pwrite_type(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_init_cast_to_string(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_select_for_extension_function(T800* C,T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800datatype_pk_char(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_select_list(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sp_insert_name(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_combine_expression(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800value_representation_current_timestamp(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800as_string(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_init_expression(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800echo(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800datatype_char(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_create_generator(void);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlgetconstant(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800columndatatype_base(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800generator_name(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800write_extend(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800createviews(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
void r800write_index(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800constant_identifier(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_value_assign_outside_sp(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800sp_end(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sp_use_param(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800datatype_money(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800sp_body_statements(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800optional_create_value_declare(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlcolumnconstraint_base(T800* C,T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800check_if_required(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_subselect_for_attribute(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800datatype_int(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_procedure(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800is_value_data_type_changed(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800datatype_numeric(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800datatype_picture(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_cast_to_integer(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_value_create_table(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800storedprocedureparamlistend(void);
/*SQL_GENERATOR_INTERBASE6*/
void r800_25Pcreate_select_function(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlcolumndefault_base(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlgetvalue_inside_sp(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800column_constraint_name(T800* C,T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlfunction_any(void);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlgetvalue(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800set_sequence_name_format(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800valuetablename(void);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_constant_assignment(T800* C,T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800safe_string(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800do_sql_cast_to_date(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
void r800write_type(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800equal(T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_combine_expression_as_wildcard(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800extension_name(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800createtemporarytablestatement(void);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800noonelinecommentssupported(void);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_use_database(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800value_identifier(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_primary_key_generator(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800formatter(void);
/*SQL_GENERATOR_INTERBASE6*/
void r800write_sql(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800createdomains(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
void r800write_one_line_comment(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800value_representation_date(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_assertion(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800_798Psp_start(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800quote_identifier(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_constant(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800drop_sp(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800datatype_float(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800set_primary_key_format(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800extension_index_name(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800set_options(T800* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_init_cast_to_date(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_view(T800* C,T0* a1);
extern T0*oBC801sqlcoalesce;
/*SQL_GENERATOR_INTERBASE6*/
void r800write_use_database(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800domain_identifier(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_value(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800sp_user_result(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_sp_update(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_value_assign(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800do_create_select_list(T800* C,T0* a1,T6 a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_cast_to_real(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlcolumnrequired_type(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sp_get_auto_generated_primary_key(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_table(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800value_representation_char(T800* C,T2 a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800value_representation_boolean(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800createtimestamp(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sp_function_type_for_selection(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlcheck_boolean(T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800finishtemporarytablestatement(void);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_init_combine_expression(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlinitvalue_if(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800_801Pcreate_use_database(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sp_name(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800coalescesupported(void);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_subselect_for_extension(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlinitvalue_attribute(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800table_pk_name(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800drop_constant(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_insert(T800* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sp_delete_name(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800autoprimarykeyconstraint(void);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sp_define_in_param(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800is_value_declared(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800columndatatype_assertion(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_init_cast_to_integer(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
void r800make(T800* C);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800value_representation_integer(T800* C,T2 a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800sp_user_declaration(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800_25Psqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800table_ts_name(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_extend_create_index(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T6 r800createindex(void);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800create_table_name(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_init(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800format(T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_expression_as_boolean_value(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800index_name(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_select_joins_oldstyle(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_delete(T800* C,T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_select_joins_ansi92(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800do_sql_cast_to_string(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_domain(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_notnot_expression(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800storedprocedureparamliststart(void);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_not_expression(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sql_select_for_extension_expression(T800* C,T0* a1);
/*SQL_GENERATOR_INTERBASE6*/
T0* r800sqlcheck_in(T800* C,T0* a1,T0* a2);
/*SQL_GENERATOR_INTERBASE6*/
void r800create_value_declare(T800* C,T0* a1);
/*XPLAIN_ASSERTION*/
T0* r243out(T243* C);
/*XPLAIN_ASSERTION*/
T6 r243is_complex(T243* C);
/*XPLAIN_ASSERTION*/
T0* r243quoted_name(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
T0* r243sqlpkname(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
T0* r243new_data_attributes_cursor(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
void r243remove_extension(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
T0* r243columndatatype(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
T6 r243is_equal(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
T0* r243sqlcolumnidentifier(T243* C,T0* a1,T0* a2);
/*XPLAIN_ASSERTION*/
T0* r243q_sql_select_name(T243* C,T0* a1,T0* a2);
/*XPLAIN_ASSERTION*/
void r243add_extension(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
T0* r243create_expression(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
T0* r243sql_insert_name(T243* C,T0* a1,T0* a2);
/*XPLAIN_ASSERTION*/
void r243write_drop_attribute(T243* C,T0* a1,T0* a2);
/*XPLAIN_ASSERTION*/
void r243out_in_tagged_out_memory(T243* C);
/*XPLAIN_ASSERTION*/
T6 r243is_function(T243* C);
/*XPLAIN_ASSERTION*/
T0* r243q_sqlpkname(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
void r243add_assertion(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
void r243make_abstract_type(T243* C,T0* a1,T0* a2);
/*XPLAIN_ASSERTION*/
void r243make(T243* C,T0* a1,T0* a2,T0* a3,T0* a4,T0* a5);
/*XPLAIN_ASSERTION*/
T6 r243has_non_constant_init(T243* C);
/*XPLAIN_ASSERTION*/
T6 r243equal(T0* a1,T0* a2);
/*XPLAIN_ASSERTION*/
T2 r243hash_code(T243* C);
/*XPLAIN_ASSERTION*/
T6 r243has_non_literal_init(T243* C);
/*XPLAIN_ASSERTION*/
T0* r243sql_qualified_name(T243* C,T0* a1,T0* a2);
/*XPLAIN_ASSERTION*/
T6 r243has_updatable_attributes(T243* C);
/*XPLAIN_ASSERTION*/
T0* r243q_sql_insert_name(T243* C,T0* a1,T0* a2);
/*XPLAIN_ASSERTION*/
T6 r243is_literal(T243* C);
/*XPLAIN_ASSERTION*/
T0* r243new_all_attributes_cursor(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
T0* r243sql_select_name(T243* C,T0* a1,T0* a2);
/*XPLAIN_ASSERTION*/
void r243hack_anode(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
void r243make_type(T243* C,T0* a1,T0* a2,T0* a3);
/*XPLAIN_ASSERTION*/
T0* r243sqlname(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
T0* r243find_attribute(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
T0* r243new_init_attributes_cursor(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
T6 r243is_simple(T243* C);
/*XPLAIN_ASSERTION*/
void r243next_constraint_number(T243* C);
/*XPLAIN_ASSERTION*/
T6 r243has_auto_pk(T243* C,T0* a1);
/*XPLAIN_ASSERTION*/
T6 r243has_attribute(T243* C,T0* a1,T0* a2);
/*XPLAIN_ASSERTION*/
T0* r243sqltablename(T243* C,T0* a1);
/*XPLAIN_PROCEDURE_STATEMENT*/
void r104write(T104* C,T0* a1);
/*XPLAIN_STATEMENT_NODE*/
void r159make(T159* C,T0* a1,T0* a2);
/*XPLAIN_EXPRESSION_NODE*/
void r166make_node(T166* C,T0* a1,T0* a2);
/*XPLAIN_EXPRESSION_NODE*/
T0* r166column_name(T166* C);
/*XPLAIN_EXPRESSION_NODE*/
void r166give_column_names(T166* C,T2 a1);
/*XPLAIN_EXPRESSION_NODE*/
void r166make(T166* C,T0* a1,T0* a2,T0* a3);
/*XPLAIN_NE_NULL_EXPRESSION*/
void r584add_to_join(T584* C,T0* a1,T0* a2);
/*XPLAIN_NE_NULL_EXPRESSION*/
T6 r584uses_parameter(T584* C,T0* a1);
/*XPLAIN_NE_NULL_EXPRESSION*/
T0* r584sqlmaxvalue(T0* a1);
/*XPLAIN_NE_NULL_EXPRESSION*/
T6 r584is_string_expression(void);
/*XPLAIN_NE_NULL_EXPRESSION*/
T0* r584representation(T0* a1);
/*XPLAIN_NE_NULL_EXPRESSION*/
T0* r584outer_sqlvalue(T584* C,T0* a1);
/*XPLAIN_NE_NULL_EXPRESSION*/
T0* r584sqlvalue_as_wildcard(T584* C,T0* a1);
/*XPLAIN_NE_NULL_EXPRESSION*/
T0* r584exact_representation(T0* a1);
/*XPLAIN_NE_NULL_EXPRESSION*/
T0* r584sqlvalue(T584* C,T0* a1);
/*XPLAIN_NE_NULL_EXPRESSION*/
T0* r584sqlinitvalue(T584* C,T0* a1);
/*XPLAIN_NE_NULL_EXPRESSION*/
T0* r584sqlminvalue(T0* a1);
/*XPLAIN_VIRTUAL_ATTRIBUTE*/
T0* r628out(T628* C);
/*XPLAIN_VIRTUAL_ATTRIBUTE*/
T0* r628full_name(T628* C);
/*XPLAIN_VIRTUAL_ATTRIBUTE*/
T0* r628name(T628* C);
/*XPLAIN_VIRTUAL_ATTRIBUTE*/
T6 r628is_equal(T628* C,T0* a1);
/*XPLAIN_VIRTUAL_ATTRIBUTE*/
T0* r628q_sql_select_name(T628* C,T0* a1);
/*XPLAIN_VIRTUAL_ATTRIBUTE*/
void r628inherited_make(T628* C,T0* a1,T0* a2,T6 a3,T6 a4,T6 a5,T6 a6);
/*XPLAIN_VIRTUAL_ATTRIBUTE*/
void r628out_in_tagged_out_memory(T628* C);
/*XPLAIN_VIRTUAL_ATTRIBUTE*/
void r628set_init(T628* C,T0* a1);
/*XPLAIN_VIRTUAL_ATTRIBUTE*/
void r628write_drop(T628* C,T0* a1,T0* a2);
/*XPLAIN_VIRTUAL_ATTRIBUTE*/
T0* r628sql_select_name(T628* C,T0* a1);
/*XPLAIN_VIRTUAL_ATTRIBUTE*/
void r628set_init_default(T628* C,T0* a1);
/*XPLAIN_SELECTION_EXPRESSION*/
T0* r708sqlmaxvalue(T708* C,T0* a1);
/*XPLAIN_SELECTION_EXPRESSION*/
T0* r708column_name(T708* C);
/*XPLAIN_SELECTION_EXPRESSION*/
T6 r708is_string_expression(void);
/*XPLAIN_SELECTION_EXPRESSION*/
T0* r708outer_sqlvalue(T708* C,T0* a1);
/*XPLAIN_SELECTION_EXPRESSION*/
T0* r708sqlvalue_as_wildcard(T708* C,T0* a1);
/*XPLAIN_SELECTION_EXPRESSION*/
T0* r708exact_representation(T708* C,T0* a1);
/*XPLAIN_SELECTION_EXPRESSION*/
T0* r708sqlinitvalue(T708* C,T0* a1);
/*XPLAIN_SELECTION_EXPRESSION*/
T0* r708sqlminvalue(T708* C,T0* a1);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
void r476center_format_to(T476* C,T0* a1,T0* a2);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
void r476append_abs_to_string(T476* C,T2 a1,T0* a2);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
T6 r476valid_parameter(T0* a1);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
void r476_471Pmake(T476* C);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
void r476make(T476* C);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
void r476_475Pinteger_format_to(T476* C,T2 a1,T0* a2);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
void r476format_to(T476* C,T0* a1,T0* a2);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
void r476right_format_to(T476* C,T0* a1,T0* a2);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
void r476_471Preset_options(T476* C);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
void r476integer_format_to(T476* C,T2 a1,T0* a2);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
void r476reset_options(T476* C);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
void r476append_to_string(T476* C,T2 a1,T0* a2);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
void r476justify_format_to(T476* C,T0* a1,T0* a2);
/*ST_UNSIGNED_HEXADECIMAL_FORMATTER*/
void r476left_format_to(T476* C,T0* a1,T0* a2);
/*XPLAIN_NUMBER_EXPRESSION*/
T0* r601sqlmaxvalue(T601* C,T0* a1);
/*XPLAIN_NUMBER_EXPRESSION*/
T6 r601is_string_expression(void);
/*XPLAIN_NUMBER_EXPRESSION*/
T0* r601representation(T601* C,T0* a1);
/*XPLAIN_NUMBER_EXPRESSION*/
T0* r601outer_sqlvalue(T601* C,T0* a1);
/*XPLAIN_NUMBER_EXPRESSION*/
T0* r601sqlvalue_as_wildcard(T601* C,T0* a1);
/*XPLAIN_NUMBER_EXPRESSION*/
T0* r601exact_representation(T601* C,T0* a1);
/*XPLAIN_NUMBER_EXPRESSION*/
T0* r601sqlinitvalue(T601* C,T0* a1);
/*XPLAIN_NUMBER_EXPRESSION*/
T0* r601sqlminvalue(T601* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION*/
T6 r196uses_parameter(T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION*/
void r196set_extension(T196* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_EXPRESSION*/
T0* r196sqlmaxvalue(T196* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION*/
T0* r196column_name(T196* C);
/*XPLAIN_EXTENSION_EXPRESSION*/
T0* r196sqlfromaliasname(void);
/*XPLAIN_EXTENSION_EXPRESSION*/
T6 r196is_string_expression(void);
/*XPLAIN_EXTENSION_EXPRESSION*/
void r196make(T196* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_EXPRESSION*/
T0* r196representation(T196* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION*/
T0* r196outer_sqlvalue(T196* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION*/
T0* r196sqlvalue_as_wildcard(T196* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION*/
T6 r196is_using_other_attributes(T196* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION*/
T0* r196exact_representation(T196* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION*/
T0* r196sqlvalue(T196* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION*/
T0* r196sqlinitvalue(T196* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION*/
T6 r196is_logical_expression(T196* C);
/*XPLAIN_EXTENSION_EXPRESSION*/
T0* r196sqlname(T196* C,T0* a1);
/*XPLAIN_EXTENSION_EXPRESSION*/
T0* r196sqlminvalue(T196* C,T0* a1);
/*XPLAIN_R_REPRESENTATION*/
T0* r616domain(T616* C);
/*XPLAIN_R_REPRESENTATION*/
T0* r616min_value(T616* C,T0* a1);
/*XPLAIN_R_REPRESENTATION*/
void r616make(T616* C,T2 a1,T2 a2);
extern T0*oBC616default_value;
/*XPLAIN_R_REPRESENTATION*/
T0* r616value_representation(T0* a1);
/*XPLAIN_R_REPRESENTATION*/
void r616set_domain_restriction(T616* C,T0* a1,T0* a2);
/*XPLAIN_R_REPRESENTATION*/
T0* r616xml_schema_data_type(void);
/*XPLAIN_R_REPRESENTATION*/
T0* r616max_value(T616* C,T0* a1);
/*XPLAIN_R_REPRESENTATION*/
T0* r616datatype(T616* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819_25Pdrop_table(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819do_create_value_assign(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819output_update_from_clause(T819* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
void r819sp_start(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_extend(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819_25Psql_infix_expression(T819* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL70*/
T0* r819sp_define_out_param(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819drop_table(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819no_space_identifier(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819write_drop(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819make_valid_sp_identifier(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819scientific_formatter(void);
/*SQL_GENERATOR_TSQL70*/
T0* r819domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlcolumnrequired_base(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819write_procedure(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819value_representation_system_user(T819* C);
/*SQL_GENERATOR_TSQL70*/
T0* r819datatype_ref_int(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819table_has_identity_column(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819do_sql_cast_to_real(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_extension_function(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_value_alter_table(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819init_necessary(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819do_do_create_select_list(T819* C,T0* a1,T6 a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819value_representation_float(T819* C);
/*SQL_GENERATOR_TSQL70*/
T6 r819table_has_auto_pk(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819make_valid_identifier(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819columndatatype_type(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_get_insert(T819* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlcolumnidentifier_type(T819* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819tabtab(void);
/*SQL_GENERATOR_TSQL70*/
void r819do_create_value_declare(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819_25Psqlcolumnrequired_base(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819write_select(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819datatype_varchar(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819write_assertion(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819value_representation_text(T819* C);
/*SQL_GENERATOR_TSQL70*/
T0* r819make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_infix_expression(T819* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlcolumnconstraint_type(T819* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819quoted_value_identifier(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819datatype_pk_int(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sp_update_name(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_predicate(T819* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
void r819create_sp_insert(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_cast_to_date(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819_25Pcreate_constant(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819table_name(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819drop_domain(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819do_drop_procedure(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819drop_table_if_exist(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819temporarytableprefix(void);
/*SQL_GENERATOR_TSQL70*/
T0* r819sp_define_param_name(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819assertion_name(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlcolumndefault_type(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_select_value(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819createautoprimarykey(T819* C);
/*SQL_GENERATOR_TSQL70*/
void r819_25Pcreate_table(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_select_function(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819init_forced_null(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_infix_expression_as_wildcard(T819* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_select_function_as_subselect(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_extend_create_table(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_cast_to_string(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_select_function_as_left_outer_join(T819* C,T0* a1);
extern T0*oBC819target_name;
/*SQL_GENERATOR_TSQL70*/
T0* r819do_sql_cast_to_integer(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819do_sql_select_for_extension_function(T819* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlfunction_nil(void);
/*SQL_GENERATOR_TSQL70*/
void r819write_init(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819createassert(T819* C);
/*SQL_GENERATOR_TSQL70*/
void r819write_base(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_sp_delete(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819value_representation_money(T819* C);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_select_joins(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_update(T819* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL70*/
void r819create_index(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlgetvalue_outside_sp(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819constraint_names(void);
/*SQL_GENERATOR_TSQL70*/
void r819_25Pwrite_type(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_select_for_extension_function(T819* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819datatype_pk_char(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sp_insert_name(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_combine_expression(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819value_representation_current_timestamp(T819* C);
/*SQL_GENERATOR_TSQL70*/
T0* r819as_string(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819echo(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819datatype_char(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlgetconstant(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819columndatatype_base(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819_25Pdrop_constant(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819_25Pcreate_insert(T819* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL70*/
void r819write_extend(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819createviews(T819* C);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_select_function_limit_before(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819write_index(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819sp_end(T819* C);
/*SQL_GENERATOR_TSQL70*/
T0* r819constant_identifier(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sp_use_param(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819init_forced_default(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819sp_body_statements(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819optional_create_value_declare(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819conditional_drop_procedure(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlcolumnconstraint_base(T819* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T6 r819check_if_required(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_subselect_for_attribute(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819do_create_select_value(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819datatype_int(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_procedure(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819is_value_data_type_changed(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819datatype_numeric(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_cast_to_integer(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_value_create_table(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819storedprocedureparamlistend(void);
/*SQL_GENERATOR_TSQL70*/
T0* r819quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlcolumndefault_base(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlgetvalue_inside_sp(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819column_constraint_name(T819* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlfunction_any(void);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlgetvalue(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819set_sequence_name_format(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819valuetablename(void);
/*SQL_GENERATOR_TSQL70*/
void r819create_constant_assignment(T819* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819safe_string(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819do_sql_cast_to_date(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819rule_identifier(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819write_type(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819equal(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_combine_expression_as_wildcard(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819extension_name(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819_25Pcreate_assertion(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819createtemporarytablestatement(void);
/*SQL_GENERATOR_TSQL70*/
void r819output_update_extend_from_clause(T819* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T6 r819noonelinecommentssupported(void);
/*SQL_GENERATOR_TSQL70*/
void r819create_use_database(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819value_identifier(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819init_trigger_name(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819formatter(void);
/*SQL_GENERATOR_TSQL70*/
void r819write_sql(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819createdomains(T819* C);
/*SQL_GENERATOR_TSQL70*/
void r819write_one_line_comment(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819value_representation_date(T819* C);
/*SQL_GENERATOR_TSQL70*/
void r819create_assertion(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819_798Psp_start(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819quote_identifier(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_constant(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819drop_sp(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819set_primary_key_format(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819extension_index_name(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819set_options(T819* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_TSQL70*/
void r819create_view(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819write_use_database(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819domain_identifier(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_value(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819sp_user_result(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_sp_update(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_value_assign(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819do_create_select_list(T819* C,T0* a1,T6 a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819storedprocedurereturnparamliststart(void);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_cast_to_real(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlcolumnrequired_type(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sp_get_auto_generated_primary_key(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_table(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819value_representation_char(T819* C,T2 a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819value_representation_boolean(T819* C);
/*SQL_GENERATOR_TSQL70*/
T6 r819createtimestamp(T819* C);
/*SQL_GENERATOR_TSQL70*/
T0* r819sp_function_type_for_selection(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819finishtemporarytablestatement(void);
/*SQL_GENERATOR_TSQL70*/
T0* r819sp_name(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819coalescesupported(void);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_subselect_for_extension(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819table_pk_name(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819drop_constant(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_insert(T819* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL70*/
T0* r819sp_delete_name(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819autoprimarykeyconstraint(void);
/*SQL_GENERATOR_TSQL70*/
T0* r819sp_define_in_param(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819is_value_declared(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819columndatatype_assertion(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T6 r819valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
void r819make(T819* C);
/*SQL_GENERATOR_TSQL70*/
T0* r819value_representation_integer(T819* C,T2 a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_echo(T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819_25Pcreate_index(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819_25Psqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819table_ts_name(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_extend_create_index(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T6 r819createindex(void);
/*SQL_GENERATOR_TSQL70*/
T0* r819column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819create_table_name(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_init(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819format(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_expression_as_boolean_value(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819index_name(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_select_joins_oldstyle(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_delete(T819* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_select_joins_ansi92(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819do_sql_cast_to_string(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
void r819create_domain(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_notnot_expression(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819storedprocedureparamliststart(void);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_not_expression(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sql_select_for_extension_expression(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL70*/
T0* r819sqlcheck_in(T819* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL70*/
void r819create_value_declare(T819* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821_25Pdrop_table(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821do_create_value_assign(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821output_update_from_clause(T821* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
void r821sp_start(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_extend(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821_25Psql_infix_expression(T821* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL65*/
T0* r821sp_define_out_param(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821drop_table(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821print(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821no_space_identifier(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821write_drop(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821make_valid_sp_identifier(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821scientific_formatter(void);
/*SQL_GENERATOR_TSQL65*/
T0* r821domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlcolumnrequired_base(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821write_procedure(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821value_representation_system_user(T821* C);
/*SQL_GENERATOR_TSQL65*/
T0* r821datatype_ref_int(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T6 r821table_has_identity_column(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821do_sql_cast_to_real(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_extension_function(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_value_alter_table(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T6 r821init_necessary(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821do_do_create_select_list(T821* C,T0* a1,T6 a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821value_representation_float(T821* C);
/*SQL_GENERATOR_TSQL65*/
T6 r821table_has_auto_pk(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821make_valid_identifier(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821columndatatype_type(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_get_insert(T821* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlcolumnidentifier_type(T821* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821tabtab(void);
/*SQL_GENERATOR_TSQL65*/
void r821do_create_value_declare(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821_25Psqlcolumnrequired_base(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821write_select(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821datatype_varchar(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821write_assertion(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821value_representation_text(T821* C);
/*SQL_GENERATOR_TSQL65*/
T0* r821make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_infix_expression(T821* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlcolumnconstraint_type(T821* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821quoted_value_identifier(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821datatype_pk_int(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sp_update_name(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_predicate(T821* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
void r821create_sp_insert(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_cast_to_date(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821_25Pcreate_constant(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821table_name(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821drop_domain(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821do_drop_procedure(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821drop_table_if_exist(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821temporarytableprefix(void);
/*SQL_GENERATOR_TSQL65*/
T0* r821sp_define_param_name(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821assertion_name(T0* a1);
extern T0*oBC820sqlfalse;
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlcolumndefault_type(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_select_value(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T6 r821createautoprimarykey(T821* C);
/*SQL_GENERATOR_TSQL65*/
void r821_25Pcreate_table(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_select_function(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T6 r821init_forced_null(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_infix_expression_as_wildcard(T821* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_select_function_as_subselect(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_extend_create_table(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_cast_to_string(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_select_function_as_left_outer_join(T821* C,T0* a1);
extern T0*oBC821target_name;
/*SQL_GENERATOR_TSQL65*/
T0* r821do_sql_cast_to_integer(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821do_sql_select_for_extension_function(T821* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlfunction_nil(void);
/*SQL_GENERATOR_TSQL65*/
void r821write_init(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T6 r821createassert(T821* C);
/*SQL_GENERATOR_TSQL65*/
void r821write_base(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_sp_delete(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821value_representation_money(T821* C);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_select_joins(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_update(T821* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL65*/
void r821create_index(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlgetvalue_outside_sp(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821constraint_names(void);
/*SQL_GENERATOR_TSQL65*/
void r821_25Pwrite_type(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_select_for_extension_function(T821* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821datatype_pk_char(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sp_insert_name(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_combine_expression(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821value_representation_current_timestamp(T821* C);
/*SQL_GENERATOR_TSQL65*/
T0* r821as_string(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821echo(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821datatype_char(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlgetconstant(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821columndatatype_base(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821_25Pdrop_constant(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821_25Pcreate_insert(T821* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL65*/
void r821write_extend(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T6 r821createviews(T821* C);
/*SQL_GENERATOR_TSQL65*/
void r821write_index(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821sp_end(T821* C);
/*SQL_GENERATOR_TSQL65*/
T0* r821constant_identifier(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sp_use_param(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T6 r821init_forced_default(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821sp_body_statements(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821optional_create_value_declare(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlcolumnconstraint_base(T821* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T6 r821check_if_required(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_subselect_for_attribute(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821do_create_select_value(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821datatype_int(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_procedure(T821* C,T0* a1);
extern T2 oBC821maxtemporarytablenamelength;
/*SQL_GENERATOR_TSQL65*/
T6 r821is_value_data_type_changed(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821datatype_numeric(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_cast_to_integer(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_value_create_table(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821storedprocedureparamlistend(void);
/*SQL_GENERATOR_TSQL65*/
T0* r821quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlcolumndefault_base(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlgetvalue_inside_sp(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821column_constraint_name(T821* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlfunction_any(void);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlgetvalue(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821set_sequence_name_format(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821valuetablename(void);
/*SQL_GENERATOR_TSQL65*/
void r821create_constant_assignment(T821* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821safe_string(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821do_sql_cast_to_date(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821rule_identifier(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821write_type(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T6 r821equal(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_combine_expression_as_wildcard(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821extension_name(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821_25Pcreate_assertion(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821createtemporarytablestatement(void);
/*SQL_GENERATOR_TSQL65*/
void r821output_update_extend_from_clause(T821* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T6 r821noonelinecommentssupported(void);
/*SQL_GENERATOR_TSQL65*/
void r821create_use_database(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821value_identifier(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821init_trigger_name(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821formatter(void);
/*SQL_GENERATOR_TSQL65*/
void r821write_sql(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T6 r821createdomains(T821* C);
/*SQL_GENERATOR_TSQL65*/
void r821write_one_line_comment(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821value_representation_date(T821* C);
/*SQL_GENERATOR_TSQL65*/
void r821create_assertion(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821_798Psp_start(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821quote_identifier(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_constant(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821drop_sp(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821set_primary_key_format(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821extension_index_name(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821set_options(T821* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_TSQL65*/
void r821create_view(T821* C,T0* a1);
extern T0*oBC821sqlcoalesce;
/*SQL_GENERATOR_TSQL65*/
void r821write_use_database(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821domain_identifier(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_value(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_sp_update(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T6 r821assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_value_assign(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821do_create_select_list(T821* C,T0* a1,T6 a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821storedprocedurereturnparamliststart(void);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_cast_to_real(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlcolumnrequired_type(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sp_get_auto_generated_primary_key(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_table(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821value_representation_char(T821* C,T2 a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821value_representation_boolean(T821* C);
/*SQL_GENERATOR_TSQL65*/
T6 r821createtimestamp(T821* C);
/*SQL_GENERATOR_TSQL65*/
T0* r821sp_function_type_for_selection(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821finishtemporarytablestatement(void);
/*SQL_GENERATOR_TSQL65*/
T0* r821sp_name(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T6 r821coalescesupported(void);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_subselect_for_extension(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821table_pk_name(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821drop_constant(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_insert(T821* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_TSQL65*/
T0* r821sp_delete_name(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821autoprimarykeyconstraint(void);
/*SQL_GENERATOR_TSQL65*/
T0* r821sp_define_in_param(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T6 r821is_value_declared(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821columndatatype_assertion(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlcolumnidentifier_base(T0* a1,T0* a2);
extern T0*oBC820sqltrue;
/*SQL_GENERATOR_TSQL65*/
T6 r821valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
void r821make(T821* C);
extern T2 oBC821maxidentifierlength;
/*SQL_GENERATOR_TSQL65*/
T0* r821value_representation_integer(T821* C,T2 a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_echo(T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821_25Pcreate_index(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821_25Psqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821table_ts_name(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_extend_create_index(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T6 r821createindex(void);
/*SQL_GENERATOR_TSQL65*/
T0* r821column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821create_table_name(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_init(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821format(T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_expression_as_boolean_value(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821index_name(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_select_joins_oldstyle(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_delete(T821* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_select_joins_ansi92(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821do_sql_cast_to_string(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
void r821create_domain(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_notnot_expression(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821storedprocedureparamliststart(void);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_not_expression(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sql_select_for_extension_expression(T821* C,T0* a1);
/*SQL_GENERATOR_TSQL65*/
T0* r821sqlcheck_in(T821* C,T0* a1,T0* a2);
/*SQL_GENERATOR_TSQL65*/
void r821create_value_declare(T821* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817drop_value(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_extend(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817datatype_text(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817drop_table(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817no_space_identifier(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817write_drop(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817scientific_formatter(void);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlcolumnrequired_base(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817write_procedure(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817value_representation_system_user(T817* C);
extern T6 oBC817checksnullaftertrigger;
/*SQL_GENERATOR_SQLITE_3*/
T0* r817datatype_ref_int(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817do_sql_cast_to_real(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_extension_function(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_value_alter_table(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817init_necessary(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817do_do_create_select_list(T817* C,T0* a1,T6 a2);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817value_representation_float(T817* C);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817table_has_auto_pk(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817make_valid_identifier(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817columndatatype_type(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_get_insert(T817* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlcolumnidentifier_type(T817* C,T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817tabtab(void);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_last_auto_generated_primary_key(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817_25Psqlcolumnrequired_base(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817write_select(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_value_declare_outside_sp(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817drop_procedure(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817datatype_varchar(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817datatype_datetime(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817write_assertion(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817value_representation_text(T817* C);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817datatype_boolean(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_infix_expression(T817* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlcolumnconstraint_type(T817* C,T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817quoted_value_identifier(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817datatype_pk_int(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_predicate(T817* C,T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
void r817drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_cast_to_date(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817table_name(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817drop_domain(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_init_cast_to_real(T817* C,T0* a1);
extern T6 oBC817dropcolumnsupported;
/*SQL_GENERATOR_SQLITE_3*/
T0* r817temporarytableprefix(void);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817assertion_name(T0* a1);
extern T0*oBC817sqlfalse;
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlcolumndefault_type(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_select_value(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817createautoprimarykey(T817* C);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_select_function(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817init_forced_null(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_infix_expression_as_wildcard(T817* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_select_function_as_subselect(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_extend_create_table(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_cast_to_string(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_select_function_as_left_outer_join(T817* C,T0* a1);
extern T0*oBC817target_name;
/*SQL_GENERATOR_SQLITE_3*/
T0* r817do_sql_select_for_extension_function(T817* C,T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817do_sql_cast_to_integer(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlfunction_nil(void);
/*SQL_GENERATOR_SQLITE_3*/
void r817write_init(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817createassert(T817* C);
/*SQL_GENERATOR_SQLITE_3*/
void r817write_base(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817value_representation_money(T817* C);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_init_infix_expression(T817* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_select_joins(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_update(T817* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_index(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlgetvalue_outside_sp(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817constraint_names(void);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817createdomaincheck(T817* C);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_init_cast_to_string(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_select_for_extension_function(T817* C,T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817datatype_pk_char(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_combine_expression(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817value_representation_current_timestamp(T817* C);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817as_string(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_init_expression(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817echo(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817datatype_char(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlgetconstant(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817columndatatype_base(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817write_extend(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817createviews(T817* C);
/*SQL_GENERATOR_SQLITE_3*/
void r817write_index(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817constant_identifier(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_value_assign_outside_sp(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817datatype_money(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817init_forced_default(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817optional_create_value_declare(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlcolumnconstraint_base(T817* C,T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817check_if_required(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_subselect_for_attribute(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817is_value_data_type_changed(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817datatype_numeric(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817datatype_picture(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_cast_to_integer(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_value_create_table(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlcolumndefault_base(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817column_constraint_name(T817* C,T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlfunction_any(void);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlgetvalue(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817set_sequence_name_format(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817valuetablename(void);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_constant_assignment(T817* C,T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817safe_string(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817do_sql_cast_to_date(T817* C,T0* a1);
extern T6 oBC817domainssupported;
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817equal(T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_SQLITE_3*/
void r817write_type(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_combine_expression_as_wildcard(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817extension_name(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817createtemporarytablestatement(void);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817noonelinecommentssupported(void);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817value_identifier(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817formatter(void);
/*SQL_GENERATOR_SQLITE_3*/
void r817write_sql(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817createdomains(T817* C);
/*SQL_GENERATOR_SQLITE_3*/
void r817write_one_line_comment(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817value_representation_date(T817* C);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_assertion(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817quote_identifier(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_constant(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817datatype_float(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817set_primary_key_format(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817extension_index_name(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817set_options(T817* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_init_cast_to_date(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_view(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817write_use_database(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817domain_identifier(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_value(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817do_create_select_list(T817* C,T0* a1,T6 a2);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_cast_to_real(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlcolumnrequired_type(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_table(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817value_representation_char(T817* C,T2 a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817value_representation_boolean(T817* C);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817createtimestamp(T817* C);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sp_function_type_for_selection(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817finishtemporarytablestatement(void);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_init_combine_expression(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlinitvalue_if(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817coalescesupported(void);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_subselect_for_extension(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlinitvalue_attribute(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817table_pk_name(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817drop_constant(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_insert(T817* C,T0* a1,T0* a2,T0* a3);
extern T0*oBC817autoprimarykeyconstraint;
extern int fBC817autoprimarykeyconstraint;
/*SQL_GENERATOR_SQLITE_3*/
T0* r817autoprimarykeyconstraint(void);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817is_value_declared(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817columndatatype_assertion(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlcolumnidentifier_base(T0* a1,T0* a2);
extern T0*oBC817sqltrue;
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_init_cast_to_integer(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
void r817make(T817* C);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817value_representation_integer(T817* C,T2 a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817_25Psqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817table_ts_name(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_extend_create_index(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T6 r817createindex(void);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817create_table_name(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_init(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817format(T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_expression_as_boolean_value(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817index_name(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_select_joins_oldstyle(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_delete(T817* C,T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_select_joins_ansi92(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817do_sql_cast_to_string(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_domain(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_notnot_expression(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_not_expression(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sql_select_for_extension_expression(T817* C,T0* a1);
/*SQL_GENERATOR_SQLITE_3*/
T0* r817sqlcheck_in(T817* C,T0* a1,T0* a2);
/*SQL_GENERATOR_SQLITE_3*/
void r817create_value_declare(T817* C,T0* a1);
/*XPLAIN_IF_EXPRESSION*/
void r592add_to_join(T592* C,T0* a1,T0* a2);
/*XPLAIN_IF_EXPRESSION*/
T6 r592uses_parameter(T592* C,T0* a1);
/*XPLAIN_IF_EXPRESSION*/
T0* r592sqlmaxvalue(T592* C,T0* a1);
/*XPLAIN_IF_EXPRESSION*/
T6 r592is_string_expression(void);
/*XPLAIN_IF_EXPRESSION*/
T0* r592representation(T592* C,T0* a1);
/*XPLAIN_IF_EXPRESSION*/
void r592make(T592* C,T0* a1,T0* a2,T0* a3);
/*XPLAIN_IF_EXPRESSION*/
T0* r592outer_sqlvalue(T592* C,T0* a1);
/*XPLAIN_IF_EXPRESSION*/
T0* r592sqlvalue_as_wildcard(T592* C,T0* a1);
/*XPLAIN_IF_EXPRESSION*/
T6 r592is_using_other_attributes(T592* C,T0* a1);
/*XPLAIN_IF_EXPRESSION*/
T0* r592exact_representation(T592* C,T0* a1);
/*XPLAIN_IF_EXPRESSION*/
T0* r592sqlvalue(T592* C,T0* a1);
/*XPLAIN_IF_EXPRESSION*/
T0* r592sqlinitvalue(T592* C,T0* a1);
/*XPLAIN_IF_EXPRESSION*/
T0* r592sqlminvalue(T592* C,T0* a1);
/*XPLAIN_ASSIGNMENT*/
void r231make(T231* C,T0* a1,T0* a2);
/*ST_FLOATING_POINT_FORMATTER*/
void r480center_format_to(T480* C,T0* a1,T0* a2);
/*ST_FLOATING_POINT_FORMATTER*/
void r480build_integer_and_fractional_parts(T480* C,T5 a1);
/*ST_FLOATING_POINT_FORMATTER*/
void r480append_integer_to_string(T480* C,T2 a1,T2 a2,T0* a3);
/*ST_FLOATING_POINT_FORMATTER*/
T6 r480valid_parameter(T0* a1);
/*ST_FLOATING_POINT_FORMATTER*/
void r480_471Pmake(T480* C);
/*ST_FLOATING_POINT_FORMATTER*/
void r480make(T480* C);
/*ST_FLOATING_POINT_FORMATTER*/
T2 r480double_sign(T5 a1);
extern T0*oBC482double_;
/*ST_FLOATING_POINT_FORMATTER*/
void r480format_to(T480* C,T0* a1,T0* a2);
/*ST_FLOATING_POINT_FORMATTER*/
void r480right_format_to(T480* C,T0* a1,T0* a2);
/*ST_FLOATING_POINT_FORMATTER*/
void r480_471Preset_options(T480* C);
/*ST_FLOATING_POINT_FORMATTER*/
void r480reset_options(T480* C);
/*ST_FLOATING_POINT_FORMATTER*/
T5 r480ten_power(T2 a1);
/*ST_FLOATING_POINT_FORMATTER*/
void r480double_format_to(T480* C,T5 a1,T0* a2);
/*ST_FLOATING_POINT_FORMATTER*/
void r480justify_format_to(T480* C,T0* a1,T0* a2);
/*ST_FLOATING_POINT_FORMATTER*/
void r480left_format_to(T480* C,T0* a1,T0* a2);
/*XPLAIN_TRAJECTORY*/
T0* r569sqldomainconstraint(T569* C,T0* a1,T0* a2);
/*XPLAIN_TRAJECTORY*/
void r569make(T569* C,T0* a1,T0* a2);
/*XPLAIN_TRAJECTORY*/
void r569check_attachment(T569* C,T0* a1,T0* a2);
/*XPLAIN_TRAJECTORY*/
T0* r569sqlcolumnconstraint(T569* C,T0* a1,T0* a2);
/*XPLAIN_GET_STATEMENT*/
T6 r110uses_parameter(T110* C,T0* a1);
/*XPLAIN_GET_STATEMENT*/
void r110write(T110* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811_25Pdrop_table(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811drop_value(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811sp_start(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_extend(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811datatype_text(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sp_define_out_param(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811drop_table(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811_25Pdrop_value(T811* C,T0* a1);
extern T0*oBC811sqlsysfunction_system_user;
/*SQL_GENERATOR_ORACLE*/
T0* r811no_space_identifier(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811write_drop(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811make_valid_sp_identifier(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811scientific_formatter(void);
/*SQL_GENERATOR_ORACLE*/
T0* r811domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlcolumnrequired_base(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811write_procedure(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811value_representation_system_user(T811* C);
/*SQL_GENERATOR_ORACLE*/
T0* r811datatype_ref_int(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_value_declare_inside_sp(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811do_sql_cast_to_real(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_extension_function(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811trigger_primary_key_update_name(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_value_alter_table(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811init_necessary(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811do_do_create_select_list(T811* C,T0* a1,T6 a2);
/*SQL_GENERATOR_ORACLE*/
T0* r811value_representation_float(T811* C);
/*SQL_GENERATOR_ORACLE*/
T6 r811table_has_auto_pk(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811do_drop_function(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811make_valid_identifier(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811columndatatype_type(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_get_insert(T811* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlcolumnidentifier_type(T811* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
T0* r811tabtab(void);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_last_auto_generated_primary_key(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811drop_primary_key_generator(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_value_assign_inside_sp(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811_25Psqlcolumnrequired_base(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811write_select(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_value_declare_outside_sp(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811drop_procedure(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811datatype_varchar(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811datatype_datetime(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811write_assertion(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811value_representation_text(T811* C);
/*SQL_GENERATOR_ORACLE*/
T0* r811datatype_boolean(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_infix_expression(T811* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlcolumnconstraint_type(T811* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
T0* r811quoted_value_identifier(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811datatype_pk_int(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sp_update_name(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_predicate(T811* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
void r811create_sp_insert(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_cast_to_date(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811table_name(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811drop_domain(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_init_cast_to_real(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811do_drop_procedure(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811temporarytableprefix(void);
/*SQL_GENERATOR_ORACLE*/
T0* r811sp_define_param_name(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811assertion_name(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlcolumndefault_type(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_select_value(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811createautoprimarykey(T811* C);
/*SQL_GENERATOR_ORACLE*/
void r811create_select_function(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811init_forced_null(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_infix_expression_as_wildcard(T811* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_select_function_as_subselect(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811forbid_update_of_primary_key(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_extend_create_table(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_cast_to_string(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_select_function_as_left_outer_join(T811* C,T0* a1);
extern T0*oBC811target_name;
/*SQL_GENERATOR_ORACLE*/
void r811_25Pcreate_select_list(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811do_sql_select_for_extension_function(T811* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
T0* r811do_sql_cast_to_integer(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlfunction_nil(void);
/*SQL_GENERATOR_ORACLE*/
void r811write_init(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811createassert(T811* C);
/*SQL_GENERATOR_ORACLE*/
void r811create_select_value_inside_sp(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811write_base(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_sp_delete(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811value_representation_money(T811* C);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_init_infix_expression(T811* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_select_joins(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_update(T811* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_ORACLE*/
void r811create_index(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlgetvalue_outside_sp(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811constraint_names(void);
/*SQL_GENERATOR_ORACLE*/
T6 r811createdomaincheck(T811* C);
/*SQL_GENERATOR_ORACLE*/
void r811_25Pwrite_type(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_init_cast_to_string(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_select_for_extension_function(T811* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
T0* r811datatype_pk_char(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_select_list(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sp_insert_name(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_combine_expression(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811value_representation_current_timestamp(T811* C);
/*SQL_GENERATOR_ORACLE*/
T0* r811as_string(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_init_expression(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811echo(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811datatype_char(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlgetconstant(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811columndatatype_base(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811createviews(T811* C);
/*SQL_GENERATOR_ORACLE*/
void r811write_index(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811constant_identifier(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_value_assign_outside_sp(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811sp_end(T811* C);
/*SQL_GENERATOR_ORACLE*/
T0* r811sp_use_param(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811datatype_money(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811init_forced_default(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811sp_body_statements(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811optional_create_value_declare(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlcolumnconstraint_base(T811* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
T6 r811check_if_required(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_subselect_for_attribute(T811* C,T0* a1);
extern T0*oBC811sp_return_parameter_format_string;
/*SQL_GENERATOR_ORACLE*/
T0* r811datatype_int(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_procedure(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811is_value_data_type_changed(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811datatype_numeric(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811datatype_picture(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_cast_to_integer(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_value_create_table(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811storedprocedureparamlistend(void);
/*SQL_GENERATOR_ORACLE*/
void r811_25Pcreate_select_function(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlcolumndefault_base(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlgetvalue_inside_sp(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811column_constraint_name(T811* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
void r811drop_temporary_table_if_exist(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlfunction_any(void);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlgetvalue(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811set_sequence_name_format(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811valuetablename(void);
/*SQL_GENERATOR_ORACLE*/
void r811create_constant_assignment(T811* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
T0* r811safe_string(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811do_sql_cast_to_date(T811* C,T0* a1);
extern T6 oBC811domainssupported;
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
void r811write_type(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811equal(T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
T0* r811finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_combine_expression_as_wildcard(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sequence_name(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811_25Pas_string(T0* a1);
extern T0*oBC811sqlsysfunction_current_timestamp;
/*SQL_GENERATOR_ORACLE*/
T0* r811extension_name(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811noonelinecommentssupported(void);
/*SQL_GENERATOR_ORACLE*/
T0* r811value_identifier(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_primary_key_generator(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811formatter(void);
/*SQL_GENERATOR_ORACLE*/
void r811write_sql(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811createdomains(T811* C);
/*SQL_GENERATOR_ORACLE*/
void r811write_one_line_comment(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811value_representation_date(T811* C);
/*SQL_GENERATOR_ORACLE*/
void r811create_assertion(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811quote_identifier(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_constant(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811drop_sp(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811set_primary_key_format(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811extension_index_name(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811set_options(T811* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_init_cast_to_date(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_view(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811write_use_database(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811domain_identifier(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_value(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_sp_update(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_value_assign(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811do_create_select_list(T811* C,T0* a1,T6 a2);
/*SQL_GENERATOR_ORACLE*/
T0* r811storedprocedurereturnparamliststart(void);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_cast_to_real(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlcolumnrequired_type(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sp_get_auto_generated_primary_key(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_table(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811value_representation_char(T811* C,T2 a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811value_representation_boolean(T811* C);
/*SQL_GENERATOR_ORACLE*/
T6 r811createtimestamp(T811* C);
/*SQL_GENERATOR_ORACLE*/
T0* r811sp_function_type_for_selection(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811finishtemporarytablestatement(void);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_init_combine_expression(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlinitvalue_if(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sp_name(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811coalescesupported(void);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_subselect_for_extension(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlinitvalue_attribute(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811table_pk_name(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811drop_constant(T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_insert(T811* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_ORACLE*/
T0* r811sp_delete_name(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811autoprimarykeyconstraint(void);
/*SQL_GENERATOR_ORACLE*/
T0* r811sp_define_in_param(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811is_value_declared(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811columndatatype_assertion(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_init_cast_to_integer(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
void r811make(T811* C);
/*SQL_GENERATOR_ORACLE*/
T0* r811value_representation_integer(T811* C,T2 a1);
/*SQL_GENERATOR_ORACLE*/
void r811sp_user_declaration(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811_25Psqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811table_ts_name(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_extend_create_index(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T6 r811createindex(void);
/*SQL_GENERATOR_ORACLE*/
T0* r811column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811create_table_name(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_init(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811format(T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_expression_as_boolean_value(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811index_name(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811sp_result_parameter(T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_select_joins_oldstyle(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_delete(T811* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_select_joins_ansi92(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811do_sql_cast_to_string(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
void r811create_domain(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_notnot_expression(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811storedprocedureparamliststart(void);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_not_expression(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sql_select_for_extension_expression(T811* C,T0* a1);
/*SQL_GENERATOR_ORACLE*/
T0* r811sqlcheck_in(T811* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ORACLE*/
void r811create_value_declare(T811* C,T0* a1);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T0* r636sqlmaxvalue(T636* C,T0* a1);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T0* r636column_name(T636* C);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T6 r636is_specialization(T636* C);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T6 r636is_string_expression(void);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T0* r636representation(T636* C,T0* a1);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T0* r636outer_sqlvalue(T636* C,T0* a1);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T0* r636sqlvalue_as_wildcard(T636* C,T0* a1);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T6 r636is_using_other_attributes(T636* C,T0* a1);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T0* r636exact_representation(T636* C,T0* a1);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T6 r636can_be_null(T636* C);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T0* r636sqlvalue(T636* C,T0* a1);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T0* r636sqlinitvalue(T636* C,T0* a1);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T6 r636is_logical_expression(T636* C);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T0* r636sqlname(T636* C,T0* a1);
/*XPLAIN_ATTRIBUTE_EXPRESSION*/
T0* r636sqlminvalue(T636* C,T0* a1);
/*XPLAIN_PARSER*/
T0* r53get_known_type(T53* C,T0* a1);
/*XPLAIN_PARSER*/
T0* r53yyfixed_array(T0* a1);
/*XPLAIN_PARSER*/
T0* r53universe(void);
/*XPLAIN_PARSER*/
T6 r53equal(T0* a1,T0* a2);
/*XPLAIN_PARSER*/
T0* r53scientific_formatter(void);
/*XPLAIN_PARSER*/
void r53preprocessor_include(T53* C);
/*XPLAIN_PARSER*/
void r53yy_build_tables(T53* C);
/*XPLAIN_PARSER*/
void r53yy_load_input_buffer(T53* C);
/*XPLAIN_PARSER*/
void r53set_input_buffer(T53* C,T0* a1);
/*XPLAIN_PARSER*/
T0* r53text(T53* C);
/*XPLAIN_PARSER*/
void r53make_with_stdin(T53* C,T0* a1);
/*XPLAIN_PARSER*/
void r53make_scanner_with_file(T53* C,T0* a1);
/*XPLAIN_PARSER*/
T2 r53yy_null_trans_state(T53* C,T2 a1);
extern T0*oBC53yydefgoto_template;
extern int fBC53yydefgoto_template;
/*XPLAIN_PARSER*/
T0* r53yydefgoto_template(void);
/*XPLAIN_PARSER*/
void r53yy_execute_eof_action(T53* C,T2 a1);
/*XPLAIN_PARSER*/
void r53warn_attributes_with_inits(T53* C,T0* a1);
/*XPLAIN_PARSER*/
void r53preprocessor_use(T53* C);
/*XPLAIN_PARSER*/
void r53yy_push_last_value(T53* C,T2 a1);
extern T0*oBC53yypact_template;
extern int fBC53yypact_template;
/*XPLAIN_PARSER*/
T0* r53yypact_template(void);
extern T0*oBC53yytable_template;
extern int fBC53yytable_template;
/*XPLAIN_PARSER*/
T0* r53yytable_template(void);
/*XPLAIN_PARSER*/
T0* r53unquote_string(T0* a1);
/*XPLAIN_PARSER*/
void r53make_parser_skeleton(T53* C);
extern T0*oBC54yy_ec_template;
extern int fBC54yy_ec_template;
/*XPLAIN_PARSER*/
T0* r53yy_ec_template(void);
/*XPLAIN_PARSER*/
void r53yy_push_error_value(T53* C);
extern T0*oBC53yycheck_template;
extern int fBC53yycheck_template;
/*XPLAIN_PARSER*/
T0* r53yycheck_template(void);
/*XPLAIN_PARSER*/
void r53make_with_file(T53* C,T0* a1,T0* a2);
/*XPLAIN_PARSER*/
void r53make_scanner_with_stdin(T53* C);
extern T0*oBC54yy_meta_template;
extern int fBC54yy_meta_template;
/*XPLAIN_PARSER*/
T0* r53yy_meta_template(void);
/*XPLAIN_PARSER*/
T0* r53get_known_base_or_type(T53* C,T0* a1);
/*XPLAIN_PARSER*/
T3 r53text_item(T53* C,T2 a1);
/*XPLAIN_PARSER*/
void r53yy_set_line_column(T53* C);
/*XPLAIN_PARSER*/
void r53report_warning(T53* C,T0* a1);
/*XPLAIN_PARSER*/
T0* r53get_object_if_valid_tree(T53* C,T0* a1);
/*XPLAIN_PARSER*/
void r53yy_build_parser_tables(T53* C);
/*XPLAIN_PARSER*/
void r53yy_execute_action(T53* C,T2 a1);
/*XPLAIN_PARSER*/
void r53make_with_buffer(T53* C,T0* a1);
/*XPLAIN_PARSER*/
void r53yy_do_error_action(T53* C,T2 a1);
/*XPLAIN_PARSER*/
void r53parse(T53* C);
/*XPLAIN_PARSER*/
T0* r53new_file_buffer(T0* a1);
/*XPLAIN_PARSER*/
T2 r53yy_previous_state(T53* C);
extern T0*oBC53yydefact_template;
extern int fBC53yydefact_template;
/*XPLAIN_PARSER*/
T0* r53yydefact_template(void);
/*XPLAIN_PARSER*/
T0* r53make_relative_path(T53* C,T0* a1);
/*XPLAIN_PARSER*/
void r53read_token(T53* C);
extern T0*oBC53yytypes1_template;
extern int fBC53yytypes1_template;
/*XPLAIN_PARSER*/
T0* r53yytypes1_template(void);
extern T0*oBC61integer_array_;
/*XPLAIN_PARSER*/
void r53error_unknown_attribute(T53* C,T0* a1,T0* a2);
/*XPLAIN_PARSER*/
void r53fatal_error(T0* a1);
/*XPLAIN_PARSER*/
void r53yy_initialize(T53* C);
/*XPLAIN_PARSER*/
void r53write_pending_init(T53* C);
/*XPLAIN_PARSER*/
T0* r53format(T0* a1,T0* a2);
extern T0*oBC54yy_base_template;
extern int fBC54yy_base_template;
/*XPLAIN_PARSER*/
T0* r53yy_base_template(void);
/*XPLAIN_PARSER*/
void r53yy_do_action(T53* C,T2 a1);
/*XPLAIN_PARSER*/
T6 r53immediate_output_mode(T53* C);
extern T0*oBC54yy_chk_template;
extern int fBC54yy_chk_template;
/*XPLAIN_PARSER*/
T0* r53yy_chk_template(void);
/*XPLAIN_PARSER*/
void r53conditional_parse_domain(T53* C,T2 a1);
extern T0*oBC53yytypes2_template;
extern int fBC53yytypes2_template;
/*XPLAIN_PARSER*/
T0* r53yytypes2_template(void);
/*XPLAIN_PARSER*/
void r53make(T53* C,T0* a1);
/*XPLAIN_PARSER*/
void r53write_pending_type(T53* C);
/*XPLAIN_PARSER*/
void r53less(T53* C,T2 a1);
extern T0*oBC54yy_nxt_template;
extern int fBC54yy_nxt_template;
/*XPLAIN_PARSER*/
T0* r53yy_nxt_template(void);
/*XPLAIN_PARSER*/
void r53yy_init_value_stacks(T53* C);
/*XPLAIN_PARSER*/
void r53set_start_condition(T53* C,T2 a1);
extern T0*oBC53yypgoto_template;
extern int fBC53yypgoto_template;
/*XPLAIN_PARSER*/
T0* r53yypgoto_template(void);
/*XPLAIN_PARSER*/
void r53read_character(T53* C);
/*XPLAIN_PARSER*/
T6 r53use_mode(T53* C);
/*XPLAIN_PARSER*/
T0* r53formatter(void);
extern T0*oBC54yy_def_template;
extern int fBC54yy_def_template;
/*XPLAIN_PARSER*/
T0* r53yy_def_template(void);
/*XPLAIN_PARSER*/
T0* r53new_logical_infix_expression(T0* a1,T0* a2,T0* a3);
/*XPLAIN_PARSER*/
void r53report_error(T53* C,T0* a1);
/*XPLAIN_PARSER*/
void r53yy_set_content(T53* C,T0* a1);
/*XPLAIN_PARSER*/
T6 r53is_parameter_declared(T53* C,T0* a1);
/*XPLAIN_PARSER*/
T6 r53wrap(T53* C);
/*XPLAIN_PARSER*/
void r53do_make(T53* C);
/*XPLAIN_PARSER*/
T0* r53get_known_value(T53* C,T0* a1);
extern T0*oBC53yytranslate_template;
extern int fBC53yytranslate_template;
/*XPLAIN_PARSER*/
T0* r53yytranslate_template(void);
/*XPLAIN_PARSER*/
void r53write_pending_statement(T53* C);
/*XPLAIN_PARSER*/
void r53yy_refill_input_buffer(T53* C);
/*XPLAIN_PARSER*/
void r53yy_clear_value_stacks(T53* C);
/*XPLAIN_PARSER*/
T0* r53yy_fixed_array(T0* a1);
extern T0*oBC54yy_accept_template;
extern int fBC54yy_accept_template;
/*XPLAIN_PARSER*/
T0* r53yy_accept_template(void);
/*XPLAIN_PARSER*/
T0* r53get_known_object(T53* C,T0* a1);
extern T0*oBC53yyr1_template;
extern int fBC53yyr1_template;
/*XPLAIN_PARSER*/
T0* r53yyr1_template(void);
/*XPLAIN_PARSER*/
void r53yy_pop_last_value(T53* C,T2 a1);
/*XPLAIN_I_ENUMERATION*/
T0* r563integer_cell(T2 a1);
/*XPLAIN_I_ENUMERATION*/
T0* r563format(T0* a1,T0* a2);
/*XPLAIN_I_ENUMERATION*/
T0* r563sqldomainconstraint(T563* C,T0* a1,T0* a2);
/*XPLAIN_I_ENUMERATION*/
void r563make(T563* C,T0* a1);
/*XPLAIN_I_ENUMERATION*/
void r563check_attachment(T563* C,T0* a1,T0* a2);
/*XPLAIN_I_ENUMERATION*/
T0* r563scientific_formatter(void);
/*XPLAIN_I_ENUMERATION*/
T0* r563double_cell(T5 a1);
/*XPLAIN_I_ENUMERATION*/
T0* r563sqlcolumnconstraint(T563* C,T0* a1,T0* a2);
/*XPLAIN_I_ENUMERATION*/
T0* r563formatter(void);
/*ST_STRING_FORMATTER*/
void r470center_format_to(T470* C,T0* a1,T0* a2);
/*ST_STRING_FORMATTER*/
void r470string_format_to(T470* C,T0* a1,T0* a2);
/*ST_STRING_FORMATTER*/
T6 r470valid_parameter(T0* a1);
/*ST_STRING_FORMATTER*/
void r470format_to(T470* C,T0* a1,T0* a2);
/*ST_STRING_FORMATTER*/
void r470right_format_to(T470* C,T0* a1,T0* a2);
/*ST_STRING_FORMATTER*/
void r470_471Preset_options(T470* C);
/*ST_STRING_FORMATTER*/
void r470reset_options(T470* C);
/*ST_STRING_FORMATTER*/
void r470justify_format_to(T470* C,T0* a1,T0* a2);
/*ST_STRING_FORMATTER*/
void r470left_format_to(T470* C,T0* a1,T0* a2);
/*XPLAIN_I_REPRESENTATION*/
T0* r613domain(T613* C);
/*XPLAIN_I_REPRESENTATION*/
T0* r613min_value(T613* C,T0* a1);
/*XPLAIN_I_REPRESENTATION*/
T0* r613value_representation(T613* C,T0* a1);
/*XPLAIN_I_REPRESENTATION*/
void r613set_domain_restriction(T613* C,T0* a1,T0* a2);
/*XPLAIN_I_REPRESENTATION*/
T0* r613xml_schema_data_type(T613* C);
/*XPLAIN_I_REPRESENTATION*/
T0* r613max_value(T613* C,T0* a1);
/*XPLAIN_I_REPRESENTATION*/
T0* r613datatype(T613* C,T0* a1);
/*XPLAIN_ATTRIBUTE_NAME_NODE*/
T0* r284last(T284* C);
/*XPLAIN_ATTRIBUTE_NAME_NODE*/
void r284set_prefix_table(T284* C,T0* a1);
/*XPLAIN_ATTRIBUTE_NAME_NODE*/
void r284make(T284* C,T0* a1,T0* a2);
/*XPLAIN_ATTRIBUTE_NAME_NODE*/
T6 r284has(T284* C,T0* a1);
/*ST_FIXED_POINT_FORMATTER*/
void r483center_format_to(T483* C,T0* a1,T0* a2);
/*ST_FIXED_POINT_FORMATTER*/
void r483build_integer_and_fractional_parts(T483* C,T5 a1);
/*ST_FIXED_POINT_FORMATTER*/
void r483append_integer_to_string(T483* C,T2 a1,T2 a2,T0* a3);
/*ST_FIXED_POINT_FORMATTER*/
T6 r483valid_parameter(T0* a1);
/*ST_FIXED_POINT_FORMATTER*/
void r483_471Pmake(T483* C);
/*ST_FIXED_POINT_FORMATTER*/
void r483make(T483* C);
/*ST_FIXED_POINT_FORMATTER*/
T2 r483double_sign(T5 a1);
/*ST_FIXED_POINT_FORMATTER*/
void r483format_to(T483* C,T0* a1,T0* a2);
/*ST_FIXED_POINT_FORMATTER*/
void r483right_format_to(T483* C,T0* a1,T0* a2);
/*ST_FIXED_POINT_FORMATTER*/
void r483_471Preset_options(T483* C);
/*ST_FIXED_POINT_FORMATTER*/
void r483reset_options(T483* C);
/*ST_FIXED_POINT_FORMATTER*/
void r483double_format_to(T483* C,T5 a1,T0* a2);
/*ST_FIXED_POINT_FORMATTER*/
void r483left_format_to(T483* C,T0* a1,T0* a2);
/*ST_BOOLEAN_FORMATTER*/
void r499center_format_to(T499* C,T0* a1,T0* a2);
/*ST_BOOLEAN_FORMATTER*/
T6 r499valid_parameter(T0* a1);
/*ST_BOOLEAN_FORMATTER*/
void r499boolean_format_to(T499* C,T6 a1,T0* a2);
/*ST_BOOLEAN_FORMATTER*/
void r499format_to(T499* C,T0* a1,T0* a2);
/*ST_BOOLEAN_FORMATTER*/
void r499right_format_to(T499* C,T0* a1,T0* a2);
/*ST_BOOLEAN_FORMATTER*/
void r499reset_options(T499* C);
/*ST_BOOLEAN_FORMATTER*/
void r499justify_format_to(T499* C,T0* a1,T0* a2);
/*ST_BOOLEAN_FORMATTER*/
void r499left_format_to(T499* C,T0* a1,T0* a2);
/*XPLAIN_STRING_FUNCTION*/
void r598add_to_join(T598* C,T0* a1,T0* a2);
/*XPLAIN_STRING_FUNCTION*/
T6 r598uses_parameter(T598* C,T0* a1);
/*XPLAIN_STRING_FUNCTION*/
T0* r598sqlmaxvalue(T0* a1);
/*XPLAIN_STRING_FUNCTION*/
T6 r598is_string_expression(void);
/*XPLAIN_STRING_FUNCTION*/
T0* r598representation(T0* a1);
/*XPLAIN_STRING_FUNCTION*/
T0* r598outer_sqlvalue(T598* C,T0* a1);
/*XPLAIN_STRING_FUNCTION*/
T0* r598sqlvalue_as_wildcard(T598* C,T0* a1);
/*XPLAIN_STRING_FUNCTION*/
T6 r598is_using_other_attributes(T598* C,T0* a1);
/*XPLAIN_STRING_FUNCTION*/
T0* r598exact_representation(T0* a1);
/*XPLAIN_STRING_FUNCTION*/
T0* r598sqlvalue(T598* C,T0* a1);
/*XPLAIN_STRING_FUNCTION*/
T0* r598sqlinitvalue(T598* C,T0* a1);
/*XPLAIN_STRING_FUNCTION*/
T0* r598sqlminvalue(T0* a1);
/*UC_STRING*/
T0* r385out(T385* C);
/*UC_STRING*/
void r385copy(T385* C,T0* a1);
/*UC_STRING*/
T0* r385substring(T385* C,T2 a1,T2 a2);
/*UC_STRING*/
void r385reset_byte_index_cache(T385* C);
/*UC_STRING*/
T2 r385shifted_byte_index(T385* C,T2 a1,T2 a2);
/*UC_STRING*/
void r385wipe_out(T385* C);
/*UC_STRING*/
void r385keep_tail(T385* C,T2 a1);
/*UC_STRING*/
void r385remove_first(T385* C,T2 a1);
/*UC_STRING*/
T6 r385same_unicode_string(T385* C,T0* a1);
/*UC_STRING*/
T2 r385item_code(T385* C,T2 a1);
/*UC_STRING*/
T3 r385character_item_at_byte_index(T385* C,T2 a1);
/*UC_STRING*/
void r385_7Pmake(T385* C,T2 a1);
/*UC_STRING*/
void r385put(T385* C,T3 a1,T2 a2);
/*UC_STRING*/
void r385remove_between(T385* C,T2 a1,T2 a2);
/*UC_STRING*/
T6 r385is_equal(T385* C,T0* a1);
/*UC_STRING*/
void r385insert_character(T385* C,T3 a1,T2 a2);
/*UC_STRING*/
T3 r385item(T385* C,T2 a1);
/*UC_STRING*/
void r385resize_byte_storage(T385* C,T2 a1);
/*UC_STRING*/
void r385append(T385* C,T0* a1);
/*UC_STRING*/
T2 r385byte_index(T385* C,T2 a1);
/*UC_STRING*/
void r385print_on(T385* C,T0* a1);
/*UC_STRING*/
void r385make_from_string(T385* C,T0* a1);
/*UC_STRING*/
T2 r385index_of(T385* C,T3 a1,T2 a2);
/*UC_STRING*/
void r385out_in_tagged_out_memory(T385* C);
/*UC_STRING*/
void r385move_bytes_right(T385* C,T2 a1,T2 a2);
/*UC_STRING*/
void r385set_count(T385* C,T2 a1);
/*UC_STRING*/
T2 r385next_byte_index(T385* C,T2 a1);
extern T0*oBC385dummy_uc_string;
extern int fBC385dummy_uc_string;
/*UC_STRING*/
T0* r385dummy_uc_string(void);
/*UC_STRING*/
void r385remove_tail(T385* C,T2 a1);
/*UC_STRING*/
T6 r385is_integer(T385* C);
/*UC_STRING*/
void r385make(T385* C,T2 a1);
/*UC_STRING*/
void r385fill_tagged_out_memory(T385* C);
/*UC_STRING*/
void r385append_string(T385* C,T0* a1);
/*UC_STRING*/
void r385make_filled(T385* C,T3 a1,T2 a2);
/*UC_STRING*/
void r385remove(T385* C,T2 a1);
/*UC_STRING*/
void r385append_substring(T385* C,T0* a1,T2 a2,T2 a3);
/*UC_STRING*/
T2 r385item_code_at_byte_index(T385* C,T2 a1);
/*UC_STRING*/
T0* r385string(T385* C);
/*UC_STRING*/
void r385extend(T385* C,T3 a1);
/*UC_STRING*/
void r385insert_string(T385* C,T0* a1,T2 a2);
/*UC_STRING*/
T2 r385hash_code(T385* C);
/*UC_STRING*/
void r385remove_last(T385* C,T2 a1);
/*UC_STRING*/
T6 r385has(T385* C,T3 a1);
/*UC_STRING*/
void r385keep_head(T385* C,T2 a1);
/*UC_STRING*/
T2 r385to_integer(T385* C);
/*UC_STRING*/
void r385precede(T385* C,T3 a1);
/*UC_STRING*/
T0* r385new_empty_string(T2 a1);
/*UC_STRING*/
void r385append_character(T385* C,T3 a1);
/*UC_STRING*/
void r385put_code_at_byte_index(T385* C,T2 a1,T2 a2,T2 a3);
/*UC_STRING*/
void r385make_from_substring(T385* C,T0* a1,T2 a2,T2 a3);
/*UC_STRING*/
void r385fill_with(T385* C,T3 a1);
/*UC_STRING*/
void r385put_character_at_byte_index(T385* C,T3 a1,T2 a2,T2 a3);
/*UC_STRING*/
void r385_7Pappend_string(T385* C,T0* a1);
/*UC_STRING*/
void r385resize(T385* C,T2 a1);
/*UC_STRING*/
void r385put_substring_at_byte_index(T385* C,T0* a1,T2 a2,T2 a3,T2 a4,T2 a5);
/*UC_STRING*/
T2 r385substring_index(T385* C,T0* a1,T2 a2);
extern T0*oBC387utf8;
/*UC_STRING*/
void r385right_adjust(T385* C);
/*UC_STRING*/
void r385move_bytes_left(T385* C,T2 a1,T2 a2);
/*UC_STRING*/
T8 r385to_external(T385* C);
/*UC_STRING*/
T6 r385same_string(T385* C,T0* a1);
/*UC_STRING*/
T0* r385twin(T385* C);
/*UC_STRING*/
T2 r385index_of_item_code(T385* C,T2 a1,T2 a2);
/*UC_STRING*/
T0* r385to_utf8(T385* C);
/*UC_STRING*/
T0* r385cloned_string(T385* C);
/*UC_STRING*/
T0* r385_ix_43(T385* C,T0* a1);
extern T0*oBC383unicode;
/*UC_STRING*/
T2 r385_7Phash_code(T385* C);
/*UC_STRING*/
T2 r385unicode_substring_index(T385* C,T0* a1,T2 a2);
/*UC_STRING*/
void r385swap(T385* C,T2 a1,T2 a2);
/*XPLAIN_REQUIRED*/
T0* r549sqlcolumnconstraint(T549* C,T0* a1,T0* a2);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T6 r587is_constant(T587* C);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
void r587add_to_join(T587* C,T0* a1,T0* a2);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T6 r587uses_parameter(T587* C,T0* a1);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T0* r587sqlmaxvalue(T587* C,T0* a1);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T0* r587column_name(T587* C);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T6 r587is_string_expression(void);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T0* r587representation(T587* C,T0* a1);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T0* r587outer_sqlvalue(T587* C,T0* a1);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T0* r587sqlvalue_as_wildcard(T587* C,T0* a1);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T6 r587is_using_other_attributes(T587* C,T0* a1);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T0* r587exact_representation(T587* C,T0* a1);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T6 r587is_literal(T587* C);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T0* r587sqlvalue(T587* C,T0* a1);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T0* r587sqlinitvalue(T587* C,T0* a1);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T6 r587is_logical_constant(T587* C);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T6 r587is_logical_expression(T587* C);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T0* r587sqlname(T587* C,T0* a1);
/*XPLAIN_PARENTHESIS_EXPRESSION*/
T0* r587sqlminvalue(T587* C,T0* a1);
/*XPLAIN_CASCADE_STATEMENT*/
void r136write(T136* C,T0* a1);
/*XPLAIN_CASCADE_STATEMENT*/
void r136make(T136* C,T0* a1,T0* a2,T0* a3,T0* a4);
/*XPLAIN_A_ENUMERATION*/
T0* r561sqldomainconstraint(T561* C,T0* a1,T0* a2);
/*XPLAIN_A_ENUMERATION*/
void r561make(T561* C,T0* a1);
/*XPLAIN_A_ENUMERATION*/
void r561check_attachment(T561* C,T0* a1,T0* a2);
/*XPLAIN_A_ENUMERATION*/
T0* r561sqlcolumnconstraint(T561* C,T0* a1,T0* a2);
/*YY_FILE_BUFFER*/
void r502fill(T502* C);
/*YY_FILE_BUFFER*/
void r502compact_left(T502* C);
/*YY_FILE_BUFFER*/
void r502set_position(T502* C,T2 a1,T2 a2,T2 a3);
extern T2 oBC396default_capacity;
/*YY_FILE_BUFFER*/
void r502resize(T502* C);
/*YY_FILE_BUFFER*/
T0* r502new_default_buffer(T2 a1);
/*YY_FILE_BUFFER*/
void r502make_with_size(T502* C,T0* a1,T2 a2);
/*YY_FILE_BUFFER*/
void r502set_file(T502* C,T0* a1);
/*YY_FILE_BUFFER*/
void r502flush(T502* C);
/*XPLAIN_SQL_STATEMENT*/
void r98write(T98* C,T0* a1);
/*KL_STDOUT_FILE*/
void r419make(T419* C);
/*KL_STDOUT_FILE*/
void r419old_put_string(T419* C,T0* a1);
/*KL_STDOUT_FILE*/
void r419old_put_character(T419* C,T3 a1);
/*KL_STDOUT_FILE*/
void r419old_make(T419* C);
/*KL_STDOUT_FILE*/
void r419write_buffer(T419* C);
/*KL_STDOUT_FILE*/
void r419put_string(T419* C,T0* a1);
/*XPLAIN_GET_INSERT_STATEMENT*/
void r632write(T632* C,T0* a1);
/*XPLAIN_GET_INSERT_STATEMENT*/
void r632make(T632* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*KL_STDERR_FILE*/
void r361old_put_string(T0* a1);
/*KL_STDERR_FILE*/
void r361put_integer(T2 a1);
/*KL_STDERR_FILE*/
void r361put_line(T0* a1);
/*KL_STDERR_FILE*/
void r361put_string(T0* a1);
/*XPLAIN_DATEF_FUNCTION*/
void r595add_to_join(T595* C,T0* a1,T0* a2);
/*XPLAIN_DATEF_FUNCTION*/
T6 r595uses_parameter(T595* C,T0* a1);
/*XPLAIN_DATEF_FUNCTION*/
T0* r595sqlmaxvalue(T0* a1);
/*XPLAIN_DATEF_FUNCTION*/
T6 r595is_string_expression(void);
/*XPLAIN_DATEF_FUNCTION*/
T0* r595representation(T0* a1);
/*XPLAIN_DATEF_FUNCTION*/
T0* r595outer_sqlvalue(T595* C,T0* a1);
/*XPLAIN_DATEF_FUNCTION*/
T0* r595sqlvalue_as_wildcard(T595* C,T0* a1);
/*XPLAIN_DATEF_FUNCTION*/
T6 r595is_using_other_attributes(T595* C,T0* a1);
/*XPLAIN_DATEF_FUNCTION*/
T0* r595exact_representation(T0* a1);
/*XPLAIN_DATEF_FUNCTION*/
T0* r595sqlvalue(T595* C,T0* a1);
/*XPLAIN_DATEF_FUNCTION*/
T0* r595sqlinitvalue(T595* C,T0* a1);
/*XPLAIN_DATEF_FUNCTION*/
T0* r595sqlminvalue(T0* a1);
/*XPLAIN_SORT_NODE*/
void r178make_node(T178* C,T0* a1,T0* a2);
/*XPLAIN_SORT_NODE*/
void r178make(T178* C,T0* a1,T6 a2,T0* a3);
/*XPLAIN_SQL_EXPRESSION*/
T0* r604sqlmaxvalue(T604* C,T0* a1);
/*XPLAIN_SQL_EXPRESSION*/
T6 r604is_string_expression(void);
/*XPLAIN_SQL_EXPRESSION*/
T0* r604representation(T604* C,T0* a1);
/*XPLAIN_SQL_EXPRESSION*/
T0* r604outer_sqlvalue(T604* C,T0* a1);
/*XPLAIN_SQL_EXPRESSION*/
T0* r604sqlvalue_as_wildcard(T604* C,T0* a1);
/*XPLAIN_SQL_EXPRESSION*/
T0* r604exact_representation(T604* C,T0* a1);
/*XPLAIN_SQL_EXPRESSION*/
T0* r604sqlinitvalue(T604* C,T0* a1);
/*XPLAIN_SQL_EXPRESSION*/
T0* r604sqlminvalue(T604* C,T0* a1);
/*XPLAIN_STRING_EXPRESSION*/
T0* r600sqlmaxvalue(T600* C,T0* a1);
/*XPLAIN_STRING_EXPRESSION*/
T0* r600representation(T600* C,T0* a1);
/*XPLAIN_STRING_EXPRESSION*/
T0* r600outer_sqlvalue(T600* C,T0* a1);
/*XPLAIN_STRING_EXPRESSION*/
T0* r600sqlvalue_as_wildcard(T600* C,T0* a1);
/*XPLAIN_STRING_EXPRESSION*/
T0* r600exact_representation(T600* C,T0* a1);
/*XPLAIN_STRING_EXPRESSION*/
T0* r600sqlvalue(T600* C,T0* a1);
/*XPLAIN_STRING_EXPRESSION*/
T0* r600sqlinitvalue(T600* C,T0* a1);
/*XPLAIN_STRING_EXPRESSION*/
T0* r600sqlminvalue(T600* C,T0* a1);
/*XPLAIN_STRING_EXPRESSION*/
T6 r600has_wild_card_characters(T600* C);
/*SQL_GENERATOR_ANSI*/
void r772drop_value(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_extend(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772datatype_text(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772drop_table(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772no_space_identifier(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772write_drop(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772scientific_formatter(void);
/*SQL_GENERATOR_ANSI*/
T0* r772domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlcolumnrequired_base(T772* C,T0* a1);
extern T6 oBC772temporarytablessupported;
/*SQL_GENERATOR_ANSI*/
void r772write_procedure(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772value_representation_system_user(T772* C);
/*SQL_GENERATOR_ANSI*/
T0* r772datatype_ref_int(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772do_sql_cast_to_real(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_extension_function(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_value_alter_table(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T6 r772init_necessary(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772do_do_create_select_list(T772* C,T0* a1,T6 a2);
/*SQL_GENERATOR_ANSI*/
T0* r772value_representation_float(T772* C);
/*SQL_GENERATOR_ANSI*/
T6 r772table_has_auto_pk(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772make_valid_identifier(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772columndatatype_type(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_get_insert(T772* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlcolumnidentifier_type(T772* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T0* r772tabtab(void);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_last_auto_generated_primary_key(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772write_select(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_value_declare_outside_sp(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772drop_procedure(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772write_assertion(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772datatype_datetime(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772datatype_varchar(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772value_representation_text(T772* C);
/*SQL_GENERATOR_ANSI*/
T0* r772datatype_boolean(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_infix_expression(T772* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlcolumnconstraint_type(T772* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T0* r772quoted_value_identifier(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772datatype_pk_int(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_predicate(T772* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
void r772drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_cast_to_date(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772table_name(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772drop_domain(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772temporarytableprefix(void);
/*SQL_GENERATOR_ANSI*/
T0* r772assertion_name(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlcolumndefault_type(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_select_value(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T6 r772createautoprimarykey(T772* C);
/*SQL_GENERATOR_ANSI*/
void r772create_select_function(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_infix_expression_as_wildcard(T772* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_select_function_as_subselect(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_extend_create_table(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_cast_to_string(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_select_function_as_left_outer_join(T772* C,T0* a1);
extern T0*oBC772target_name;
/*SQL_GENERATOR_ANSI*/
T0* r772do_sql_cast_to_integer(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772do_sql_select_for_extension_function(T772* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlfunction_nil(void);
/*SQL_GENERATOR_ANSI*/
void r772write_init(T0* a1);
/*SQL_GENERATOR_ANSI*/
T6 r772createassert(T772* C);
/*SQL_GENERATOR_ANSI*/
void r772write_base(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772value_representation_money(T772* C);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_select_joins(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_update(T772* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_ANSI*/
void r772create_index(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlgetvalue_outside_sp(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772constraint_names(void);
/*SQL_GENERATOR_ANSI*/
T6 r772createdomaincheck(T772* C);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_select_for_extension_function(T772* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T0* r772datatype_pk_char(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_combine_expression(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772value_representation_current_timestamp(T772* C);
/*SQL_GENERATOR_ANSI*/
T0* r772as_string(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772echo(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772datatype_char(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlgetconstant(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772columndatatype_base(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772write_extend(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T6 r772createviews(T772* C);
/*SQL_GENERATOR_ANSI*/
void r772write_index(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772constant_identifier(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_value_assign_outside_sp(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772datatype_money(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772optional_create_value_declare(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlcolumnconstraint_base(T772* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T6 r772check_if_required(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_subselect_for_attribute(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772datatype_int(T0* a1);
/*SQL_GENERATOR_ANSI*/
T6 r772is_value_data_type_changed(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772datatype_numeric(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772datatype_picture(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_cast_to_integer(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_value_create_table(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlcolumndefault_base(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772column_constraint_name(T772* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlfunction_any(void);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlgetvalue(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772set_sequence_name_format(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772valuetablename(void);
/*SQL_GENERATOR_ANSI*/
void r772create_constant_assignment(T772* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T0* r772safe_string(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772do_sql_cast_to_date(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T6 r772equal(T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T0* r772finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_ANSI*/
void r772write_type(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_combine_expression_as_wildcard(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772extension_name(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772createtemporarytablestatement(void);
/*SQL_GENERATOR_ANSI*/
T6 r772noonelinecommentssupported(void);
/*SQL_GENERATOR_ANSI*/
T0* r772value_identifier(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772formatter(void);
/*SQL_GENERATOR_ANSI*/
void r772write_sql(T0* a1);
/*SQL_GENERATOR_ANSI*/
T6 r772createdomains(T772* C);
/*SQL_GENERATOR_ANSI*/
void r772write_one_line_comment(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772value_representation_date(T772* C);
/*SQL_GENERATOR_ANSI*/
void r772create_assertion(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772quote_identifier(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_constant(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772datatype_float(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772set_primary_key_format(T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772extension_index_name(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772set_options(T772* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_ANSI*/
void r772create_view(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772write_use_database(T772* C,T0* a1);
extern T6 oBC772identifierwithspacessupported;
/*SQL_GENERATOR_ANSI*/
T0* r772domain_identifier(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_value(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T6 r772assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772do_create_select_list(T772* C,T0* a1,T6 a2);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_cast_to_real(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_table(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772value_representation_char(T772* C,T2 a1);
/*SQL_GENERATOR_ANSI*/
T0* r772value_representation_boolean(T772* C);
/*SQL_GENERATOR_ANSI*/
T6 r772createtimestamp(T772* C);
/*SQL_GENERATOR_ANSI*/
T0* r772sp_function_type_for_selection(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772finishtemporarytablestatement(void);
/*SQL_GENERATOR_ANSI*/
T6 r772coalescesupported(void);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_subselect_for_extension(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772table_pk_name(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772drop_constant(T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_insert(T772* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_ANSI*/
T0* r772autoprimarykeyconstraint(void);
/*SQL_GENERATOR_ANSI*/
T6 r772is_value_declared(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772columndatatype_assertion(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T6 r772valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
void r772make(T772* C);
/*SQL_GENERATOR_ANSI*/
T0* r772value_representation_integer(T772* C,T2 a1);
/*SQL_GENERATOR_ANSI*/
T0* r772table_ts_name(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_extend_create_index(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T6 r772createindex(void);
/*SQL_GENERATOR_ANSI*/
T0* r772column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_ANSI*/
T0* r772create_table_name(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772format(T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_expression_as_boolean_value(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772index_name(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_select_joins_oldstyle(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_delete(T772* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_select_joins_ansi92(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772do_sql_cast_to_string(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
void r772create_domain(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_notnot_expression(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_not_expression(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sql_select_for_extension_expression(T772* C,T0* a1);
/*SQL_GENERATOR_ANSI*/
T0* r772sqlcheck_in(T772* C,T0* a1,T0* a2);
/*SQL_GENERATOR_ANSI*/
void r772create_value_declare(T772* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795_25Pdrop_table(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795drop_value(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795sp_start(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_extend(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795datatype_text(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sp_define_out_param(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795drop_table(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795_25Pdrop_value(T795* C,T0* a1);
extern T0*oBC795sqlsysfunction_system_user;
/*SQL_GENERATOR_DB2_71*/
T0* r795no_space_identifier(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795write_drop(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795make_valid_sp_identifier(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795scientific_formatter(void);
/*SQL_GENERATOR_DB2_71*/
T0* r795domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlcolumnrequired_base(T795* C,T0* a1);
extern T6 oBC795temporarytablessupported;
/*SQL_GENERATOR_DB2_71*/
void r795write_procedure(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795value_representation_system_user(T795* C);
/*SQL_GENERATOR_DB2_71*/
T0* r795datatype_ref_int(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_value_declare_inside_sp(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795do_sql_cast_to_real(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_extension_function(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_value_alter_table(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795init_necessary(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795do_do_create_select_list(T795* C,T0* a1,T6 a2);
extern T6 oBC795columnnullallowed;
/*SQL_GENERATOR_DB2_71*/
T0* r795value_representation_float(T795* C);
/*SQL_GENERATOR_DB2_71*/
T6 r795table_has_auto_pk(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795make_valid_identifier(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795columndatatype_type(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_get_insert(T795* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlcolumnidentifier_type(T795* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
T0* r795tabtab(void);
extern T0*oBC795sql_last_auto_generated_primary_key;
/*SQL_GENERATOR_DB2_71*/
void r795create_value_assign_inside_sp(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795_25Psqlcolumnrequired_base(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795write_select(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_value_declare_outside_sp(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795datatype_varchar(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795datatype_datetime(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795write_assertion(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795value_representation_text(T795* C);
/*SQL_GENERATOR_DB2_71*/
T0* r795datatype_boolean(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_infix_expression(T795* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlcolumnconstraint_type(T795* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
T0* r795quoted_value_identifier(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795datatype_pk_int(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sp_update_name(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_predicate(T795* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
void r795create_sp_insert(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795drop_column(T795* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_cast_to_date(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795table_name(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795drop_domain(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_init_cast_to_real(T795* C,T0* a1);
extern T6 oBC795dropcolumnsupported;
/*SQL_GENERATOR_DB2_71*/
void r795do_drop_procedure(T795* C,T0* a1);
extern T0*oBC795temporarytableprefix;
/*SQL_GENERATOR_DB2_71*/
T0* r795sp_define_param_name(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795assertion_name(T0* a1);
extern T0*oBC795sqlfalse;
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlcolumndefault_type(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_select_value(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795createautoprimarykey(T795* C);
/*SQL_GENERATOR_DB2_71*/
void r795create_select_function(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795init_forced_null(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_infix_expression_as_wildcard(T795* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_select_function_as_subselect(T795* C,T0* a1);
extern T6 oBC795autoprimarykeysupported;
/*SQL_GENERATOR_DB2_71*/
void r795create_extend_create_table(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_cast_to_string(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_select_function_as_left_outer_join(T795* C,T0* a1);
extern T0*oBC795target_name;
/*SQL_GENERATOR_DB2_71*/
void r795_25Pcreate_select_list(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795do_sql_select_for_extension_function(T795* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
T0* r795do_sql_cast_to_integer(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlfunction_nil(void);
/*SQL_GENERATOR_DB2_71*/
void r795write_init(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795createassert(T795* C);
/*SQL_GENERATOR_DB2_71*/
void r795create_select_value_inside_sp(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795write_base(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_sp_delete(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795value_representation_money(T795* C);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_init_infix_expression(T795* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_select_joins(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_update(T795* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_DB2_71*/
void r795create_index(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlgetvalue_outside_sp(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795constraint_names(void);
/*SQL_GENERATOR_DB2_71*/
void r795create_sync_auto_generated_primary_key_with_supplied_value(T795* C,T0* a1,T2 a2);
/*SQL_GENERATOR_DB2_71*/
T6 r795createdomaincheck(T795* C);
/*SQL_GENERATOR_DB2_71*/
void r795_25Pwrite_type(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_init_cast_to_string(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_select_for_extension_function(T795* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
T0* r795datatype_pk_char(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_select_list(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sp_insert_name(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_combine_expression(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795value_representation_current_timestamp(T795* C);
/*SQL_GENERATOR_DB2_71*/
T0* r795as_string(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_init_expression(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795echo(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795datatype_char(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlgetconstant(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795columndatatype_base(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_end(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795createviews(T795* C);
/*SQL_GENERATOR_DB2_71*/
void r795write_index(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795constant_identifier(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_value_assign_outside_sp(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795sp_end(T795* C);
/*SQL_GENERATOR_DB2_71*/
T0* r795sp_use_param(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795datatype_money(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795init_forced_default(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795sp_body_statements(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795optional_create_value_declare(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795commandseparator(T795* C);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlcolumnconstraint_base(T795* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
T6 r795check_if_required(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_subselect_for_attribute(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795datatype_int(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_procedure(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795is_value_data_type_changed(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795datatype_numeric(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795datatype_picture(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_cast_to_integer(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_value_create_table(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795storedprocedureparamlistend(void);
/*SQL_GENERATOR_DB2_71*/
void r795_25Pcreate_select_function(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlcolumndefault_base(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlgetvalue_inside_sp(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795column_constraint_name(T795* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlfunction_any(void);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlgetvalue(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795set_sequence_name_format(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795valuetablename(void);
/*SQL_GENERATOR_DB2_71*/
void r795create_constant_assignment(T795* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
T0* r795safe_string(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795do_sql_cast_to_date(T795* C,T0* a1);
extern T6 oBC795domainssupported;
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
void r795write_type(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795equal(T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_combine_expression_as_wildcard(T795* C,T0* a1);
extern T0*oBC795sqlsysfunction_current_timestamp;
/*SQL_GENERATOR_DB2_71*/
T0* r795extension_name(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795createtemporarytablestatement(void);
/*SQL_GENERATOR_DB2_71*/
T6 r795noonelinecommentssupported(void);
/*SQL_GENERATOR_DB2_71*/
void r795create_use_database(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795value_identifier(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795formatter(void);
/*SQL_GENERATOR_DB2_71*/
void r795write_sql(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795_25Pvalue_identifier(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795createdomains(T795* C);
/*SQL_GENERATOR_DB2_71*/
void r795write_one_line_comment(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795value_representation_date(T795* C);
/*SQL_GENERATOR_DB2_71*/
void r795create_assertion(T795* C,T0* a1);
extern T2 oBC795maxconstraintidentifierlength;
/*SQL_GENERATOR_DB2_71*/
T0* r795quote_identifier(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_constant(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795drop_sp(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795datatype_float(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795set_primary_key_format(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795extension_index_name(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795set_options(T795* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_init_cast_to_date(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_view(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795write_use_database(T795* C,T0* a1);
extern T6 oBC795identifierwithspacessupported;
/*SQL_GENERATOR_DB2_71*/
T0* r795domain_identifier(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_value(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_sp_update(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_value_assign(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795do_create_select_list(T795* C,T0* a1,T6 a2);
/*SQL_GENERATOR_DB2_71*/
T0* r795storedprocedurereturnparamliststart(void);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_cast_to_real(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlcolumnrequired_type(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sp_get_auto_generated_primary_key(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_table(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795value_representation_char(T795* C,T2 a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795value_representation_boolean(T795* C);
/*SQL_GENERATOR_DB2_71*/
T6 r795createtimestamp(T795* C);
/*SQL_GENERATOR_DB2_71*/
T0* r795sp_function_type_for_selection(T795* C,T0* a1);
extern T0*oBC795finishtemporarytablestatement;
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_init_combine_expression(T795* C,T0* a1);
extern T6 oBC795supportsdefaultvalues;
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlinitvalue_if(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sp_name(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795coalescesupported(void);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_subselect_for_extension(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlinitvalue_attribute(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795table_pk_name(T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795drop_constant(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_insert(T795* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_DB2_71*/
T0* r795sp_delete_name(T795* C,T0* a1);
extern T0*oBC795autoprimarykeyconstraint;
/*SQL_GENERATOR_DB2_71*/
T0* r795sp_define_in_param(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795is_value_declared(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795columndatatype_assertion(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlcolumnidentifier_base(T0* a1,T0* a2);
extern T0*oBC795sqltrue;
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_init_cast_to_integer(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
void r795make(T795* C);
extern T2 oBC795maxidentifierlength;
/*SQL_GENERATOR_DB2_71*/
T0* r795value_representation_integer(T795* C,T2 a1);
/*SQL_GENERATOR_DB2_71*/
void r795sp_user_declaration(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795_25Psqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795table_ts_name(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_extend_create_index(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T6 r795createindex(void);
/*SQL_GENERATOR_DB2_71*/
T0* r795column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795create_table_name(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_init(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795format(T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_expression_as_boolean_value(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795index_name(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795sp_result_parameter(T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_select_joins_oldstyle(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_delete(T795* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_select_joins_ansi92(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795do_sql_cast_to_string(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
void r795create_domain(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_notnot_expression(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795storedprocedureparamliststart(void);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_not_expression(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sql_select_for_extension_expression(T795* C,T0* a1);
/*SQL_GENERATOR_DB2_71*/
T0* r795sqlcheck_in(T795* C,T0* a1,T0* a2);
/*SQL_GENERATOR_DB2_71*/
void r795create_value_declare(T795* C,T0* a1);
/*ST_DECIMAL_FORMATTER*/
void r478center_format_to(T478* C,T0* a1,T0* a2);
/*ST_DECIMAL_FORMATTER*/
void r478append_abs_to_string(T478* C,T2 a1,T0* a2);
/*ST_DECIMAL_FORMATTER*/
T6 r478valid_parameter(T0* a1);
/*ST_DECIMAL_FORMATTER*/
void r478_471Pmake(T478* C);
/*ST_DECIMAL_FORMATTER*/
void r478make(T478* C);
/*ST_DECIMAL_FORMATTER*/
void r478format_to(T478* C,T0* a1,T0* a2);
/*ST_DECIMAL_FORMATTER*/
void r478right_format_to(T478* C,T0* a1,T0* a2);
/*ST_DECIMAL_FORMATTER*/
void r478_471Preset_options(T478* C);
/*ST_DECIMAL_FORMATTER*/
void r478integer_format_to(T478* C,T2 a1,T0* a2);
/*ST_DECIMAL_FORMATTER*/
void r478reset_options(T478* C);
/*ST_DECIMAL_FORMATTER*/
void r478append_to_string(T478* C,T2 a1,T0* a2);
/*ST_DECIMAL_FORMATTER*/
void r478justify_format_to(T478* C,T0* a1,T0* a2);
/*ST_DECIMAL_FORMATTER*/
void r478left_format_to(T478* C,T0* a1,T0* a2);
/*XPLAIN_LOGICAL_EXPRESSION*/
T6 r308is_constant(T308* C);
/*XPLAIN_LOGICAL_EXPRESSION*/
void r308add_to_join(T308* C,T0* a1,T0* a2);
/*XPLAIN_LOGICAL_EXPRESSION*/
T6 r308uses_parameter(T308* C,T0* a1);
/*XPLAIN_LOGICAL_EXPRESSION*/
T0* r308sqlmaxvalue(T308* C,T0* a1);
/*XPLAIN_LOGICAL_EXPRESSION*/
T0* r308column_name(T308* C);
/*XPLAIN_LOGICAL_EXPRESSION*/
T6 r308is_string_expression(void);
/*XPLAIN_LOGICAL_EXPRESSION*/
T0* r308representation(T308* C,T0* a1);
/*XPLAIN_LOGICAL_EXPRESSION*/
T0* r308outer_sqlvalue(T308* C,T0* a1);
/*XPLAIN_LOGICAL_EXPRESSION*/
T0* r308sqlvalue_as_wildcard(T308* C,T0* a1);
/*XPLAIN_LOGICAL_EXPRESSION*/
T6 r308is_using_other_attributes(T308* C,T0* a1);
/*XPLAIN_LOGICAL_EXPRESSION*/
T0* r308exact_representation(T308* C,T0* a1);
/*XPLAIN_LOGICAL_EXPRESSION*/
T6 r308is_literal(T308* C);
/*XPLAIN_LOGICAL_EXPRESSION*/
T0* r308sqlvalue(T308* C,T0* a1);
/*XPLAIN_LOGICAL_EXPRESSION*/
T0* r308sqlinitvalue(T308* C,T0* a1);
/*XPLAIN_LOGICAL_EXPRESSION*/
T6 r308is_logical_constant(T308* C);
/*XPLAIN_LOGICAL_EXPRESSION*/
T0* r308sqlname(T308* C,T0* a1);
/*XPLAIN_LOGICAL_EXPRESSION*/
T0* r308sqlminvalue(T308* C,T0* a1);
/*XPLAIN_EQ_NULL_EXPRESSION*/
void r582add_to_join(T582* C,T0* a1,T0* a2);
/*XPLAIN_EQ_NULL_EXPRESSION*/
T6 r582uses_parameter(T582* C,T0* a1);
/*XPLAIN_EQ_NULL_EXPRESSION*/
T0* r582sqlmaxvalue(T0* a1);
/*XPLAIN_EQ_NULL_EXPRESSION*/
T6 r582is_string_expression(void);
/*XPLAIN_EQ_NULL_EXPRESSION*/
T0* r582representation(T0* a1);
/*XPLAIN_EQ_NULL_EXPRESSION*/
T0* r582outer_sqlvalue(T582* C,T0* a1);
/*XPLAIN_EQ_NULL_EXPRESSION*/
T0* r582sqlvalue_as_wildcard(T582* C,T0* a1);
/*XPLAIN_EQ_NULL_EXPRESSION*/
T0* r582exact_representation(T0* a1);
/*XPLAIN_EQ_NULL_EXPRESSION*/
T0* r582sqlvalue(T582* C,T0* a1);
/*XPLAIN_EQ_NULL_EXPRESSION*/
T0* r582sqlinitvalue(T582* C,T0* a1);
/*XPLAIN_EQ_NULL_EXPRESSION*/
T0* r582sqlminvalue(T0* a1);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479center_format_to(T479* C,T0* a1,T0* a2);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479build_integer_and_fractional_parts(T479* C,T5 a1);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479append_integer_to_string(T479* C,T2 a1,T2 a2,T0* a3);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479_483Pdouble_format_to(T479* C,T5 a1,T0* a2);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
T6 r479valid_parameter(T0* a1);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479_471Pmake(T479* C);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479make(T479* C);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
T2 r479double_sign(T5 a1);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479format_to(T479* C,T0* a1,T0* a2);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479right_format_to(T479* C,T0* a1,T0* a2);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479_471Preset_options(T479* C);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479reset_options(T479* C);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
T5 r479ten_power(T2 a1);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479double_format_to(T479* C,T5 a1,T0* a2);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479_480Pdouble_format_to(T479* C,T5 a1,T0* a2);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479justify_format_to(T479* C,T0* a1,T0* a2);
/*ST_FIXED_OR_FLOATING_POINT_FORMATTER*/
void r479left_format_to(T479* C,T0* a1,T0* a2);
/*XPLAIN_PARAMETER_EXPRESSION*/
T0* r581sqlmaxvalue(T0* a1);
/*XPLAIN_PARAMETER_EXPRESSION*/
T6 r581is_string_expression(void);
/*XPLAIN_PARAMETER_EXPRESSION*/
T0* r581representation(T0* a1);
/*XPLAIN_PARAMETER_EXPRESSION*/
T0* r581outer_sqlvalue(T581* C,T0* a1);
/*XPLAIN_PARAMETER_EXPRESSION*/
T0* r581sqlvalue_as_wildcard(T581* C,T0* a1);
/*XPLAIN_PARAMETER_EXPRESSION*/
T0* r581exact_representation(T0* a1);
/*XPLAIN_PARAMETER_EXPRESSION*/
T0* r581sqlvalue(T581* C,T0* a1);
/*XPLAIN_PARAMETER_EXPRESSION*/
T0* r581sqlinitvalue(T581* C,T0* a1);
/*XPLAIN_PARAMETER_EXPRESSION*/
T0* r581sqlminvalue(T0* a1);
/*XPLAIN_A_REFERENCES*/
T0* r619sqlcolumnconstraint(T619* C,T0* a1,T0* a2);
/*XPLAIN_REAL_FUNCTION*/
void r597add_to_join(T597* C,T0* a1,T0* a2);
/*XPLAIN_REAL_FUNCTION*/
T6 r597uses_parameter(T597* C,T0* a1);
/*XPLAIN_REAL_FUNCTION*/
T0* r597sqlmaxvalue(T0* a1);
/*XPLAIN_REAL_FUNCTION*/
T6 r597is_string_expression(void);
/*XPLAIN_REAL_FUNCTION*/
T0* r597representation(T0* a1);
/*XPLAIN_REAL_FUNCTION*/
T0* r597outer_sqlvalue(T597* C,T0* a1);
/*XPLAIN_REAL_FUNCTION*/
T0* r597sqlvalue_as_wildcard(T597* C,T0* a1);
/*XPLAIN_REAL_FUNCTION*/
T6 r597is_using_other_attributes(T597* C,T0* a1);
/*XPLAIN_REAL_FUNCTION*/
T0* r597exact_representation(T0* a1);
/*XPLAIN_REAL_FUNCTION*/
T0* r597sqlvalue(T597* C,T0* a1);
/*XPLAIN_REAL_FUNCTION*/
T0* r597sqlinitvalue(T597* C,T0* a1);
/*XPLAIN_REAL_FUNCTION*/
T0* r597sqlminvalue(T0* a1);
/*XPLAIN_VARIABLE_EXPRESSION*/
T0* r626sqlmaxvalue(T626* C,T0* a1);
/*XPLAIN_VARIABLE_EXPRESSION*/
T6 r626is_string_expression(void);
/*XPLAIN_VARIABLE_EXPRESSION*/
T0* r626representation(T626* C,T0* a1);
/*XPLAIN_VARIABLE_EXPRESSION*/
T0* r626outer_sqlvalue(T626* C,T0* a1);
/*XPLAIN_VARIABLE_EXPRESSION*/
T0* r626sqlvalue_as_wildcard(T626* C,T0* a1);
/*XPLAIN_VARIABLE_EXPRESSION*/
T0* r626exact_representation(T626* C,T0* a1);
/*XPLAIN_VARIABLE_EXPRESSION*/
T0* r626sqlvalue(T626* C,T0* a1);
/*XPLAIN_VARIABLE_EXPRESSION*/
T0* r626sqlinitvalue(T626* C,T0* a1);
/*XPLAIN_VARIABLE_EXPRESSION*/
T0* r626sqlminvalue(T626* C,T0* a1);
/*XPLAIN_NOT_EXPRESSION*/
void r577add_to_join(T577* C,T0* a1,T0* a2);
/*XPLAIN_NOT_EXPRESSION*/
T6 r577uses_parameter(T577* C,T0* a1);
/*XPLAIN_NOT_EXPRESSION*/
T0* r577sqlmaxvalue(T577* C,T0* a1);
/*XPLAIN_NOT_EXPRESSION*/
T6 r577is_string_expression(void);
/*XPLAIN_NOT_EXPRESSION*/
T0* r577representation(T577* C,T0* a1);
/*XPLAIN_NOT_EXPRESSION*/
void r577make(T577* C,T0* a1);
/*XPLAIN_NOT_EXPRESSION*/
T0* r577outer_sqlvalue(T577* C,T0* a1);
/*XPLAIN_NOT_EXPRESSION*/
T0* r577sqlvalue_as_wildcard(T577* C,T0* a1);
/*XPLAIN_NOT_EXPRESSION*/
T6 r577is_using_other_attributes(T577* C,T0* a1);
/*XPLAIN_NOT_EXPRESSION*/
T0* r577exact_representation(T577* C,T0* a1);
/*XPLAIN_NOT_EXPRESSION*/
T0* r577sqlvalue(T577* C,T0* a1);
/*XPLAIN_NOT_EXPRESSION*/
T0* r577sqlinitvalue(T577* C,T0* a1);
/*XPLAIN_NOT_EXPRESSION*/
T0* r577sqlminvalue(T577* C,T0* a1);
/*XPLAIN_I_NODE*/
void r315make(T315* C,T0* a1,T0* a2);
/*XPLAIN_I_NODE*/
T0* r315to_sqlcode(T315* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808drop_value(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_extend(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808datatype_text(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808drop_table(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808no_space_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808write_drop(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808scientific_formatter(void);
/*SQL_GENERATOR_MYSQL4*/
T0* r808domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlcolumnrequired_base(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808write_procedure(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808value_representation_system_user(T808* C);
/*SQL_GENERATOR_MYSQL4*/
T0* r808datatype_ref_int(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808do_sql_cast_to_real(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_extension_function(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_value_alter_table(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T6 r808init_necessary(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808do_do_create_select_list(T808* C,T0* a1,T6 a2);
/*SQL_GENERATOR_MYSQL4*/
T0* r808value_representation_float(T808* C);
/*SQL_GENERATOR_MYSQL4*/
T6 r808table_has_auto_pk(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808make_valid_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808columndatatype_type(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_get_insert(T808* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlcolumnidentifier_type(T808* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T0* r808tabtab(void);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_last_auto_generated_primary_key(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808write_select(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_value_declare_outside_sp(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808drop_procedure(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808write_assertion(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808datatype_datetime(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808datatype_varchar(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808value_representation_text(T808* C);
/*SQL_GENERATOR_MYSQL4*/
T0* r808datatype_boolean(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_infix_expression(T808* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlcolumnconstraint_type(T808* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T0* r808quoted_value_identifier(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808datatype_pk_int(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_predicate(T808* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
void r808drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_cast_to_date(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808table_name(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808drop_domain(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808drop_table_if_exist(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808temporarytableprefix(void);
/*SQL_GENERATOR_MYSQL4*/
T0* r808assertion_name(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlcolumndefault_type(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_select_value(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T6 r808createautoprimarykey(T808* C);
/*SQL_GENERATOR_MYSQL4*/
void r808create_select_function(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_infix_expression_as_wildcard(T808* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_select_function_as_subselect(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_extend_create_table(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_cast_to_string(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_select_function_as_left_outer_join(T808* C,T0* a1);
extern T0*oBC808target_name;
/*SQL_GENERATOR_MYSQL4*/
T0* r808do_sql_cast_to_integer(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808do_sql_select_for_extension_function(T808* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlfunction_nil(void);
/*SQL_GENERATOR_MYSQL4*/
void r808write_init(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T6 r808createassert(T808* C);
/*SQL_GENERATOR_MYSQL4*/
void r808write_base(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808value_representation_money(T808* C);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_select_joins(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_update(T808* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MYSQL4*/
void r808create_index(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlgetvalue_outside_sp(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808constraint_names(void);
/*SQL_GENERATOR_MYSQL4*/
T6 r808createdomaincheck(T808* C);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_select_for_extension_function(T808* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T0* r808datatype_pk_char(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_combine_expression(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808value_representation_current_timestamp(T808* C);
/*SQL_GENERATOR_MYSQL4*/
T0* r808as_string(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808echo(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808datatype_char(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlgetconstant(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808columndatatype_base(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808write_extend(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T6 r808createviews(T808* C);
/*SQL_GENERATOR_MYSQL4*/
void r808write_index(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808constant_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_value_assign_outside_sp(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808datatype_money(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808optional_create_value_declare(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlcolumnconstraint_base(T808* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T6 r808check_if_required(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_subselect_for_attribute(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808datatype_int(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T6 r808is_value_data_type_changed(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808datatype_numeric(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808datatype_picture(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_cast_to_integer(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_value_create_table(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlcolumndefault_base(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808column_constraint_name(T808* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlfunction_any(void);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlgetvalue(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808set_sequence_name_format(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808valuetablename(void);
/*SQL_GENERATOR_MYSQL4*/
void r808create_constant_assignment(T808* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T0* r808safe_string(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808do_sql_cast_to_date(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T6 r808equal(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T0* r808finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_MYSQL4*/
void r808write_type(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_combine_expression_as_wildcard(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808extension_name(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808createtemporarytablestatement(void);
/*SQL_GENERATOR_MYSQL4*/
T6 r808noonelinecommentssupported(void);
/*SQL_GENERATOR_MYSQL4*/
T0* r808value_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808formatter(void);
/*SQL_GENERATOR_MYSQL4*/
void r808write_sql(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T6 r808createdomains(T808* C);
/*SQL_GENERATOR_MYSQL4*/
void r808write_one_line_comment(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808value_representation_date(T808* C);
/*SQL_GENERATOR_MYSQL4*/
void r808create_assertion(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808quote_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_constant(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808datatype_float(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808set_primary_key_format(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808extension_index_name(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808set_options(T808* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_MYSQL4*/
void r808create_view(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808write_use_database(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808domain_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_value(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T6 r808assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808do_create_select_list(T808* C,T0* a1,T6 a2);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_cast_to_real(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_table(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808value_representation_char(T808* C,T2 a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808value_representation_boolean(T808* C);
/*SQL_GENERATOR_MYSQL4*/
T6 r808createtimestamp(T808* C);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sp_function_type_for_selection(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808finishtemporarytablestatement(void);
/*SQL_GENERATOR_MYSQL4*/
T6 r808coalescesupported(void);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_subselect_for_extension(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808table_pk_name(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808drop_constant(T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_insert(T808* C,T0* a1,T0* a2,T0* a3);
extern T0*oBC808autoprimarykeyconstraint;
extern int fBC808autoprimarykeyconstraint;
/*SQL_GENERATOR_MYSQL4*/
T0* r808autoprimarykeyconstraint(void);
/*SQL_GENERATOR_MYSQL4*/
T6 r808is_value_declared(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808columndatatype_assertion(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T6 r808valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
void r808make(T808* C);
/*SQL_GENERATOR_MYSQL4*/
T0* r808value_representation_integer(T808* C,T2 a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808table_ts_name(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_extend_create_index(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T6 r808createindex(void);
/*SQL_GENERATOR_MYSQL4*/
T0* r808column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808create_table_name(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808format(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_expression_as_boolean_value(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808index_name(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_select_joins_oldstyle(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_delete(T808* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_select_joins_ansi92(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808do_sql_cast_to_string(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
void r808create_domain(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_notnot_expression(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_not_expression(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sql_select_for_extension_expression(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL4*/
T0* r808sqlcheck_in(T808* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL4*/
void r808create_value_declare(T808* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807_25Pdrop_table(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807drop_value(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807sp_start(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_extend(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807datatype_text(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sp_define_out_param(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807drop_table(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807_25Pdrop_value(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807no_space_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807write_drop(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807make_valid_sp_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807scientific_formatter(void);
/*SQL_GENERATOR_MYSQL5*/
T0* r807domain_null_or_not_null(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlcolumnrequired_base(T807* C,T0* a1);
extern T6 oBC807temporarytablessupported;
/*SQL_GENERATOR_MYSQL5*/
void r807write_procedure(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807value_representation_system_user(T807* C);
extern T6 oBC807constraintnamesupported;
extern T6 oBC807checksnullaftertrigger;
/*SQL_GENERATOR_MYSQL5*/
T0* r807datatype_ref_int(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807do_sql_cast_to_real(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlcheck_between(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_extension_function(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_value_alter_table(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807init_necessary(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807do_do_create_select_list(T807* C,T0* a1,T6 a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807value_representation_float(T807* C);
/*SQL_GENERATOR_MYSQL5*/
T6 r807table_has_auto_pk(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807output_update_join_clause(T807* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807make_valid_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807columndatatype_type(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_get_insert(T807* C,T0* a1,T0* a2,T6 a3,T0* a4);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlcolumnidentifier_type(T807* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807tabtab(void);
extern T0*oBC807sql_last_auto_generated_primary_key;
extern T2 oBC807max_numeric_precision;
/*SQL_GENERATOR_MYSQL5*/
void r807create_value_assign_inside_sp(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807_25Psqlcolumnrequired_base(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807write_select(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807datatype_varchar(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807datatype_datetime(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807write_assertion(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807value_representation_text(T807* C);
/*SQL_GENERATOR_MYSQL5*/
T0* r807datatype_boolean(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807make_valid_constraint_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_infix_expression(T807* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlcolumnconstraint_type(T807* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807quoted_value_identifier(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807datatype_pk_int(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sp_update_name(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_predicate(T807* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
void r807create_sp_insert(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807drop_column(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_cast_to_date(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807table_name(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807drop_domain(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_init_cast_to_real(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807do_drop_procedure(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807drop_table_if_exist(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807temporarytableprefix(void);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sp_define_param_name(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807assertion_name(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlcolumndefault_type(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_select_value(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807createautoprimarykey(T807* C);
/*SQL_GENERATOR_MYSQL5*/
void r807create_select_function(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807init_forced_null(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_infix_expression_as_wildcard(T807* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_select_function_as_subselect(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_extend_create_table(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_cast_to_string(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_select_function_as_left_outer_join(T807* C,T0* a1);
extern T0*oBC807target_name;
/*SQL_GENERATOR_MYSQL5*/
T0* r807do_sql_select_for_extension_function(T807* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807do_sql_cast_to_integer(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlfunction_nil(void);
/*SQL_GENERATOR_MYSQL5*/
void r807write_init(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807createassert(T807* C);
/*SQL_GENERATOR_MYSQL5*/
void r807write_base(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_sp_delete(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807value_representation_money(T807* C);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_init_infix_expression(T807* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_select_joins(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_update(T807* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MYSQL5*/
void r807create_index(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlgetvalue_outside_sp(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807constraint_names(void);
/*SQL_GENERATOR_MYSQL5*/
T6 r807createdomaincheck(T807* C);
/*SQL_GENERATOR_MYSQL5*/
void r807_25Pwrite_type(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_init_cast_to_string(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_select_for_extension_function(T807* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807datatype_pk_char(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sp_insert_name(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_combine_expression(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807value_representation_current_timestamp(T807* C);
/*SQL_GENERATOR_MYSQL5*/
T0* r807as_string(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_init_expression(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807echo(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807datatype_char(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlgetconstant(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807columndatatype_base(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807write_extend(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807createviews(T807* C);
/*SQL_GENERATOR_MYSQL5*/
void r807write_index(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807constant_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_value_assign_outside_sp(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807sp_end(T807* C);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sp_use_param(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807datatype_money(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807init_forced_default(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807sp_body_statements(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807output_update_extend_join_clause(T807* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MYSQL5*/
void r807optional_create_value_declare(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlcolumnconstraint_base(T807* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
T6 r807check_if_required(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_subselect_for_attribute(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807datatype_int(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_procedure(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807is_value_data_type_changed(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807datatype_numeric(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807datatype_picture(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_cast_to_integer(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_value_create_table(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807storedprocedureparamlistend(void);
/*SQL_GENERATOR_MYSQL5*/
T0* r807quote_valid_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlcolumndefault_base(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlgetvalue_inside_sp(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807column_constraint_name(T807* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
void r807drop_temporary_table_if_exist(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlfunction_any(void);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlgetvalue(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807set_sequence_name_format(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807valuetablename(void);
/*SQL_GENERATOR_MYSQL5*/
void r807create_constant_assignment(T807* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807safe_string(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807do_sql_cast_to_date(T807* C,T0* a1);
extern T6 oBC807domainssupported;
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlcheck_like(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
void r807write_type(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807equal(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807finishtemporaryvaluetablestatement(void);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_combine_expression_as_wildcard(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807extension_name(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807createtemporarytablestatement(void);
/*SQL_GENERATOR_MYSQL5*/
T6 r807noonelinecommentssupported(void);
/*SQL_GENERATOR_MYSQL5*/
void r807create_use_database(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807value_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807formatter(void);
/*SQL_GENERATOR_MYSQL5*/
void r807write_sql(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807createdomains(T807* C);
/*SQL_GENERATOR_MYSQL5*/
void r807write_one_line_comment(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807value_representation_date(T807* C);
/*SQL_GENERATOR_MYSQL5*/
void r807create_assertion(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807_798Psp_start(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807quote_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_constant(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807drop_sp(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807datatype_float(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807set_primary_key_format(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807extension_index_name(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807set_options(T807* C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_init_cast_to_date(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_view(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807write_use_database(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807domain_identifier(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_value(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_sp_update(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807assert_implemented_as_view(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_value_assign(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807do_create_select_list(T807* C,T0* a1,T6 a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807storedprocedurereturnparamliststart(void);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_cast_to_real(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlcolumnrequired_type(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sp_get_auto_generated_primary_key(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_table(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807value_representation_char(T807* C,T2 a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807value_representation_boolean(T807* C);
/*SQL_GENERATOR_MYSQL5*/
void r807_798Psp_end(T807* C);
/*SQL_GENERATOR_MYSQL5*/
T6 r807createtimestamp(T807* C);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sp_function_type_for_selection(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807finishtemporarytablestatement(void);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_init_combine_expression(T807* C,T0* a1);
extern T6 oBC807supportsdefaultvalues;
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlinitvalue_if(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sp_name(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807coalescesupported(void);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_subselect_for_extension(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlinitvalue_attribute(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807table_pk_name(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807drop_constant(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_insert(T807* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sp_delete_name(T807* C,T0* a1);
extern T0*oBC807autoprimarykeyconstraint;
extern int fBC807autoprimarykeyconstraint;
/*SQL_GENERATOR_MYSQL5*/
T0* r807autoprimarykeyconstraint(void);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sp_define_in_param(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807is_value_declared(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807columndatatype_assertion(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlcolumnidentifier_base(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_init_cast_to_integer(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807valid_format_and_parameters(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
void r807make(T807* C);
extern T2 oBC807maxidentifierlength;
/*SQL_GENERATOR_MYSQL5*/
T0* r807value_representation_integer(T807* C,T2 a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807_25Psqlcolumnrequired_type(T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807table_ts_name(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_extend_create_index(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T6 r807createindex(void);
/*SQL_GENERATOR_MYSQL5*/
T0* r807column_null_or_not_null(T6 a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807create_table_name(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_init(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807format(T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_expression_as_boolean_value(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807index_name(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_select_joins_oldstyle(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_delete(T807* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_select_joins_ansi92(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807do_sql_cast_to_string(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807create_domain(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_notnot_expression(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807storedprocedureparamliststart(void);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_not_expression(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sql_select_for_extension_expression(T807* C,T0* a1);
/*SQL_GENERATOR_MYSQL5*/
void r807_25Poutput_update_extend_join_clause(T807* C,T0* a1,T0* a2,T0* a3);
/*SQL_GENERATOR_MYSQL5*/
T0* r807sqlcheck_in(T807* C,T0* a1,T0* a2);
/*SQL_GENERATOR_MYSQL5*/
void r807create_value_declare(T807* C,T0* a1);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
void r473center_format_to(T473* C,T0* a1,T0* a2);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
void r473append_abs_to_string(T473* C,T2 a1,T0* a2);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
T6 r473valid_parameter(T0* a1);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
void r473_471Pmake(T473* C);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
void r473make(T473* C);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
void r473_475Pinteger_format_to(T473* C,T2 a1,T0* a2);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
void r473format_to(T473* C,T0* a1,T0* a2);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
void r473right_format_to(T473* C,T0* a1,T0* a2);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
void r473_471Preset_options(T473* C);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
void r473integer_format_to(T473* C,T2 a1,T0* a2);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
void r473reset_options(T473* C);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
void r473append_to_string(T473* C,T2 a1,T0* a2);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
void r473justify_format_to(T473* C,T0* a1,T0* a2);
/*ST_UNSIGNED_DECIMAL_FORMATTER*/
void r473left_format_to(T473* C,T0* a1,T0* a2);
/*XPLAIN_DELETE_STATEMENT*/
T6 r122uses_parameter(T122* C,T0* a1);
/*XPLAIN_DELETE_STATEMENT*/
void r122write(T122* C,T0* a1);
/*XPLAIN_DELETE_STATEMENT*/
void r122make(T122* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
void r627add_to_join(T627* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
void r627set_extension(T627* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T0* r627sqlmaxvalue(T627* C,T0* a1);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
void r627inherited_make(T627* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T0* r627sqlselect(T627* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T0* r627column_name(T627* C);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T6 r627is_string_expression(void);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T0* r627representation(T627* C,T0* a1);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
void r627make(T627* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T0* r627outer_sqlvalue(T627* C,T0* a1);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T0* r627sqlvalue_as_wildcard(T627* C,T0* a1);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T6 r627is_using_other_attributes(T627* C,T0* a1);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T0* r627exact_representation(T627* C,T0* a1);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
void r627_196Pset_extension(T627* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T0* r627sqlvalue(T627* C,T0* a1);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T0* r627sqlinitvalue(T627* C,T0* a1);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T6 r627is_logical_expression(T627* C);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T0* r627sqlname(T627* C,T0* a1);
/*XPLAIN_EXTENSION_FUNCTION_EXPRESSION*/
T0* r627sqlminvalue(T627* C,T0* a1);
/*STD_OUTPUT*/
void r420make(T420* C);
/*STD_OUTPUT*/
void r420flush(T420* C);
/*STD_OUTPUT*/
void r420write_buffer(T420* C);
/*STD_OUTPUT*/
void r420put_character(T420* C,T3 a1);
/*STD_OUTPUT*/
void r420put_string(T420* C,T0* a1);
/*XPLAIN_A_PATTERN*/
T0* r559sqldomainconstraint(T559* C,T0* a1,T0* a2);
/*XPLAIN_A_PATTERN*/
void r559make(T559* C,T0* a1);
/*XPLAIN_A_PATTERN*/
T0* r559sqlcolumnconstraint(T559* C,T0* a1,T0* a2);
extern T0*oBC19command_arguments;
extern int fBC19command_arguments;
/*KL_ARGUMENTS*/
T0* r792command_arguments(void);
/*KL_ARGUMENTS*/
T0* r792argument(T2 a1);
/*XPLAIN_NOTNOT_EXPRESSION*/
T6 r575is_constant(T575* C);
/*XPLAIN_NOTNOT_EXPRESSION*/
void r575add_to_join(T575* C,T0* a1,T0* a2);
/*XPLAIN_NOTNOT_EXPRESSION*/
T6 r575uses_parameter(T575* C,T0* a1);
/*XPLAIN_NOTNOT_EXPRESSION*/
T0* r575sqlmaxvalue(T575* C,T0* a1);
/*XPLAIN_NOTNOT_EXPRESSION*/
T0* r575column_name(T575* C);
/*XPLAIN_NOTNOT_EXPRESSION*/
T6 r575is_string_expression(void);
/*XPLAIN_NOTNOT_EXPRESSION*/
T0* r575representation(T575* C,T0* a1);
/*XPLAIN_NOTNOT_EXPRESSION*/
T0* r575outer_sqlvalue(T575* C,T0* a1);
/*XPLAIN_NOTNOT_EXPRESSION*/
T0* r575sqlvalue_as_wildcard(T575* C,T0* a1);
/*XPLAIN_NOTNOT_EXPRESSION*/
T6 r575is_using_other_attributes(T575* C,T0* a1);
/*XPLAIN_NOTNOT_EXPRESSION*/
T0* r575exact_representation(T575* C,T0* a1);
/*XPLAIN_NOTNOT_EXPRESSION*/
T6 r575is_literal(T575* C);
/*XPLAIN_NOTNOT_EXPRESSION*/
T0* r575sqlvalue(T575* C,T0* a1);
/*XPLAIN_NOTNOT_EXPRESSION*/
T0* r575sqlinitvalue(T575* C,T0* a1);
/*XPLAIN_NOTNOT_EXPRESSION*/
T6 r575is_logical_constant(T575* C);
/*XPLAIN_NOTNOT_EXPRESSION*/
T6 r575is_logical_expression(T575* C);
/*XPLAIN_NOTNOT_EXPRESSION*/
T0* r575sqlname(T575* C,T0* a1);
/*XPLAIN_NOTNOT_EXPRESSION*/
T0* r575sqlminvalue(T575* C,T0* a1);
/*XPLAIN_EXTENSION*/
T0* r208out(T208* C);
/*XPLAIN_EXTENSION*/
T0* r208quoted_name(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
T0* r208sqlpkname(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
T0* r208new_data_attributes_cursor(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
void r208remove_extension(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
T0* r208columndatatype(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
T6 r208is_equal(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
T0* r208sqlcolumnidentifier(T208* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION*/
T0* r208q_sql_select_name(T208* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION*/
T0* r208sqlcolumndefault(T0* a1,T0* a2);
/*XPLAIN_EXTENSION*/
void r208add_extension(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
T0* r208create_expression(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
T0* r208sql_insert_name(T208* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION*/
void r208write_drop_attribute(T208* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION*/
void r208out_in_tagged_out_memory(T208* C);
/*XPLAIN_EXTENSION*/
T0* r208q_sqlpkname(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
void r208add_assertion(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
void r208make_abstract_type(T208* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION*/
void r208make(T208* C,T0* a1,T0* a2,T0* a3,T0* a4);
/*XPLAIN_EXTENSION*/
T6 r208has_non_constant_init(T208* C);
/*XPLAIN_EXTENSION*/
T6 r208equal(T0* a1,T0* a2);
/*XPLAIN_EXTENSION*/
T2 r208hash_code(T208* C);
/*XPLAIN_EXTENSION*/
T6 r208has_non_literal_init(T208* C);
/*XPLAIN_EXTENSION*/
T0* r208sql_qualified_name(T208* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION*/
T6 r208has_updatable_attributes(T208* C);
/*XPLAIN_EXTENSION*/
T0* r208q_sql_insert_name(T208* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION*/
T0* r208new_all_attributes_cursor(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
void r208hack_anode(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
T0* r208sql_select_name(T208* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION*/
void r208make_type(T208* C,T0* a1,T0* a2,T0* a3);
/*XPLAIN_EXTENSION*/
T0* r208sqlname(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
T0* r208find_attribute(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
T0* r208new_init_attributes_cursor(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
void r208next_constraint_number(T208* C);
/*XPLAIN_EXTENSION*/
T6 r208has_auto_pk(T208* C,T0* a1);
/*XPLAIN_EXTENSION*/
T6 r208has_attribute(T208* C,T0* a1,T0* a2);
/*XPLAIN_EXTENSION*/
T0* r208sqltablename(T208* C,T0* a1);
/*XPLAIN_ATTRIBUTE_NAME*/
void r278set_attribute(T278* C,T0* a1);
/*XPLAIN_ATTRIBUTE_NAME*/
T0* r278quoted_name(T278* C,T0* a1);
/*XPLAIN_ATTRIBUTE_NAME*/
T0* r278full_name(T278* C);
/*XPLAIN_ATTRIBUTE_NAME*/
T0* r278sqlcolumnidentifier(T278* C,T0* a1);
/*XPLAIN_ATTRIBUTE_NAME*/
T6 r278is_equal(T278* C,T0* a1);
/*XPLAIN_ATTRIBUTE_NAME*/
T0* r278q_sql_select_name(T278* C,T0* a1);
/*XPLAIN_ATTRIBUTE_NAME*/
T0* r278type(T278* C);
/*XPLAIN_ATTRIBUTE_NAME*/
T0* r278variable(T278* C);
/*XPLAIN_ATTRIBUTE_NAME*/
void r278make_from_attribute(T278* C,T0* a1);
/*XPLAIN_ATTRIBUTE_NAME*/
void r278make(T278* C,T0* a1,T0* a2);
/*XPLAIN_ATTRIBUTE_NAME*/
T0* r278value(T278* C);
/*XPLAIN_ATTRIBUTE_NAME*/
T0* r278abstracttype(T278* C);
/*XPLAIN_ATTRIBUTE_NAME*/
T0* r278abstracttype_if_known(T278* C);
/*KL_STRING_OUTPUT_STREAM*/
void r497put_substring(T497* C,T0* a1,T2 a2,T2 a3);
/*KL_STRING_OUTPUT_STREAM*/
void r497put_character(T497* C,T3 a1);
/*KL_STRING_OUTPUT_STREAM*/
void r497put_string(T497* C,T0* a1);
/*XPLAIN_NIL_FUNCTION*/
T6 r639needs_limit(T0* a1);
/*XPLAIN_NIL_FUNCTION*/
T0* r639sqlfunction(T0* a1);
/*XPLAIN_NIL_FUNCTION*/
T0* r639representation(T0* a1,T0* a2,T0* a3);
/*XPLAIN_NIL_FUNCTION*/
T0* r639sqlextenddefault(T0* a1,T0* a2);
/*XPLAIN_NIL_FUNCTION*/
T0* r639sp_function_type(T0* a1,T0* a2);
/*XPLAIN_D_REPRESENTATION*/
T0* r612min_value(T0* a1);
/*XPLAIN_D_REPRESENTATION*/
T0* r612value_representation(T0* a1);
/*XPLAIN_D_REPRESENTATION*/
void r612set_domain_restriction(T612* C,T0* a1,T0* a2);
/*XPLAIN_D_REPRESENTATION*/
T0* r612xml_schema_data_type(void);
/*XPLAIN_D_REPRESENTATION*/
T0* r612max_value(T0* a1);
/*XPLAIN_D_REPRESENTATION*/
T0* r612datatype(T612* C,T0* a1);
/*XPLAIN_TOTAL_FUNCTION*/
T0* r724sqlfunction(T0* a1);
/*XPLAIN_TOTAL_FUNCTION*/
T0* r724representation(T0* a1,T0* a2,T0* a3);
/*XPLAIN_TOTAL_FUNCTION*/
T0* r724sqlextenddefault(T0* a1,T0* a2);
/*XPLAIN_TOTAL_FUNCTION*/
T0* r724sp_function_type(T0* a1,T0* a2);
/*XPLAIN_B_REPRESENTATION*/
T0* r610min_value(T0* a1);
/*XPLAIN_B_REPRESENTATION*/
T0* r610value_representation(T0* a1);
/*XPLAIN_B_REPRESENTATION*/
void r610set_domain_restriction(T610* C,T0* a1,T0* a2);
/*XPLAIN_B_REPRESENTATION*/
T0* r610xml_schema_data_type(void);
/*XPLAIN_B_REPRESENTATION*/
T0* r610max_value(T0* a1);
/*XPLAIN_B_REPRESENTATION*/
T0* r610datatype(T610* C,T0* a1);
extern T0*oBC360error;
extern int fBC360error;
/*KL_STANDARD_FILES*/
T0* r360error(void);
extern T0*oBC360input;
extern int fBC360input;
/*KL_STANDARD_FILES*/
T0* r360input(void);
extern T0*oBC360output;
extern int fBC360output;
/*KL_STANDARD_FILES*/
T0* r360output(void);
/*XPLAIN_MAX_FUNCTION*/
T0* r722sqlfunction(T0* a1);
/*XPLAIN_MAX_FUNCTION*/
T0* r722representation(T0* a1,T0* a2,T0* a3);
/*XPLAIN_MAX_FUNCTION*/
T0* r722sqlextenddefault(T0* a1,T0* a2);
/*XPLAIN_MAX_FUNCTION*/
T0* r722sp_function_type(T0* a1,T0* a2);
/*XPLAIN_F_REPRESENTATION*/
T0* r834min_value(T0* a1);
/*XPLAIN_F_REPRESENTATION*/
void r834set_domain_restriction(T834* C,T0* a1,T0* a2);
/*XPLAIN_F_REPRESENTATION*/
T0* r834xml_schema_data_type(void);
/*XPLAIN_F_REPRESENTATION*/
T0* r834max_value(T0* a1);
/*XPLAIN_F_REPRESENTATION*/
T0* r834datatype(T834* C,T0* a1);
extern T2 oBC827maximum_character_code;
extern int fBC827maximum_character_code;
/*KL_PLATFORM*/
T2 r827maximum_character_code(T827* C);
extern T2 oBC827minimum_integer;
/*XPLAIN_ANY_FUNCTION*/
T6 r637needs_limit(T0* a1);
/*XPLAIN_ANY_FUNCTION*/
T0* r637sqlfunction(T0* a1);
/*XPLAIN_ANY_FUNCTION*/
T0* r637representation(T0* a1,T0* a2,T0* a3);
/*XPLAIN_ANY_FUNCTION*/
T0* r637sqlextenddefault(T0* a1,T0* a2);
/*XPLAIN_ANY_FUNCTION*/
T0* r637sp_function_type(T0* a1,T0* a2);
/*XPLAIN_COUNT_FUNCTION*/
T0* r725sqlfunction(T0* a1);
/*XPLAIN_COUNT_FUNCTION*/
T0* r725representation(T0* a1,T0* a2,T0* a3);
extern T0*oBC725sqlextenddefault;
/*XPLAIN_COUNT_FUNCTION*/
T0* r725sp_function_type(T0* a1,T0* a2);
/*XPLAIN_LOGINNAME_EXPRESSION*/
T0* r591sqlmaxvalue(T0* a1);
extern T0*oBC591column_name;
/*XPLAIN_LOGINNAME_EXPRESSION*/
T6 r591is_string_expression(void);
/*XPLAIN_LOGINNAME_EXPRESSION*/
T0* r591representation(T0* a1);
/*XPLAIN_LOGINNAME_EXPRESSION*/
T0* r591outer_sqlvalue(T0* a1);
/*XPLAIN_LOGINNAME_EXPRESSION*/
T0* r591sqlvalue_as_wildcard(T0* a1);
/*XPLAIN_LOGINNAME_EXPRESSION*/
T0* r591exact_representation(T0* a1);
/*XPLAIN_LOGINNAME_EXPRESSION*/
T0* r591sqlvalue(T0* a1);
/*XPLAIN_LOGINNAME_EXPRESSION*/
T0* r591sqlinitvalue(T0* a1);
/*XPLAIN_LOGINNAME_EXPRESSION*/
T0* r591sqlminvalue(T0* a1);
/*XPLAIN_MIN_FUNCTION*/
T0* r723sqlfunction(T0* a1);
/*XPLAIN_MIN_FUNCTION*/
T0* r723representation(T0* a1,T0* a2,T0* a3);
/*XPLAIN_MIN_FUNCTION*/
T0* r723sqlextenddefault(T0* a1,T0* a2);
/*XPLAIN_MIN_FUNCTION*/
T0* r723sp_function_type(T0* a1,T0* a2);
/*XPLAIN_T_REPRESENTATION*/
T0* r617min_value(T0* a1);
/*XPLAIN_T_REPRESENTATION*/
T0* r617value_representation(T0* a1);
/*XPLAIN_T_REPRESENTATION*/
void r617set_domain_restriction(T617* C,T0* a1,T0* a2);
/*XPLAIN_T_REPRESENTATION*/
T0* r617xml_schema_data_type(void);
/*XPLAIN_T_REPRESENTATION*/
T0* r617max_value(T0* a1);
/*XPLAIN_T_REPRESENTATION*/
T0* r617datatype(T617* C,T0* a1);
/*UC_UTF8_ROUTINES*/
T2 r580encoded_next_value(T3 a1);
/*UC_UTF8_ROUTINES*/
T2 r580character_byte_count(T3 a1);
extern T0*oBC580dummy_uc_string;
extern int fBC580dummy_uc_string;
/*UC_UTF8_ROUTINES*/
T0* r580dummy_uc_string(void);
/*UC_UTF8_ROUTINES*/
T2 r580encoded_first_value(T3 a1);
/*UC_UTF8_ROUTINES*/
T2 r580code_byte_count(T2 a1);
/*UC_UTF8_ROUTINES*/
T2 r580encoded_byte_count(T3 a1);
/*UC_UTF8_ROUTINES*/
T2 r580substring_byte_count(T0* a1,T2 a2,T2 a3);
/*KL_ANY_ROUTINES*/
T0* r392to_any(T0* a1);
/*KL_ANY_ROUTINES*/
T6 r392equal_objects(T0* a1,T0* a2);
/*KL_ANY_ROUTINES*/
T6 r392same_types(T0* a1,T0* a2);
/*KL_INTEGER_ROUTINES*/
T2 r829power(T2 a1,T2 a2);
/*KL_INTEGER_ROUTINES*/
T6 r829is_even(T2 a1);
/*KL_INTEGER_ROUTINES*/
T2 r829div(T2 a1,T2 a2);
/*KL_INTEGER_ROUTINES*/
T2 r829mod(T2 a1,T2 a2);
/*KL_INTEGER_ROUTINES*/
T3 r829to_character(T2 a1);
/*XPLAIN_SOME_FUNCTION*/
T0* r726sqlfunction(T0* a1);
/*XPLAIN_SOME_FUNCTION*/
T0* r726representation(T0* a1,T0* a2,T0* a3);
/*XPLAIN_SOME_FUNCTION*/
T0* r726sqlextenddefault(T0* a1,T0* a2);
/*XPLAIN_SOME_FUNCTION*/
T0* r726sp_function_type(T0* a1,T0* a2);
/*reference INTEGER*/
T0* r567out(T567* C);
/*reference INTEGER*/
void r567append_in(T567* C,T0* a1);
/*XPLAIN_P_REPRESENTATION*/
T0* r615min_value(T0* a1);
/*XPLAIN_P_REPRESENTATION*/
void r615set_domain_restriction(T615* C,T0* a1,T0* a2);
/*XPLAIN_P_REPRESENTATION*/
T0* r615xml_schema_data_type(void);
/*XPLAIN_P_REPRESENTATION*/
T0* r615max_value(T0* a1);
/*XPLAIN_P_REPRESENTATION*/
T0* r615datatype(T615* C,T0* a1);
/*XPLAIN_M_REPRESENTATION*/
T0* r614min_value(T0* a1);
/*XPLAIN_M_REPRESENTATION*/
T0* r614value_representation(T0* a1);
/*XPLAIN_M_REPRESENTATION*/
void r614set_domain_restriction(T614* C,T0* a1,T0* a2);
/*XPLAIN_M_REPRESENTATION*/
T0* r614xml_schema_data_type(void);
/*XPLAIN_M_REPRESENTATION*/
T0* r614max_value(T0* a1);
/*XPLAIN_M_REPRESENTATION*/
T0* r614datatype(T614* C,T0* a1);
/*XML_GENERATOR*/
void r761set_sp_name(T761* C,T0* a1,T0* a2);
/*XML_GENERATOR*/
T0* r761columndatatype_type(T761* C,T0* a1);
extern T0*oBC761datatype_picture;
extern T0*oBC761datatype_boolean;
extern T0*oBC761datatype_money;
/*XML_GENERATOR*/
void r761write_select_value(T761* C,T0* a1);
/*XML_GENERATOR*/
T6 r761is_base_char(T2 a1);
extern T0*oBC761datatype_datetime;
extern T0*oBC761datatype_varchar;
/*XML_GENERATOR*/
void r761dump_statements(T761* C,T0* a1,T0* a2);
extern T0*oBC761datatype_char;
/*XML_GENERATOR*/
T0* r761datatype_ref_int(T0* a1);
/*XML_GENERATOR*/
T6 r761is_name_first(T2 a1);
/*XML_GENERATOR*/
T0* r761as_ncname(T0* a1);
extern T0*oBC761datatype_pk_int;
/*XML_GENERATOR*/
T6 r761is_letter(T2 a1);
/*XML_GENERATOR*/
T0* r761columndatatype_assertion(T0* a1);
/*XML_GENERATOR*/
T0* r761as_some_string(T0* a1,T3 a2);
extern T0*oBC761datatype_int;
/*XML_GENERATOR*/
void r761set_names(T761* C,T0* a1,T0* a2,T0* a3,T0* a4,T0* a5,T0* a6);
extern T0*oBC761datatype_text;
/*XML_GENERATOR*/
void r761write_select_list(T761* C,T0* a1);
/*XML_GENERATOR*/
T0* r761columndatatype_base(T761* C,T0* a1);
/*XML_GENERATOR*/
void r761dump_columns(T761* C,T0* a1);
/*XML_GENERATOR*/
T0* r761as_eiffel_string(T0* a1);
extern T0*oBC761datatype_numeric;
/*XML_GENERATOR*/
T6 r761is_ideographic(T2 a1);
/*XML_GENERATOR*/
T0* r761as_c_string(T0* a1);
extern T0*oBC761datatype_pk_char;
/*XML_GENERATOR*/
T0* r761code_common_identifier(T0* a1);
/*XML_GENERATOR*/
void r761write_constant(T761* C,T0* a1);
/*XML_GENERATOR*/
void r761write_select_function(T761* C,T0* a1);
/*XML_GENERATOR*/
void r761write_procedure(T761* C,T0* a1);
extern T0*oBC761datatype_float;
/*XML_GENERATOR*/
void r761write_type(T761* C,T0* a1);
/*KL_STRING_EQUALITY_TESTER*/
T6 r436test(T0* a1,T0* a2);
/*KL_STRING_ROUTINES*/
void r380wipe_out(T0* a1);
/*KL_STRING_ROUTINES*/
T0* r380as_string(T0* a1);
/*KL_STRING_ROUTINES*/
T0* r380new_empty_string(T0* a1,T2 a2);
/*KL_STRING_ROUTINES*/
T6 r380same_string(T0* a1,T0* a2);
/*KL_STRING_ROUTINES*/
T0* r380cloned_string(T0* a1);
/*KL_STRING_ROUTINES*/
T6 r380elks_same_string(T0* a1,T0* a2);
extern T0*oBC21arguments;
extern int fBC21arguments;
/*XPLAIN2SQL*/
T0* r12arguments(void);
/*XPLAIN2SQL*/
T6 r12valid_format_and_parameters(T0* a1,T0* a2);
/*XPLAIN2SQL*/
void r12make(T12* C);
/*XPLAIN2SQL*/
T6 r12equal(T0* a1,T0* a2);
/*XPLAIN2SQL*/
T0* r12scientific_formatter(void);
/*XPLAIN2SQL*/
T0* r12formatter(void);
/*KL_DOUBLE_ROUTINES*/
T2 r830truncated_to_integer(T5 a1);
/*KL_DOUBLE_ROUTINES*/
T5 r830log10(T5 a1);
/*KL_DOUBLE_ROUTINES*/
T2 r830rounded_to_integer(T5 a1);
/*KL_DOUBLE_ROUTINES*/
T2 r830floor_to_integer(T5 a1);
/*XPLAIN_SYSTEMDATE_EXPRESSION*/
T0* r590sqlmaxvalue(T0* a1);
extern T0*oBC590column_name;
/*XPLAIN_SYSTEMDATE_EXPRESSION*/
T6 r590is_string_expression(void);
/*XPLAIN_SYSTEMDATE_EXPRESSION*/
T0* r590representation(T0* a1);
/*XPLAIN_SYSTEMDATE_EXPRESSION*/
T0* r590outer_sqlvalue(T0* a1);
/*XPLAIN_SYSTEMDATE_EXPRESSION*/
T0* r590sqlvalue_as_wildcard(T0* a1);
/*XPLAIN_SYSTEMDATE_EXPRESSION*/
T0* r590exact_representation(T0* a1);
/*XPLAIN_SYSTEMDATE_EXPRESSION*/
T0* r590sqlvalue(T0* a1);
/*XPLAIN_SYSTEMDATE_EXPRESSION*/
T0* r590sqlinitvalue(T0* a1);
/*XPLAIN_SYSTEMDATE_EXPRESSION*/
T0* r590sqlminvalue(T0* a1);
extern T12*eiffel_root_object;
extern int se_argc;
extern char**se_argv;
#define SE_MAXID 868
extern T7*g[];
extern T7*t[];
void se_atexit(void);
void initialize_eiffel_runtime(int argc,char*argv[]);
extern T0*ms25_952887;
extern T0*ms7_241908472;
extern T0*ms814_1898286166;
extern T0*ms834_1391;
extern T0*ms25_1293058332;
extern T0*ms615_1441;
extern T0*ms817_7752aa;
extern T0*ms820_1720244181;
extern T0*ms617_1461;
extern T0*ms820_51317690a;
extern T0*ms802_1062203941;
extern T0*ms25_1137a;
extern T0*ms475_2083830567;
extern T0*ms814_437480;
extern T0*ms25_1137aaaa;
extern T0*ms817_7752aaaa;
extern T0*ms814_35200;
extern T0*ms25_2256187a;
extern T0*ms814_4437276a;
extern T0*ms12_39729;
extern T0*ms136_48;
extern T0*ms136_49;
extern T0*ms53_43;
extern T0*ms761_451011;
extern T0*ms33_250860571;
extern T0*ms53_95;
extern T0*ms380_0aaaa;
extern T0*ms814_1140829532;
extern T0*ms54_10;
extern T0*ms858_39219;
extern T0*ms761_1619253645a;
extern T0*ms499_14036;
extern T0*ms761_388645;
extern T0*ms25_16320;
extern T0*ms761_16516aa;
extern T0*ms25_952887a;
extern T0*ms858_3339;
extern T0*ms637_3096;
extern T0*ms814_4437276;
extern T0*ms817_7752aaa;
extern T0*ms817_7752a;
extern T0*ms25_2113798604a;
extern T0*ms136_293459512;
extern T0*ms761_16516aaa;
extern T0*ms53_1371;
extern T0*ms639_3383;
extern T0*ms798_351231;
extern T0*ms820_51317690;
extern T0*ms811_181352aaa;
extern T0*ms761_272092470;
extern T0*ms53_3075;
extern T0*ms811_181352aa;
extern T0*ms499_18036;
extern T0*ms726_17796;
extern T0*ms25_1137aaa;
extern T0*ms25_2256187;
extern T0*ms814_1046125751;
extern T0*ms136_48aa;
extern T0*ms813_216;
extern T0*ms7_280756769;
extern T0*ms811_1364a;
extern T0*ms858_8089;
extern T0*ms811_433569;
extern T0*ms811_1434a;
extern T0*ms812_1740892670;
extern T0*ms380_0aaaaa;
extern T0*ms798_292331;
extern T0*ms25_252aa;
extern T0*ms811_16018;
extern T0*ms25_121924290;
extern T0*ms136_1984144;
extern T0*ms811_15574;
extern T0*ms498_35;
extern T0*ms761_16516;
extern T0*ms723_3360;
extern T0*ms584_1459239347;
extern T0*ms761_17176;
extern T0*ms725_79341;
extern T0*ms811_181352;
extern T0*ms25_24730993;
extern T0*ms25_2195712;
extern T0*ms25_3496a;
extern T0*ms800_371096635;
extern T0*ms816_1763620637a;
extern T0*ms25_492143801;
extern T0*ms814_250456587;
extern T0*ms380_0aaa;
extern T0*ms499_18036aaa;
extern T0*ms761_17176a;
extern T0*ms475_206463207;
extern T0*ms7_1983847;
extern T0*ms811_1364;
extern T0*ms585_61a;
extern T0*ms811_1434;
extern T0*ms820_13816;
extern T0*ms811_374850603;
extern T0*ms25_2113798604;
extern T0*ms820_1047;
extern T0*ms136_48aaa;
extern T0*ms761_16516a;
extern T0*ms25_200;
extern T0*ms25_201;
extern T0*ms815_1786635846;
extern T0*ms25_215;
extern T0*ms25_230;
extern T0*ms25_234;
extern T0*ms25_192;
extern T0*ms25_252;
extern T0*ms811_1419017542;
extern T0*ms816_1763620637;
extern T0*ms25_41a;
extern T0*ms586_362;
extern T0*ms617_1461a;
extern T0*ms817_7752aaaaa;
extern T0*ms802_1245230322;
extern T0*ms612_1381;
extern T0*ms380_0a;
extern T0*ms798_314461;
extern T0*ms614_1426;
extern T0*ms25_1137aa;
extern T0*ms811_16018a;
extern T0*ms811_181352a;
extern T0*ms800_522611813;
extern T0*ms761_1957581;
extern T0*ms136_277376200;
extern T0*ms761_2077861575;
extern T0*ms19_14150;
extern T0*ms820_11286583;
extern T0*ms25_1137;
extern T0*ms858_207414;
extern T0*ms25_200a;
extern T0*ms817_7752;
extern T0*ms814_84720;
extern T0*ms25_215a;
extern T0*ms25_230a;
extern T0*ms25_252aaa;
extern T0*ms25_252a;
extern T0*ms25_2195712a;
extern T0*ms25_3530;
extern T0*ms25_781685270;
extern T0*ms25_3496;
extern T0*ms25_561377415;
extern T0*ms820_1438302609;
extern T0*ms811_53166;
extern T0*ms577_3421;
extern T0*ms585_61;
extern T0*ms25_20320712;
extern T0*ms858_88664;
extern T0*ms814_1409229223;
extern T0*ms25_2111934300;
extern T0*ms816_84200;
extern T0*ms499_59251;
extern T0*ms208_1189421311;
extern T0*ms586_362a;
extern T0*ms814_9958817;
extern T0*ms25_7335;
extern T0*ms807_11026;
extern T0*ms25_952887aa;
extern T0*ms795_537180045;
extern T0*ms795_64;
extern T0*ms761_10867218;
extern T0*ms25_80795;
extern T0*ms25_81352;
extern T0*ms816_88950;
extern T0*ms166_395830;
extern T0*ms136_48aaaa;
extern T0*ms722_3330;
extern T0*ms499_18036a;
extern T0*ms136_48a;
extern T0*ms25_4537323;
extern T0*ms815_1853742980;
extern T0*ms53_669;
extern T0*ms166_395830a;
extern T0*ms380_0aa;
extern T0*ms807_1977920;
extern T0*ms761_1619253645;
extern T0*ms811_2233699;
extern T0*ms25_41;
extern T0*ms25_60;
extern T0*ms25_59;
extern T0*ms761_498291602;
extern T0*ms380_0;
extern T0*ms25_2195712aa;
extern T0*ms858_15469;
extern T0*ms499_79251;
extern T0*ms761_85618278;
extern T0*ms814_1395343340;
extern T0*ms54_10a;
extern T0*ms724_89868;
extern T0*ms25_252aaaa;
extern T0*ms802_395741;
extern T0*ms499_18036aa;
T0*se_ms(int c,char*e);
T0*se_string(char*e);
void se_msi1(void);
void se_msi2(void);
void se_msi3(void);
void se_msi4(void);
void*se_ma838(int argc,...);
void*se_ma841(int argc,...);
void*se_ma466(int argc,...);
void*se_ma764(int argc,...);
T6 X439test(T0*C,T0* a1,T0* a2);
T6 X70uses_parameter(T0*C,T0* a1);
void X70write(T0*C,T0* a1);
void X70cleanup(T0*C);
T0* X797sqlinitvalue_if(T0*C,T0* a1);
T0* X797sql_init_cast_to_real(T0*C,T0* a1);
T0* X797sql_init_cast_to_integer(T0*C,T0* a1);
T0* X797sql_init_infix_expression(T0*C,T0* a1,T0* a2,T0* a3);
T0* X797sql_init_combine_expression(T0*C,T0* a1);
T0* X797sqlinitvalue_attribute(T0*C,T0* a1);
T0* X797sql_init_cast_to_string(T0*C,T0* a1);
T0* X797sql_init_cast_to_date(T0*C,T0* a1);
T6 X172is_existential(T0*C);
T0* X172name(T0*C);
T0* X172sqlfunction(T0*C,T0* a1);
T6 X172needs_limit(T0*C,T0* a1);
T6 X172needs_coalesce(T0*C);
T0* X172representation(T0*C,T0* a1,T0* a2,T0* a3);
T2 X172property_required(T0*C);
T0* X172sqlextenddefault(T0*C,T0* a1,T0* a2);
T6 X172needs_distinct(T0*C);
T0* X172sp_function_type(T0*C,T0* a1,T0* a2);
void X613set_domain_restriction(T0*C,T0* a1,T0* a2);
T0* X835to_sqlcode(T0*C,T0* a1);
T0* X210sqlcolumnrequired(T0*C,T0* a1,T0* a2);
T0* X210columndatatype(T0*C,T0* a1);
T0* X210sqlcolumnidentifier(T0*C,T0* a1,T0* a2);
T0* X210q_sql_select_name(T0*C,T0* a1,T0* a2);
T0* X210sqlcolumndefault(T0*C,T0* a1,T0* a2);
void X210hack_anode(T0*C,T0* a1);
T0* X210sql_select_name(T0*C,T0* a1,T0* a2);
T0* X25value_representation_char(T0*C,T2 a1);
T0* X25value_representation_boolean(T0*C);
T0* X25sql_infix_expression_as_wildcard(T0*C,T0* a1,T0* a2,T0* a3);
T0* X25sqlfunction_nil(T0*C);
T0* X25value_representation_system_user(T0*C);
void X25write_index(T0*C,T0* a1);
T0* X25sqltrue(T0*C);
void X25write_value(T0*C,T0* a1);
void X25write_update(T0*C,T0* a1,T0* a2,T0* a3);
T0* X25sp_define_in_param(T0*C,T0* a1);
T0* X25value_identifier(T0*C,T0* a1);
T0* X25sqlcolumnidentifier_base(T0*C,T0* a1,T0* a2);
T0* X25sqlsysfunction_current_timestamp(T0*C);
void X25write_drop_extension(T0*C,T0* a1);
T0* X25sqlcolumnconstraint_base(T0*C,T0* a1,T0* a2);
T0* X25as_string(T0*C,T0* a1);
void X25write_echo(T0*C,T0* a1);
T0* X25sql_not_expression(T0*C,T0* a1);
T0* X25sp_delete_name(T0*C,T0* a1);
void X25set_primary_key_format(T0*C,T0* a1);
T0* X25sql_select_function_as_subselect(T0*C,T0* a1);
void X25write_base(T0*C,T0* a1);
T0* X25constant_identifier(T0*C,T0* a1);
void X25write_assertion(T0*C,T0* a1);
T0* X25quote_identifier(T0*C,T0* a1);
void X25write_init(T0*C,T0* a1);
void X25write_delete(T0*C,T0* a1,T0* a2);
T0* X25value_representation_money(T0*C);
T0* X25sp_function_type_for_selection(T0*C,T0* a1);
T6 X25createstoredprocedure(T0*C);
T0* X25sqlcheck_in(T0*C,T0* a1,T0* a2);
T6 X25namedparameterssupported(T0*C);
T0* X25sp_function_type_for_selection_list(T0*C,T0* a1);
T0* X25sql_expression_as_boolean_value(T0*C,T0* a1);
void X25write_select_value(T0*C,T0* a1);
T0* X25sqlcolumndefault_base(T0*C,T0* a1);
T0* X25sql_infix_expression(T0*C,T0* a1,T0* a2,T0* a3);
void X25write_constant_assignment(T0*C,T0* a1,T0* a2);
T0* X25create_table_name(T0*C,T0* a1);
T0* X25value_representation_current_timestamp(T0*C);
T0* X25sql_last_auto_generated_primary_key(T0*C,T0* a1);
T0* X25extension_name(T0*C,T0* a1);
void X25set_sequence_name_format(T0*C,T0* a1);
T0* X25sql_combine_expression_as_wildcard(T0*C,T0* a1);
T0* X25assertion_name(T0*C,T0* a1);
T6 X25supportsdomainsinstoredprocedures(T0*C);
T0* X25sp_name(T0*C,T0* a1);
T0* X25sql_notnot_expression(T0*C,T0* a1);
T0* X25sqlgetvalue(T0*C,T0* a1);
void X25drop_constant(T0*C,T0* a1);
T0* X25sqlcolumnconstraint_type(T0*C,T0* a1,T0* a2);
T0* X25sql_cast_to_string(T0*C,T0* a1);
void X25drop_domain(T0*C,T0* a1);
T0* X25sqlfunction_any(T0*C);
void X25write_extend(T0*C,T0* a1);
T6 X25createautoprimarykey(T0*C);
T0* X25target_name(T0*C);
T0* X25value_representation_integer(T0*C,T2 a1);
void X25drop_procedure(T0*C,T0* a1);
T0* X25sql_combine_expression(T0*C,T0* a1);
T0* X25sqlcolumnrequired_base(T0*C,T0* a1);
T0* X25quoted_value_identifier(T0*C,T0* a1);
void X25write_insert(T0*C,T0* a1,T0* a2,T0* a3);
void X25write_drop_column(T0*C,T0* a1,T0* a2);
T0* X25sql_cast_to_date(T0*C,T0* a1);
T0* X25sql_cast_to_integer(T0*C,T0* a1);
T0* X25sql_select_for_extension_expression(T0*C,T0* a1);
T0* X25sqlcolumndefault_type(T0*C,T0* a1);
void X25write_drop(T0*C,T0* a1);
T0* X25value_representation_float(T0*C);
T0* X25sql_extension_function(T0*C,T0* a1);
T0* X25sqlcheck_boolean(T0*C,T0* a1,T0* a2);
T6 X25calculatedcolumnssupported(T0*C);
T0* X25temporarytableprefix(T0*C);
T6 X25storedproceduresupported(T0*C);
T6 X25table_has_auto_pk(T0*C,T0* a1);
T0* X25sql_cast_to_real(T0*C,T0* a1);
T0* X25sp_insert_name(T0*C,T0* a1);
T0* X25sqlfunction_some(T0*C);
void X25drop_table(T0*C,T0* a1);
void X25drop_value(T0*C,T0* a1);
void X25write_select(T0*C,T0* a1);
T6 X25assert_implemented_as_view(T0*C,T0* a1);
T0* X25value_representation_text(T0*C);
T0* X25sp_define_param_name(T0*C,T0* a1);
T0* X25sqlsysfunction_system_user(T0*C);
T0* X25sqlfalse(T0*C);
T0* X25table_name(T0*C,T0* a1);
T0* X25sp_function_type_for_selection_value(T0*C,T0* a1,T0* a2);
T0* X25sqlgetconstant(T0*C,T0* a1);
T0* X25sql_subselect_for_attribute(T0*C,T0* a1);
void X25write_constant(T0*C,T0* a1);
void X25write_procedure(T0*C,T0* a1);
T0* X25sqlcolumnidentifier_type(T0*C,T0* a1,T0* a2);
T0* X25value_representation_date(T0*C);
void X25set_options(T0*C,T6 a1,T6 a2,T6 a3,T6 a4,T6 a5,T6 a6,T6 a7,T6 a8,T6 a9,T6 a10,T6 a11,T6 a12);
void X25write_use_database(T0*C,T0* a1);
T0* X25make_valid_identifier(T0*C,T0* a1);
T0* X25table_pk_name(T0*C,T0* a1);
T0* X25sql_subselect_for_extension(T0*C,T0* a1);
T0* X25sqlcolumnrequired_type(T0*C,T0* a1);
void X25write_type(T0*C,T0* a1);
void X25write_one_line_comment(T0*C,T0* a1);
T0* X25sp_update_name(T0*C,T0* a1);
T6 X25existentialfromneeded(T0*C);
T0* X25sp_use_param(T0*C,T0* a1);
T6 X25check_if_required(T0*C,T0* a1);
T0* X25sql_select_for_extension_function(T0*C,T0* a1,T0* a2);
void X25write_end(T0*C,T0* a1);
T0* X7substring(T0*C,T2 a1,T2 a2);
void X7wipe_out(T0*C);
void X7keep_tail(T0*C,T2 a1);
T2 X7item_code(T0*C,T2 a1);
void X7put(T0*C,T3 a1,T2 a2);
T6 X7is_equal(T0*C,T0* a1);
void X7insert_character(T0*C,T3 a1,T2 a2);
T3 X7item(T0*C,T2 a1);
void X7append(T0*C,T0* a1);
T2 X7index_of(T0*C,T3 a1,T2 a2);
void X7set_count(T0*C,T2 a1);
T6 X7is_integer(T0*C);
void X7remove_tail(T0*C,T2 a1);
void X7append_string(T0*C,T0* a1);
void X7remove(T0*C,T2 a1);
T6 X7is_empty(T0*C);
T0* X7string(T0*C);
void X7extend(T0*C,T3 a1);
void X7insert_string(T0*C,T0* a1,T2 a2);
T2 X7hash_code(T0*C);
T6 X7has(T0*C,T3 a1);
void X7keep_head(T0*C,T2 a1);
T2 X7to_integer(T0*C);
void X7precede(T0*C,T3 a1);
void X7append_character(T0*C,T3 a1);
void X7resize(T0*C,T2 a1);
void X7right_adjust(T0*C);
T8 X7to_external(T0*C);
T6 X7same_string(T0*C,T0* a1);
T0* X7twin(T0*C);
T0* X7_ix_43(T0*C,T0* a1);
void X7swap(T0*C,T2 a1,T2 a2);
void X504cursor_back(T0*C,T0* a1);
T6 X504after(T0*C);
T0* X504item_for_iteration(T0*C);
void X504forth(T0*C);
void X504cursor_finish(T0*C,T0* a1);
void X504start(T0*C);
void X504cursor_forth(T0*C,T0* a1);
void X504put_first(T0*C,T0* a1);
void X504cursor_start(T0*C,T0* a1);
T6 X504cursor_is_first(T0*C,T0* a1);
T0* X17out(T0*C);
T6 X17is_equal(T0*C,T0* a1);
T6 X17same_dynamic_type(T0*C,T0* a1);
void X741set(T0*C,T0* a1,T6 a2,T6 a3);
T6 X741is_first(T0*C);
void X741set_next_cursor(T0*C,T0* a1);
T6 X741after(T0*C);
T6 X741before(T0*C);
T6 X185uses_parameter(T0*C,T0* a1);
void X185write_select(T0*C,T0* a1);
T0* X185sp_function_type(T0*C,T0* a1);
void X19print_on(T0*C,T0* a1);
void X609set_domain_restriction(T0*C,T0* a1,T0* a2);
T0* X328sqldomainconstraint(T0*C,T0* a1,T0* a2);
void X328check_attachment(T0*C,T0* a1,T0* a2);
T0* X328sqlcolumnconstraint(T0*C,T0* a1,T0* a2);
T6 X471valid_parameter(T0*C,T0* a1);
void X471format_to(T0*C,T0* a1,T0* a2);
void X471reset_options(T0*C);
T0* X44name(T0*C);
T2 X44read_to_string(T0*C,T0* a1,T2 a2,T2 a3);
void X44read_character(T0*C);
T2 X44read_to_buffer(T0*C,T0* a1,T2 a2,T2 a3);
T6 X44end_of_input(T0*C);
T3 X44last_character(T0*C);
T6 X249is_assertion(T0*C);
T0* X249full_name(T0*C);
void X249write_drop(T0*C,T0* a1,T0* a2);
T0* X249sql_select_name(T0*C,T0* a1);
T6 X249is_extension(T0*C);
void X196add_to_join(T0*C,T0* a1,T0* a2);
T6 X196uses_parameter(T0*C,T0* a1);
void X196set_extension(T0*C,T0* a1,T0* a2);
T0* X196sqlselect(T0*C,T0* a1,T0* a2);
T0* X196sqlfromaliasname(T0*C);
T0* X196representation(T0*C,T0* a1);
T0* X196outer_sqlvalue(T0*C,T0* a1);
T6 X196is_literal(T0*C);
T0* X196sqlvalue(T0*C,T0* a1);
T6 X196uses_non_data_attributes(T0*C);
void X734cursor_back(T0*C,T0* a1);
T0* X734cursor_item(T0*C,T0* a1);
T6 X734cursor_before(T0*C,T0* a1);
T6 X734cursor_after(T0*C,T0* a1);
void X734cursor_finish(T0*C,T0* a1);
void X734cursor_forth(T0*C,T0* a1);
void X734cursor_start(T0*C,T0* a1);
T0* X262domain(T0*C);
T6 X262is_blob(T0*C,T0* a1);
T0* X262min_value(T0*C,T0* a1);
T0* X262default_value(T0*C);
T0* X262value_representation(T0*C,T0* a1);
void X262set_domain_restriction(T0*C,T0* a1,T0* a2);
T0* X262xml_schema_data_type(T0*C);
T0* X262max_value(T0*C,T0* a1);
T0* X262datatype(T0*C,T0* a1);
T0* X261domain(T0*C);
T6 X261write_with_quotes(T0*C);
T6 X261is_integer(T0*C);
void X261set_domain_restriction(T0*C,T0* a1,T0* a2);
T0* X261pkdatatype(T0*C,T0* a1);
T0* X261max_value(T0*C,T0* a1);
T0* X261xml_schema_data_type(T0*C);
T0* X261datatype(T0*C,T0* a1);
T0* X421item(T0*C);
T6 X421is_first(T0*C);
void X421forth(T0*C);
void X421start(T0*C);
T0* X211create_expression(T0*C,T0* a1);
T6 X211may_be_redefined(T0*C);
void X211write_drop(T0*C,T0* a1);
void X366put_substring(T0*C,T0* a1,T2 a2,T2 a3);
void X366put_character(T0*C,T3 a1);
void X366put_string(T0*C,T0* a1);
T0* X212quoted_name(T0*C,T0* a1);
T0* X212sqlcolumnidentifier(T0*C,T0* a1,T0* a2);
T0* X212sql_qualified_name(T0*C,T0* a1,T0* a2);
T0* X212q_sql_insert_name(T0*C,T0* a1,T0* a2);
T0* X212sql_select_name(T0*C,T0* a1,T0* a2);
void X212hack_anode(T0*C,T0* a1);
T0* X212sqlname(T0*C,T0* a1);
void X739back(T0*C);
T0* X739item(T0*C);
T6 X739after(T0*C);
void X739forth(T0*C);
void X739start(T0*C);
T6 X739before(T0*C);
void X739finish(T0*C);
T0* X500item(T0*C,T2 a1);
T5 X825item(T0*C);
T0* X209quoted_name(T0*C,T0* a1);
T0* X209sqlpkname(T0*C,T0* a1);
T2 X209constraint_number(T0*C);
T0* X209new_data_attributes_cursor(T0*C,T0* a1);
void X209remove_extension(T0*C,T0* a1);
T0* X209columndatatype(T0*C,T0* a1);
T0* X209sqlcolumnidentifier(T0*C,T0* a1,T0* a2);
T0* X209q_sql_select_name(T0*C,T0* a1,T0* a2);
void X209add_extension(T0*C,T0* a1);
void X209write_drop_attribute(T0*C,T0* a1,T0* a2);
T0* X209q_sqlpkname(T0*C,T0* a1);
void X209add_assertion(T0*C,T0* a1);
T0* X209representation(T0*C);
T6 X209has_non_constant_init(T0*C);
T2 X209hash_code(T0*C);
T6 X209has_non_literal_init(T0*C);
T6 X209has_updatable_attributes(T0*C);
T0* X209new_all_attributes_cursor(T0*C,T0* a1);
T0* X209sqlname(T0*C,T0* a1);
T0* X209find_attribute(T0*C,T0* a1);
T0* X209new_init_attributes_cursor(T0*C,T0* a1);
T0* X209attributes(T0*C);
void X209next_constraint_number(T0*C);
T6 X209has_auto_pk(T0*C,T0* a1);
T6 X209has_attribute(T0*C,T0* a1,T0* a2);
T0* X209sqltablename(T0*C,T0* a1);
void X505put_right(T0*C,T0* a1);
T6 X554is_first(T0*C);
T6 X554is_last(T0*C);
T0* X24columndatatype_type(T0*C,T0* a1);
void X24write_value(T0*C,T0* a1);
void X24write_update(T0*C,T0* a1,T0* a2,T0* a3);
T0* X24datatype_picture(T0*C,T0* a1);
T0* X24datatype_boolean(T0*C,T0* a1);
T0* X24datatype_money(T0*C,T0* a1);
void X24write_delete(T0*C,T0* a1,T0* a2);
void X24write_select_value(T0*C,T0* a1);
void X24write_constant_assignment(T0*C,T0* a1,T0* a2);
T0* X24datatype_datetime(T0*C,T0* a1);
T0* X24datatype_varchar(T0*C,T0* a1);
T0* X24datatype_char(T0*C,T0* a1);
T0* X24datatype_ref_int(T0*C,T0* a1);
T0* X24datatype_pk_int(T0*C,T0* a1);
void X24write_extend(T0*C,T0* a1);
T0* X24columndatatype_assertion(T0*C,T0* a1);
void X24write_get_insert(T0*C,T0* a1,T0* a2,T6 a3,T0* a4);
T0* X24datatype_int(T0*C,T0* a1);
void X24write_insert(T0*C,T0* a1,T0* a2,T0* a3);
T0* X24datatype_text(T0*C,T0* a1);
void X24write_select_list(T0*C,T0* a1);
T0* X24columndatatype_base(T0*C,T0* a1);
T0* X24datatype_numeric(T0*C,T0* a1);
void X24write_select(T0*C,T0* a1);
T0* X24datatype_pk_char(T0*C,T0* a1);
void X24write_constant(T0*C,T0* a1);
void X24write_select_function(T0*C,T0* a1);
void X24write_procedure(T0*C,T0* a1);
T0* X24datatype_float(T0*C,T0* a1);
void X24write_sql(T0*C,T0* a1);
void X24write_type(T0*C,T0* a1);
T6 X130is_constant(T0*C);
void X130add_to_join(T0*C,T0* a1,T0* a2);
T6 X130uses_parameter(T0*C,T0* a1);
T0* X130sqlmaxvalue(T0*C,T0* a1);
T0* X130column_name(T0*C);
T6 X130is_specialization(T0*C);
T6 X130is_string_expression(T0*C);
T0* X130representation(T0*C,T0* a1);
T0* X130outer_sqlvalue(T0*C,T0* a1);
T0* X130sqlvalue_as_wildcard(T0*C,T0* a1);
T6 X130is_using_other_attributes(T0*C,T0* a1);
T0* X130exact_representation(T0*C,T0* a1);
T6 X130is_literal(T0*C);
T6 X130can_be_null(T0*C);
T0* X130sqlvalue(T0*C,T0* a1);
T0* X130sqlinitvalue(T0*C,T0* a1);
T6 X130is_logical_constant(T0*C);
T6 X130is_logical_expression(T0*C);
T0* X130sqlname(T0*C,T0* a1);
T0* X130sqlminvalue(T0*C,T0* a1);
T6 X130has_wild_card_characters(T0*C);
T0* T2toT567(T2 source);
T0* T5toT831(T5 source);
T2 T567toT2(T567* source);

#ifdef __cplusplus
}
#endif
